Class: Falcon::ActorECrimeKillChain
- Inherits:
-
Object
- Object
- Falcon::ActorECrimeKillChain
- Defined in:
- lib/crimson-falcon/models/actor_e_crime_kill_chain.rb
Instance Attribute Summary collapse
-
#attribution ⇒ Object
Free form text describing attribution of the ecrime actor.
-
#crimes ⇒ Object
Free form text describing actor’s crimes.
-
#customers ⇒ Object
Free form text describing ecrime actor’s customers and affiliates.
-
#exploitation ⇒ Object
Comma separated values of vulnerabilities by CVE codes that are exploited by actor.
-
#marketing ⇒ Object
Free form text describing ecrime actor’s marketing campaigns and advertisement.
-
#monetization ⇒ Object
Legacy field, not used and empty.
-
#rich_text_attribution ⇒ Object
Rich text version of the attribution field.
-
#rich_text_crimes ⇒ Object
Rich text version of the crimes field.
-
#rich_text_customers ⇒ Object
Rich text version of the customers field.
-
#rich_text_exploitation ⇒ Object
Rich text version of the exploitation field.
-
#rich_text_marketing ⇒ Object
Rich text version of the marketing field.
-
#rich_text_monetization ⇒ Object
Legacy field, not used and empty.
-
#rich_text_services_offered ⇒ Object
Rich text version of the services_offered field.
-
#rich_text_services_used ⇒ Object
Rich text version of the services_used field.
-
#rich_text_technical_tradecraft ⇒ Object
Rich text version of the technical_tradecraft field.
-
#rich_text_victims ⇒ Object
Rich text version of the victims field.
-
#services_offered ⇒ Object
Free form text describing ecrime actor’s services offered and monetized.
-
#services_used ⇒ Object
Free form text describing ecrime actor’s used services provided by other actors or groups.
-
#technical_tradecraft ⇒ Object
Free form text describing methods and descriptions of techniques used by actor.
-
#victims ⇒ Object
Free form text describing victims or their characteristics of the ecrime actor.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ActorECrimeKillChain
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ActorECrimeKillChain
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 159 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ActorECrimeKillChain` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ActorECrimeKillChain`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attribution') self.attribution = attributes[:'attribution'] end if attributes.key?(:'crimes') self.crimes = attributes[:'crimes'] end if attributes.key?(:'customers') self.customers = attributes[:'customers'] end if attributes.key?(:'exploitation') self.exploitation = attributes[:'exploitation'] end if attributes.key?(:'marketing') self.marketing = attributes[:'marketing'] end if attributes.key?(:'monetization') self.monetization = attributes[:'monetization'] end if attributes.key?(:'rich_text_attribution') self.rich_text_attribution = attributes[:'rich_text_attribution'] end if attributes.key?(:'rich_text_crimes') self.rich_text_crimes = attributes[:'rich_text_crimes'] end if attributes.key?(:'rich_text_customers') self.rich_text_customers = attributes[:'rich_text_customers'] end if attributes.key?(:'rich_text_exploitation') self.rich_text_exploitation = attributes[:'rich_text_exploitation'] end if attributes.key?(:'rich_text_marketing') self.rich_text_marketing = attributes[:'rich_text_marketing'] end if attributes.key?(:'rich_text_monetization') self.rich_text_monetization = attributes[:'rich_text_monetization'] end if attributes.key?(:'rich_text_services_offered') self.rich_text_services_offered = attributes[:'rich_text_services_offered'] end if attributes.key?(:'rich_text_services_used') self.rich_text_services_used = attributes[:'rich_text_services_used'] end if attributes.key?(:'rich_text_technical_tradecraft') self.rich_text_technical_tradecraft = attributes[:'rich_text_technical_tradecraft'] end if attributes.key?(:'rich_text_victims') self.rich_text_victims = attributes[:'rich_text_victims'] end if attributes.key?(:'services_offered') self.services_offered = attributes[:'services_offered'] end if attributes.key?(:'services_used') self.services_used = attributes[:'services_used'] end if attributes.key?(:'technical_tradecraft') self.technical_tradecraft = attributes[:'technical_tradecraft'] end if attributes.key?(:'victims') self.victims = attributes[:'victims'] end end |
Instance Attribute Details
#attribution ⇒ Object
Free form text describing attribution of the ecrime actor
35 36 37 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 35 def attribution @attribution end |
#crimes ⇒ Object
Free form text describing actor’s crimes
38 39 40 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 38 def crimes @crimes end |
#customers ⇒ Object
Free form text describing ecrime actor’s customers and affiliates
41 42 43 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 41 def customers @customers end |
#exploitation ⇒ Object
Comma separated values of vulnerabilities by CVE codes that are exploited by actor
44 45 46 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 44 def exploitation @exploitation end |
#marketing ⇒ Object
Free form text describing ecrime actor’s marketing campaigns and advertisement
47 48 49 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 47 def marketing @marketing end |
#monetization ⇒ Object
Legacy field, not used and empty
50 51 52 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 50 def monetization @monetization end |
#rich_text_attribution ⇒ Object
Rich text version of the attribution field
53 54 55 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 53 def rich_text_attribution @rich_text_attribution end |
#rich_text_crimes ⇒ Object
Rich text version of the crimes field
56 57 58 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 56 def rich_text_crimes @rich_text_crimes end |
#rich_text_customers ⇒ Object
Rich text version of the customers field
59 60 61 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 59 def rich_text_customers @rich_text_customers end |
#rich_text_exploitation ⇒ Object
Rich text version of the exploitation field
62 63 64 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 62 def rich_text_exploitation @rich_text_exploitation end |
#rich_text_marketing ⇒ Object
Rich text version of the marketing field
65 66 67 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 65 def rich_text_marketing @rich_text_marketing end |
#rich_text_monetization ⇒ Object
Legacy field, not used and empty
68 69 70 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 68 def rich_text_monetization @rich_text_monetization end |
#rich_text_services_offered ⇒ Object
Rich text version of the services_offered field
71 72 73 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 71 def rich_text_services_offered @rich_text_services_offered end |
#rich_text_services_used ⇒ Object
Rich text version of the services_used field
74 75 76 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 74 def rich_text_services_used @rich_text_services_used end |
#rich_text_technical_tradecraft ⇒ Object
Rich text version of the technical_tradecraft field
77 78 79 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 77 def rich_text_technical_tradecraft @rich_text_technical_tradecraft end |
#rich_text_victims ⇒ Object
Rich text version of the victims field
80 81 82 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 80 def rich_text_victims @rich_text_victims end |
#services_offered ⇒ Object
Free form text describing ecrime actor’s services offered and monetized
83 84 85 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 83 def services_offered @services_offered end |
#services_used ⇒ Object
Free form text describing ecrime actor’s used services provided by other actors or groups
86 87 88 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 86 def services_used @services_used end |
#technical_tradecraft ⇒ Object
Free form text describing methods and descriptions of techniques used by actor
89 90 91 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 89 def technical_tradecraft @technical_tradecraft end |
#victims ⇒ Object
Free form text describing victims or their characteristics of the ecrime actor
92 93 94 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 92 def victims @victims end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
121 122 123 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 121 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 95 def self.attribute_map { :'attribution' => :'attribution', :'crimes' => :'crimes', :'customers' => :'customers', :'exploitation' => :'exploitation', :'marketing' => :'marketing', :'monetization' => :'monetization', :'rich_text_attribution' => :'rich_text_attribution', :'rich_text_crimes' => :'rich_text_crimes', :'rich_text_customers' => :'rich_text_customers', :'rich_text_exploitation' => :'rich_text_exploitation', :'rich_text_marketing' => :'rich_text_marketing', :'rich_text_monetization' => :'rich_text_monetization', :'rich_text_services_offered' => :'rich_text_services_offered', :'rich_text_services_used' => :'rich_text_services_used', :'rich_text_technical_tradecraft' => :'rich_text_technical_tradecraft', :'rich_text_victims' => :'rich_text_victims', :'services_offered' => :'services_offered', :'services_used' => :'services_used', :'technical_tradecraft' => :'technical_tradecraft', :'victims' => :'victims' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 308 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
152 153 154 155 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 152 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 126 def self.openapi_types { :'attribution' => :'String', :'crimes' => :'String', :'customers' => :'String', :'exploitation' => :'String', :'marketing' => :'String', :'monetization' => :'String', :'rich_text_attribution' => :'String', :'rich_text_crimes' => :'String', :'rich_text_customers' => :'String', :'rich_text_exploitation' => :'String', :'rich_text_marketing' => :'String', :'rich_text_monetization' => :'String', :'rich_text_services_offered' => :'String', :'rich_text_services_used' => :'String', :'rich_text_technical_tradecraft' => :'String', :'rich_text_victims' => :'String', :'services_offered' => :'String', :'services_used' => :'String', :'technical_tradecraft' => :'String', :'victims' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 268 def ==(o) return true if self.equal?(o) self.class == o.class && attribution == o.attribution && crimes == o.crimes && customers == o.customers && exploitation == o.exploitation && marketing == o.marketing && monetization == o.monetization && rich_text_attribution == o.rich_text_attribution && rich_text_crimes == o.rich_text_crimes && rich_text_customers == o.rich_text_customers && rich_text_exploitation == o.rich_text_exploitation && rich_text_marketing == o.rich_text_marketing && rich_text_monetization == o.rich_text_monetization && rich_text_services_offered == o.rich_text_services_offered && rich_text_services_used == o.rich_text_services_used && rich_text_technical_tradecraft == o.rich_text_technical_tradecraft && rich_text_victims == o.rich_text_victims && services_offered == o.services_offered && services_used == o.services_used && technical_tradecraft == o.technical_tradecraft && victims == o.victims end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 339 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 410 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 315 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
295 296 297 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 295 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 301 def hash [attribution, crimes, customers, exploitation, marketing, monetization, rich_text_attribution, rich_text_crimes, rich_text_customers, rich_text_exploitation, rich_text_marketing, rich_text_monetization, rich_text_services_offered, rich_text_services_used, rich_text_technical_tradecraft, rich_text_victims, services_offered, services_used, technical_tradecraft, victims].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
255 256 257 258 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 255 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
386 387 388 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 386 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
380 381 382 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 380 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
262 263 264 |
# File 'lib/crimson-falcon/models/actor_e_crime_kill_chain.rb', line 262 def valid? true end |