Class: Falcon::AlertGetAlertsResponse
- Inherits:
-
Object
- Object
- Falcon::AlertGetAlertsResponse
- Defined in:
- lib/crimson-falcon/models/alert_get_alerts_response.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#affected_diff ⇒ Object
Returns the value of attribute affected_diff.
-
#alert_type ⇒ Object
Returns the value of attribute alert_type.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#integration ⇒ Object
Returns the value of attribute integration.
-
#is_archived ⇒ Object
Returns the value of attribute is_archived.
-
#new_affected_count ⇒ Object
Returns the value of attribute new_affected_count.
-
#security_check_api_link ⇒ Object
Returns the value of attribute security_check_api_link.
-
#source ⇒ Object
Returns the value of attribute source.
-
#source_id ⇒ Object
Returns the value of attribute source_id.
-
#threat_api_link ⇒ Object
Returns the value of attribute threat_api_link.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
-
#user_who_archived ⇒ Object
Returns the value of attribute user_who_archived.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlertGetAlertsResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AlertGetAlertsResponse
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::AlertGetAlertsResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::AlertGetAlertsResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'affected_diff') if (value = attributes[:'affected_diff']).is_a?(Array) self.affected_diff = value end end if attributes.key?(:'alert_type') self.alert_type = attributes[:'alert_type'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'integration') if (value = attributes[:'integration']).is_a?(Hash) self.integration = value end end if attributes.key?(:'is_archived') self.is_archived = attributes[:'is_archived'] end if attributes.key?(:'new_affected_count') self.new_affected_count = attributes[:'new_affected_count'] end if attributes.key?(:'security_check_api_link') self.security_check_api_link = attributes[:'security_check_api_link'] end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] end if attributes.key?(:'threat_api_link') self.threat_api_link = attributes[:'threat_api_link'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'user_who_archived') self.user_who_archived = attributes[:'user_who_archived'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
34 35 36 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 34 def account_id @account_id end |
#affected_diff ⇒ Object
Returns the value of attribute affected_diff.
36 37 38 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 36 def affected_diff @affected_diff end |
#alert_type ⇒ Object
Returns the value of attribute alert_type.
38 39 40 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 38 def alert_type @alert_type end |
#description ⇒ Object
Returns the value of attribute description.
40 41 42 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 40 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
42 43 44 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 42 def id @id end |
#integration ⇒ Object
Returns the value of attribute integration.
44 45 46 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 44 def integration @integration end |
#is_archived ⇒ Object
Returns the value of attribute is_archived.
46 47 48 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 46 def is_archived @is_archived end |
#new_affected_count ⇒ Object
Returns the value of attribute new_affected_count.
48 49 50 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 48 def new_affected_count @new_affected_count end |
#security_check_api_link ⇒ Object
Returns the value of attribute security_check_api_link.
50 51 52 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 50 def security_check_api_link @security_check_api_link end |
#source ⇒ Object
Returns the value of attribute source.
52 53 54 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 52 def source @source end |
#source_id ⇒ Object
Returns the value of attribute source_id.
54 55 56 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 54 def source_id @source_id end |
#threat_api_link ⇒ Object
Returns the value of attribute threat_api_link.
56 57 58 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 56 def threat_api_link @threat_api_link end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
58 59 60 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 58 def @timestamp end |
#user_who_archived ⇒ Object
Returns the value of attribute user_who_archived.
60 61 62 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 60 def user_who_archived @user_who_archived end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 83 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 63 def self.attribute_map { :'account_id' => :'account_id', :'affected_diff' => :'affected_diff', :'alert_type' => :'alert_type', :'description' => :'description', :'id' => :'id', :'integration' => :'integration', :'is_archived' => :'is_archived', :'new_affected_count' => :'new_affected_count', :'security_check_api_link' => :'security_check_api_link', :'source' => :'source', :'source_id' => :'source_id', :'threat_api_link' => :'threat_api_link', :'timestamp' => :'timestamp', :'user_who_archived' => :'user_who_archived' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
422 423 424 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 422 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 88 def self.openapi_types { :'account_id' => :'String', :'affected_diff' => :'Array<String>', :'alert_type' => :'String', :'description' => :'String', :'id' => :'String', :'integration' => :'Hash<String, String>', :'is_archived' => :'Boolean', :'new_affected_count' => :'Integer', :'security_check_api_link' => :'String', :'source' => :'String', :'source_id' => :'String', :'threat_api_link' => :'String', :'timestamp' => :'Time', :'user_who_archived' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 388 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && affected_diff == o.affected_diff && alert_type == o.alert_type && description == o.description && id == o.id && integration == o.integration && is_archived == o.is_archived && new_affected_count == o.new_affected_count && security_check_api_link == o.security_check_api_link && source == o.source && source_id == o.source_id && threat_api_link == o.threat_api_link && == o. && user_who_archived == o.user_who_archived end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 453 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 524 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 429 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
409 410 411 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 409 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
415 416 417 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 415 def hash [account_id, affected_diff, alert_type, description, id, integration, is_archived, new_affected_count, security_check_api_link, source, source_id, threat_api_link, , user_who_archived].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 191 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @affected_diff.nil? invalid_properties.push('invalid value for "affected_diff", affected_diff cannot be nil.') end if @alert_type.nil? invalid_properties.push('invalid value for "alert_type", alert_type cannot be nil.') end if @alert_type.to_s.length < 1 invalid_properties.push('invalid value for "alert_type", the character length must be great than or equal to 1.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @integration.nil? invalid_properties.push('invalid value for "integration", integration cannot be nil.') end if @is_archived.nil? invalid_properties.push('invalid value for "is_archived", is_archived cannot be nil.') end if @new_affected_count.nil? invalid_properties.push('invalid value for "new_affected_count", new_affected_count cannot be nil.') end if @security_check_api_link.nil? invalid_properties.push('invalid value for "security_check_api_link", security_check_api_link cannot be nil.') end if @security_check_api_link.to_s.length < 1 invalid_properties.push('invalid value for "security_check_api_link", the character length must be great than or equal to 1.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @source.to_s.length < 1 invalid_properties.push('invalid value for "source", the character length must be great than or equal to 1.') end if @source_id.nil? invalid_properties.push('invalid value for "source_id", source_id cannot be nil.') end if @threat_api_link.nil? invalid_properties.push('invalid value for "threat_api_link", threat_api_link cannot be nil.') end if @threat_api_link.to_s.length < 1 invalid_properties.push('invalid value for "threat_api_link", the character length must be great than or equal to 1.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end if @user_who_archived.nil? invalid_properties.push('invalid value for "user_who_archived", user_who_archived cannot be nil.') end if @user_who_archived.to_s.length < 1 invalid_properties.push('invalid value for "user_who_archived", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
500 501 502 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 500 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 506 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
494 495 496 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 494 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/crimson-falcon/models/alert_get_alerts_response.rb', line 278 def valid? return false if @account_id.nil? return false if @affected_diff.nil? return false if @alert_type.nil? return false if @alert_type.to_s.length < 1 return false if @description.nil? return false if @description.to_s.length < 1 return false if @id.nil? return false if @integration.nil? return false if @is_archived.nil? return false if @new_affected_count.nil? return false if @security_check_api_link.nil? return false if @security_check_api_link.to_s.length < 1 return false if @source.nil? return false if @source.to_s.length < 1 return false if @source_id.nil? return false if @threat_api_link.nil? return false if @threat_api_link.to_s.length < 1 return false if @timestamp.nil? return false if @user_who_archived.nil? return false if @user_who_archived.to_s.length < 1 true end |