Class: Falcon::ApiCertBasedExclusionCreateReqV1
- Inherits:
-
Object
- Object
- Falcon::ApiCertBasedExclusionCreateReqV1
- Defined in:
- lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb
Instance Attribute Summary collapse
-
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
-
#certificate ⇒ Object
Returns the value of attribute certificate.
-
#children_cids ⇒ Object
Returns the value of attribute children_cids.
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#description ⇒ Object
Returns the value of attribute description.
-
#host_groups ⇒ Object
Returns the value of attribute host_groups.
-
#modified_by ⇒ Object
Returns the value of attribute modified_by.
-
#modified_on ⇒ Object
Returns the value of attribute modified_on.
-
#name ⇒ Object
Returns the value of attribute name.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiCertBasedExclusionCreateReqV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApiCertBasedExclusionCreateReqV1
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiCertBasedExclusionCreateReqV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiCertBasedExclusionCreateReqV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'applied_globally') self.applied_globally = attributes[:'applied_globally'] end if attributes.key?(:'certificate') self.certificate = attributes[:'certificate'] end if attributes.key?(:'children_cids') if (value = attributes[:'children_cids']).is_a?(Array) self.children_cids = value end end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'host_groups') if (value = attributes[:'host_groups']).is_a?(Array) self.host_groups = value end end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'modified_on') self.modified_on = attributes[:'modified_on'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
34 35 36 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 34 def applied_globally @applied_globally end |
#certificate ⇒ Object
Returns the value of attribute certificate.
36 37 38 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 36 def certificate @certificate end |
#children_cids ⇒ Object
Returns the value of attribute children_cids.
38 39 40 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 38 def children_cids @children_cids end |
#comment ⇒ Object
Returns the value of attribute comment.
40 41 42 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 40 def comment @comment end |
#created_by ⇒ Object
Returns the value of attribute created_by.
42 43 44 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 42 def created_by @created_by end |
#created_on ⇒ Object
Returns the value of attribute created_on.
44 45 46 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 44 def created_on @created_on end |
#description ⇒ Object
Returns the value of attribute description.
46 47 48 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 46 def description @description end |
#host_groups ⇒ Object
Returns the value of attribute host_groups.
48 49 50 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 48 def host_groups @host_groups end |
#modified_by ⇒ Object
Returns the value of attribute modified_by.
50 51 52 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 50 def modified_by @modified_by end |
#modified_on ⇒ Object
Returns the value of attribute modified_on.
52 53 54 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 52 def modified_on @modified_on end |
#name ⇒ Object
Returns the value of attribute name.
54 55 56 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 54 def name @name end |
#status ⇒ Object
Returns the value of attribute status.
56 57 58 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 56 def status @status end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 59 def self.attribute_map { :'applied_globally' => :'applied_globally', :'certificate' => :'certificate', :'children_cids' => :'children_cids', :'comment' => :'comment', :'created_by' => :'created_by', :'created_on' => :'created_on', :'description' => :'description', :'host_groups' => :'host_groups', :'modified_by' => :'modified_by', :'modified_on' => :'modified_on', :'name' => :'name', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 225 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 82 def self.openapi_types { :'applied_globally' => :'Boolean', :'certificate' => :'ApiCertificateReqV1', :'children_cids' => :'Array<String>', :'comment' => :'String', :'created_by' => :'String', :'created_on' => :'Time', :'description' => :'String', :'host_groups' => :'Array<String>', :'modified_by' => :'String', :'modified_on' => :'Time', :'name' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && applied_globally == o.applied_globally && certificate == o.certificate && children_cids == o.children_cids && comment == o.comment && created_by == o.created_by && created_on == o.created_on && description == o.description && host_groups == o.host_groups && modified_by == o.modified_by && modified_on == o.modified_on && name == o.name && status == o.status end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 256 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 232 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 218 def hash [applied_globally, certificate, children_cids, comment, created_by, created_on, description, host_groups, modified_by, modified_on, name, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 175 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 |
# File 'lib/crimson-falcon/models/api_cert_based_exclusion_create_req_v1.rb', line 186 def valid? return false if @name.nil? true end |