Class: Falcon::ApiContentPatternV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_content_pattern_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiContentPatternV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiContentPatternV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiContentPatternV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'example')
    self.example = attributes[:'example']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'min_match_threshold')
    self.min_match_threshold = attributes[:'min_match_threshold']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'regexes')
    if (value = attributes[:'regexes']).is_a?(Array)
      self.regexes = value
    end
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



34
35
36
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 34

def category
  @category
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 36

def cid
  @cid
end

#createdObject

Returns the value of attribute created.



38
39
40
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 38

def created
  @created
end

#deletedObject

Returns the value of attribute deleted.



40
41
42
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 40

def deleted
  @deleted
end

#descriptionObject

Returns the value of attribute description.



42
43
44
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 42

def description
  @description
end

#exampleObject

Returns the value of attribute example.



44
45
46
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 44

def example
  @example
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 46

def id
  @id
end

#last_updatedObject

Returns the value of attribute last_updated.



48
49
50
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 48

def last_updated
  @last_updated
end

#min_match_thresholdObject

Returns the value of attribute min_match_threshold.



50
51
52
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 50

def min_match_threshold
  @min_match_threshold
end

#nameObject

Returns the value of attribute name.



52
53
54
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 52

def name
  @name
end

#regexesObject

Returns the value of attribute regexes.



54
55
56
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 54

def regexes
  @regexes
end

#regionObject

Returns the value of attribute region.



56
57
58
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 56

def region
  @region
end

#typeObject

Returns the value of attribute type.



58
59
60
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 58

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 61

def self.attribute_map
  {
    :'category' => :'category',
    :'cid' => :'cid',
    :'created' => :'created',
    :'deleted' => :'deleted',
    :'description' => :'description',
    :'example' => :'example',
    :'id' => :'id',
    :'last_updated' => :'last_updated',
    :'min_match_threshold' => :'min_match_threshold',
    :'name' => :'name',
    :'regexes' => :'regexes',
    :'region' => :'region',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 272

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 85

def self.openapi_types
  {
    :'category' => :'String',
    :'cid' => :'String',
    :'created' => :'Time',
    :'deleted' => :'Boolean',
    :'description' => :'String',
    :'example' => :'String',
    :'id' => :'String',
    :'last_updated' => :'Time',
    :'min_match_threshold' => :'Integer',
    :'name' => :'String',
    :'regexes' => :'Array<String>',
    :'region' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      category == o.category &&
      cid == o.cid &&
      created == o.created &&
      deleted == o.deleted &&
      description == o.description &&
      example == o.example &&
      id == o.id &&
      last_updated == o.last_updated &&
      min_match_threshold == o.min_match_threshold &&
      name == o.name &&
      regexes == o.regexes &&
      region == o.region &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 303

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 279

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 265

def hash
  [category, cid, created, deleted, description, example, id, last_updated, min_match_threshold, name, regexes, region, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @deleted.nil?
    invalid_properties.push('invalid value for "deleted", deleted cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @example.nil?
    invalid_properties.push('invalid value for "example", example cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @min_match_threshold.nil?
    invalid_properties.push('invalid value for "min_match_threshold", min_match_threshold cannot be nil.')
  end

  if @regexes.nil?
    invalid_properties.push('invalid value for "regexes", regexes cannot be nil.')
  end

  if @region.nil?
    invalid_properties.push('invalid value for "region", region cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/crimson-falcon/models/api_content_pattern_v1.rb', line 224

def valid?
  return false if @category.nil?
  return false if @deleted.nil?
  return false if @description.nil?
  return false if @example.nil?
  return false if @id.nil?
  return false if @min_match_threshold.nil?
  return false if @regexes.nil?
  return false if @region.nil?
  return false if @type.nil?
  true
end