Class: Falcon::ApiFieldV1
- Inherits:
-
Object
- Object
- Falcon::ApiFieldV1
- Defined in:
- lib/crimson-falcon/models/api_field_v1.rb
Instance Attribute Summary collapse
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_by_name ⇒ Object
Returns the value of attribute created_by_name.
-
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
-
#data_type ⇒ Object
Returns the value of attribute data_type.
-
#default_value ⇒ Object
Returns the value of attribute default_value.
-
#display_order ⇒ Object
Returns the value of attribute display_order.
-
#id ⇒ Object
Returns the value of attribute id.
-
#input_type ⇒ Object
Returns the value of attribute input_type.
-
#multivalued ⇒ Object
Returns the value of attribute multivalued.
-
#name ⇒ Object
Returns the value of attribute name.
-
#options ⇒ Object
Returns the value of attribute options.
-
#required ⇒ Object
Returns the value of attribute required.
-
#updated_by ⇒ Object
Returns the value of attribute updated_by.
-
#updated_by_name ⇒ Object
Returns the value of attribute updated_by_name.
-
#updated_timestamp ⇒ Object
Returns the value of attribute updated_timestamp.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiFieldV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApiFieldV1
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiFieldV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiFieldV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_by_name') self.created_by_name = attributes[:'created_by_name'] end if attributes.key?(:'created_timestamp') self. = attributes[:'created_timestamp'] end if attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] end if attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] end if attributes.key?(:'display_order') self.display_order = attributes[:'display_order'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'input_type') self.input_type = attributes[:'input_type'] end if attributes.key?(:'multivalued') self.multivalued = attributes[:'multivalued'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end end if attributes.key?(:'required') self.required = attributes[:'required'] end if attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] end if attributes.key?(:'updated_by_name') self.updated_by_name = attributes[:'updated_by_name'] end if attributes.key?(:'updated_timestamp') self. = attributes[:'updated_timestamp'] end end |
Instance Attribute Details
#created_by ⇒ Object
Returns the value of attribute created_by.
34 35 36 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 34 def created_by @created_by end |
#created_by_name ⇒ Object
Returns the value of attribute created_by_name.
36 37 38 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 36 def created_by_name @created_by_name end |
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
38 39 40 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 38 def @created_timestamp end |
#data_type ⇒ Object
Returns the value of attribute data_type.
40 41 42 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 40 def data_type @data_type end |
#default_value ⇒ Object
Returns the value of attribute default_value.
42 43 44 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 42 def default_value @default_value end |
#display_order ⇒ Object
Returns the value of attribute display_order.
44 45 46 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 44 def display_order @display_order end |
#id ⇒ Object
Returns the value of attribute id.
46 47 48 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 46 def id @id end |
#input_type ⇒ Object
Returns the value of attribute input_type.
48 49 50 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 48 def input_type @input_type end |
#multivalued ⇒ Object
Returns the value of attribute multivalued.
50 51 52 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 50 def multivalued @multivalued end |
#name ⇒ Object
Returns the value of attribute name.
52 53 54 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 52 def name @name end |
#options ⇒ Object
Returns the value of attribute options.
54 55 56 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 54 def @options end |
#required ⇒ Object
Returns the value of attribute required.
56 57 58 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 56 def required @required end |
#updated_by ⇒ Object
Returns the value of attribute updated_by.
58 59 60 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 58 def updated_by @updated_by end |
#updated_by_name ⇒ Object
Returns the value of attribute updated_by_name.
60 61 62 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 60 def updated_by_name @updated_by_name end |
#updated_timestamp ⇒ Object
Returns the value of attribute updated_timestamp.
62 63 64 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 62 def @updated_timestamp end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 65 def self.attribute_map { :'created_by' => :'created_by', :'created_by_name' => :'created_by_name', :'created_timestamp' => :'created_timestamp', :'data_type' => :'data_type', :'default_value' => :'default_value', :'display_order' => :'display_order', :'id' => :'id', :'input_type' => :'input_type', :'multivalued' => :'multivalued', :'name' => :'name', :'options' => :'options', :'required' => :'required', :'updated_by' => :'updated_by', :'updated_by_name' => :'updated_by_name', :'updated_timestamp' => :'updated_timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 305 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 91 def self.openapi_types { :'created_by' => :'ApiActorV1', :'created_by_name' => :'String', :'created_timestamp' => :'Time', :'data_type' => :'String', :'default_value' => :'String', :'display_order' => :'Integer', :'id' => :'String', :'input_type' => :'String', :'multivalued' => :'Boolean', :'name' => :'String', :'options' => :'Array<ApiFieldOptionV1>', :'required' => :'Boolean', :'updated_by' => :'ApiActorV1', :'updated_by_name' => :'String', :'updated_timestamp' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 270 def ==(o) return true if self.equal?(o) self.class == o.class && created_by == o.created_by && created_by_name == o.created_by_name && == o. && data_type == o.data_type && default_value == o.default_value && display_order == o.display_order && id == o.id && input_type == o.input_type && multivalued == o.multivalued && name == o.name && == o. && required == o.required && updated_by == o.updated_by && updated_by_name == o.updated_by_name && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 336 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 407 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 312 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
292 293 294 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 292 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
298 299 300 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 298 def hash [created_by, created_by_name, , data_type, default_value, display_order, id, input_type, multivalued, name, , required, updated_by, updated_by_name, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 197 def list_invalid_properties invalid_properties = Array.new if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @created_by_name.nil? invalid_properties.push('invalid value for "created_by_name", created_by_name cannot be nil.') end if @created_timestamp.nil? invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.') end if @data_type.nil? invalid_properties.push('invalid value for "data_type", data_type cannot be nil.') end if @display_order.nil? invalid_properties.push('invalid value for "display_order", display_order cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @input_type.nil? invalid_properties.push('invalid value for "input_type", input_type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @required.nil? invalid_properties.push('invalid value for "required", required cannot be nil.') end if @updated_by.nil? invalid_properties.push('invalid value for "updated_by", updated_by cannot be nil.') end if @updated_by_name.nil? invalid_properties.push('invalid value for "updated_by_name", updated_by_name cannot be nil.') end if @updated_timestamp.nil? invalid_properties.push('invalid value for "updated_timestamp", updated_timestamp cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
383 384 385 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 383 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 389 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 377 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/crimson-falcon/models/api_field_v1.rb', line 252 def valid? return false if @created_by.nil? return false if @created_by_name.nil? return false if @created_timestamp.nil? return false if @data_type.nil? return false if @display_order.nil? return false if @id.nil? return false if @input_type.nil? return false if @name.nil? return false if @required.nil? return false if @updated_by.nil? return false if @updated_by_name.nil? return false if @updated_timestamp.nil? true end |