Class: Falcon::ApiFieldV1UpdateRequest
- Inherits:
-
Object
- Object
- Falcon::ApiFieldV1UpdateRequest
- Defined in:
- lib/crimson-falcon/models/api_field_v1_update_request.rb
Instance Attribute Summary collapse
-
#data_type ⇒ Object
Returns the value of attribute data_type.
-
#default_value ⇒ Object
Returns the value of attribute default_value.
-
#display_order ⇒ Object
Returns the value of attribute display_order.
-
#id ⇒ Object
Returns the value of attribute id.
-
#input_type ⇒ Object
Returns the value of attribute input_type.
-
#multivalued ⇒ Object
Returns the value of attribute multivalued.
-
#name ⇒ Object
Returns the value of attribute name.
-
#options ⇒ Object
Returns the value of attribute options.
-
#required ⇒ Object
Returns the value of attribute required.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiFieldV1UpdateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApiFieldV1UpdateRequest
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiFieldV1UpdateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiFieldV1UpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] end if attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] end if attributes.key?(:'display_order') self.display_order = attributes[:'display_order'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'input_type') self.input_type = attributes[:'input_type'] end if attributes.key?(:'multivalued') self.multivalued = attributes[:'multivalued'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end end if attributes.key?(:'required') self.required = attributes[:'required'] end end |
Instance Attribute Details
#data_type ⇒ Object
Returns the value of attribute data_type.
34 35 36 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 34 def data_type @data_type end |
#default_value ⇒ Object
Returns the value of attribute default_value.
36 37 38 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 36 def default_value @default_value end |
#display_order ⇒ Object
Returns the value of attribute display_order.
38 39 40 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 38 def display_order @display_order end |
#id ⇒ Object
Returns the value of attribute id.
40 41 42 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 40 def id @id end |
#input_type ⇒ Object
Returns the value of attribute input_type.
42 43 44 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 42 def input_type @input_type end |
#multivalued ⇒ Object
Returns the value of attribute multivalued.
44 45 46 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 44 def multivalued @multivalued end |
#name ⇒ Object
Returns the value of attribute name.
46 47 48 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 46 def name @name end |
#options ⇒ Object
Returns the value of attribute options.
48 49 50 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 48 def @options end |
#required ⇒ Object
Returns the value of attribute required.
50 51 52 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 50 def required @required end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 53 def self.attribute_map { :'data_type' => :'data_type', :'default_value' => :'default_value', :'display_order' => :'display_order', :'id' => :'id', :'input_type' => :'input_type', :'multivalued' => :'multivalued', :'name' => :'name', :'options' => :'options', :'required' => :'required' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 221 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 73 def self.openapi_types { :'data_type' => :'String', :'default_value' => :'String', :'display_order' => :'Integer', :'id' => :'String', :'input_type' => :'String', :'multivalued' => :'Boolean', :'name' => :'String', :'options' => :'Array<ApiFieldV1UpdateRequestOptions>', :'required' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 192 def ==(o) return true if self.equal?(o) self.class == o.class && data_type == o.data_type && default_value == o.default_value && display_order == o.display_order && id == o.id && input_type == o.input_type && multivalued == o.multivalued && name == o.name && == o. && required == o.required end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 252 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 214 def hash [data_type, default_value, display_order, id, input_type, multivalued, name, , required].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 149 def list_invalid_properties invalid_properties = Array.new if @data_type.nil? invalid_properties.push('invalid value for "data_type", data_type cannot be nil.') end if @display_order.nil? invalid_properties.push('invalid value for "display_order", display_order cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @input_type.nil? invalid_properties.push('invalid value for "input_type", input_type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @required.nil? invalid_properties.push('invalid value for "required", required cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
299 300 301 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 299 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 293 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 |
# File 'lib/crimson-falcon/models/api_field_v1_update_request.rb', line 180 def valid? return false if @data_type.nil? return false if @display_order.nil? return false if @id.nil? return false if @input_type.nil? return false if @name.nil? return false if @required.nil? true end |