Class: Falcon::ApiHostMigration

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_host_migration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiHostMigration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiHostMigration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiHostMigration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.key?(:'host_migration_id')
    self.host_migration_id = attributes[:'host_migration_id']
  end

  if attributes.key?(:'hostgroups')
    if (value = attributes[:'hostgroups']).is_a?(Array)
      self.hostgroups = value
    end
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'migration_id')
    self.migration_id = attributes[:'migration_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'source_cid')
    self.source_cid = attributes[:'source_cid']
  end

  if attributes.key?(:'source_device_id')
    self.source_device_id = attributes[:'source_device_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_details')
    self.status_details = attributes[:'status_details']
  end

  if attributes.key?(:'target_cid')
    self.target_cid = attributes[:'target_cid']
  end

  if attributes.key?(:'target_device_id')
    self.target_device_id = attributes[:'target_device_id']
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end
end

Instance Attribute Details

#created_timeObject

Returns the value of attribute created_time.



34
35
36
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 34

def created_time
  @created_time
end

#eventsObject

Returns the value of attribute events.



36
37
38
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 36

def events
  @events
end

#host_migration_idObject

Returns the value of attribute host_migration_id.



38
39
40
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 38

def host_migration_id
  @host_migration_id
end

#hostgroupsObject

assigned static hostgroups, may need more details here



41
42
43
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 41

def hostgroups
  @hostgroups
end

#hostnameObject

hostname at the time of migration



44
45
46
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 44

def hostname
  @hostname
end

#migration_idObject

Returns the value of attribute migration_id.



46
47
48
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 46

def migration_id
  @migration_id
end

#platformObject

platform at the time of migration



49
50
51
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 49

def platform
  @platform
end

#source_cidObject

Returns the value of attribute source_cid.



51
52
53
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 51

def source_cid
  @source_cid
end

#source_device_idObject

device_id in the source cid



54
55
56
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 54

def source_device_id
  @source_device_id
end

#statusObject

Returns the value of attribute status.



56
57
58
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 56

def status
  @status
end

#status_detailsObject

Returns the value of attribute status_details.



58
59
60
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 58

def status_details
  @status_details
end

#target_cidObject

not sure if this is necessary since it’s common



61
62
63
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 61

def target_cid
  @target_cid
end

#target_device_idObject

device_id in the target cid. This may change while the migration is incomplete.



64
65
66
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 64

def target_device_id
  @target_device_id
end

#updated_timeObject

Returns the value of attribute updated_time.



66
67
68
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 66

def updated_time
  @updated_time
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 69

def self.attribute_map
  {
    :'created_time' => :'created_time',
    :'events' => :'events',
    :'host_migration_id' => :'host_migration_id',
    :'hostgroups' => :'hostgroups',
    :'hostname' => :'hostname',
    :'migration_id' => :'migration_id',
    :'platform' => :'platform',
    :'source_cid' => :'source_cid',
    :'source_device_id' => :'source_device_id',
    :'status' => :'status',
    :'status_details' => :'status_details',
    :'target_cid' => :'target_cid',
    :'target_device_id' => :'target_device_id',
    :'updated_time' => :'updated_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 309

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 94

def self.openapi_types
  {
    :'created_time' => :'Time',
    :'events' => :'Array<ApiEvent>',
    :'host_migration_id' => :'String',
    :'hostgroups' => :'Array<String>',
    :'hostname' => :'String',
    :'migration_id' => :'String',
    :'platform' => :'String',
    :'source_cid' => :'String',
    :'source_device_id' => :'String',
    :'status' => :'String',
    :'status_details' => :'String',
    :'target_cid' => :'String',
    :'target_device_id' => :'String',
    :'updated_time' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 275

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_time == o.created_time &&
      events == o.events &&
      host_migration_id == o.host_migration_id &&
      hostgroups == o.hostgroups &&
      hostname == o.hostname &&
      migration_id == o.migration_id &&
      platform == o.platform &&
      source_cid == o.source_cid &&
      source_device_id == o.source_device_id &&
      status == o.status &&
      status_details == o.status_details &&
      target_cid == o.target_cid &&
      target_device_id == o.target_device_id &&
      updated_time == o.updated_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 340

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 411

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 316

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 302

def hash
  [created_time, events, host_migration_id, hostgroups, hostname, migration_id, platform, source_cid, source_device_id, status, status_details, target_cid, target_device_id, updated_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 197

def list_invalid_properties
  invalid_properties = Array.new
  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @host_migration_id.nil?
    invalid_properties.push('invalid value for "host_migration_id", host_migration_id cannot be nil.')
  end

  if @hostgroups.nil?
    invalid_properties.push('invalid value for "hostgroups", hostgroups cannot be nil.')
  end

  if @hostname.nil?
    invalid_properties.push('invalid value for "hostname", hostname cannot be nil.')
  end

  if @migration_id.nil?
    invalid_properties.push('invalid value for "migration_id", migration_id cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @source_cid.nil?
    invalid_properties.push('invalid value for "source_cid", source_cid cannot be nil.')
  end

  if @source_device_id.nil?
    invalid_properties.push('invalid value for "source_device_id", source_device_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @status_details.nil?
    invalid_properties.push('invalid value for "status_details", status_details cannot be nil.')
  end

  if @target_cid.nil?
    invalid_properties.push('invalid value for "target_cid", target_cid cannot be nil.')
  end

  if @target_device_id.nil?
    invalid_properties.push('invalid value for "target_device_id", target_device_id cannot be nil.')
  end

  if @updated_time.nil?
    invalid_properties.push('invalid value for "updated_time", updated_time cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 387

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



381
382
383
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 381

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/crimson-falcon/models/api_host_migration.rb', line 256

def valid?
  return false if @created_time.nil?
  return false if @host_migration_id.nil?
  return false if @hostgroups.nil?
  return false if @hostname.nil?
  return false if @migration_id.nil?
  return false if @platform.nil?
  return false if @source_cid.nil?
  return false if @source_device_id.nil?
  return false if @status.nil?
  return false if @status_details.nil?
  return false if @target_cid.nil?
  return false if @target_device_id.nil?
  return false if @updated_time.nil?
  true
end