Class: Falcon::ApiIndicatorV1
- Inherits:
-
Object
- Object
- Falcon::ApiIndicatorV1
- Defined in:
- lib/crimson-falcon/models/api_indicator_v1.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#description ⇒ Object
Returns the value of attribute description.
-
#expiration ⇒ Object
Returns the value of attribute expiration.
-
#expired ⇒ Object
Returns the value of attribute expired.
-
#from_parent ⇒ Object
Returns the value of attribute from_parent.
-
#host_groups ⇒ Object
Returns the value of attribute host_groups.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#mobile_action ⇒ Object
Returns the value of attribute mobile_action.
-
#modified_by ⇒ Object
Returns the value of attribute modified_by.
-
#modified_on ⇒ Object
Returns the value of attribute modified_on.
-
#parent_cid_name ⇒ Object
Returns the value of attribute parent_cid_name.
-
#platforms ⇒ Object
Returns the value of attribute platforms.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#source ⇒ Object
Returns the value of attribute source.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#type ⇒ Object
Returns the value of attribute type.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiIndicatorV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApiIndicatorV1
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 147 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiIndicatorV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiIndicatorV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'applied_globally') self.applied_globally = attributes[:'applied_globally'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] end if attributes.key?(:'expired') self.expired = attributes[:'expired'] end if attributes.key?(:'from_parent') self.from_parent = attributes[:'from_parent'] end if attributes.key?(:'host_groups') if (value = attributes[:'host_groups']).is_a?(Array) self.host_groups = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'mobile_action') self.mobile_action = attributes[:'mobile_action'] end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'modified_on') self.modified_on = attributes[:'modified_on'] end if attributes.key?(:'parent_cid_name') self.parent_cid_name = attributes[:'parent_cid_name'] end if attributes.key?(:'platforms') if (value = attributes[:'platforms']).is_a?(Array) self.platforms = value end end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
34 35 36 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 34 def action @action end |
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
36 37 38 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 36 def applied_globally @applied_globally end |
#created_by ⇒ Object
Returns the value of attribute created_by.
38 39 40 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 38 def created_by @created_by end |
#created_on ⇒ Object
Returns the value of attribute created_on.
40 41 42 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 40 def created_on @created_on end |
#deleted ⇒ Object
Returns the value of attribute deleted.
42 43 44 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 42 def deleted @deleted end |
#description ⇒ Object
Returns the value of attribute description.
44 45 46 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 44 def description @description end |
#expiration ⇒ Object
Returns the value of attribute expiration.
46 47 48 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 46 def expiration @expiration end |
#expired ⇒ Object
Returns the value of attribute expired.
48 49 50 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 48 def expired @expired end |
#from_parent ⇒ Object
Returns the value of attribute from_parent.
50 51 52 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 50 def from_parent @from_parent end |
#host_groups ⇒ Object
Returns the value of attribute host_groups.
52 53 54 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 52 def host_groups @host_groups end |
#id ⇒ Object
Returns the value of attribute id.
54 55 56 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 54 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
56 57 58 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 56 def @metadata end |
#mobile_action ⇒ Object
Returns the value of attribute mobile_action.
58 59 60 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 58 def mobile_action @mobile_action end |
#modified_by ⇒ Object
Returns the value of attribute modified_by.
60 61 62 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 60 def modified_by @modified_by end |
#modified_on ⇒ Object
Returns the value of attribute modified_on.
62 63 64 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 62 def modified_on @modified_on end |
#parent_cid_name ⇒ Object
Returns the value of attribute parent_cid_name.
64 65 66 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 64 def parent_cid_name @parent_cid_name end |
#platforms ⇒ Object
Returns the value of attribute platforms.
66 67 68 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 66 def platforms @platforms end |
#severity ⇒ Object
Returns the value of attribute severity.
68 69 70 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 68 def severity @severity end |
#source ⇒ Object
Returns the value of attribute source.
70 71 72 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 70 def source @source end |
#tags ⇒ Object
Returns the value of attribute tags.
72 73 74 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 72 def @tags end |
#type ⇒ Object
Returns the value of attribute type.
74 75 76 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 74 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
76 77 78 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 76 def value @value end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
107 108 109 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 107 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 79 def self.attribute_map { :'action' => :'action', :'applied_globally' => :'applied_globally', :'created_by' => :'created_by', :'created_on' => :'created_on', :'deleted' => :'deleted', :'description' => :'description', :'expiration' => :'expiration', :'expired' => :'expired', :'from_parent' => :'from_parent', :'host_groups' => :'host_groups', :'id' => :'id', :'metadata' => :'metadata', :'mobile_action' => :'mobile_action', :'modified_by' => :'modified_by', :'modified_on' => :'modified_on', :'parent_cid_name' => :'parent_cid_name', :'platforms' => :'platforms', :'severity' => :'severity', :'source' => :'source', :'tags' => :'tags', :'type' => :'type', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 312 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
140 141 142 143 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 140 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 112 def self.openapi_types { :'action' => :'String', :'applied_globally' => :'Boolean', :'created_by' => :'String', :'created_on' => :'Time', :'deleted' => :'Boolean', :'description' => :'String', :'expiration' => :'Time', :'expired' => :'Boolean', :'from_parent' => :'Boolean', :'host_groups' => :'Array<String>', :'id' => :'String', :'metadata' => :'ApiMetadataV1', :'mobile_action' => :'String', :'modified_by' => :'String', :'modified_on' => :'Time', :'parent_cid_name' => :'String', :'platforms' => :'Array<String>', :'severity' => :'String', :'source' => :'String', :'tags' => :'Array<String>', :'type' => :'String', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 270 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && applied_globally == o.applied_globally && created_by == o.created_by && created_on == o.created_on && deleted == o.deleted && description == o.description && expiration == o.expiration && expired == o.expired && from_parent == o.from_parent && host_groups == o.host_groups && id == o.id && == o. && mobile_action == o.mobile_action && modified_by == o.modified_by && modified_on == o.modified_on && parent_cid_name == o.parent_cid_name && platforms == o.platforms && severity == o.severity && source == o.source && == o. && type == o.type && value == o.value end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 343 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 414 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 319 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
299 300 301 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 299 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
305 306 307 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 305 def hash [action, applied_globally, created_by, created_on, deleted, description, expiration, expired, from_parent, host_groups, id, , mobile_action, modified_by, modified_on, parent_cid_name, platforms, severity, source, , type, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
257 258 259 260 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 257 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
390 391 392 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 390 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 396 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 384 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 |
# File 'lib/crimson-falcon/models/api_indicator_v1.rb', line 264 def valid? true end |