Class: Falcon::ApiParser

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_parser.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiParser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/models/api_parser.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiParser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiParser`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'fields_to_be_removed_before_parsing')
    if (value = attributes[:'fields_to_be_removed_before_parsing']).is_a?(Array)
      self.fields_to_be_removed_before_parsing = value
    end
  end

  if attributes.key?(:'fields_to_tag')
    if (value = attributes[:'fields_to_tag']).is_a?(Array)
      self.fields_to_tag = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_built_in')
    self.is_built_in = attributes[:'is_built_in']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'package_id')
    self.package_id = attributes[:'package_id']
  end

  if attributes.key?(:'script')
    self.script = attributes[:'script']
  end

  if attributes.key?(:'test_cases')
    if (value = attributes[:'test_cases']).is_a?(Array)
      self.test_cases = value
    end
  end
end

Instance Attribute Details

#descriptionObject

A description of what the parser does, how it works, notes or similar



35
36
37
# File 'lib/crimson-falcon/models/api_parser.rb', line 35

def description
  @description
end

#display_nameObject

The human-readable name shown in the UI



38
39
40
# File 'lib/crimson-falcon/models/api_parser.rb', line 38

def display_name
  @display_name
end

#fields_to_be_removed_before_parsingObject

A list of fields that will be removed from the event before it’s parsed. These fields will not be included when calculating usage



41
42
43
# File 'lib/crimson-falcon/models/api_parser.rb', line 41

def fields_to_be_removed_before_parsing
  @fields_to_be_removed_before_parsing
end

#fields_to_tagObject

A list of fields that should be used for sharding. See library.humio.com/stable/docs/parsers/tagging/



44
45
46
# File 'lib/crimson-falcon/models/api_parser.rb', line 44

def fields_to_tag
  @fields_to_tag
end

#idObject

The unique identifier of the parser



47
48
49
# File 'lib/crimson-falcon/models/api_parser.rb', line 47

def id
  @id
end

#is_built_inObject

Indicates whether this is a system-provided parser



50
51
52
# File 'lib/crimson-falcon/models/api_parser.rb', line 50

def is_built_in
  @is_built_in
end

#nameObject

The name of parser template



53
54
55
# File 'lib/crimson-falcon/models/api_parser.rb', line 53

def name
  @name
end

#package_idObject

Identifies the package this parser belongs to, if any



56
57
58
# File 'lib/crimson-falcon/models/api_parser.rb', line 56

def package_id
  @package_id
end

#scriptObject

The parser script that transforms the input into events. Humio Language v1



59
60
61
# File 'lib/crimson-falcon/models/api_parser.rb', line 59

def script
  @script
end

#test_casesObject

A list of tests that the parser can be tested against



62
63
64
# File 'lib/crimson-falcon/models/api_parser.rb', line 62

def test_cases
  @test_cases
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/api_parser.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/api_parser.rb', line 65

def self.attribute_map
  {
    :'description' => :'description',
    :'display_name' => :'display_name',
    :'fields_to_be_removed_before_parsing' => :'fields_to_be_removed_before_parsing',
    :'fields_to_tag' => :'fields_to_tag',
    :'id' => :'id',
    :'is_built_in' => :'is_built_in',
    :'name' => :'name',
    :'package_id' => :'package_id',
    :'script' => :'script',
    :'test_cases' => :'test_cases'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
# File 'lib/crimson-falcon/models/api_parser.rb', line 249

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/api_parser.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/api_parser.rb', line 86

def self.openapi_types
  {
    :'description' => :'String',
    :'display_name' => :'String',
    :'fields_to_be_removed_before_parsing' => :'Array<String>',
    :'fields_to_tag' => :'Array<String>',
    :'id' => :'String',
    :'is_built_in' => :'Boolean',
    :'name' => :'String',
    :'package_id' => :'String',
    :'script' => :'String',
    :'test_cases' => :'Array<ApiParserTestCase>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/crimson-falcon/models/api_parser.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      display_name == o.display_name &&
      fields_to_be_removed_before_parsing == o.fields_to_be_removed_before_parsing &&
      fields_to_tag == o.fields_to_tag &&
      id == o.id &&
      is_built_in == o.is_built_in &&
      name == o.name &&
      package_id == o.package_id &&
      script == o.script &&
      test_cases == o.test_cases
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/api_parser.rb', line 280

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/crimson-falcon/models/api_parser.rb', line 351

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/crimson-falcon/models/api_parser.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/crimson-falcon/models/api_parser.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/crimson-falcon/models/api_parser.rb', line 242

def hash
  [description, display_name, fields_to_be_removed_before_parsing, fields_to_tag, id, is_built_in, name, package_id, script, test_cases].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/crimson-falcon/models/api_parser.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  if @display_name.nil?
    invalid_properties.push('invalid value for "display_name", display_name cannot be nil.')
  end

  if @fields_to_be_removed_before_parsing.nil?
    invalid_properties.push('invalid value for "fields_to_be_removed_before_parsing", fields_to_be_removed_before_parsing cannot be nil.')
  end

  if @fields_to_tag.nil?
    invalid_properties.push('invalid value for "fields_to_tag", fields_to_tag cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @is_built_in.nil?
    invalid_properties.push('invalid value for "is_built_in", is_built_in cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @script.nil?
    invalid_properties.push('invalid value for "script", script cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
# File 'lib/crimson-falcon/models/api_parser.rb', line 327

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/crimson-falcon/models/api_parser.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



321
322
323
# File 'lib/crimson-falcon/models/api_parser.rb', line 321

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
# File 'lib/crimson-falcon/models/api_parser.rb', line 206

def valid?
  return false if @display_name.nil?
  return false if @fields_to_be_removed_before_parsing.nil?
  return false if @fields_to_tag.nil?
  return false if @id.nil?
  return false if @is_built_in.nil?
  return false if @name.nil?
  return false if @script.nil?
  true
end