Class: Falcon::ApiRuleV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_rule_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiRuleV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiRuleV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiRuleV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action_label')
    self.action_label = attributes[:'action_label']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'committed_on')
    self.committed_on = attributes[:'committed_on']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'disposition_id')
    self.disposition_id = attributes[:'disposition_id']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'field_values')
    if (value = attributes[:'field_values']).is_a?(Array)
      self.field_values = value
    end
  end

  if attributes.key?(:'instance_id')
    self.instance_id = attributes[:'instance_id']
  end

  if attributes.key?(:'instance_version')
    self.instance_version = attributes[:'instance_version']
  end

  if attributes.key?(:'magic_cookie')
    self.magic_cookie = attributes[:'magic_cookie']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'modified_on')
    self.modified_on = attributes[:'modified_on']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'pattern_id')
    self.pattern_id = attributes[:'pattern_id']
  end

  if attributes.key?(:'pattern_severity')
    self.pattern_severity = attributes[:'pattern_severity']
  end

  if attributes.key?(:'rulegroup_id')
    self.rulegroup_id = attributes[:'rulegroup_id']
  end

  if attributes.key?(:'ruletype_id')
    self.ruletype_id = attributes[:'ruletype_id']
  end

  if attributes.key?(:'ruletype_name')
    self.ruletype_name = attributes[:'ruletype_name']
  end

  if attributes.key?(:'version_ids')
    if (value = attributes[:'version_ids']).is_a?(Array)
      self.version_ids = value
    end
  end
end

Instance Attribute Details

#action_labelObject

Returns the value of attribute action_label.



34
35
36
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 34

def action_label
  @action_label
end

#commentObject

Returns the value of attribute comment.



36
37
38
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 36

def comment
  @comment
end

#committed_onObject

Returns the value of attribute committed_on.



38
39
40
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 38

def committed_on
  @committed_on
end

#created_byObject

Returns the value of attribute created_by.



40
41
42
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 40

def created_by
  @created_by
end

#created_onObject

Returns the value of attribute created_on.



42
43
44
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 42

def created_on
  @created_on
end

#customer_idObject

Returns the value of attribute customer_id.



44
45
46
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 44

def customer_id
  @customer_id
end

#deletedObject

Returns the value of attribute deleted.



46
47
48
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 46

def deleted
  @deleted
end

#descriptionObject

Returns the value of attribute description.



48
49
50
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 48

def description
  @description
end

#disposition_idObject

Returns the value of attribute disposition_id.



50
51
52
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 50

def disposition_id
  @disposition_id
end

#enabledObject

Returns the value of attribute enabled.



52
53
54
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 52

def enabled
  @enabled
end

#field_valuesObject

Returns the value of attribute field_values.



54
55
56
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 54

def field_values
  @field_values
end

#instance_idObject

Returns the value of attribute instance_id.



56
57
58
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 56

def instance_id
  @instance_id
end

#instance_versionObject

Returns the value of attribute instance_version.



58
59
60
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 58

def instance_version
  @instance_version
end

Returns the value of attribute magic_cookie.



60
61
62
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 60

def magic_cookie
  @magic_cookie
end

#modified_byObject

Returns the value of attribute modified_by.



62
63
64
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 62

def modified_by
  @modified_by
end

#modified_onObject

Returns the value of attribute modified_on.



64
65
66
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 64

def modified_on
  @modified_on
end

#nameObject

Returns the value of attribute name.



66
67
68
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 66

def name
  @name
end

#pattern_idObject

Returns the value of attribute pattern_id.



68
69
70
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 68

def pattern_id
  @pattern_id
end

#pattern_severityObject

Returns the value of attribute pattern_severity.



70
71
72
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 70

def pattern_severity
  @pattern_severity
end

#rulegroup_idObject

Returns the value of attribute rulegroup_id.



72
73
74
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 72

def rulegroup_id
  @rulegroup_id
end

#ruletype_idObject

Returns the value of attribute ruletype_id.



74
75
76
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 74

def ruletype_id
  @ruletype_id
end

#ruletype_nameObject

Returns the value of attribute ruletype_name.



76
77
78
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 76

def ruletype_name
  @ruletype_name
end

#version_idsObject

Returns the value of attribute version_ids.



78
79
80
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 78

def version_ids
  @version_ids
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 81

def self.attribute_map
  {
    :'action_label' => :'action_label',
    :'comment' => :'comment',
    :'committed_on' => :'committed_on',
    :'created_by' => :'created_by',
    :'created_on' => :'created_on',
    :'customer_id' => :'customer_id',
    :'deleted' => :'deleted',
    :'description' => :'description',
    :'disposition_id' => :'disposition_id',
    :'enabled' => :'enabled',
    :'field_values' => :'field_values',
    :'instance_id' => :'instance_id',
    :'instance_version' => :'instance_version',
    :'magic_cookie' => :'magic_cookie',
    :'modified_by' => :'modified_by',
    :'modified_on' => :'modified_on',
    :'name' => :'name',
    :'pattern_id' => :'pattern_id',
    :'pattern_severity' => :'pattern_severity',
    :'rulegroup_id' => :'rulegroup_id',
    :'ruletype_id' => :'ruletype_id',
    :'ruletype_name' => :'ruletype_name',
    :'version_ids' => :'version_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



434
435
436
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 434

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



144
145
146
147
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 144

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 115

def self.openapi_types
  {
    :'action_label' => :'String',
    :'comment' => :'String',
    :'committed_on' => :'Time',
    :'created_by' => :'String',
    :'created_on' => :'Time',
    :'customer_id' => :'String',
    :'deleted' => :'Boolean',
    :'description' => :'String',
    :'disposition_id' => :'Integer',
    :'enabled' => :'Boolean',
    :'field_values' => :'Array<DomainFieldValue>',
    :'instance_id' => :'String',
    :'instance_version' => :'Integer',
    :'magic_cookie' => :'Integer',
    :'modified_by' => :'String',
    :'modified_on' => :'Time',
    :'name' => :'String',
    :'pattern_id' => :'String',
    :'pattern_severity' => :'String',
    :'rulegroup_id' => :'String',
    :'ruletype_id' => :'String',
    :'ruletype_name' => :'String',
    :'version_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 391

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action_label == o.action_label &&
      comment == o.comment &&
      committed_on == o.committed_on &&
      created_by == o.created_by &&
      created_on == o.created_on &&
      customer_id == o.customer_id &&
      deleted == o.deleted &&
      description == o.description &&
      disposition_id == o.disposition_id &&
      enabled == o.enabled &&
      field_values == o.field_values &&
      instance_id == o.instance_id &&
      instance_version == o.instance_version &&
      magic_cookie == o.magic_cookie &&
      modified_by == o.modified_by &&
      modified_on == o.modified_on &&
      name == o.name &&
      pattern_id == o.pattern_id &&
      pattern_severity == o.pattern_severity &&
      rulegroup_id == o.rulegroup_id &&
      ruletype_id == o.ruletype_id &&
      ruletype_name == o.ruletype_name &&
      version_ids == o.version_ids
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 465

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 536

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 441

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


421
422
423
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 421

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



427
428
429
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 427

def hash
  [action_label, comment, committed_on, created_by, created_on, customer_id, deleted, description, disposition_id, enabled, field_values, instance_id, instance_version, magic_cookie, modified_by, modified_on, name, pattern_id, pattern_severity, rulegroup_id, ruletype_id, ruletype_name, version_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 263

def list_invalid_properties
  invalid_properties = Array.new
  if @action_label.nil?
    invalid_properties.push('invalid value for "action_label", action_label cannot be nil.')
  end

  if @comment.nil?
    invalid_properties.push('invalid value for "comment", comment cannot be nil.')
  end

  if @committed_on.nil?
    invalid_properties.push('invalid value for "committed_on", committed_on cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @deleted.nil?
    invalid_properties.push('invalid value for "deleted", deleted cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @disposition_id.nil?
    invalid_properties.push('invalid value for "disposition_id", disposition_id cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @field_values.nil?
    invalid_properties.push('invalid value for "field_values", field_values cannot be nil.')
  end

  if @instance_id.nil?
    invalid_properties.push('invalid value for "instance_id", instance_id cannot be nil.')
  end

  if @instance_version.nil?
    invalid_properties.push('invalid value for "instance_version", instance_version cannot be nil.')
  end

  if @magic_cookie.nil?
    invalid_properties.push('invalid value for "magic_cookie", magic_cookie cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @modified_on.nil?
    invalid_properties.push('invalid value for "modified_on", modified_on cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @pattern_id.nil?
    invalid_properties.push('invalid value for "pattern_id", pattern_id cannot be nil.')
  end

  if @pattern_severity.nil?
    invalid_properties.push('invalid value for "pattern_severity", pattern_severity cannot be nil.')
  end

  if @rulegroup_id.nil?
    invalid_properties.push('invalid value for "rulegroup_id", rulegroup_id cannot be nil.')
  end

  if @ruletype_id.nil?
    invalid_properties.push('invalid value for "ruletype_id", ruletype_id cannot be nil.')
  end

  if @ruletype_name.nil?
    invalid_properties.push('invalid value for "ruletype_name", ruletype_name cannot be nil.')
  end

  if @version_ids.nil?
    invalid_properties.push('invalid value for "version_ids", version_ids cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



512
513
514
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 512

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 518

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



506
507
508
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 506

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/crimson-falcon/models/api_rule_v1.rb', line 362

def valid?
  return false if @action_label.nil?
  return false if @comment.nil?
  return false if @committed_on.nil?
  return false if @created_by.nil?
  return false if @created_on.nil?
  return false if @customer_id.nil?
  return false if @deleted.nil?
  return false if @description.nil?
  return false if @disposition_id.nil?
  return false if @enabled.nil?
  return false if @field_values.nil?
  return false if @instance_id.nil?
  return false if @instance_version.nil?
  return false if @magic_cookie.nil?
  return false if @modified_by.nil?
  return false if @modified_on.nil?
  return false if @name.nil?
  return false if @pattern_id.nil?
  return false if @pattern_severity.nil?
  return false if @rulegroup_id.nil?
  return false if @ruletype_id.nil?
  return false if @ruletype_name.nil?
  return false if @version_ids.nil?
  true
end