Class: Falcon::ApiTemplateSnapshotV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_template_snapshot_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiTemplateSnapshotV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiTemplateSnapshotV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiTemplateSnapshotV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_by_name')
    self.created_by_name = attributes[:'created_by_name']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'updated_by_name')
    self.updated_by_name = attributes[:'updated_by_name']
  end

  if attributes.key?(:'updated_timestamp')
    self.updated_timestamp = attributes[:'updated_timestamp']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



34
35
36
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 34

def cid
  @cid
end

#created_byObject

Returns the value of attribute created_by.



36
37
38
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 36

def created_by
  @created_by
end

#created_by_nameObject

Returns the value of attribute created_by_name.



38
39
40
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 38

def created_by_name
  @created_by_name
end

#created_timestampObject

Returns the value of attribute created_timestamp.



40
41
42
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 40

def created_timestamp
  @created_timestamp
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 42

def id
  @id
end

#templateObject

Returns the value of attribute template.



44
45
46
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 44

def template
  @template
end

#template_idObject

Returns the value of attribute template_id.



46
47
48
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 46

def template_id
  @template_id
end

#updated_byObject

Returns the value of attribute updated_by.



48
49
50
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 48

def updated_by
  @updated_by
end

#updated_by_nameObject

Returns the value of attribute updated_by_name.



50
51
52
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 50

def updated_by_name
  @updated_by_name
end

#updated_timestampObject

Returns the value of attribute updated_timestamp.



52
53
54
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 52

def updated_timestamp
  @updated_timestamp
end

#versionObject

Returns the value of attribute version.



54
55
56
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 54

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 57

def self.attribute_map
  {
    :'cid' => :'cid',
    :'created_by' => :'created_by',
    :'created_by_name' => :'created_by_name',
    :'created_timestamp' => :'created_timestamp',
    :'id' => :'id',
    :'template' => :'template',
    :'template_id' => :'template_id',
    :'updated_by' => :'updated_by',
    :'updated_by_name' => :'updated_by_name',
    :'updated_timestamp' => :'updated_timestamp',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 262

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 79

def self.openapi_types
  {
    :'cid' => :'String',
    :'created_by' => :'ApiActorV1',
    :'created_by_name' => :'String',
    :'created_timestamp' => :'Time',
    :'id' => :'String',
    :'template' => :'String',
    :'template_id' => :'String',
    :'updated_by' => :'ApiActorV1',
    :'updated_by_name' => :'String',
    :'updated_timestamp' => :'Time',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      created_by == o.created_by &&
      created_by_name == o.created_by_name &&
      created_timestamp == o.created_timestamp &&
      id == o.id &&
      template == o.template &&
      template_id == o.template_id &&
      updated_by == o.updated_by &&
      updated_by_name == o.updated_by_name &&
      updated_timestamp == o.updated_timestamp &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 293

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 269

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 255

def hash
  [cid, created_by, created_by_name, created_timestamp, id, template, template_id, updated_by, updated_by_name, updated_timestamp, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 163

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_by_name.nil?
    invalid_properties.push('invalid value for "created_by_name", created_by_name cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @template.nil?
    invalid_properties.push('invalid value for "template", template cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @updated_by.nil?
    invalid_properties.push('invalid value for "updated_by", updated_by cannot be nil.')
  end

  if @updated_by_name.nil?
    invalid_properties.push('invalid value for "updated_by_name", updated_by_name cannot be nil.')
  end

  if @updated_timestamp.nil?
    invalid_properties.push('invalid value for "updated_timestamp", updated_timestamp cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/crimson-falcon/models/api_template_snapshot_v1.rb', line 214

def valid?
  return false if @cid.nil?
  return false if @created_by.nil?
  return false if @created_by_name.nil?
  return false if @created_timestamp.nil?
  return false if @id.nil?
  return false if @template.nil?
  return false if @template_id.nil?
  return false if @updated_by.nil?
  return false if @updated_by_name.nil?
  return false if @updated_timestamp.nil?
  return false if @version.nil?
  true
end