Class: Falcon::ApiTemplateV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_template_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiTemplateV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiTemplateV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiTemplateV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_tags')
    if (value = attributes[:'access_tags']).is_a?(Array)
      self.access_tags = value
    end
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_by_name')
    self.created_by_name = attributes[:'created_by_name']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'fields')
    if (value = attributes[:'fields']).is_a?(Array)
      self.fields = value
    end
  end

  if attributes.key?(:'has_access')
    self.has_access = attributes[:'has_access']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'sla_id')
    self.sla_id = attributes[:'sla_id']
  end

  if attributes.key?(:'sla_method')
    self.sla_method = attributes[:'sla_method']
  end

  if attributes.key?(:'sla_rules')
    if (value = attributes[:'sla_rules']).is_a?(Array)
      self.sla_rules = value
    end
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'updated_by_name')
    self.updated_by_name = attributes[:'updated_by_name']
  end

  if attributes.key?(:'updated_timestamp')
    self.updated_timestamp = attributes[:'updated_timestamp']
  end

  if attributes.key?(:'workflows')
    if (value = attributes[:'workflows']).is_a?(Array)
      self.workflows = value
    end
  end
end

Instance Attribute Details

#access_tagsObject

Returns the value of attribute access_tags.



34
35
36
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 34

def access_tags
  @access_tags
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 36

def cid
  @cid
end

#created_byObject

Returns the value of attribute created_by.



38
39
40
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 38

def created_by
  @created_by
end

#created_by_nameObject

Returns the value of attribute created_by_name.



40
41
42
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 40

def created_by_name
  @created_by_name
end

#created_timestampObject

Returns the value of attribute created_timestamp.



42
43
44
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 42

def created_timestamp
  @created_timestamp
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 44

def description
  @description
end

#fieldsObject

Returns the value of attribute fields.



46
47
48
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 46

def fields
  @fields
end

#has_accessObject

Returns the value of attribute has_access.



48
49
50
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 48

def has_access
  @has_access
end

#idObject

Returns the value of attribute id.



50
51
52
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 50

def id
  @id
end

#nameObject

Returns the value of attribute name.



52
53
54
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 52

def name
  @name
end

#sla_idObject

Returns the value of attribute sla_id.



54
55
56
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 54

def sla_id
  @sla_id
end

#sla_methodObject

Returns the value of attribute sla_method.



56
57
58
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 56

def sla_method
  @sla_method
end

#sla_rulesObject

Returns the value of attribute sla_rules.



58
59
60
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 58

def sla_rules
  @sla_rules
end

#updated_byObject

Returns the value of attribute updated_by.



60
61
62
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 60

def updated_by
  @updated_by
end

#updated_by_nameObject

Returns the value of attribute updated_by_name.



62
63
64
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 62

def updated_by_name
  @updated_by_name
end

#updated_timestampObject

Returns the value of attribute updated_timestamp.



64
65
66
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 64

def updated_timestamp
  @updated_timestamp
end

#workflowsObject

Returns the value of attribute workflows.



66
67
68
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 66

def workflows
  @workflows
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 69

def self.attribute_map
  {
    :'access_tags' => :'access_tags',
    :'cid' => :'cid',
    :'created_by' => :'created_by',
    :'created_by_name' => :'created_by_name',
    :'created_timestamp' => :'created_timestamp',
    :'description' => :'description',
    :'fields' => :'fields',
    :'has_access' => :'has_access',
    :'id' => :'id',
    :'name' => :'name',
    :'sla_id' => :'sla_id',
    :'sla_method' => :'sla_method',
    :'sla_rules' => :'sla_rules',
    :'updated_by' => :'updated_by',
    :'updated_by_name' => :'updated_by_name',
    :'updated_timestamp' => :'updated_timestamp',
    :'workflows' => :'workflows'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



319
320
321
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 319

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 97

def self.openapi_types
  {
    :'access_tags' => :'Array<ApiAccessTagV1>',
    :'cid' => :'String',
    :'created_by' => :'ApiActorV1',
    :'created_by_name' => :'String',
    :'created_timestamp' => :'Time',
    :'description' => :'String',
    :'fields' => :'Array<ApiFieldV1>',
    :'has_access' => :'Boolean',
    :'id' => :'String',
    :'name' => :'String',
    :'sla_id' => :'String',
    :'sla_method' => :'String',
    :'sla_rules' => :'Array<ApiTemplateSLARuleV1>',
    :'updated_by' => :'ApiActorV1',
    :'updated_by_name' => :'String',
    :'updated_timestamp' => :'Time',
    :'workflows' => :'Array<ApiWorkflowV1>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_tags == o.access_tags &&
      cid == o.cid &&
      created_by == o.created_by &&
      created_by_name == o.created_by_name &&
      created_timestamp == o.created_timestamp &&
      description == o.description &&
      fields == o.fields &&
      has_access == o.has_access &&
      id == o.id &&
      name == o.name &&
      sla_id == o.sla_id &&
      sla_method == o.sla_method &&
      sla_rules == o.sla_rules &&
      updated_by == o.updated_by &&
      updated_by_name == o.updated_by_name &&
      updated_timestamp == o.updated_timestamp &&
      workflows == o.workflows
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 350

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 421

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 326

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 306

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



312
313
314
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 312

def hash
  [access_tags, cid, created_by, created_by_name, created_timestamp, description, fields, has_access, id, name, sla_id, sla_method, sla_rules, updated_by, updated_by_name, updated_timestamp, workflows].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 219

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_by_name.nil?
    invalid_properties.push('invalid value for "created_by_name", created_by_name cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @has_access.nil?
    invalid_properties.push('invalid value for "has_access", has_access cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @updated_by.nil?
    invalid_properties.push('invalid value for "updated_by", updated_by cannot be nil.')
  end

  if @updated_by_name.nil?
    invalid_properties.push('invalid value for "updated_by_name", updated_by_name cannot be nil.')
  end

  if @updated_timestamp.nil?
    invalid_properties.push('invalid value for "updated_timestamp", updated_timestamp cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 397

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 403

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



391
392
393
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 391

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/crimson-falcon/models/api_template_v1.rb', line 266

def valid?
  return false if @cid.nil?
  return false if @created_by.nil?
  return false if @created_by_name.nil?
  return false if @created_timestamp.nil?
  return false if @has_access.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if @updated_by.nil?
  return false if @updated_by_name.nil?
  return false if @updated_timestamp.nil?
  true
end