Class: Falcon::ApiUpdateParserRequestV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/api_update_parser_request_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiUpdateParserRequestV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiUpdateParserRequestV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiUpdateParserRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'fields_to_be_removed_before_parsing')
    if (value = attributes[:'fields_to_be_removed_before_parsing']).is_a?(Array)
      self.fields_to_be_removed_before_parsing = value
    end
  end

  if attributes.key?(:'fields_to_tag')
    if (value = attributes[:'fields_to_tag']).is_a?(Array)
      self.fields_to_tag = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'script')
    self.script = attributes[:'script']
  end

  if attributes.key?(:'test_cases')
    if (value = attributes[:'test_cases']).is_a?(Array)
      self.test_cases = value
    end
  end
end

Instance Attribute Details

#fields_to_be_removed_before_parsingObject

A list of fields that will be removed from the event before it’s parsed. These fields will not be included when calculating usage



35
36
37
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 35

def fields_to_be_removed_before_parsing
  @fields_to_be_removed_before_parsing
end

#fields_to_tagObject

A list of fields that should be used for sharding. See library.humio.com/stable/docs/parsers/tagging/



38
39
40
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 38

def fields_to_tag
  @fields_to_tag
end

#idObject

The unique identifier of the parser to update



41
42
43
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 41

def id
  @id
end

#repositoryObject

The name of the repository containing the parser



44
45
46
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 44

def repository
  @repository
end

#scriptObject

The parser script that transforms the input into events. Humio Language v1



47
48
49
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 47

def script
  @script
end

#test_casesObject

A list of tests that the parser can be tested against



50
51
52
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 50

def test_cases
  @test_cases
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 53

def self.attribute_map
  {
    :'fields_to_be_removed_before_parsing' => :'fields_to_be_removed_before_parsing',
    :'fields_to_tag' => :'fields_to_tag',
    :'id' => :'id',
    :'repository' => :'repository',
    :'script' => :'script',
    :'test_cases' => :'test_cases'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 199

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 70

def self.openapi_types
  {
    :'fields_to_be_removed_before_parsing' => :'Array<String>',
    :'fields_to_tag' => :'Array<String>',
    :'id' => :'String',
    :'repository' => :'String',
    :'script' => :'String',
    :'test_cases' => :'Array<ApiParserTestCase>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      fields_to_be_removed_before_parsing == o.fields_to_be_removed_before_parsing &&
      fields_to_tag == o.fields_to_tag &&
      id == o.id &&
      repository == o.repository &&
      script == o.script &&
      test_cases == o.test_cases
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 230

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 301

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 206

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 192

def hash
  [fields_to_be_removed_before_parsing, fields_to_tag, id, repository, script, test_cases].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 135

def list_invalid_properties
  invalid_properties = Array.new
  if @fields_to_be_removed_before_parsing.nil?
    invalid_properties.push('invalid value for "fields_to_be_removed_before_parsing", fields_to_be_removed_before_parsing cannot be nil.')
  end

  if @fields_to_tag.nil?
    invalid_properties.push('invalid value for "fields_to_tag", fields_to_tag cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @repository.nil?
    invalid_properties.push('invalid value for "repository", repository cannot be nil.')
  end

  if @script.nil?
    invalid_properties.push('invalid value for "script", script cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 277

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 283

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



271
272
273
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 271

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
# File 'lib/crimson-falcon/models/api_update_parser_request_v1.rb', line 162

def valid?
  return false if @fields_to_be_removed_before_parsing.nil?
  return false if @fields_to_tag.nil?
  return false if @id.nil?
  return false if @repository.nil?
  return false if @script.nil?
  true
end