Class: Falcon::ApimodelsControl

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/apimodels_control.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApimodelsControl

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApimodelsControl` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApimodelsControl`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applicable_profiles')
    if (value = attributes[:'applicable_profiles']).is_a?(Array)
      self.applicable_profiles = value
    end
  end

  if attributes.key?(:'authority')
    self.authority = attributes[:'authority']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'control_type')
    self.control_type = attributes[:'control_type']
  end

  if attributes.key?(:'control_version')
    self.control_version = attributes[:'control_version']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'requirement')
    self.requirement = attributes[:'requirement']
  end

  if attributes.key?(:'section_name')
    self.section_name = attributes[:'section_name']
  end

  if attributes.key?(:'security_framework')
    if (value = attributes[:'security_framework']).is_a?(Array)
      self.security_framework = value
    end
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end
end

Instance Attribute Details

#applicable_profilesObject

Returns the value of attribute applicable_profiles.



34
35
36
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 34

def applicable_profiles
  @applicable_profiles
end

#authorityObject

Returns the value of attribute authority.



36
37
38
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 36

def authority
  @authority
end

#codeObject

Returns the value of attribute code.



38
39
40
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 38

def code
  @code
end

#control_typeObject

Returns the value of attribute control_type.



40
41
42
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 40

def control_type
  @control_type
end

#control_versionObject

Returns the value of attribute control_version.



42
43
44
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 42

def control_version
  @control_version
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 44

def description
  @description
end

#nameObject

Returns the value of attribute name.



46
47
48
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 46

def name
  @name
end

#originObject

Returns the value of attribute origin.



48
49
50
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 48

def origin
  @origin
end

#requirementObject

Returns the value of attribute requirement.



50
51
52
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 50

def requirement
  @requirement
end

#section_nameObject

Returns the value of attribute section_name.



52
53
54
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 52

def section_name
  @section_name
end

#security_frameworkObject

Returns the value of attribute security_framework.



54
55
56
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 54

def security_framework
  @security_framework
end

#uuidObject

Returns the value of attribute uuid.



56
57
58
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 56

def uuid
  @uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 59

def self.attribute_map
  {
    :'applicable_profiles' => :'applicable_profiles',
    :'authority' => :'authority',
    :'code' => :'code',
    :'control_type' => :'control_type',
    :'control_version' => :'control_version',
    :'description' => :'description',
    :'name' => :'name',
    :'origin' => :'origin',
    :'requirement' => :'requirement',
    :'section_name' => :'section_name',
    :'security_framework' => :'security_framework',
    :'uuid' => :'uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 245

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 82

def self.openapi_types
  {
    :'applicable_profiles' => :'Array<String>',
    :'authority' => :'String',
    :'code' => :'String',
    :'control_type' => :'String',
    :'control_version' => :'String',
    :'description' => :'String',
    :'name' => :'String',
    :'origin' => :'String',
    :'requirement' => :'String',
    :'section_name' => :'String',
    :'security_framework' => :'Array<ApimodelsSecurityFramework>',
    :'uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applicable_profiles == o.applicable_profiles &&
      authority == o.authority &&
      code == o.code &&
      control_type == o.control_type &&
      control_version == o.control_version &&
      description == o.description &&
      name == o.name &&
      origin == o.origin &&
      requirement == o.requirement &&
      section_name == o.section_name &&
      security_framework == o.security_framework &&
      uuid == o.uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 276

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 347

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 252

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 238

def hash
  [applicable_profiles, authority, code, control_type, control_version, description, name, origin, requirement, section_name, security_framework, uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 175

def list_invalid_properties
  invalid_properties = Array.new
  if @authority.nil?
    invalid_properties.push('invalid value for "authority", authority cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @origin.nil?
    invalid_properties.push('invalid value for "origin", origin cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 323

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



317
318
319
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 317

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
# File 'lib/crimson-falcon/models/apimodels_control.rb', line 202

def valid?
  return false if @authority.nil?
  return false if @code.nil?
  return false if @name.nil?
  return false if @origin.nil?
  return false if @uuid.nil?
  true
end