Class: Falcon::ApimodelsRuleOverride

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/apimodels_rule_override.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApimodelsRuleOverride

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApimodelsRuleOverride` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApimodelsRuleOverride`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'asset_filter')
    self.asset_filter = attributes[:'asset_filter']
  end

  if attributes.key?(:'asset_scope_type')
    self.asset_scope_type = attributes[:'asset_scope_type']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'deleted_by')
    self.deleted_by = attributes[:'deleted_by']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'override_details')
    self.override_details = attributes[:'override_details']
  end

  if attributes.key?(:'override_type')
    self.override_type = attributes[:'override_type']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'rule_id')
    self.rule_id = attributes[:'rule_id']
  end

  if attributes.key?(:'suppression_rule_id')
    self.suppression_rule_id = attributes[:'suppression_rule_id']
  end

  if attributes.key?(:'target_region')
    self.target_region = attributes[:'target_region']
  end

  if attributes.key?(:'update_reason')
    self.update_reason = attributes[:'update_reason']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end
end

Instance Attribute Details

#asset_filterObject

Returns the value of attribute asset_filter.



34
35
36
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 34

def asset_filter
  @asset_filter
end

#asset_scope_typeObject

Returns the value of attribute asset_scope_type.



36
37
38
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 36

def asset_scope_type
  @asset_scope_type
end

#cidObject

Returns the value of attribute cid.



38
39
40
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 38

def cid
  @cid
end

#commentObject

Returns the value of attribute comment.



40
41
42
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 40

def comment
  @comment
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 42

def created_at
  @created_at
end

#created_byObject

Returns the value of attribute created_by.



44
45
46
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 44

def created_by
  @created_by
end

#crnObject

Returns the value of attribute crn.



46
47
48
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 46

def crn
  @crn
end

#deleted_atObject

Returns the value of attribute deleted_at.



48
49
50
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 48

def deleted_at
  @deleted_at
end

#deleted_byObject

Returns the value of attribute deleted_by.



50
51
52
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 50

def deleted_by
  @deleted_by
end

#expires_atObject

Returns the value of attribute expires_at.



52
53
54
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 52

def expires_at
  @expires_at
end

#override_detailsObject

Returns the value of attribute override_details.



54
55
56
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 54

def override_details
  @override_details
end

#override_typeObject

Returns the value of attribute override_type.



56
57
58
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 56

def override_type
  @override_type
end

#reasonObject

Returns the value of attribute reason.



58
59
60
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 58

def reason
  @reason
end

#rule_idObject

Returns the value of attribute rule_id.



60
61
62
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 60

def rule_id
  @rule_id
end

#suppression_rule_idObject

Returns the value of attribute suppression_rule_id.



62
63
64
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 62

def suppression_rule_id
  @suppression_rule_id
end

#target_regionObject

Returns the value of attribute target_region.



64
65
66
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 64

def target_region
  @target_region
end

#update_reasonObject

Returns the value of attribute update_reason.



66
67
68
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 66

def update_reason
  @update_reason
end

#updated_atObject

Returns the value of attribute updated_at.



68
69
70
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 68

def updated_at
  @updated_at
end

#updated_byObject

Returns the value of attribute updated_by.



70
71
72
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 70

def updated_by
  @updated_by
end

#user_idObject

Returns the value of attribute user_id.



72
73
74
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 72

def user_id
  @user_id
end

#uuidObject

Returns the value of attribute uuid.



74
75
76
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 74

def uuid
  @uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 77

def self.attribute_map
  {
    :'asset_filter' => :'asset_filter',
    :'asset_scope_type' => :'asset_scope_type',
    :'cid' => :'cid',
    :'comment' => :'comment',
    :'created_at' => :'created_at',
    :'created_by' => :'created_by',
    :'crn' => :'crn',
    :'deleted_at' => :'deleted_at',
    :'deleted_by' => :'deleted_by',
    :'expires_at' => :'expires_at',
    :'override_details' => :'override_details',
    :'override_type' => :'override_type',
    :'reason' => :'reason',
    :'rule_id' => :'rule_id',
    :'suppression_rule_id' => :'suppression_rule_id',
    :'target_region' => :'target_region',
    :'update_reason' => :'update_reason',
    :'updated_at' => :'updated_at',
    :'updated_by' => :'updated_by',
    :'user_id' => :'user_id',
    :'uuid' => :'uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 357

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 109

def self.openapi_types
  {
    :'asset_filter' => :'ApimodelsAssetFilter',
    :'asset_scope_type' => :'String',
    :'cid' => :'String',
    :'comment' => :'String',
    :'created_at' => :'Time',
    :'created_by' => :'String',
    :'crn' => :'String',
    :'deleted_at' => :'Time',
    :'deleted_by' => :'String',
    :'expires_at' => :'Time',
    :'override_details' => :'String',
    :'override_type' => :'String',
    :'reason' => :'String',
    :'rule_id' => :'String',
    :'suppression_rule_id' => :'String',
    :'target_region' => :'String',
    :'update_reason' => :'String',
    :'updated_at' => :'Time',
    :'updated_by' => :'String',
    :'user_id' => :'String',
    :'uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      asset_filter == o.asset_filter &&
      asset_scope_type == o.asset_scope_type &&
      cid == o.cid &&
      comment == o.comment &&
      created_at == o.created_at &&
      created_by == o.created_by &&
      crn == o.crn &&
      deleted_at == o.deleted_at &&
      deleted_by == o.deleted_by &&
      expires_at == o.expires_at &&
      override_details == o.override_details &&
      override_type == o.override_type &&
      reason == o.reason &&
      rule_id == o.rule_id &&
      suppression_rule_id == o.suppression_rule_id &&
      target_region == o.target_region &&
      update_reason == o.update_reason &&
      updated_at == o.updated_at &&
      updated_by == o.updated_by &&
      user_id == o.user_id &&
      uuid == o.uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 388

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 459

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 364

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


344
345
346
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



350
351
352
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 350

def hash
  [asset_filter, asset_scope_type, cid, comment, created_at, created_by, crn, deleted_at, deleted_by, expires_at, override_details, override_type, reason, rule_id, suppression_rule_id, target_region, update_reason, updated_at, updated_by, user_id, uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 243

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @comment.nil?
    invalid_properties.push('invalid value for "comment", comment cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @crn.nil?
    invalid_properties.push('invalid value for "crn", crn cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @override_details.nil?
    invalid_properties.push('invalid value for "override_details", override_details cannot be nil.')
  end

  if @override_type.nil?
    invalid_properties.push('invalid value for "override_type", override_type cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  if @target_region.nil?
    invalid_properties.push('invalid value for "target_region", target_region cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 435

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



429
430
431
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 429

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/crimson-falcon/models/apimodels_rule_override.rb', line 298

def valid?
  return false if @cid.nil?
  return false if @comment.nil?
  return false if @created_at.nil?
  return false if @created_by.nil?
  return false if @crn.nil?
  return false if @expires_at.nil?
  return false if @override_details.nil?
  return false if @override_type.nil?
  return false if @reason.nil?
  return false if @target_region.nil?
  return false if @user_id.nil?
  return false if @uuid.nil?
  true
end