Class: Falcon::AssetgroupmanagerV1UpdateCloudGroupMessage
- Inherits:
-
Object
- Object
- Falcon::AssetgroupmanagerV1UpdateCloudGroupMessage
- Defined in:
- lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#business_impact ⇒ Object
The new Business Impact for the group.
-
#business_unit ⇒ Object
Business Impact is one of the "business context" field of the group.
-
#description ⇒ Object
The new Description for the group.
-
#environment ⇒ Object
Environment is one of the "business context" field of the group.
-
#id ⇒ Object
The UUID of the group to be updated.
-
#name ⇒ Object
Group name is unique and case insensitive.
-
#owners ⇒ Object
The owners field contains a list of user emails.
-
#selectors ⇒ Object
Returns the value of attribute selectors.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssetgroupmanagerV1UpdateCloudGroupMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AssetgroupmanagerV1UpdateCloudGroupMessage
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::AssetgroupmanagerV1UpdateCloudGroupMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::AssetgroupmanagerV1UpdateCloudGroupMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'business_impact') self.business_impact = attributes[:'business_impact'] end if attributes.key?(:'business_unit') self.business_unit = attributes[:'business_unit'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'owners') if (value = attributes[:'owners']).is_a?(Array) self.owners = value end end if attributes.key?(:'selectors') self.selectors = attributes[:'selectors'] end end |
Instance Attribute Details
#business_impact ⇒ Object
The new Business Impact for the group. It will be deleted if the value is sent empty.
35 36 37 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 35 def business_impact @business_impact end |
#business_unit ⇒ Object
Business Impact is one of the "business context" field of the group. It will be deleted if the value is sent empty.
38 39 40 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 38 def business_unit @business_unit end |
#description ⇒ Object
The new Description for the group.
41 42 43 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 41 def description @description end |
#environment ⇒ Object
Environment is one of the "business context" field of the group. It will be deleted if the value is sent empty.
44 45 46 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 44 def environment @environment end |
#id ⇒ Object
The UUID of the group to be updated.
47 48 49 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 47 def id @id end |
#name ⇒ Object
Group name is unique and case insensitive.
50 51 52 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 50 def name @name end |
#owners ⇒ Object
The owners field contains a list of user emails. An empty list of owners means that the group will be updated to have no owners.
53 54 55 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 53 def owners @owners end |
#selectors ⇒ Object
Returns the value of attribute selectors.
55 56 57 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 55 def selectors @selectors end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 94 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 80 def self.attribute_map { :'business_impact' => :'business_impact', :'business_unit' => :'business_unit', :'description' => :'description', :'environment' => :'environment', :'id' => :'id', :'name' => :'name', :'owners' => :'owners', :'selectors' => :'selectors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 280 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 99 def self.openapi_types { :'business_impact' => :'String', :'business_unit' => :'String', :'description' => :'String', :'environment' => :'String', :'id' => :'String', :'name' => :'String', :'owners' => :'Array<String>', :'selectors' => :'AssetgroupmanagerV1WriteCloudGroupSelectors' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && business_impact == o.business_impact && business_unit == o.business_unit && description == o.description && environment == o.environment && id == o.id && name == o.name && owners == o.owners && selectors == o.selectors end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 311 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 382 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 287 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 273 def hash [business_impact, business_unit, description, environment, id, name, owners, selectors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 170 def list_invalid_properties invalid_properties = Array.new if !@business_unit.nil? && @business_unit.to_s.length > 100 invalid_properties.push('invalid value for "business_unit", the character length must be smaller than or equal to 100.') end if !@description.nil? && @description.to_s.length > 1000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.') end if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
358 359 360 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 358 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
352 353 354 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 352 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/crimson-falcon/models/assetgroupmanager_v1_update_cloud_group_message.rb', line 189 def valid? business_impact_validator = EnumAttributeValidator.new('String', ["", "high", "moderate", "low"]) return false unless business_impact_validator.valid?(@business_impact) return false if !@business_unit.nil? && @business_unit.to_s.length > 100 return false if !@description.nil? && @description.to_s.length > 1000 environment_validator = EnumAttributeValidator.new('String', ["", "dev", "test", "stage", "prod"]) return false unless environment_validator.valid?(@environment) return false if !@name.nil? && @name.to_s.length > 100 true end |