Class: Falcon::AzureDeletedRegistration

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/azure_deleted_registration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AzureDeletedRegistration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::AzureDeletedRegistration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::AzureDeletedRegistration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'activity_log_diagnostic_settings_name')
    self.activity_log_diagnostic_settings_name = attributes[:'activity_log_diagnostic_settings_name']
  end

  if attributes.key?(:'cs_infra_subscription_id')
    self.cs_infra_subscription_id = attributes[:'cs_infra_subscription_id']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'deployment_method')
    self.deployment_method = attributes[:'deployment_method']
  end

  if attributes.key?(:'deployment_stack_location')
    self.deployment_stack_location = attributes[:'deployment_stack_location']
  end

  if attributes.key?(:'deployment_stack_name')
    self.deployment_stack_name = attributes[:'deployment_stack_name']
  end

  if attributes.key?(:'deployment_stack_scope')
    self.deployment_stack_scope = attributes[:'deployment_stack_scope']
  end

  if attributes.key?(:'deprovision_scripts')
    self.deprovision_scripts = attributes[:'deprovision_scripts']
  end

  if attributes.key?(:'enterprise_app_url')
    self.enterprise_app_url = attributes[:'enterprise_app_url']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'subscriptions')
    if (value = attributes[:'subscriptions']).is_a?(Array)
      self.subscriptions = value
    end
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'tenant_name')
    self.tenant_name = attributes[:'tenant_name']
  end
end

Instance Attribute Details

#activity_log_diagnostic_settings_nameObject

Returns the value of attribute activity_log_diagnostic_settings_name.



34
35
36
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 34

def activity_log_diagnostic_settings_name
  @activity_log_diagnostic_settings_name
end

#cs_infra_subscription_idObject

Returns the value of attribute cs_infra_subscription_id.



36
37
38
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 36

def cs_infra_subscription_id
  @cs_infra_subscription_id
end

#deletedObject

Returns the value of attribute deleted.



38
39
40
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 38

def deleted
  @deleted
end

#deployment_methodObject

Returns the value of attribute deployment_method.



40
41
42
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 40

def deployment_method
  @deployment_method
end

#deployment_stack_locationObject

Returns the value of attribute deployment_stack_location.



42
43
44
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 42

def deployment_stack_location
  @deployment_stack_location
end

#deployment_stack_nameObject

Returns the value of attribute deployment_stack_name.



44
45
46
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 44

def deployment_stack_name
  @deployment_stack_name
end

#deployment_stack_scopeObject

Returns the value of attribute deployment_stack_scope.



46
47
48
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 46

def deployment_stack_scope
  @deployment_stack_scope
end

#deprovision_scriptsObject

Returns the value of attribute deprovision_scripts.



48
49
50
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 48

def deprovision_scripts
  @deprovision_scripts
end

#enterprise_app_urlObject

Returns the value of attribute enterprise_app_url.



50
51
52
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 50

def enterprise_app_url
  @enterprise_app_url
end

#productsObject

Returns the value of attribute products.



52
53
54
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 52

def products
  @products
end

#statusObject

Returns the value of attribute status.



54
55
56
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 54

def status
  @status
end

#subscriptionsObject

Returns the value of attribute subscriptions.



56
57
58
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 56

def subscriptions
  @subscriptions
end

#tenant_idObject

Returns the value of attribute tenant_id.



58
59
60
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 58

def tenant_id
  @tenant_id
end

#tenant_nameObject

Returns the value of attribute tenant_name.



60
61
62
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 60

def tenant_name
  @tenant_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 63

def self.attribute_map
  {
    :'activity_log_diagnostic_settings_name' => :'activity_log_diagnostic_settings_name',
    :'cs_infra_subscription_id' => :'cs_infra_subscription_id',
    :'deleted' => :'deleted',
    :'deployment_method' => :'deployment_method',
    :'deployment_stack_location' => :'deployment_stack_location',
    :'deployment_stack_name' => :'deployment_stack_name',
    :'deployment_stack_scope' => :'deployment_stack_scope',
    :'deprovision_scripts' => :'deprovision_scripts',
    :'enterprise_app_url' => :'enterprise_app_url',
    :'products' => :'products',
    :'status' => :'status',
    :'subscriptions' => :'subscriptions',
    :'tenant_id' => :'tenant_id',
    :'tenant_name' => :'tenant_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



298
299
300
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 298

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 88

def self.openapi_types
  {
    :'activity_log_diagnostic_settings_name' => :'String',
    :'cs_infra_subscription_id' => :'String',
    :'deleted' => :'Boolean',
    :'deployment_method' => :'String',
    :'deployment_stack_location' => :'String',
    :'deployment_stack_name' => :'String',
    :'deployment_stack_scope' => :'String',
    :'deprovision_scripts' => :'AzureDeprovisionScripts',
    :'enterprise_app_url' => :'String',
    :'products' => :'Array<DomainProductFeatures>',
    :'status' => :'String',
    :'subscriptions' => :'Array<AzureDeletedSubscriptionInfo>',
    :'tenant_id' => :'String',
    :'tenant_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      activity_log_diagnostic_settings_name == o.activity_log_diagnostic_settings_name &&
      cs_infra_subscription_id == o.cs_infra_subscription_id &&
      deleted == o.deleted &&
      deployment_method == o.deployment_method &&
      deployment_stack_location == o.deployment_stack_location &&
      deployment_stack_name == o.deployment_stack_name &&
      deployment_stack_scope == o.deployment_stack_scope &&
      deprovision_scripts == o.deprovision_scripts &&
      enterprise_app_url == o.enterprise_app_url &&
      products == o.products &&
      status == o.status &&
      subscriptions == o.subscriptions &&
      tenant_id == o.tenant_id &&
      tenant_name == o.tenant_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 329

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 400

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 305

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


285
286
287
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 285

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



291
292
293
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 291

def hash
  [activity_log_diagnostic_settings_name, cs_infra_subscription_id, deleted, deployment_method, deployment_stack_location, deployment_stack_name, deployment_stack_scope, deprovision_scripts, enterprise_app_url, products, status, subscriptions, tenant_id, tenant_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 191

def list_invalid_properties
  invalid_properties = Array.new
  if @cs_infra_subscription_id.nil?
    invalid_properties.push('invalid value for "cs_infra_subscription_id", cs_infra_subscription_id cannot be nil.')
  end

  if @deleted.nil?
    invalid_properties.push('invalid value for "deleted", deleted cannot be nil.')
  end

  if @deployment_method.nil?
    invalid_properties.push('invalid value for "deployment_method", deployment_method cannot be nil.')
  end

  if @deployment_stack_location.nil?
    invalid_properties.push('invalid value for "deployment_stack_location", deployment_stack_location cannot be nil.')
  end

  if @deployment_stack_name.nil?
    invalid_properties.push('invalid value for "deployment_stack_name", deployment_stack_name cannot be nil.')
  end

  if @deployment_stack_scope.nil?
    invalid_properties.push('invalid value for "deployment_stack_scope", deployment_stack_scope cannot be nil.')
  end

  if @enterprise_app_url.nil?
    invalid_properties.push('invalid value for "enterprise_app_url", enterprise_app_url cannot be nil.')
  end

  if @products.nil?
    invalid_properties.push('invalid value for "products", products cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @subscriptions.nil?
    invalid_properties.push('invalid value for "subscriptions", subscriptions cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @tenant_name.nil?
    invalid_properties.push('invalid value for "tenant_name", tenant_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



376
377
378
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 376

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



370
371
372
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 370

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/crimson-falcon/models/azure_deleted_registration.rb', line 246

def valid?
  return false if @cs_infra_subscription_id.nil?
  return false if @deleted.nil?
  return false if @deployment_method.nil?
  return false if @deployment_stack_location.nil?
  return false if @deployment_stack_name.nil?
  return false if @deployment_stack_scope.nil?
  return false if @enterprise_app_url.nil?
  return false if @products.nil?
  return false if @status.nil?
  return false if @subscriptions.nil?
  return false if @tenant_id.nil?
  return false if @tenant_name.nil?
  true
end