Class: Falcon::AzureTenantRegistration

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/azure_tenant_registration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AzureTenantRegistration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 258

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::AzureTenantRegistration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::AzureTenantRegistration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  end

  if attributes.key?(:'additional_features')
    if (value = attributes[:'additional_features']).is_a?(Array)
      self.additional_features = value
    end
  end

  if attributes.key?(:'additional_properties')
    self.additional_properties = attributes[:'additional_properties']
  end

  if attributes.key?(:'admin_consent_url')
    self.admin_consent_url = attributes[:'admin_consent_url']
  end

  if attributes.key?(:'api_client_key_id')
    self.api_client_key_id = attributes[:'api_client_key_id']
  end

  if attributes.key?(:'api_client_key_type')
    self.api_client_key_type = attributes[:'api_client_key_type']
  end

  if attributes.key?(:'app_registration_id')
    self.app_registration_id = attributes[:'app_registration_id']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'cs_infra_region')
    self.cs_infra_region = attributes[:'cs_infra_region']
  end

  if attributes.key?(:'cs_infra_subscription_id')
    self.cs_infra_subscription_id = attributes[:'cs_infra_subscription_id']
  end

  if attributes.key?(:'cs_infra_subscription_name')
    self.cs_infra_subscription_name = attributes[:'cs_infra_subscription_name']
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.key?(:'deployment_method')
    self.deployment_method = attributes[:'deployment_method']
  end

  if attributes.key?(:'deployment_stack_host_id')
    self.deployment_stack_host_id = attributes[:'deployment_stack_host_id']
  end

  if attributes.key?(:'deployment_stack_host_region')
    self.deployment_stack_host_region = attributes[:'deployment_stack_host_region']
  end

  if attributes.key?(:'deployment_stack_host_type')
    self.deployment_stack_host_type = attributes[:'deployment_stack_host_type']
  end

  if attributes.key?(:'deployment_stack_host_url')
    self.deployment_stack_host_url = attributes[:'deployment_stack_host_url']
  end

  if attributes.key?(:'deployment_stack_name')
    self.deployment_stack_name = attributes[:'deployment_stack_name']
  end

  if attributes.key?(:'dspm_custom_vnet_configuration')
    if (value = attributes[:'dspm_custom_vnet_configuration']).is_a?(Hash)
      self.dspm_custom_vnet_configuration = value
    end
  end

  if attributes.key?(:'dspm_host_subscription_id')
    self.dspm_host_subscription_id = attributes[:'dspm_host_subscription_id']
  end

  if attributes.key?(:'dspm_network_configuration_type')
    self.dspm_network_configuration_type = attributes[:'dspm_network_configuration_type']
  end

  if attributes.key?(:'dspm_regions')
    if (value = attributes[:'dspm_regions']).is_a?(Array)
      self.dspm_regions = value
    end
  end

  if attributes.key?(:'enterprise_app_url')
    self.enterprise_app_url = attributes[:'enterprise_app_url']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'event_hub_settings')
    if (value = attributes[:'event_hub_settings']).is_a?(Array)
      self.event_hub_settings = value
    end
  end

  if attributes.key?(:'key_info')
    self.key_info = attributes[:'key_info']
  end

  if attributes.key?(:'management_group_ids')
    if (value = attributes[:'management_group_ids']).is_a?(Array)
      self.management_group_ids = value
    end
  end

  if attributes.key?(:'microsoft_graph_permission_ids')
    if (value = attributes[:'microsoft_graph_permission_ids']).is_a?(Array)
      self.microsoft_graph_permission_ids = value
    end
  end

  if attributes.key?(:'microsoft_graph_permission_ids_readonly')
    self.microsoft_graph_permission_ids_readonly = attributes[:'microsoft_graph_permission_ids_readonly']
  end

  if attributes.key?(:'primary_domain')
    self.primary_domain = attributes[:'primary_domain']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'registration_description')
    self.registration_description = attributes[:'registration_description']
  end

  if attributes.key?(:'registration_id')
    self.registration_id = attributes[:'registration_id']
  end

  if attributes.key?(:'registration_name')
    self.registration_name = attributes[:'registration_name']
  end

  if attributes.key?(:'resource_name_prefix')
    self.resource_name_prefix = attributes[:'resource_name_prefix']
  end

  if attributes.key?(:'resource_name_suffix')
    self.resource_name_suffix = attributes[:'resource_name_suffix']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'subscription_ids')
    if (value = attributes[:'subscription_ids']).is_a?(Array)
      self.subscription_ids = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'template_version')
    self.template_version = attributes[:'template_version']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'tenant_name')
    self.tenant_name = attributes[:'tenant_name']
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end
end

Instance Attribute Details

#account_typeObject

Returns the value of attribute account_type.



34
35
36
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 34

def 
  @account_type
end

#additional_featuresObject

Returns the value of attribute additional_features.



36
37
38
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 36

def additional_features
  @additional_features
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



38
39
40
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 38

def additional_properties
  @additional_properties
end

Returns the value of attribute admin_consent_url.



40
41
42
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 40

def admin_consent_url
  @admin_consent_url
end

#api_client_key_idObject

Returns the value of attribute api_client_key_id.



42
43
44
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 42

def api_client_key_id
  @api_client_key_id
end

#api_client_key_typeObject

Returns the value of attribute api_client_key_type.



44
45
46
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 44

def api_client_key_type
  @api_client_key_type
end

#app_registration_idObject

Returns the value of attribute app_registration_id.



46
47
48
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 46

def app_registration_id
  @app_registration_id
end

#cidObject

Returns the value of attribute cid.



48
49
50
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 48

def cid
  @cid
end

#createdObject

Returns the value of attribute created.



50
51
52
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 50

def created
  @created
end

#cs_infra_regionObject

Returns the value of attribute cs_infra_region.



52
53
54
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 52

def cs_infra_region
  @cs_infra_region
end

#cs_infra_subscription_idObject

Returns the value of attribute cs_infra_subscription_id.



54
55
56
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 54

def cs_infra_subscription_id
  @cs_infra_subscription_id
end

#cs_infra_subscription_nameObject

Returns the value of attribute cs_infra_subscription_name.



56
57
58
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 56

def cs_infra_subscription_name
  @cs_infra_subscription_name
end

#deletedObject

Returns the value of attribute deleted.



58
59
60
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 58

def deleted
  @deleted
end

#deployment_methodObject

Returns the value of attribute deployment_method.



60
61
62
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 60

def deployment_method
  @deployment_method
end

#deployment_stack_host_idObject

Returns the value of attribute deployment_stack_host_id.



62
63
64
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 62

def deployment_stack_host_id
  @deployment_stack_host_id
end

#deployment_stack_host_regionObject

Returns the value of attribute deployment_stack_host_region.



64
65
66
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 64

def deployment_stack_host_region
  @deployment_stack_host_region
end

#deployment_stack_host_typeObject

Returns the value of attribute deployment_stack_host_type.



66
67
68
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 66

def deployment_stack_host_type
  @deployment_stack_host_type
end

#deployment_stack_host_urlObject

Returns the value of attribute deployment_stack_host_url.



68
69
70
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 68

def deployment_stack_host_url
  @deployment_stack_host_url
end

#deployment_stack_nameObject

Returns the value of attribute deployment_stack_name.



70
71
72
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 70

def deployment_stack_name
  @deployment_stack_name
end

#dspm_custom_vnet_configurationObject

Returns the value of attribute dspm_custom_vnet_configuration.



72
73
74
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 72

def dspm_custom_vnet_configuration
  @dspm_custom_vnet_configuration
end

#dspm_host_subscription_idObject

Returns the value of attribute dspm_host_subscription_id.



74
75
76
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 74

def dspm_host_subscription_id
  @dspm_host_subscription_id
end

#dspm_network_configuration_typeObject

Network configuration type for DSPM



77
78
79
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 77

def dspm_network_configuration_type
  @dspm_network_configuration_type
end

#dspm_regionsObject

Returns the value of attribute dspm_regions.



79
80
81
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 79

def dspm_regions
  @dspm_regions
end

#enterprise_app_urlObject

Returns the value of attribute enterprise_app_url.



81
82
83
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 81

def enterprise_app_url
  @enterprise_app_url
end

#environmentObject

Returns the value of attribute environment.



83
84
85
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 83

def environment
  @environment
end

#event_hub_settingsObject

Returns the value of attribute event_hub_settings.



85
86
87
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 85

def event_hub_settings
  @event_hub_settings
end

#key_infoObject

Returns the value of attribute key_info.



87
88
89
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 87

def key_info
  @key_info
end

#management_group_idsObject

Returns the value of attribute management_group_ids.



89
90
91
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 89

def management_group_ids
  @management_group_ids
end

#microsoft_graph_permission_idsObject

Returns the value of attribute microsoft_graph_permission_ids.



91
92
93
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 91

def microsoft_graph_permission_ids
  @microsoft_graph_permission_ids
end

#microsoft_graph_permission_ids_readonlyObject

Returns the value of attribute microsoft_graph_permission_ids_readonly.



93
94
95
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 93

def microsoft_graph_permission_ids_readonly
  @microsoft_graph_permission_ids_readonly
end

#primary_domainObject

Returns the value of attribute primary_domain.



95
96
97
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 95

def primary_domain
  @primary_domain
end

#productsObject

Returns the value of attribute products.



97
98
99
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 97

def products
  @products
end

#registration_descriptionObject

Returns the value of attribute registration_description.



99
100
101
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 99

def registration_description
  @registration_description
end

#registration_idObject

Returns the value of attribute registration_id.



101
102
103
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 101

def registration_id
  @registration_id
end

#registration_nameObject

Returns the value of attribute registration_name.



103
104
105
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 103

def registration_name
  @registration_name
end

#resource_name_prefixObject

Returns the value of attribute resource_name_prefix.



105
106
107
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 105

def resource_name_prefix
  @resource_name_prefix
end

#resource_name_suffixObject

Returns the value of attribute resource_name_suffix.



107
108
109
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 107

def resource_name_suffix
  @resource_name_suffix
end

#statusObject

Returns the value of attribute status.



109
110
111
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 109

def status
  @status
end

#subscription_idsObject

Returns the value of attribute subscription_ids.



111
112
113
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 111

def subscription_ids
  @subscription_ids
end

#tagsObject

Returns the value of attribute tags.



113
114
115
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 113

def tags
  @tags
end

#template_versionObject

Returns the value of attribute template_version.



115
116
117
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 115

def template_version
  @template_version
end

#tenant_idObject

Returns the value of attribute tenant_id.



117
118
119
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 117

def tenant_id
  @tenant_id
end

#tenant_nameObject

Returns the value of attribute tenant_name.



119
120
121
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 119

def tenant_name
  @tenant_name
end

#updatedObject

Returns the value of attribute updated.



121
122
123
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 121

def updated
  @updated
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



196
197
198
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 196

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 146

def self.attribute_map
  {
    :'account_type' => :'account_type',
    :'additional_features' => :'additional_features',
    :'additional_properties' => :'additional_properties',
    :'admin_consent_url' => :'admin_consent_url',
    :'api_client_key_id' => :'api_client_key_id',
    :'api_client_key_type' => :'api_client_key_type',
    :'app_registration_id' => :'app_registration_id',
    :'cid' => :'cid',
    :'created' => :'created',
    :'cs_infra_region' => :'cs_infra_region',
    :'cs_infra_subscription_id' => :'cs_infra_subscription_id',
    :'cs_infra_subscription_name' => :'cs_infra_subscription_name',
    :'deleted' => :'deleted',
    :'deployment_method' => :'deployment_method',
    :'deployment_stack_host_id' => :'deployment_stack_host_id',
    :'deployment_stack_host_region' => :'deployment_stack_host_region',
    :'deployment_stack_host_type' => :'deployment_stack_host_type',
    :'deployment_stack_host_url' => :'deployment_stack_host_url',
    :'deployment_stack_name' => :'deployment_stack_name',
    :'dspm_custom_vnet_configuration' => :'dspm_custom_vnet_configuration',
    :'dspm_host_subscription_id' => :'dspm_host_subscription_id',
    :'dspm_network_configuration_type' => :'dspm_network_configuration_type',
    :'dspm_regions' => :'dspm_regions',
    :'enterprise_app_url' => :'enterprise_app_url',
    :'environment' => :'environment',
    :'event_hub_settings' => :'event_hub_settings',
    :'key_info' => :'key_info',
    :'management_group_ids' => :'management_group_ids',
    :'microsoft_graph_permission_ids' => :'microsoft_graph_permission_ids',
    :'microsoft_graph_permission_ids_readonly' => :'microsoft_graph_permission_ids_readonly',
    :'primary_domain' => :'primary_domain',
    :'products' => :'products',
    :'registration_description' => :'registration_description',
    :'registration_id' => :'registration_id',
    :'registration_name' => :'registration_name',
    :'resource_name_prefix' => :'resource_name_prefix',
    :'resource_name_suffix' => :'resource_name_suffix',
    :'status' => :'status',
    :'subscription_ids' => :'subscription_ids',
    :'tags' => :'tags',
    :'template_version' => :'template_version',
    :'tenant_id' => :'tenant_id',
    :'tenant_name' => :'tenant_name',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



617
618
619
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 617

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



251
252
253
254
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 251

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 201

def self.openapi_types
  {
    :'account_type' => :'String',
    :'additional_features' => :'Array<AzureAdditionalFeature>',
    :'additional_properties' => :'Object',
    :'admin_consent_url' => :'String',
    :'api_client_key_id' => :'String',
    :'api_client_key_type' => :'String',
    :'app_registration_id' => :'String',
    :'cid' => :'String',
    :'created' => :'Time',
    :'cs_infra_region' => :'String',
    :'cs_infra_subscription_id' => :'String',
    :'cs_infra_subscription_name' => :'String',
    :'deleted' => :'Time',
    :'deployment_method' => :'String',
    :'deployment_stack_host_id' => :'String',
    :'deployment_stack_host_region' => :'String',
    :'deployment_stack_host_type' => :'String',
    :'deployment_stack_host_url' => :'String',
    :'deployment_stack_name' => :'String',
    :'dspm_custom_vnet_configuration' => :'Hash<String, AzureDSPMRegionCustomNetworkConfiguration>',
    :'dspm_host_subscription_id' => :'String',
    :'dspm_network_configuration_type' => :'String',
    :'dspm_regions' => :'Array<String>',
    :'enterprise_app_url' => :'String',
    :'environment' => :'String',
    :'event_hub_settings' => :'Array<AzureEventHubSettings>',
    :'key_info' => :'AzureClientKeyInfo',
    :'management_group_ids' => :'Array<String>',
    :'microsoft_graph_permission_ids' => :'Array<String>',
    :'microsoft_graph_permission_ids_readonly' => :'Boolean',
    :'primary_domain' => :'String',
    :'products' => :'Array<DomainProductFeatures>',
    :'registration_description' => :'String',
    :'registration_id' => :'String',
    :'registration_name' => :'String',
    :'resource_name_prefix' => :'String',
    :'resource_name_suffix' => :'String',
    :'status' => :'String',
    :'subscription_ids' => :'Array<String>',
    :'tags' => :'Hash<String, String>',
    :'template_version' => :'String',
    :'tenant_id' => :'String',
    :'tenant_name' => :'String',
    :'updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 553

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      additional_features == o.additional_features &&
      additional_properties == o.additional_properties &&
      admin_consent_url == o.admin_consent_url &&
      api_client_key_id == o.api_client_key_id &&
      api_client_key_type == o.api_client_key_type &&
      app_registration_id == o.app_registration_id &&
      cid == o.cid &&
      created == o.created &&
      cs_infra_region == o.cs_infra_region &&
      cs_infra_subscription_id == o.cs_infra_subscription_id &&
      cs_infra_subscription_name == o.cs_infra_subscription_name &&
      deleted == o.deleted &&
      deployment_method == o.deployment_method &&
      deployment_stack_host_id == o.deployment_stack_host_id &&
      deployment_stack_host_region == o.deployment_stack_host_region &&
      deployment_stack_host_type == o.deployment_stack_host_type &&
      deployment_stack_host_url == o.deployment_stack_host_url &&
      deployment_stack_name == o.deployment_stack_name &&
      dspm_custom_vnet_configuration == o.dspm_custom_vnet_configuration &&
      dspm_host_subscription_id == o.dspm_host_subscription_id &&
      dspm_network_configuration_type == o.dspm_network_configuration_type &&
      dspm_regions == o.dspm_regions &&
      enterprise_app_url == o.enterprise_app_url &&
      environment == o.environment &&
      event_hub_settings == o.event_hub_settings &&
      key_info == o.key_info &&
      management_group_ids == o.management_group_ids &&
      microsoft_graph_permission_ids == o.microsoft_graph_permission_ids &&
      microsoft_graph_permission_ids_readonly == o.microsoft_graph_permission_ids_readonly &&
      primary_domain == o.primary_domain &&
      products == o.products &&
      registration_description == o.registration_description &&
      registration_id == o.registration_id &&
      registration_name == o.registration_name &&
      resource_name_prefix == o.resource_name_prefix &&
      resource_name_suffix == o.resource_name_suffix &&
      status == o.status &&
      subscription_ids == o.subscription_ids &&
      tags == o.tags &&
      template_version == o.template_version &&
      tenant_id == o.tenant_id &&
      tenant_name == o.tenant_name &&
      updated == o.updated
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 648

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



719
720
721
722
723
724
725
726
727
728
729
730
731
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 719

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 624

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


604
605
606
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 604

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



610
611
612
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 610

def hash
  [, additional_features, additional_properties, admin_consent_url, api_client_key_id, api_client_key_type, app_registration_id, cid, created, cs_infra_region, cs_infra_subscription_id, cs_infra_subscription_name, deleted, deployment_method, deployment_stack_host_id, deployment_stack_host_region, deployment_stack_host_type, deployment_stack_host_url, deployment_stack_name, dspm_custom_vnet_configuration, dspm_host_subscription_id, dspm_network_configuration_type, dspm_regions, enterprise_app_url, environment, event_hub_settings, key_info, management_group_ids, microsoft_graph_permission_ids, microsoft_graph_permission_ids_readonly, primary_domain, products, registration_description, registration_id, registration_name, resource_name_prefix, resource_name_suffix, status, subscription_ids, tags, template_version, tenant_id, tenant_name, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 468

def list_invalid_properties
  invalid_properties = Array.new
  if @additional_features.nil?
    invalid_properties.push('invalid value for "additional_features", additional_features cannot be nil.')
  end

  if @deployment_method.nil?
    invalid_properties.push('invalid value for "deployment_method", deployment_method cannot be nil.')
  end

  if @dspm_regions.nil?
    invalid_properties.push('invalid value for "dspm_regions", dspm_regions cannot be nil.')
  end

  if @event_hub_settings.nil?
    invalid_properties.push('invalid value for "event_hub_settings", event_hub_settings cannot be nil.')
  end

  if @key_info.nil?
    invalid_properties.push('invalid value for "key_info", key_info cannot be nil.')
  end

  if @management_group_ids.nil?
    invalid_properties.push('invalid value for "management_group_ids", management_group_ids cannot be nil.')
  end

  if @microsoft_graph_permission_ids.nil?
    invalid_properties.push('invalid value for "microsoft_graph_permission_ids", microsoft_graph_permission_ids cannot be nil.')
  end

  if @primary_domain.nil?
    invalid_properties.push('invalid value for "primary_domain", primary_domain cannot be nil.')
  end

  if @subscription_ids.nil?
    invalid_properties.push('invalid value for "subscription_ids", subscription_ids cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @tenant_name.nil?
    invalid_properties.push('invalid value for "tenant_name", tenant_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



695
696
697
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 695

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 701

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



689
690
691
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 689

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/crimson-falcon/models/azure_tenant_registration.rb', line 523

def valid?
  return false if @additional_features.nil?
  return false if @deployment_method.nil?
  dspm_network_configuration_type_validator = EnumAttributeValidator.new('String', ["managed", "managed_no_nat", "custom"])
  return false unless dspm_network_configuration_type_validator.valid?(@dspm_network_configuration_type)
  return false if @dspm_regions.nil?
  return false if @event_hub_settings.nil?
  return false if @key_info.nil?
  return false if @management_group_ids.nil?
  return false if @microsoft_graph_permission_ids.nil?
  return false if @primary_domain.nil?
  return false if @subscription_ids.nil?
  return false if @tags.nil?
  return false if @tenant_id.nil?
  return false if @tenant_name.nil?
  true
end