Class: Falcon::CaseFiles

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/case_files.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CaseFiles

Returns a new instance of CaseFiles.



35
36
37
# File 'lib/crimson-falcon/api/case_files.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/case_files.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#aggregates_file_details_post_v1(ids, body, opts = {}) ⇒ CasefilesapiAggregatesResponseV1

Get file details aggregates as specified via json in the request body.

Parameters:

  • ids (Array<String>)

    Resource IDs

  • body (Array<Object>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

Returns:



44
45
46
47
# File 'lib/crimson-falcon/api/case_files.rb', line 44

def aggregates_file_details_post_v1(ids, body, opts = {})
  data, _status_code, _headers = aggregates_file_details_post_v1_with_http_info(ids, body, opts)
  data
end

#aggregates_file_details_post_v1_with_http_info(ids, body, opts = {}) ⇒ Array<(CasefilesapiAggregatesResponseV1, Integer, Hash)>

Get file details aggregates as specified via json in the request body.

Parameters:

  • ids (Array<String>)

    Resource IDs

  • body (Array<Object>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

Returns:



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/crimson-falcon/api/case_files.rb', line 55

def aggregates_file_details_post_v1_with_http_info(ids, body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.aggregates_file_details_post_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CaseFiles.aggregates_file_details_post_v1"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.aggregates_file_details_post_v1"
  end
  # resource path
  local_var_path = '/case-files/aggregates/file-details/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiAggregatesResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.aggregates_file_details_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#aggregates_file_details_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#combined_file_details_get_v1(opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

Query file details

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

  • :limit (Integer)

    Page size

  • :offset (Integer)

    Page offset

Returns:



120
121
122
123
# File 'lib/crimson-falcon/api/case_files.rb', line 120

def combined_file_details_get_v1(opts = {})
  data, _status_code, _headers = combined_file_details_get_v1_with_http_info(opts)
  data
end

#combined_file_details_get_v1_with_http_info(opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

Query file details

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

  • :limit (Integer)

    Page size

  • :offset (Integer)

    Page offset

Returns:



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/crimson-falcon/api/case_files.rb', line 131

def combined_file_details_get_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.combined_file_details_get_v1 ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CaseFiles.combined_file_details_get_v1, must be smaller than or equal to 10.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CaseFiles.combined_file_details_get_v1, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CaseFiles.combined_file_details_get_v1, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/case-files/combined/file-details/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.combined_file_details_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#combined_file_details_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_file_details_get_v1(ids, opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

Get file details by id

Parameters:

  • ids (Array<String>)

    Resource IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



194
195
196
197
# File 'lib/crimson-falcon/api/case_files.rb', line 194

def entities_file_details_get_v1(ids, opts = {})
  data, _status_code, _headers = entities_file_details_get_v1_with_http_info(ids, opts)
  data
end

#entities_file_details_get_v1_with_http_info(ids, opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

Get file details by id

Parameters:

  • ids (Array<String>)

    Resource IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/crimson-falcon/api/case_files.rb', line 203

def entities_file_details_get_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_file_details_get_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CaseFiles.entities_file_details_get_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/file-details/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_file_details_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_file_details_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_file_details_patch_v1(body, opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

Update file details

Parameters:

Returns:



256
257
258
259
# File 'lib/crimson-falcon/api/case_files.rb', line 256

def entities_file_details_patch_v1(body, opts = {})
  data, _status_code, _headers = entities_file_details_patch_v1_with_http_info(body, opts)
  data
end

#entities_file_details_patch_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

Update file details

Parameters:

Returns:



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/crimson-falcon/api/case_files.rb', line 265

def entities_file_details_patch_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_file_details_patch_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_file_details_patch_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/file-details/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_file_details_patch_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_file_details_patch_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_files_bulk_download_post_v1(body, opts = {}) ⇒ CasefilesapiDownloadResponseV1

Download multiple existing file from case as a ZIP

Parameters:

Returns:



322
323
324
325
# File 'lib/crimson-falcon/api/case_files.rb', line 322

def entities_files_bulk_download_post_v1(body, opts = {})
  data, _status_code, _headers = entities_files_bulk_download_post_v1_with_http_info(body, opts)
  data
end

#entities_files_bulk_download_post_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiDownloadResponseV1, Integer, Hash)>

Download multiple existing file from case as a ZIP

Parameters:

Returns:



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crimson-falcon/api/case_files.rb', line 331

def entities_files_bulk_download_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_files_bulk_download_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_files_bulk_download_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/files/bulk-download/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiDownloadResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_files_bulk_download_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_files_bulk_download_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_files_delete_v1(ids, opts = {}) ⇒ CasefilesapiMSAResponseString

Delete file details by id

Parameters:

  • ids (Array<String>)

    Resource IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



388
389
390
391
# File 'lib/crimson-falcon/api/case_files.rb', line 388

def entities_files_delete_v1(ids, opts = {})
  data, _status_code, _headers = entities_files_delete_v1_with_http_info(ids, opts)
  data
end

#entities_files_delete_v1_with_http_info(ids, opts = {}) ⇒ Array<(CasefilesapiMSAResponseString, Integer, Hash)>

Delete file details by id

Parameters:

  • ids (Array<String>)

    Resource IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/crimson-falcon/api/case_files.rb', line 397

def entities_files_delete_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_files_delete_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CaseFiles.entities_files_delete_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/files/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiMSAResponseString'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_files_delete_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_files_delete_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_files_download_get_v1(id, opts = {}) ⇒ CasefilesapiDownloadResponseV1

Download existing file from case

Parameters:

  • id (String)

    Resource ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



450
451
452
453
# File 'lib/crimson-falcon/api/case_files.rb', line 450

def entities_files_download_get_v1(id, opts = {})
  data, _status_code, _headers = entities_files_download_get_v1_with_http_info(id, opts)
  data
end

#entities_files_download_get_v1_with_http_info(id, opts = {}) ⇒ Array<(CasefilesapiDownloadResponseV1, Integer, Hash)>

Download existing file from case

Parameters:

  • id (String)

    Resource ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/crimson-falcon/api/case_files.rb', line 459

def entities_files_download_get_v1_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_files_download_get_v1 ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling CaseFiles.entities_files_download_get_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/files/download/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiDownloadResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_files_download_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_files_download_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_files_download_post_v1(body, opts = {}) ⇒ CasefilesapiDownloadResponseV1

Download existing files from case

Parameters:

Returns:



512
513
514
515
# File 'lib/crimson-falcon/api/case_files.rb', line 512

def entities_files_download_post_v1(body, opts = {})
  data, _status_code, _headers = entities_files_download_post_v1_with_http_info(body, opts)
  data
end

#entities_files_download_post_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiDownloadResponseV1, Integer, Hash)>

Download existing files from case

Parameters:

Returns:



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/crimson-falcon/api/case_files.rb', line 521

def entities_files_download_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_files_download_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_files_download_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/files/download/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiDownloadResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_files_download_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_files_download_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_files_upload_post_v1(file, case_id, opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

Upload file for case

Parameters:

  • file (File)

    Local file to Upload

  • case_id (String)

    Case ID for the file

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :description (String)

    Description of the file

Returns:



580
581
582
583
# File 'lib/crimson-falcon/api/case_files.rb', line 580

def entities_files_upload_post_v1(file, case_id, opts = {})
  data, _status_code, _headers = entities_files_upload_post_v1_with_http_info(file, case_id, opts)
  data
end

#entities_files_upload_post_v1_with_http_info(file, case_id, opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

Upload file for case

Parameters:

  • file (File)

    Local file to Upload

  • case_id (String)

    Case ID for the file

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :description (String)

    Description of the file

Returns:



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/crimson-falcon/api/case_files.rb', line 591

def entities_files_upload_post_v1_with_http_info(file, case_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_files_upload_post_v1 ...'
  end
  # verify the required parameter 'file' is set
  if @api_client.config.client_side_validation && file.nil?
    fail ArgumentError, "Missing the required parameter 'file' when calling CaseFiles.entities_files_upload_post_v1"
  end
  # verify the required parameter 'case_id' is set
  if @api_client.config.client_side_validation && case_id.nil?
    fail ArgumentError, "Missing the required parameter 'case_id' when calling CaseFiles.entities_files_upload_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/files/upload/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['file'] = file
  form_params['case_id'] = case_id
  form_params['description'] = opts[:'description'] if !opts[:'description'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_files_upload_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_files_upload_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_get_rtr_file_metadata_post_v1(body, opts = {}) ⇒ CasefilesapiValidateRTRResponseV1

gets metadata for a file via RTR without retrieving it

Parameters:

Returns:



655
656
657
658
# File 'lib/crimson-falcon/api/case_files.rb', line 655

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#entities_get_rtr_file_metadata_post_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiValidateRTRResponseV1, Integer, Hash)>

gets metadata for a file via RTR without retrieving it

Parameters:

Returns:



664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
# File 'lib/crimson-falcon/api/case_files.rb', line 664

def (body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_get_rtr_file_metadata_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_get_rtr_file_metadata_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/get-rtr-file-metadata/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiValidateRTRResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_get_rtr_file_metadata_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_get_rtr_file_metadata_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_retrieve_rtr_file_post_v1(body, opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

retrieves a file from host using RTR and adds it to a case

Parameters:

Returns:



721
722
723
724
# File 'lib/crimson-falcon/api/case_files.rb', line 721

def entities_retrieve_rtr_file_post_v1(body, opts = {})
  data, _status_code, _headers = entities_retrieve_rtr_file_post_v1_with_http_info(body, opts)
  data
end

#entities_retrieve_rtr_file_post_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

retrieves a file from host using RTR and adds it to a case

Parameters:

Returns:



730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'lib/crimson-falcon/api/case_files.rb', line 730

def entities_retrieve_rtr_file_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_retrieve_rtr_file_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_retrieve_rtr_file_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/retrieve-rtr-file/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_retrieve_rtr_file_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_retrieve_rtr_file_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_retrieve_rtr_recent_file_post_v1(body, opts = {}) ⇒ CasefilesapiFileDetailsResponseV1

RetrieveRecentRTRFile retrieves a recently fetched RTR file and adds it to a case

Parameters:

Returns:



787
788
789
790
# File 'lib/crimson-falcon/api/case_files.rb', line 787

def entities_retrieve_rtr_recent_file_post_v1(body, opts = {})
  data, _status_code, _headers = entities_retrieve_rtr_recent_file_post_v1_with_http_info(body, opts)
  data
end

#entities_retrieve_rtr_recent_file_post_v1_with_http_info(body, opts = {}) ⇒ Array<(CasefilesapiFileDetailsResponseV1, Integer, Hash)>

RetrieveRecentRTRFile retrieves a recently fetched RTR file and adds it to a case

Parameters:

Returns:



796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/crimson-falcon/api/case_files.rb', line 796

def entities_retrieve_rtr_recent_file_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.entities_retrieve_rtr_recent_file_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CaseFiles.entities_retrieve_rtr_recent_file_post_v1"
  end
  # resource path
  local_var_path = '/case-files/entities/retrieve-rtr-recent-file/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiFileDetailsResponseV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.entities_retrieve_rtr_recent_file_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#entities_retrieve_rtr_recent_file_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#queries_file_details_get_v1(opts = {}) ⇒ CasefilesapiMSAResponseString

Query for ids of file details

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

  • :limit (Integer)

    Page size

  • :offset (Integer)

    Page offset

Returns:



855
856
857
858
# File 'lib/crimson-falcon/api/case_files.rb', line 855

def queries_file_details_get_v1(opts = {})
  data, _status_code, _headers = queries_file_details_get_v1_with_http_info(opts)
  data
end

#queries_file_details_get_v1_with_http_info(opts = {}) ⇒ Array<(CasefilesapiMSAResponseString, Integer, Hash)>

Query for ids of file details

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL filter expression

  • :limit (Integer)

    Page size

  • :offset (Integer)

    Page offset

Returns:



866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
# File 'lib/crimson-falcon/api/case_files.rb', line 866

def queries_file_details_get_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CaseFiles.queries_file_details_get_v1 ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CaseFiles.queries_file_details_get_v1, must be smaller than or equal to 10.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CaseFiles.queries_file_details_get_v1, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CaseFiles.queries_file_details_get_v1, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/case-files/queries/file-details/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasefilesapiMSAResponseString'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CaseFiles.queries_file_details_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CaseFiles#queries_file_details_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end