Class: Falcon::Cases

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/cases.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ Cases

Returns a new instance of Cases.



35
36
37
# File 'lib/crimson-falcon/api/cases.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/cases.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#entities_alert_evidence_post_v1(body, opts = {}) ⇒ OperationsUpdateCaseResponseVM

Adds the given list of alert evidence to the specified case.

Parameters:

Returns:



42
43
44
45
# File 'lib/crimson-falcon/api/cases.rb', line 42

def entities_alert_evidence_post_v1(body, opts = {})
  data, _status_code, _headers = entities_alert_evidence_post_v1_with_http_info(body, opts)
  data
end

#entities_alert_evidence_post_v1_with_http_info(body, opts = {}) ⇒ Array<(OperationsUpdateCaseResponseVM, Integer, Hash)>

Adds the given list of alert evidence to the specified case.

Parameters:

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/crimson-falcon/api/cases.rb', line 51

def entities_alert_evidence_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_alert_evidence_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_alert_evidence_post_v1"
  end
  # resource path
  local_var_path = '/cases/entities/alert-evidence/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsUpdateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_alert_evidence_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_alert_evidence_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_case_tags_delete_v1(id, tag, opts = {}) ⇒ OperationsUpdateCaseResponseVM

Removes the specified tags from the specified case.

Parameters:

  • id (String)

    The ID of the case to remove tags from.

  • tag (Array<String>)

    The tag to remove from the case.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



109
110
111
112
# File 'lib/crimson-falcon/api/cases.rb', line 109

def entities_case_tags_delete_v1(id, tag, opts = {})
  data, _status_code, _headers = entities_case_tags_delete_v1_with_http_info(id, tag, opts)
  data
end

#entities_case_tags_delete_v1_with_http_info(id, tag, opts = {}) ⇒ Array<(OperationsUpdateCaseResponseVM, Integer, Hash)>

Removes the specified tags from the specified case.

Parameters:

  • id (String)

    The ID of the case to remove tags from.

  • tag (Array<String>)

    The tag to remove from the case.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/crimson-falcon/api/cases.rb', line 119

def entities_case_tags_delete_v1_with_http_info(id, tag, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_case_tags_delete_v1 ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling Cases.entities_case_tags_delete_v1"
  end
  # verify the required parameter 'tag' is set
  if @api_client.config.client_side_validation && tag.nil?
    fail ArgumentError, "Missing the required parameter 'tag' when calling Cases.entities_case_tags_delete_v1"
  end
  # resource path
  local_var_path = '/cases/entities/case-tags/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = id
  query_params[:'tag'] = @api_client.build_collection_param(tag, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsUpdateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_case_tags_delete_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_case_tags_delete_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_case_tags_post_v1(body, opts = {}) ⇒ OperationsUpdateCaseResponseVM

Adds the given list of tags to the specified case.

Parameters:

Returns:



177
178
179
180
# File 'lib/crimson-falcon/api/cases.rb', line 177

def entities_case_tags_post_v1(body, opts = {})
  data, _status_code, _headers = entities_case_tags_post_v1_with_http_info(body, opts)
  data
end

#entities_case_tags_post_v1_with_http_info(body, opts = {}) ⇒ Array<(OperationsUpdateCaseResponseVM, Integer, Hash)>

Adds the given list of tags to the specified case.

Parameters:

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/crimson-falcon/api/cases.rb', line 186

def entities_case_tags_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_case_tags_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_case_tags_post_v1"
  end
  # resource path
  local_var_path = '/cases/entities/case-tags/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsUpdateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_case_tags_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_case_tags_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_cases_patch_v2(body, opts = {}) ⇒ OperationsUpdateCaseResponseVM

Updates given fields on the specified case.

Parameters:

Returns:



243
244
245
246
# File 'lib/crimson-falcon/api/cases.rb', line 243

def entities_cases_patch_v2(body, opts = {})
  data, _status_code, _headers = entities_cases_patch_v2_with_http_info(body, opts)
  data
end

#entities_cases_patch_v2_with_http_info(body, opts = {}) ⇒ Array<(OperationsUpdateCaseResponseVM, Integer, Hash)>

Updates given fields on the specified case.

Parameters:

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/crimson-falcon/api/cases.rb', line 252

def entities_cases_patch_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_cases_patch_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_cases_patch_v2"
  end
  # resource path
  local_var_path = '/cases/entities/cases/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsUpdateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_cases_patch_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_cases_patch_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_cases_post_v2(body, opts = {}) ⇒ OperationsGetCasesByIDsResponseVM

Retrieves all Cases given their IDs.

Parameters:

Returns:



309
310
311
312
# File 'lib/crimson-falcon/api/cases.rb', line 309

def entities_cases_post_v2(body, opts = {})
  data, _status_code, _headers = entities_cases_post_v2_with_http_info(body, opts)
  data
end

#entities_cases_post_v2_with_http_info(body, opts = {}) ⇒ Array<(OperationsGetCasesByIDsResponseVM, Integer, Hash)>

Retrieves all Cases given their IDs.

Parameters:

Returns:



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/crimson-falcon/api/cases.rb', line 318

def entities_cases_post_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_cases_post_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_cases_post_v2"
  end
  # resource path
  local_var_path = '/cases/entities/cases/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsGetCasesByIDsResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_cases_post_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_cases_post_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_cases_put_v2(body, opts = {}) ⇒ OperationsCreateCaseResponseVM

Creates the given Case

Parameters:

Returns:



375
376
377
378
# File 'lib/crimson-falcon/api/cases.rb', line 375

def entities_cases_put_v2(body, opts = {})
  data, _status_code, _headers = entities_cases_put_v2_with_http_info(body, opts)
  data
end

#entities_cases_put_v2_with_http_info(body, opts = {}) ⇒ Array<(OperationsCreateCaseResponseVM, Integer, Hash)>

Creates the given Case

Parameters:

Returns:



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/crimson-falcon/api/cases.rb', line 384

def entities_cases_put_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_cases_put_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_cases_put_v2"
  end
  # resource path
  local_var_path = '/cases/entities/cases/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsCreateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_cases_put_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_cases_put_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_event_evidence_post_v1(body, opts = {}) ⇒ OperationsUpdateCaseResponseVM

Adds the given list of event evidence to the specified case.

Parameters:

Returns:



441
442
443
444
# File 'lib/crimson-falcon/api/cases.rb', line 441

def entities_event_evidence_post_v1(body, opts = {})
  data, _status_code, _headers = entities_event_evidence_post_v1_with_http_info(body, opts)
  data
end

#entities_event_evidence_post_v1_with_http_info(body, opts = {}) ⇒ Array<(OperationsUpdateCaseResponseVM, Integer, Hash)>

Adds the given list of event evidence to the specified case.

Parameters:

Returns:



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/crimson-falcon/api/cases.rb', line 450

def entities_event_evidence_post_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.entities_event_evidence_post_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling Cases.entities_event_evidence_post_v1"
  end
  # resource path
  local_var_path = '/cases/entities/event-evidence/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OperationsUpdateCaseResponseVM'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.entities_event_evidence_post_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#entities_event_evidence_post_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#queries_cases_get_v1(opts = {}) ⇒ CasesapiGetQueriesCasesV1Response

Retrieves all Cases IDs that match a given query.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The maximum number of Cases to return in this response (default: 100; max: 10000). Use this parameter together with the &#x60;offset&#x60; parameter to manage pagination of the results.

  • :offset (Integer)

    The first case to return, where &#x60;0&#x60; is the latest case. Use with the &#x60;offset&#x60; parameter to manage pagination of results.

  • :sort (String)

    Sort parameter takes the form &lt;field|direction&gt;. Direction can be either &#x60;asc&#x60; (ascending) or &#x60;desc&#x60; (descending) order. For example: &#x60;status|asc&#x60; or &#x60;status|desc&#x60;. The sorting fields can be any keyword field that is part of #domain.Case except for the text based fields. Most commonly used fields are status, cid, created_timestamp, updated_timestamp, assigned_to_name, assigned_to_userid, assigned_to_uuid, tags If the fields are missing from the Cases, the service will fallback to its default ordering

  • :filter (String)

    Filter Cases using a query in Falcon Query Language (FQL).Filter fields can be any keyword field that is part of #domain.Case An asterisk wildcard &#x60;*&#x60; includes all results. Empty value means to not filter on anything. Most commonly used filter fields that supports exact match: cid, id … Most commonly used filter fields that supports wildcard (*): assigned_to_name, assigned_to_uuid… Most commonly filter fields that supports range comparisons (&gt;, &lt;, &gt;&#x3D;, &lt;&#x3D;): created_timestamp, updated_timestamp… All filter fields and operations support negation (!). The full list of valid filter options is extensive. Review it in our [documentation inside the Falcon console](falcon.crowdstrike.com/documentation/45/falcon-query-language-fql).

  • :q (String)

    Search all Case metadata for the provided string

Returns:



511
512
513
514
# File 'lib/crimson-falcon/api/cases.rb', line 511

def queries_cases_get_v1(opts = {})
  data, _status_code, _headers = queries_cases_get_v1_with_http_info(opts)
  data
end

#queries_cases_get_v1_with_http_info(opts = {}) ⇒ Array<(CasesapiGetQueriesCasesV1Response, Integer, Hash)>

Retrieves all Cases IDs that match a given query.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The maximum number of Cases to return in this response (default: 100; max: 10000). Use this parameter together with the &#x60;offset&#x60; parameter to manage pagination of the results.

  • :offset (Integer)

    The first case to return, where &#x60;0&#x60; is the latest case. Use with the &#x60;offset&#x60; parameter to manage pagination of results.

  • :sort (String)

    Sort parameter takes the form &lt;field|direction&gt;. Direction can be either &#x60;asc&#x60; (ascending) or &#x60;desc&#x60; (descending) order. For example: &#x60;status|asc&#x60; or &#x60;status|desc&#x60;. The sorting fields can be any keyword field that is part of #domain.Case except for the text based fields. Most commonly used fields are status, cid, created_timestamp, updated_timestamp, assigned_to_name, assigned_to_userid, assigned_to_uuid, tags If the fields are missing from the Cases, the service will fallback to its default ordering

  • :filter (String)

    Filter Cases using a query in Falcon Query Language (FQL).Filter fields can be any keyword field that is part of #domain.Case An asterisk wildcard &#x60;*&#x60; includes all results. Empty value means to not filter on anything. Most commonly used filter fields that supports exact match: cid, id … Most commonly used filter fields that supports wildcard (*): assigned_to_name, assigned_to_uuid… Most commonly filter fields that supports range comparisons (&gt;, &lt;, &gt;&#x3D;, &lt;&#x3D;): created_timestamp, updated_timestamp… All filter fields and operations support negation (!). The full list of valid filter options is extensive. Review it in our [documentation inside the Falcon console](falcon.crowdstrike.com/documentation/45/falcon-query-language-fql).

  • :q (String)

    Search all Case metadata for the provided string

Returns:



524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/crimson-falcon/api/cases.rb', line 524

def queries_cases_get_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Cases.queries_cases_get_v1 ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Cases.queries_cases_get_v1, must be smaller than or equal to 10000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Cases.queries_cases_get_v1, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/cases/queries/cases/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CasesapiGetQueriesCasesV1Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"Cases.queries_cases_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Cases#queries_cases_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end