Class: Falcon::CertificateBasedExclusions

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/certificate_based_exclusions.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CertificateBasedExclusions

Returns a new instance of CertificateBasedExclusions.



35
36
37
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#cb_exclusions_create_v1(body, opts = {}) ⇒ ApiCertBasedExclusionRespV1

Create new Certificate Based Exclusions.

Parameters:

Returns:



42
43
44
45
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 42

def cb_exclusions_create_v1(body, opts = {})
  data, _status_code, _headers = cb_exclusions_create_v1_with_http_info(body, opts)
  data
end

#cb_exclusions_create_v1_with_http_info(body, opts = {}) ⇒ Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>

Create new Certificate Based Exclusions.

Parameters:

Returns:

  • (Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>)

    ApiCertBasedExclusionRespV1 data, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 51

def cb_exclusions_create_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.cb_exclusions_create_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CertificateBasedExclusions.cb_exclusions_create_v1"
  end
  # resource path
  local_var_path = '/exclusions/entities/cert-based-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'ApiCertBasedExclusionRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.cb_exclusions_create_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#cb_exclusions_create_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cb_exclusions_delete_v1(ids, opts = {}) ⇒ ApiCertBasedExclusionRespV1

Delete the exclusions by id

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    The comment why these exclusions were deleted

Returns:



109
110
111
112
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 109

def cb_exclusions_delete_v1(ids, opts = {})
  data, _status_code, _headers = cb_exclusions_delete_v1_with_http_info(ids, opts)
  data
end

#cb_exclusions_delete_v1_with_http_info(ids, opts = {}) ⇒ Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>

Delete the exclusions by id

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    The comment why these exclusions were deleted

Returns:

  • (Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>)

    ApiCertBasedExclusionRespV1 data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 119

def cb_exclusions_delete_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.cb_exclusions_delete_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CertificateBasedExclusions.cb_exclusions_delete_v1"
  end
  # resource path
  local_var_path = '/exclusions/entities/cert-based-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApiCertBasedExclusionRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.cb_exclusions_delete_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#cb_exclusions_delete_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cb_exclusions_get_v1(ids, opts = {}) ⇒ ApiCertBasedExclusionRespV1

Find all exclusion IDs matching the query with filter

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



173
174
175
176
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 173

def cb_exclusions_get_v1(ids, opts = {})
  data, _status_code, _headers = cb_exclusions_get_v1_with_http_info(ids, opts)
  data
end

#cb_exclusions_get_v1_with_http_info(ids, opts = {}) ⇒ Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>

Find all exclusion IDs matching the query with filter

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>)

    ApiCertBasedExclusionRespV1 data, response status code and response headers



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 182

def cb_exclusions_get_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.cb_exclusions_get_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CertificateBasedExclusions.cb_exclusions_get_v1"
  end
  # resource path
  local_var_path = '/exclusions/entities/cert-based-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApiCertBasedExclusionRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.cb_exclusions_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#cb_exclusions_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cb_exclusions_query_v1(opts = {}) ⇒ MsaspecQueryResponse

Search for cert-based exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-100]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:



238
239
240
241
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 238

def cb_exclusions_query_v1(opts = {})
  data, _status_code, _headers = cb_exclusions_query_v1_with_http_info(opts)
  data
end

#cb_exclusions_query_v1_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Search for cert-based exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-100]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 250

def cb_exclusions_query_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.cb_exclusions_query_v1 ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CertificateBasedExclusions.cb_exclusions_query_v1, must be smaller than or equal to 100.'
  end

  allowable_values = ["created_by", "created_on", "modified_by", "modified_on", "name"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/exclusions/queries/cert-based-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.cb_exclusions_query_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#cb_exclusions_query_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cb_exclusions_update_v1(body, opts = {}) ⇒ ApiCertBasedExclusionRespV1

Updates existing Certificate Based Exclusions

Parameters:

Returns:



310
311
312
313
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 310

def cb_exclusions_update_v1(body, opts = {})
  data, _status_code, _headers = cb_exclusions_update_v1_with_http_info(body, opts)
  data
end

#cb_exclusions_update_v1_with_http_info(body, opts = {}) ⇒ Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>

Updates existing Certificate Based Exclusions

Parameters:

Returns:

  • (Array<(ApiCertBasedExclusionRespV1, Integer, Hash)>)

    ApiCertBasedExclusionRespV1 data, response status code and response headers



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 319

def cb_exclusions_update_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.cb_exclusions_update_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CertificateBasedExclusions.cb_exclusions_update_v1"
  end
  # resource path
  local_var_path = '/exclusions/entities/cert-based-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'ApiCertBasedExclusionRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.cb_exclusions_update_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#cb_exclusions_update_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#certificates_get_v1(ids, opts = {}) ⇒ ApiRespCertificatesV1

Retrieves certificate signing information for a file

Parameters:

  • ids (String)

    The SHA256 Hash of the file to retrieve certificate signing info for

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



376
377
378
379
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 376

def certificates_get_v1(ids, opts = {})
  data, _status_code, _headers = certificates_get_v1_with_http_info(ids, opts)
  data
end

#certificates_get_v1_with_http_info(ids, opts = {}) ⇒ Array<(ApiRespCertificatesV1, Integer, Hash)>

Retrieves certificate signing information for a file

Parameters:

  • ids (String)

    The SHA256 Hash of the file to retrieve certificate signing info for

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ApiRespCertificatesV1, Integer, Hash)>)

    ApiRespCertificatesV1 data, response status code and response headers



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/crimson-falcon/api/certificate_based_exclusions.rb', line 385

def certificates_get_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CertificateBasedExclusions.certificates_get_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling CertificateBasedExclusions.certificates_get_v1"
  end
  # resource path
  local_var_path = '/exclusions/entities/certificates/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = ids

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApiRespCertificatesV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CertificateBasedExclusions.certificates_get_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CertificateBasedExclusions#certificates_get_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end