Class: Falcon::ClientJobStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/client_job_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClientJobStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/crimson-falcon/models/client_job_status.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ClientJobStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ClientJobStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'content_length')
    self.content_length = attributes[:'content_length']
  end

  if attributes.key?(:'digest_algo')
    self.digest_algo = attributes[:'digest_algo']
  end

  if attributes.key?(:'digest_hex')
    self.digest_hex = attributes[:'digest_hex']
  end

  if attributes.key?(:'event_count')
    self.event_count = attributes[:'event_count']
  end

  if attributes.key?(:'file_link')
    self.file_link = attributes[:'file_link']
  end

  if attributes.key?(:'filtered_event_count')
    self.filtered_event_count = attributes[:'filtered_event_count']
  end

  if attributes.key?(:'job_id')
    self.job_id = attributes[:'job_id']
  end

  if attributes.key?(:'job_url')
    self.job_url = attributes[:'job_url']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'percent_complete')
    self.percent_complete = attributes[:'percent_complete']
  end

  if attributes.key?(:'result_count')
    self.result_count = attributes[:'result_count']
  end

  if attributes.key?(:'run_duration')
    self.run_duration = attributes[:'run_duration']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#content_lengthObject

Returns the value of attribute content_length.



34
35
36
# File 'lib/crimson-falcon/models/client_job_status.rb', line 34

def content_length
  @content_length
end

#digest_algoObject

Returns the value of attribute digest_algo.



36
37
38
# File 'lib/crimson-falcon/models/client_job_status.rb', line 36

def digest_algo
  @digest_algo
end

#digest_hexObject

Returns the value of attribute digest_hex.



38
39
40
# File 'lib/crimson-falcon/models/client_job_status.rb', line 38

def digest_hex
  @digest_hex
end

#event_countObject

Returns the value of attribute event_count.



40
41
42
# File 'lib/crimson-falcon/models/client_job_status.rb', line 40

def event_count
  @event_count
end

Returns the value of attribute file_link.



42
43
44
# File 'lib/crimson-falcon/models/client_job_status.rb', line 42

def file_link
  @file_link
end

#filtered_event_countObject

Returns the value of attribute filtered_event_count.



44
45
46
# File 'lib/crimson-falcon/models/client_job_status.rb', line 44

def filtered_event_count
  @filtered_event_count
end

#job_idObject

Returns the value of attribute job_id.



46
47
48
# File 'lib/crimson-falcon/models/client_job_status.rb', line 46

def job_id
  @job_id
end

#job_urlObject

Returns the value of attribute job_url.



48
49
50
# File 'lib/crimson-falcon/models/client_job_status.rb', line 48

def job_url
  @job_url
end

#messageObject

Returns the value of attribute message.



50
51
52
# File 'lib/crimson-falcon/models/client_job_status.rb', line 50

def message
  @message
end

#percent_completeObject

Returns the value of attribute percent_complete.



52
53
54
# File 'lib/crimson-falcon/models/client_job_status.rb', line 52

def percent_complete
  @percent_complete
end

#result_countObject

Returns the value of attribute result_count.



54
55
56
# File 'lib/crimson-falcon/models/client_job_status.rb', line 54

def result_count
  @result_count
end

#run_durationObject

Returns the value of attribute run_duration.



56
57
58
# File 'lib/crimson-falcon/models/client_job_status.rb', line 56

def run_duration
  @run_duration
end

#statusObject

Returns the value of attribute status.



58
59
60
# File 'lib/crimson-falcon/models/client_job_status.rb', line 58

def status
  @status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/client_job_status.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/client_job_status.rb', line 61

def self.attribute_map
  {
    :'content_length' => :'content_length',
    :'digest_algo' => :'digest_algo',
    :'digest_hex' => :'digest_hex',
    :'event_count' => :'event_count',
    :'file_link' => :'file_link',
    :'filtered_event_count' => :'filtered_event_count',
    :'job_id' => :'job_id',
    :'job_url' => :'job_url',
    :'message' => :'message',
    :'percent_complete' => :'percent_complete',
    :'result_count' => :'result_count',
    :'run_duration' => :'run_duration',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
# File 'lib/crimson-falcon/models/client_job_status.rb', line 230

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/client_job_status.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/client_job_status.rb', line 85

def self.openapi_types
  {
    :'content_length' => :'Integer',
    :'digest_algo' => :'String',
    :'digest_hex' => :'String',
    :'event_count' => :'Integer',
    :'file_link' => :'String',
    :'filtered_event_count' => :'Integer',
    :'job_id' => :'String',
    :'job_url' => :'String',
    :'message' => :'String',
    :'percent_complete' => :'Integer',
    :'result_count' => :'Integer',
    :'run_duration' => :'Float',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/crimson-falcon/models/client_job_status.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      content_length == o.content_length &&
      digest_algo == o.digest_algo &&
      digest_hex == o.digest_hex &&
      event_count == o.event_count &&
      file_link == o.file_link &&
      filtered_event_count == o.filtered_event_count &&
      job_id == o.job_id &&
      job_url == o.job_url &&
      message == o.message &&
      percent_complete == o.percent_complete &&
      result_count == o.result_count &&
      run_duration == o.run_duration &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/crimson-falcon/models/client_job_status.rb', line 261

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/crimson-falcon/models/client_job_status.rb', line 332

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/crimson-falcon/models/client_job_status.rb', line 237

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/crimson-falcon/models/client_job_status.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/crimson-falcon/models/client_job_status.rb', line 223

def hash
  [content_length, digest_algo, digest_hex, event_count, file_link, filtered_event_count, job_id, job_url, message, percent_complete, result_count, run_duration, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
# File 'lib/crimson-falcon/models/client_job_status.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  if @job_id.nil?
    invalid_properties.push('invalid value for "job_id", job_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
# File 'lib/crimson-falcon/models/client_job_status.rb', line 308

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/crimson-falcon/models/client_job_status.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



302
303
304
# File 'lib/crimson-falcon/models/client_job_status.rb', line 302

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
# File 'lib/crimson-falcon/models/client_job_status.rb', line 190

def valid?
  return false if @job_id.nil?
  true
end