Class: Falcon::CloudAwsRegistration

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/cloud_aws_registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CloudAwsRegistration

Returns a new instance of CloudAwsRegistration.



35
36
37
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#cloud_registration_aws_create_account(body, opts = {}) ⇒ RestAWSAccountCreateResponseExtV1

Creates a new account in our system for a customer.

Parameters:

Returns:



42
43
44
45
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 42

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#cloud_registration_aws_create_account_with_http_info(body, opts = {}) ⇒ Array<(RestAWSAccountCreateResponseExtV1, Integer, Hash)>

Creates a new account in our system for a customer.

Parameters:

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 51

def (body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_create_account ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CloudAwsRegistration.cloud_registration_aws_create_account"
  end
  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSAccountCreateResponseExtV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_create_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_create_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_delete_account(opts = {}) ⇒ MsaspecResponseFields

Deletes an existing AWS account or organization in our system.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    AWS account IDs to remove

  • :organization_ids (Array<String>)

    AWS organization IDs to remove

Returns:



109
110
111
112
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 109

def (opts = {})
  data, _status_code, _headers = (opts)
  data
end

#cloud_registration_aws_delete_account_with_http_info(opts = {}) ⇒ Array<(MsaspecResponseFields, Integer, Hash)>

Deletes an existing AWS account or organization in our system.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    AWS account IDs to remove

  • :organization_ids (Array<String>)

    AWS organization IDs to remove

Returns:

  • (Array<(MsaspecResponseFields, Integer, Hash)>)

    MsaspecResponseFields data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 119

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_delete_account ...'
  end
  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil?
  query_params[:'organization-ids'] = @api_client.build_collection_param(opts[:'organization_ids'], :multi) if !opts[:'organization_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecResponseFields'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_delete_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_delete_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_get_accounts(opts = {}) ⇒ RestAWSAccountCreateResponseExtV1

Retrieve existing AWS accounts by account IDs or organization IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    AWS account IDs to filter

  • :organization_ids (Array<String>)

    AWS organization IDs to filter

Returns:



170
171
172
173
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 170

def cloud_registration_aws_get_accounts(opts = {})
  data, _status_code, _headers = cloud_registration_aws_get_accounts_with_http_info(opts)
  data
end

#cloud_registration_aws_get_accounts_with_http_info(opts = {}) ⇒ Array<(RestAWSAccountCreateResponseExtV1, Integer, Hash)>

Retrieve existing AWS accounts by account IDs or organization IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    AWS account IDs to filter

  • :organization_ids (Array<String>)

    AWS organization IDs to filter

Returns:



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 180

def cloud_registration_aws_get_accounts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_get_accounts ...'
  end
  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil?
  query_params[:'organization-ids'] = @api_client.build_collection_param(opts[:'organization_ids'], :multi) if !opts[:'organization_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSAccountCreateResponseExtV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_get_accounts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_get_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_query_accounts(products, features, opts = {}) ⇒ RestAWSAccountQueryResponseExtV1

Retrieve existing AWS accounts by account IDs

Parameters:

  • products (Array<String>)

    Products registered for an account

  • features (Array<String>)

    Features registered for an account

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organization_ids (Array<String>)

    Organization IDs used to filter accounts

  • :account_status (String)

    Account status to filter results by.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 100 is used. When larger than 500, 500 is used. (default to 100)

  • :offset (Integer)

    The offset to start retrieving records from.

  • :group_by (String)

    Field to group by.

Returns:



236
237
238
239
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 236

def cloud_registration_aws_query_accounts(products, features, opts = {})
  data, _status_code, _headers = cloud_registration_aws_query_accounts_with_http_info(products, features, opts)
  data
end

#cloud_registration_aws_query_accounts_with_http_info(products, features, opts = {}) ⇒ Array<(RestAWSAccountQueryResponseExtV1, Integer, Hash)>

Retrieve existing AWS accounts by account IDs

Parameters:

  • products (Array<String>)

    Products registered for an account

  • features (Array<String>)

    Features registered for an account

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organization_ids (Array<String>)

    Organization IDs used to filter accounts

  • :account_status (String)

    Account status to filter results by.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 100 is used. When larger than 500, 500 is used. (default to 100)

  • :offset (Integer)

    The offset to start retrieving records from.

  • :group_by (String)

    Field to group by.

Returns:



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 251

def cloud_registration_aws_query_accounts_with_http_info(products, features, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_query_accounts ...'
  end
  # verify the required parameter 'products' is set
  if @api_client.config.client_side_validation && products.nil?
    fail ArgumentError, "Missing the required parameter 'products' when calling CloudAwsRegistration.cloud_registration_aws_query_accounts"
  end
  # verify the required parameter 'features' is set
  if @api_client.config.client_side_validation && features.nil?
    fail ArgumentError, "Missing the required parameter 'features' when calling CloudAwsRegistration.cloud_registration_aws_query_accounts"
  end
  allowable_values = ["provisioned", "operational"]
  if @api_client.config.client_side_validation && opts[:'account_status'] && !allowable_values.include?(opts[:'account_status'])
    fail ArgumentError, "invalid value for \"account_status\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 500
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudAwsRegistration.cloud_registration_aws_query_accounts, must be smaller than or equal to 500.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudAwsRegistration.cloud_registration_aws_query_accounts, must be greater than or equal to 0.'
  end

  allowable_values = ["organization"]
  if @api_client.config.client_side_validation && opts[:'group_by'] && !allowable_values.include?(opts[:'group_by'])
    fail ArgumentError, "invalid value for \"group_by\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/cloud-security-registration-aws/queries/account/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'products'] = @api_client.build_collection_param(products, :multi)
  query_params[:'features'] = @api_client.build_collection_param(features, :multi)
  query_params[:'organization-ids'] = @api_client.build_collection_param(opts[:'organization_ids'], :multi) if !opts[:'organization_ids'].nil?
  query_params[:'account-status'] = opts[:'account_status'] if !opts[:'account_status'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'group_by'] = opts[:'group_by'] if !opts[:'group_by'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSAccountQueryResponseExtV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_query_accounts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_query_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_trigger_health_check(opts = {}) ⇒ RestAWSHealthCheckTriggerResponseExtV1

Trigger health check scan for AWS accounts

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_ids (Array<String>)

    AWS Account IDs.

  • :organization_ids (Array<String>)

    Organization IDs

Returns:



331
332
333
334
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 331

def cloud_registration_aws_trigger_health_check(opts = {})
  data, _status_code, _headers = cloud_registration_aws_trigger_health_check_with_http_info(opts)
  data
end

#cloud_registration_aws_trigger_health_check_with_http_info(opts = {}) ⇒ Array<(RestAWSHealthCheckTriggerResponseExtV1, Integer, Hash)>

Trigger health check scan for AWS accounts

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_ids (Array<String>)

    AWS Account IDs.

  • :organization_ids (Array<String>)

    Organization IDs

Returns:



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 341

def cloud_registration_aws_trigger_health_check_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_trigger_health_check ...'
  end
  if @api_client.config.client_side_validation && !opts[:'account_ids'].nil? && opts[:'account_ids'].length > 50
    fail ArgumentError, 'invalid value for "opts[:"account_ids"]" when calling CloudAwsRegistration.cloud_registration_aws_trigger_health_check, number of items must be less than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'organization_ids'].nil? && opts[:'organization_ids'].length > 10
    fail ArgumentError, 'invalid value for "opts[:"organization_ids"]" when calling CloudAwsRegistration.cloud_registration_aws_trigger_health_check, number of items must be less than or equal to 10.'
  end

  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account-scans/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account-ids'] = @api_client.build_collection_param(opts[:'account_ids'], :multi) if !opts[:'account_ids'].nil?
  query_params[:'organization-ids'] = @api_client.build_collection_param(opts[:'organization_ids'], :multi) if !opts[:'organization_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSHealthCheckTriggerResponseExtV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_trigger_health_check",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_trigger_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_update_account(body, opts = {}) ⇒ RestAWSAccountCreateResponseExtV1

Patches a existing account in our system for a customer.

Parameters:

Returns:



399
400
401
402
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 399

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#cloud_registration_aws_update_account_with_http_info(body, opts = {}) ⇒ Array<(RestAWSAccountCreateResponseExtV1, Integer, Hash)>

Patches a existing account in our system for a customer.

Parameters:

Returns:



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 408

def (body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_update_account ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CloudAwsRegistration.cloud_registration_aws_update_account"
  end
  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSAccountCreateResponseExtV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_update_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_update_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_registration_aws_validate_accounts(opts = {}) ⇒ RestAWSAccountValidationResponse

Validates the AWS account registration status, and discover organization child accounts if organization is specified

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    AWS Account ID. organization-id shouldn&#39;t be specified if this is specified

  • :iam_role_arn (String)

    IAM Role ARN

  • :organization_id (String)

    AWS organization ID to validate master account. account-id shouldn&#39;t be specified if this is specified

Returns:



467
468
469
470
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 467

def cloud_registration_aws_validate_accounts(opts = {})
  data, _status_code, _headers = cloud_registration_aws_validate_accounts_with_http_info(opts)
  data
end

#cloud_registration_aws_validate_accounts_with_http_info(opts = {}) ⇒ Array<(RestAWSAccountValidationResponse, Integer, Hash)>

Validates the AWS account registration status, and discover organization child accounts if organization is specified

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    AWS Account ID. organization-id shouldn&#39;t be specified if this is specified

  • :iam_role_arn (String)

    IAM Role ARN

  • :organization_id (String)

    AWS organization ID to validate master account. account-id shouldn&#39;t be specified if this is specified

Returns:



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/crimson-falcon/api/cloud_aws_registration.rb', line 478

def cloud_registration_aws_validate_accounts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudAwsRegistration.cloud_registration_aws_validate_accounts ...'
  end
  pattern = Regexp.new(/^\d{12}$/)
  if @api_client.config.client_side_validation && !opts[:'account_id'].nil? && opts[:'account_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"account_id\"]' when calling CloudAwsRegistration.cloud_registration_aws_validate_accounts, must conform to the pattern #{pattern}."
  end

  pattern = Regexp.new(/^arn:aws:iam::\d{12}:role\/.+/)
  if @api_client.config.client_side_validation && !opts[:'iam_role_arn'].nil? && opts[:'iam_role_arn'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"iam_role_arn\"]' when calling CloudAwsRegistration.cloud_registration_aws_validate_accounts, must conform to the pattern #{pattern}."
  end

  pattern = Regexp.new(/^o-[0-9a-z]{10,32}$/)
  if @api_client.config.client_side_validation && !opts[:'organization_id'].nil? && opts[:'organization_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"organization_id\"]' when calling CloudAwsRegistration.cloud_registration_aws_validate_accounts, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/cloud-security-registration-aws/entities/account/validate/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account-id'] = opts[:'account_id'] if !opts[:'account_id'].nil?
  query_params[:'iam-role-arn'] = opts[:'iam_role_arn'] if !opts[:'iam_role_arn'].nil?
  query_params[:'organization-id'] = opts[:'organization_id'] if !opts[:'organization_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RestAWSAccountValidationResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudAwsRegistration.cloud_registration_aws_validate_accounts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudAwsRegistration#cloud_registration_aws_validate_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end