Class: Falcon::CloudSecurityAssets

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/cloud_security_assets.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CloudSecurityAssets

Returns a new instance of CloudSecurityAssets.



35
36
37
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#cloud_security_assets_combined_application_findings(type, opts = {}) ⇒ AssetsGetResourceApplicationFindingsResponse

Get findings for an application resource with pagination

Parameters:

  • type (String)

    Finding type

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :crn (String)

    Deprecated: Use 'gcrn' instead. Application CRN

  • :gcrn (String)

    Application GCRN

  • :filter (String)

    FQL string to filter findings

  • :offset (Integer)

    Pagination offset (default to 0)

  • :limit (Integer)

    Page size (default to 50)

Returns:



47
48
49
50
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 47

def cloud_security_assets_combined_application_findings(type, opts = {})
  data, _status_code, _headers = cloud_security_assets_combined_application_findings_with_http_info(type, opts)
  data
end

#cloud_security_assets_combined_application_findings_with_http_info(type, opts = {}) ⇒ Array<(AssetsGetResourceApplicationFindingsResponse, Integer, Hash)>

Get findings for an application resource with pagination

Parameters:

  • type (String)

    Finding type

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :crn (String)

    Deprecated: Use &#39;gcrn&#39; instead. Application CRN

  • :gcrn (String)

    Application GCRN

  • :filter (String)

    FQL string to filter findings

  • :offset (Integer)

    Pagination offset (default to 0)

  • :limit (Integer)

    Page size (default to 50)

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 61

def cloud_security_assets_combined_application_findings_with_http_info(type, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityAssets.cloud_security_assets_combined_application_findings ...'
  end
  # verify the required parameter 'type' is set
  if @api_client.config.client_side_validation && type.nil?
    fail ArgumentError, "Missing the required parameter 'type' when calling CloudSecurityAssets.cloud_security_assets_combined_application_findings"
  end
  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityAssets.cloud_security_assets_combined_application_findings, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_combined_application_findings, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_combined_application_findings, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/cloud-security-assets/combined/application-findings/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type'] = type
  query_params[:'crn'] = opts[:'crn'] if !opts[:'crn'].nil?
  query_params[:'gcrn'] = opts[:'gcrn'] if !opts[:'gcrn'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AssetsGetResourceApplicationFindingsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityAssets.cloud_security_assets_combined_application_findings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityAssets#cloud_security_assets_combined_application_findings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_security_assets_combined_compliance_by_account(opts = {}) ⇒ AssetsComplianceResponse

Gets combined compliance data aggregated by account and region. Results can be filtered and sorted.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter on asset contents. Filterable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;assessment_id&#x60; - &#x60;business_impact&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;compliant&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.extension.status&#x60; - &#x60;control.framework&#x60; - &#x60;control.name&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;environment&#x60; - &#x60;last_evaluated&#x60; - &#x60;region&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_provider&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severities&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags_string&#x60;

  • :sort (String)

    Sort expression in format: field|direction (e.g., last_evaluated|desc). Allowed sort fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;assessment_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.framework&#x60; - &#x60;control.name&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;last_evaluated&#x60; - &#x60;region&#x60; - &#x60;resource_counts.compliant&#x60; - &#x60;resource_counts.non_compliant&#x60; - &#x60;resource_counts.total&#x60; - &#x60;resource_provider&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60;

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 20 is used. When larger than 10000, 10000 is used. (default to 20)

  • :offset (Integer)

    Offset returned controls. Use only one of &#39;offset&#39; and &#39;after&#39; parameter for paginating. &#39;offset&#39; can only be used on offsets &lt; 10,000. For paginating through the entire result set, use &#39;after&#39; parameter

  • :after (String)

    token-based pagination. use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

  • :include_failing_iom_severity_counts (Boolean)

    Include counts of failing IOMs by severity level (default to false)

Returns:



136
137
138
139
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 136

def (opts = {})
  data, _status_code, _headers = (opts)
  data
end

#cloud_security_assets_combined_compliance_by_account_with_http_info(opts = {}) ⇒ Array<(AssetsComplianceResponse, Integer, Hash)>

Gets combined compliance data aggregated by account and region. Results can be filtered and sorted.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter on asset contents. Filterable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;assessment_id&#x60; - &#x60;business_impact&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;compliant&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.extension.status&#x60; - &#x60;control.framework&#x60; - &#x60;control.name&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;environment&#x60; - &#x60;last_evaluated&#x60; - &#x60;region&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_provider&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severities&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags_string&#x60;

  • :sort (String)

    Sort expression in format: field|direction (e.g., last_evaluated|desc). Allowed sort fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;assessment_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.framework&#x60; - &#x60;control.name&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;last_evaluated&#x60; - &#x60;region&#x60; - &#x60;resource_counts.compliant&#x60; - &#x60;resource_counts.non_compliant&#x60; - &#x60;resource_counts.total&#x60; - &#x60;resource_provider&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60;

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 20 is used. When larger than 10000, 10000 is used. (default to 20)

  • :offset (Integer)

    Offset returned controls. Use only one of &#39;offset&#39; and &#39;after&#39; parameter for paginating. &#39;offset&#39; can only be used on offsets &lt; 10,000. For paginating through the entire result set, use &#39;after&#39; parameter

  • :after (String)

    token-based pagination. use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

  • :include_failing_iom_severity_counts (Boolean)

    Include counts of failing IOMs by severity level (default to false)

Returns:

  • (Array<(AssetsComplianceResponse, Integer, Hash)>)

    AssetsComplianceResponse data, response status code and response headers



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 150

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account, must be smaller than or equal to 10000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] > 9999
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account, must be smaller than or equal to 9999.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/cloud-security-assets/combined/compliance-controls/by-account-region-and-resource-type/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'include_failing_iom_severity_counts'] = opts[:'include_failing_iom_severity_counts'] if !opts[:'include_failing_iom_severity_counts'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AssetsComplianceResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityAssets.cloud_security_assets_combined_compliance_by_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityAssets#cloud_security_assets_combined_compliance_by_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_security_assets_entities_get(opts = {}) ⇒ AssetsGetResourcesResponse

Gets raw resources based on the provided IDs param. Maximum of 100 resources can be requested with this method. Use POST method with same path if more are required.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    List of assets to return (maximum 100 IDs allowed). Use POST method with same path if more entities are required.

Returns:



220
221
222
223
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 220

def cloud_security_assets_entities_get(opts = {})
  data, _status_code, _headers = cloud_security_assets_entities_get_with_http_info(opts)
  data
end

#cloud_security_assets_entities_get_with_http_info(opts = {}) ⇒ Array<(AssetsGetResourcesResponse, Integer, Hash)>

Gets raw resources based on the provided IDs param. Maximum of 100 resources can be requested with this method. Use POST method with same path if more are required.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    List of assets to return (maximum 100 IDs allowed). Use POST method with same path if more entities are required.

Returns:

  • (Array<(AssetsGetResourcesResponse, Integer, Hash)>)

    AssetsGetResourcesResponse data, response status code and response headers



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 229

def cloud_security_assets_entities_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityAssets.cloud_security_assets_entities_get ...'
  end
  # resource path
  local_var_path = '/cloud-security-assets/entities/resources/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AssetsGetResourcesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityAssets.cloud_security_assets_entities_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityAssets#cloud_security_assets_entities_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cloud_security_assets_queries(opts = {}) ⇒ AssetsGetResourceIDsResponse

Gets a list of resource IDs for the given parameters, filters and sort criteria

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :after (String)

    token-based pagination. use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

  • :filter (String)

    FQL string to filter on asset contents. Filterable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;active&#x60; - &#x60;aspm.deployment_cloud_resource_id&#x60; - &#x60;aspm.deployment_provider&#x60; - &#x60;aspm.deployment_type&#x60; - &#x60;aspm.technologies&#x60; - &#x60;azure.resource_group&#x60; - &#x60;azure.vm_id&#x60; - &#x60;business_impact&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_risks.rule&#x60; - &#x60;cloud_risks.severity&#x60; - &#x60;cloud_risks.status&#x60; - &#x60;cloud_scope&#x60; - &#x60;cluster_id&#x60; - &#x60;cluster_name&#x60; - &#x60;compartment_ocid&#x60; - &#x60;compliant.benchmark_name&#x60; - &#x60;compliant.benchmark_version&#x60; - &#x60;compliant.framework&#x60; - &#x60;compliant.policy_id&#x60; - &#x60;compliant.requirement&#x60; - &#x60;compliant.rule&#x60; - &#x60;compliant.section&#x60; - &#x60;configuration.id&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.framework&#x60; - &#x60;control.requirement&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;creation_time&#x60; - &#x60;cve_ids&#x60; - &#x60;data_classifications.found&#x60; - &#x60;data_classifications.label&#x60; - &#x60;data_classifications.label_id&#x60; - &#x60;data_classifications.scanned&#x60; - &#x60;data_classifications.tag&#x60; - &#x60;data_classifications.tag_id&#x60; - &#x60;environment&#x60; - &#x60;exprt_ratings&#x60; - &#x60;first_seen&#x60; - &#x60;highest_severity&#x60; - &#x60;id&#x60; - &#x60;insights.boolean_value&#x60; - &#x60;insights.date_value&#x60; - &#x60;insights.id&#x60; - &#x60;insights.integer_value&#x60; - &#x60;insights.string_list_value&#x60; - &#x60;insights.string_value&#x60; - &#x60;instance_id&#x60; - &#x60;instance_state&#x60; - &#x60;ioa_count&#x60; - &#x60;iom_count&#x60; - &#x60;legacy_resource_id&#x60; - &#x60;legacy_uuid&#x60; - &#x60;managed_by&#x60; - &#x60;non_compliant.benchmark_name&#x60; - &#x60;non_compliant.benchmark_version&#x60; - &#x60;non_compliant.framework&#x60; - &#x60;non_compliant.policy_id&#x60; - &#x60;non_compliant.requirement&#x60; - &#x60;non_compliant.rule&#x60; - &#x60;non_compliant.rule_name&#x60; - &#x60;non_compliant.section&#x60; - &#x60;non_compliant.severity&#x60; - &#x60;organization_Id&#x60; - &#x60;os_version&#x60; - &#x60;platform_name&#x60; - &#x60;publicly_exposed&#x60; - &#x60;region&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_name&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;sensor_priority&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;snapshot_detections&#x60; - &#x60;ssm_managed&#x60; - &#x60;status&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;tenant_id&#x60; - &#x60;updated_at&#x60; - &#x60;vmware.guest_os_id&#x60; - &#x60;vmware.guest_os_version&#x60; - &#x60;vmware.host_system_name&#x60; - &#x60;vmware.host_type&#x60; - &#x60;vmware.instance_uuid&#x60; - &#x60;vmware.vm_host_name&#x60; - &#x60;vmware.vm_tools_status&#x60; - &#x60;zone&#x60;

  • :sort (String)

    The field to sort on. Sortable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;active&#x60; - &#x60;aspm.deployment_cloud_resource_id&#x60; - &#x60;aspm.deployment_provider&#x60; - &#x60;aspm.deployment_type&#x60; - &#x60;aspm.exprt_rating&#x60; - &#x60;aspm.technologies&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_risks.open_risk_count&#x60; - &#x60;cluster_id&#x60; - &#x60;cluster_name&#x60; - &#x60;compartment_name&#x60; - &#x60;compartment_ocid&#x60; - &#x60;compartment_path&#x60; - &#x60;creation_time&#x60; - &#x60;data_classifications.found&#x60; - &#x60;data_classifications.scanned&#x60; - &#x60;first_seen&#x60; - &#x60;id&#x60; - &#x60;instance_id&#x60; - &#x60;instance_state&#x60; - &#x60;ioa_count&#x60; - &#x60;iom_count&#x60; - &#x60;managed_by&#x60; - &#x60;organization_Id&#x60; - &#x60;os_version&#x60; - &#x60;platform_name&#x60; - &#x60;publicly_exposed&#x60; - &#x60;region&#x60; - &#x60;resource_id&#x60; - &#x60;resource_name&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;ssm_managed&#x60; - &#x60;status&#x60; - &#x60;tenancy_name&#x60; - &#x60;tenancy_ocid&#x60; - &#x60;tenancy_type&#x60; - &#x60;tenant_id&#x60; - &#x60;updated_at&#x60; - &#x60;vmware.guest_os_id&#x60; - &#x60;vmware.guest_os_version&#x60; - &#x60;vmware.host_system_name&#x60; - &#x60;vmware.host_type&#x60; - &#x60;vmware.instance_uuid&#x60; - &#x60;vmware.vm_host_name&#x60; - &#x60;vmware.vm_tools_status&#x60; - &#x60;zone&#x60; - &#x60;publiclyExposedToTheInternet&#x60; - &#x60;publiclyExposedAccessRange&#x60; - &#x60;publiclyExposedExposureMethod&#x60; Use &#x60;|asc&#x60; or &#x60;|desc&#x60; suffix to specify sort direction.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets. Use only one of &#39;offset&#39; and &#39;after&#39; parameter for paginating. &#39;offset&#39; can only be used on offsets &lt; 10,000. For paginating through the entire result set, use &#39;after&#39; parameter

Returns:



282
283
284
285
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 282

def cloud_security_assets_queries(opts = {})
  data, _status_code, _headers = cloud_security_assets_queries_with_http_info(opts)
  data
end

#cloud_security_assets_queries_with_http_info(opts = {}) ⇒ Array<(AssetsGetResourceIDsResponse, Integer, Hash)>

Gets a list of resource IDs for the given parameters, filters and sort criteria

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :after (String)

    token-based pagination. use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

  • :filter (String)

    FQL string to filter on asset contents. Filterable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;active&#x60; - &#x60;aspm.deployment_cloud_resource_id&#x60; - &#x60;aspm.deployment_provider&#x60; - &#x60;aspm.deployment_type&#x60; - &#x60;aspm.technologies&#x60; - &#x60;azure.resource_group&#x60; - &#x60;azure.vm_id&#x60; - &#x60;business_impact&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_risks.rule&#x60; - &#x60;cloud_risks.severity&#x60; - &#x60;cloud_risks.status&#x60; - &#x60;cloud_scope&#x60; - &#x60;cluster_id&#x60; - &#x60;cluster_name&#x60; - &#x60;compartment_ocid&#x60; - &#x60;compliant.benchmark_name&#x60; - &#x60;compliant.benchmark_version&#x60; - &#x60;compliant.framework&#x60; - &#x60;compliant.policy_id&#x60; - &#x60;compliant.requirement&#x60; - &#x60;compliant.rule&#x60; - &#x60;compliant.section&#x60; - &#x60;configuration.id&#x60; - &#x60;control.benchmark.name&#x60; - &#x60;control.benchmark.version&#x60; - &#x60;control.framework&#x60; - &#x60;control.requirement&#x60; - &#x60;control.type&#x60; - &#x60;control.version&#x60; - &#x60;creation_time&#x60; - &#x60;cve_ids&#x60; - &#x60;data_classifications.found&#x60; - &#x60;data_classifications.label&#x60; - &#x60;data_classifications.label_id&#x60; - &#x60;data_classifications.scanned&#x60; - &#x60;data_classifications.tag&#x60; - &#x60;data_classifications.tag_id&#x60; - &#x60;environment&#x60; - &#x60;exprt_ratings&#x60; - &#x60;first_seen&#x60; - &#x60;highest_severity&#x60; - &#x60;id&#x60; - &#x60;insights.boolean_value&#x60; - &#x60;insights.date_value&#x60; - &#x60;insights.id&#x60; - &#x60;insights.integer_value&#x60; - &#x60;insights.string_list_value&#x60; - &#x60;insights.string_value&#x60; - &#x60;instance_id&#x60; - &#x60;instance_state&#x60; - &#x60;ioa_count&#x60; - &#x60;iom_count&#x60; - &#x60;legacy_resource_id&#x60; - &#x60;legacy_uuid&#x60; - &#x60;managed_by&#x60; - &#x60;non_compliant.benchmark_name&#x60; - &#x60;non_compliant.benchmark_version&#x60; - &#x60;non_compliant.framework&#x60; - &#x60;non_compliant.policy_id&#x60; - &#x60;non_compliant.requirement&#x60; - &#x60;non_compliant.rule&#x60; - &#x60;non_compliant.rule_name&#x60; - &#x60;non_compliant.section&#x60; - &#x60;non_compliant.severity&#x60; - &#x60;organization_Id&#x60; - &#x60;os_version&#x60; - &#x60;platform_name&#x60; - &#x60;publicly_exposed&#x60; - &#x60;region&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_name&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;sensor_priority&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;snapshot_detections&#x60; - &#x60;ssm_managed&#x60; - &#x60;status&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;tenant_id&#x60; - &#x60;updated_at&#x60; - &#x60;vmware.guest_os_id&#x60; - &#x60;vmware.guest_os_version&#x60; - &#x60;vmware.host_system_name&#x60; - &#x60;vmware.host_type&#x60; - &#x60;vmware.instance_uuid&#x60; - &#x60;vmware.vm_host_name&#x60; - &#x60;vmware.vm_tools_status&#x60; - &#x60;zone&#x60;

  • :sort (String)

    The field to sort on. Sortable fields include: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;active&#x60; - &#x60;aspm.deployment_cloud_resource_id&#x60; - &#x60;aspm.deployment_provider&#x60; - &#x60;aspm.deployment_type&#x60; - &#x60;aspm.exprt_rating&#x60; - &#x60;aspm.technologies&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_risks.open_risk_count&#x60; - &#x60;cluster_id&#x60; - &#x60;cluster_name&#x60; - &#x60;compartment_name&#x60; - &#x60;compartment_ocid&#x60; - &#x60;compartment_path&#x60; - &#x60;creation_time&#x60; - &#x60;data_classifications.found&#x60; - &#x60;data_classifications.scanned&#x60; - &#x60;first_seen&#x60; - &#x60;id&#x60; - &#x60;instance_id&#x60; - &#x60;instance_state&#x60; - &#x60;ioa_count&#x60; - &#x60;iom_count&#x60; - &#x60;managed_by&#x60; - &#x60;organization_Id&#x60; - &#x60;os_version&#x60; - &#x60;platform_name&#x60; - &#x60;publicly_exposed&#x60; - &#x60;region&#x60; - &#x60;resource_id&#x60; - &#x60;resource_name&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;ssm_managed&#x60; - &#x60;status&#x60; - &#x60;tenancy_name&#x60; - &#x60;tenancy_ocid&#x60; - &#x60;tenancy_type&#x60; - &#x60;tenant_id&#x60; - &#x60;updated_at&#x60; - &#x60;vmware.guest_os_id&#x60; - &#x60;vmware.guest_os_version&#x60; - &#x60;vmware.host_system_name&#x60; - &#x60;vmware.host_type&#x60; - &#x60;vmware.instance_uuid&#x60; - &#x60;vmware.vm_host_name&#x60; - &#x60;vmware.vm_tools_status&#x60; - &#x60;zone&#x60; - &#x60;publiclyExposedToTheInternet&#x60; - &#x60;publiclyExposedAccessRange&#x60; - &#x60;publiclyExposedExposureMethod&#x60; Use &#x60;|asc&#x60; or &#x60;|desc&#x60; suffix to specify sort direction.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets. Use only one of &#39;offset&#39; and &#39;after&#39; parameter for paginating. &#39;offset&#39; can only be used on offsets &lt; 10,000. For paginating through the entire result set, use &#39;after&#39; parameter

Returns:



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/crimson-falcon/api/cloud_security_assets.rb', line 295

def cloud_security_assets_queries_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityAssets.cloud_security_assets_queries ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_queries, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityAssets.cloud_security_assets_queries, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityAssets.cloud_security_assets_queries, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/cloud-security-assets/queries/resources/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AssetsGetResourceIDsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityAssets.cloud_security_assets_queries",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityAssets#cloud_security_assets_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end