Class: Falcon::CloudSecurityDetections

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/cloud_security_detections.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CloudSecurityDetections

Returns a new instance of CloudSecurityDetections.



35
36
37
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#cspm_evaluations_combined_iom_by_rule(opts = {}) ⇒ EvaluationsIOMsByRuleResponse

returns ioms grouped by rule

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter results in Falcon Query Language (FQL). Supported fields: - `account_id` - `account_name` - `applicable_profile` - `attack_type` - `benchmark_name` - `benchmark_version` - `business_impact` - `cid` - `cloud_group` - `cloud_label` - `cloud_label_id` - `cloud_provider` - `cloud_scope` - `created_at` - `environment` - `extension_status` - `first_detected` - `framework` - `last_detected` - `policy_id` - `policy_name` - `region` - `requirement` - `resource_gcrn` - `resource_id` - `resource_parent` - `resource_status` - `resource_type` - `resource_type_name` - `rule_group` - `rule_id` - `rule_name` - `rule_origin` - `section` - `service` - `service_category` - `severity` - `status` - `suppressed_by` - `tactic_id` - `tactic_name` - `tag_key` - `tag_value` - `tags` - `tags_string` - `technique_id` - `technique_name` - `tenant_id` - `zone`

  • :sort (String)

    The field to sort on. Sortable fields include: - `assessed_assets` - `cloud_provider` - `misconfigurations` - `rule_id` - `severity` Use `|asc` or `|desc` suffix to specify sort direction.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets

Returns:



45
46
47
48
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 45

def cspm_evaluations_combined_iom_by_rule(opts = {})
  data, _status_code, _headers = cspm_evaluations_combined_iom_by_rule_with_http_info(opts)
  data
end

#cspm_evaluations_combined_iom_by_rule_with_http_info(opts = {}) ⇒ Array<(EvaluationsIOMsByRuleResponse, Integer, Hash)>

returns ioms grouped by rule

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter results in Falcon Query Language (FQL). Supported fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;applicable_profile&#x60; - &#x60;attack_type&#x60; - &#x60;benchmark_name&#x60; - &#x60;benchmark_version&#x60; - &#x60;business_impact&#x60; - &#x60;cid&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;created_at&#x60; - &#x60;environment&#x60; - &#x60;extension_status&#x60; - &#x60;first_detected&#x60; - &#x60;framework&#x60; - &#x60;last_detected&#x60; - &#x60;policy_id&#x60; - &#x60;policy_name&#x60; - &#x60;region&#x60; - &#x60;requirement&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_status&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;rule_group&#x60; - &#x60;rule_id&#x60; - &#x60;rule_name&#x60; - &#x60;rule_origin&#x60; - &#x60;section&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;status&#x60; - &#x60;suppressed_by&#x60; - &#x60;tactic_id&#x60; - &#x60;tactic_name&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;technique_id&#x60; - &#x60;technique_name&#x60; - &#x60;tenant_id&#x60; - &#x60;zone&#x60;

  • :sort (String)

    The field to sort on. Sortable fields include: - &#x60;assessed_assets&#x60; - &#x60;cloud_provider&#x60; - &#x60;misconfigurations&#x60; - &#x60;rule_id&#x60; - &#x60;severity&#x60; Use &#x60;|asc&#x60; or &#x60;|desc&#x60; suffix to specify sort direction.

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets

Returns:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 57

def cspm_evaluations_combined_iom_by_rule_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/cloud-security-evaluations/combined/ioms-by-rule/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EvaluationsIOMsByRuleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_combined_iom_by_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cspm_evaluations_iom_entities(opts = {}) ⇒ EvaluationsGetIOMsResponse

Gets IOMs based on the provided IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    List of IOMs to return (maximum 100 IDs allowed). Use POST method with same path if more entities are required.

Returns:



121
122
123
124
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 121

def cspm_evaluations_iom_entities(opts = {})
  data, _status_code, _headers = cspm_evaluations_iom_entities_with_http_info(opts)
  data
end

#cspm_evaluations_iom_entities_with_http_info(opts = {}) ⇒ Array<(EvaluationsGetIOMsResponse, Integer, Hash)>

Gets IOMs based on the provided IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :ids (Array<String>)

    List of IOMs to return (maximum 100 IDs allowed). Use POST method with same path if more entities are required.

Returns:

  • (Array<(EvaluationsGetIOMsResponse, Integer, Hash)>)

    EvaluationsGetIOMsResponse data, response status code and response headers



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 130

def cspm_evaluations_iom_entities_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_iom_entities ...'
  end
  # resource path
  local_var_path = '/cloud-security-evaluations/entities/ioms/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EvaluationsGetIOMsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityDetections.cspm_evaluations_iom_entities",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_iom_entities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#cspm_evaluations_iom_queries(opts = {}) ⇒ EvaluationsQueryIOMsResponse

Gets a list of IOM IDs for the given parameters, filters and sort criteria.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter results in Falcon Query Language (FQL). Supported fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;applicable_profile&#x60; - &#x60;attack_type&#x60; - &#x60;benchmark_name&#x60; - &#x60;benchmark_version&#x60; - &#x60;business_impact&#x60; - &#x60;cid&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;created_at&#x60; - &#x60;environment&#x60; - &#x60;extension_status&#x60; - &#x60;first_detected&#x60; - &#x60;framework&#x60; - &#x60;last_detected&#x60; - &#x60;policy_id&#x60; - &#x60;policy_name&#x60; - &#x60;policy_uuid&#x60; - &#x60;region&#x60; - &#x60;requirement&#x60; - &#x60;requirement_name&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_status&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;rule_group&#x60; - &#x60;rule_id&#x60; - &#x60;rule_name&#x60; - &#x60;rule_origin&#x60; - &#x60;rule_remediation&#x60; - &#x60;section&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;status&#x60; - &#x60;suppressed_by&#x60; - &#x60;suppression_reason&#x60; - &#x60;tactic_id&#x60; - &#x60;tactic_name&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;technique_id&#x60; - &#x60;technique_name&#x60; - &#x60;tenant_id&#x60;

  • :sort (String)

    The field to sort on. Use &#x60;|asc&#x60; or &#x60;|desc&#x60; suffix to specify sort direction.Supported fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;applicable_profile&#x60; - &#x60;attack_type&#x60; - &#x60;benchmark_name&#x60; - &#x60;benchmark_version&#x60; - &#x60;business_impact&#x60; - &#x60;cid&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;created_at&#x60; - &#x60;environment&#x60; - &#x60;extension_status&#x60; - &#x60;first_detected&#x60; - &#x60;framework&#x60; - &#x60;last_detected&#x60; - &#x60;policy_id&#x60; - &#x60;policy_name&#x60; - &#x60;policy_uuid&#x60; - &#x60;region&#x60; - &#x60;requirement&#x60; - &#x60;requirement_name&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_status&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;rule_group&#x60; - &#x60;rule_id&#x60; - &#x60;rule_name&#x60; - &#x60;rule_origin&#x60; - &#x60;rule_remediation&#x60; - &#x60;section&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;status&#x60; - &#x60;suppressed_by&#x60; - &#x60;suppression_reason&#x60; - &#x60;tactic_id&#x60; - &#x60;tactic_name&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;technique_id&#x60; - &#x60;technique_name&#x60; - &#x60;tenant_id&#x60;

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets

  • :after (String)

    token-based pagination. Use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

Returns:



183
184
185
186
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 183

def cspm_evaluations_iom_queries(opts = {})
  data, _status_code, _headers = cspm_evaluations_iom_queries_with_http_info(opts)
  data
end

#cspm_evaluations_iom_queries_with_http_info(opts = {}) ⇒ Array<(EvaluationsQueryIOMsResponse, Integer, Hash)>

Gets a list of IOM IDs for the given parameters, filters and sort criteria.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    FQL string to filter results in Falcon Query Language (FQL). Supported fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;applicable_profile&#x60; - &#x60;attack_type&#x60; - &#x60;benchmark_name&#x60; - &#x60;benchmark_version&#x60; - &#x60;business_impact&#x60; - &#x60;cid&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;created_at&#x60; - &#x60;environment&#x60; - &#x60;extension_status&#x60; - &#x60;first_detected&#x60; - &#x60;framework&#x60; - &#x60;last_detected&#x60; - &#x60;policy_id&#x60; - &#x60;policy_name&#x60; - &#x60;policy_uuid&#x60; - &#x60;region&#x60; - &#x60;requirement&#x60; - &#x60;requirement_name&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_status&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;rule_group&#x60; - &#x60;rule_id&#x60; - &#x60;rule_name&#x60; - &#x60;rule_origin&#x60; - &#x60;rule_remediation&#x60; - &#x60;section&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;status&#x60; - &#x60;suppressed_by&#x60; - &#x60;suppression_reason&#x60; - &#x60;tactic_id&#x60; - &#x60;tactic_name&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;technique_id&#x60; - &#x60;technique_name&#x60; - &#x60;tenant_id&#x60;

  • :sort (String)

    The field to sort on. Use &#x60;|asc&#x60; or &#x60;|desc&#x60; suffix to specify sort direction.Supported fields: - &#x60;account_id&#x60; - &#x60;account_name&#x60; - &#x60;applicable_profile&#x60; - &#x60;attack_type&#x60; - &#x60;benchmark_name&#x60; - &#x60;benchmark_version&#x60; - &#x60;business_impact&#x60; - &#x60;cid&#x60; - &#x60;cloud_group&#x60; - &#x60;cloud_label&#x60; - &#x60;cloud_label_id&#x60; - &#x60;cloud_provider&#x60; - &#x60;cloud_scope&#x60; - &#x60;created_at&#x60; - &#x60;environment&#x60; - &#x60;extension_status&#x60; - &#x60;first_detected&#x60; - &#x60;framework&#x60; - &#x60;last_detected&#x60; - &#x60;policy_id&#x60; - &#x60;policy_name&#x60; - &#x60;policy_uuid&#x60; - &#x60;region&#x60; - &#x60;requirement&#x60; - &#x60;requirement_name&#x60; - &#x60;resource_gcrn&#x60; - &#x60;resource_id&#x60; - &#x60;resource_parent&#x60; - &#x60;resource_status&#x60; - &#x60;resource_type&#x60; - &#x60;resource_type_name&#x60; - &#x60;rule_group&#x60; - &#x60;rule_id&#x60; - &#x60;rule_name&#x60; - &#x60;rule_origin&#x60; - &#x60;rule_remediation&#x60; - &#x60;section&#x60; - &#x60;service&#x60; - &#x60;service_category&#x60; - &#x60;severity&#x60; - &#x60;status&#x60; - &#x60;suppressed_by&#x60; - &#x60;suppression_reason&#x60; - &#x60;tactic_id&#x60; - &#x60;tactic_name&#x60; - &#x60;tag_key&#x60; - &#x60;tag_value&#x60; - &#x60;tags&#x60; - &#x60;tags_string&#x60; - &#x60;technique_id&#x60; - &#x60;technique_name&#x60; - &#x60;tenant_id&#x60;

  • :limit (Integer)

    The maximum number of items to return. When not specified or 0, 500 is used. When larger than 1000, 1000 is used. (default to 500)

  • :offset (Integer)

    Offset returned assets

  • :after (String)

    token-based pagination. Use for paginating through an entire result set. Use only one of &#39;offset&#39; and &#39;after&#39; parameters for paginating

Returns:



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 196

def cspm_evaluations_iom_queries_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_iom_queries ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/cloud-security-evaluations/queries/ioms/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EvaluationsQueryIOMsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"CloudSecurityDetections.cspm_evaluations_iom_queries",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_iom_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end