Class: Falcon::CorrelationrulesapiRuleV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CorrelationrulesapiRuleV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 191

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::CorrelationrulesapiRuleV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::CorrelationrulesapiRuleV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'anomaly')
    self.anomaly = attributes[:'anomaly']
  end

  if attributes.key?(:'api_client_id')
    self.api_client_id = attributes[:'api_client_id']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'executor_rule_id')
    self.executor_rule_id = attributes[:'executor_rule_id']
  end

  if attributes.key?(:'guardrail_notifications')
    if (value = attributes[:'guardrail_notifications']).is_a?(Array)
      self.guardrail_notifications = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_execution')
    self.last_execution = attributes[:'last_execution']
  end

  if attributes.key?(:'last_updated_on')
    self.last_updated_on = attributes[:'last_updated_on']
  end

  if attributes.key?(:'mitre_attack')
    if (value = attributes[:'mitre_attack']).is_a?(Array)
      self.mitre_attack = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'next_execution_on')
    self.next_execution_on = attributes[:'next_execution_on']
  end

  if attributes.key?(:'notifications')
    if (value = attributes[:'notifications']).is_a?(Array)
      self.notifications = value
    end
  end

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  end

  if attributes.key?(:'rule_id')
    self.rule_id = attributes[:'rule_id']
  end

  if attributes.key?(:'search')
    self.search = attributes[:'search']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_msg')
    self.status_msg = attributes[:'status_msg']
  end

  if attributes.key?(:'tactic')
    self.tactic = attributes[:'tactic']
  end

  if attributes.key?(:'technique')
    self.technique = attributes[:'technique']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'updated_by_api_client_id')
    self.updated_by_api_client_id = attributes[:'updated_by_api_client_id']
  end

  if attributes.key?(:'updated_by_user_id')
    self.updated_by_user_id = attributes[:'updated_by_user_id']
  end

  if attributes.key?(:'updated_by_user_uuid')
    self.updated_by_user_uuid = attributes[:'updated_by_user_uuid']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_uuid')
    self.user_uuid = attributes[:'user_uuid']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#anomalyObject

Returns the value of attribute anomaly.



34
35
36
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 34

def anomaly
  @anomaly
end

#api_client_idObject

Returns the value of attribute api_client_id.



36
37
38
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 36

def api_client_id
  @api_client_id
end

#authorObject

Returns the value of attribute author.



38
39
40
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 38

def author
  @author
end

#commentObject

Returns the value of attribute comment.



40
41
42
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 40

def comment
  @comment
end

#created_onObject

Returns the value of attribute created_on.



42
43
44
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 42

def created_on
  @created_on
end

#customer_idObject

Returns the value of attribute customer_id.



44
45
46
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 44

def customer_id
  @customer_id
end

#descriptionObject

Returns the value of attribute description.



46
47
48
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 46

def description
  @description
end

#executor_rule_idObject

Returns the value of attribute executor_rule_id.



48
49
50
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 48

def executor_rule_id
  @executor_rule_id
end

#guardrail_notificationsObject

Returns the value of attribute guardrail_notifications.



50
51
52
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 50

def guardrail_notifications
  @guardrail_notifications
end

#idObject

Returns the value of attribute id.



52
53
54
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 52

def id
  @id
end

#last_executionObject

Returns the value of attribute last_execution.



54
55
56
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 54

def last_execution
  @last_execution
end

#last_updated_onObject

Returns the value of attribute last_updated_on.



56
57
58
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 56

def last_updated_on
  @last_updated_on
end

#mitre_attackObject

Returns the value of attribute mitre_attack.



58
59
60
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 58

def mitre_attack
  @mitre_attack
end

#nameObject

Returns the value of attribute name.



60
61
62
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 60

def name
  @name
end

#next_execution_onObject

Returns the value of attribute next_execution_on.



62
63
64
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 62

def next_execution_on
  @next_execution_on
end

#notificationsObject

Returns the value of attribute notifications.



64
65
66
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 64

def notifications
  @notifications
end

#operationObject

Returns the value of attribute operation.



66
67
68
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 66

def operation
  @operation
end

#rule_idObject

Returns the value of attribute rule_id.



68
69
70
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 68

def rule_id
  @rule_id
end

#searchObject

Returns the value of attribute search.



70
71
72
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 70

def search
  @search
end

#severityObject

Returns the value of attribute severity.



72
73
74
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 72

def severity
  @severity
end

#stateObject

Returns the value of attribute state.



74
75
76
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 74

def state
  @state
end

#statusObject

Returns the value of attribute status.



76
77
78
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 76

def status
  @status
end

#status_msgObject

Returns the value of attribute status_msg.



78
79
80
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 78

def status_msg
  @status_msg
end

#tacticObject

Returns the value of attribute tactic.



80
81
82
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 80

def tactic
  @tactic
end

#techniqueObject

Returns the value of attribute technique.



82
83
84
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 82

def technique
  @technique
end

#template_idObject

Returns the value of attribute template_id.



84
85
86
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 84

def template_id
  @template_id
end

#typeObject

Returns the value of attribute type.



86
87
88
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 86

def type
  @type
end

#updated_by_api_client_idObject

Returns the value of attribute updated_by_api_client_id.



88
89
90
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 88

def updated_by_api_client_id
  @updated_by_api_client_id
end

#updated_by_user_idObject

Returns the value of attribute updated_by_user_id.



90
91
92
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 90

def updated_by_user_id
  @updated_by_user_id
end

#updated_by_user_uuidObject

Returns the value of attribute updated_by_user_uuid.



92
93
94
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 92

def updated_by_user_uuid
  @updated_by_user_uuid
end

#user_idObject

Returns the value of attribute user_id.



94
95
96
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 94

def user_id
  @user_id
end

#user_uuidObject

Returns the value of attribute user_uuid.



96
97
98
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 96

def user_uuid
  @user_uuid
end

#versionObject

Returns the value of attribute version.



98
99
100
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 98

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



140
141
142
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 140

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 101

def self.attribute_map
  {
    :'anomaly' => :'anomaly',
    :'api_client_id' => :'api_client_id',
    :'author' => :'author',
    :'comment' => :'comment',
    :'created_on' => :'created_on',
    :'customer_id' => :'customer_id',
    :'description' => :'description',
    :'executor_rule_id' => :'executor_rule_id',
    :'guardrail_notifications' => :'guardrail_notifications',
    :'id' => :'id',
    :'last_execution' => :'last_execution',
    :'last_updated_on' => :'last_updated_on',
    :'mitre_attack' => :'mitre_attack',
    :'name' => :'name',
    :'next_execution_on' => :'next_execution_on',
    :'notifications' => :'notifications',
    :'operation' => :'operation',
    :'rule_id' => :'rule_id',
    :'search' => :'search',
    :'severity' => :'severity',
    :'state' => :'state',
    :'status' => :'status',
    :'status_msg' => :'status_msg',
    :'tactic' => :'tactic',
    :'technique' => :'technique',
    :'template_id' => :'template_id',
    :'type' => :'type',
    :'updated_by_api_client_id' => :'updated_by_api_client_id',
    :'updated_by_user_id' => :'updated_by_user_id',
    :'updated_by_user_uuid' => :'updated_by_user_uuid',
    :'user_id' => :'user_id',
    :'user_uuid' => :'user_uuid',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



511
512
513
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 511

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



184
185
186
187
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 184

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 145

def self.openapi_types
  {
    :'anomaly' => :'CorrelationrulesapiAnomalyV1',
    :'api_client_id' => :'String',
    :'author' => :'String',
    :'comment' => :'String',
    :'created_on' => :'Time',
    :'customer_id' => :'String',
    :'description' => :'String',
    :'executor_rule_id' => :'String',
    :'guardrail_notifications' => :'Array<CorrelationrulesapiRuleNotificationsV1>',
    :'id' => :'String',
    :'last_execution' => :'CorrelationrulesapiRuleLastExecutionV1',
    :'last_updated_on' => :'Time',
    :'mitre_attack' => :'Array<CorrelationrulesapiMitreAttackMappingV1>',
    :'name' => :'String',
    :'next_execution_on' => :'Time',
    :'notifications' => :'Array<CorrelationrulesapiRuleNotificationsV1>',
    :'operation' => :'CorrelationrulesapiRuleOperationV1',
    :'rule_id' => :'String',
    :'search' => :'CorrelationrulesapiRuleSearchV1',
    :'severity' => :'Integer',
    :'state' => :'String',
    :'status' => :'String',
    :'status_msg' => :'String',
    :'tactic' => :'String',
    :'technique' => :'String',
    :'template_id' => :'String',
    :'type' => :'String',
    :'updated_by_api_client_id' => :'String',
    :'updated_by_user_id' => :'String',
    :'updated_by_user_uuid' => :'String',
    :'user_id' => :'String',
    :'user_uuid' => :'String',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 458

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      anomaly == o.anomaly &&
      api_client_id == o.api_client_id &&
      author == o.author &&
      comment == o.comment &&
      created_on == o.created_on &&
      customer_id == o.customer_id &&
      description == o.description &&
      executor_rule_id == o.executor_rule_id &&
      guardrail_notifications == o.guardrail_notifications &&
      id == o.id &&
      last_execution == o.last_execution &&
      last_updated_on == o.last_updated_on &&
      mitre_attack == o.mitre_attack &&
      name == o.name &&
      next_execution_on == o.next_execution_on &&
      notifications == o.notifications &&
      operation == o.operation &&
      rule_id == o.rule_id &&
      search == o.search &&
      severity == o.severity &&
      state == o.state &&
      status == o.status &&
      status_msg == o.status_msg &&
      tactic == o.tactic &&
      technique == o.technique &&
      template_id == o.template_id &&
      type == o.type &&
      updated_by_api_client_id == o.updated_by_api_client_id &&
      updated_by_user_id == o.updated_by_user_id &&
      updated_by_user_uuid == o.updated_by_user_uuid &&
      user_id == o.user_id &&
      user_uuid == o.user_uuid &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 542

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



613
614
615
616
617
618
619
620
621
622
623
624
625
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 613

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 518

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


498
499
500
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 498

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



504
505
506
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 504

def hash
  [anomaly, api_client_id, author, comment, created_on, customer_id, description, executor_rule_id, guardrail_notifications, id, last_execution, last_updated_on, mitre_attack, name, next_execution_on, notifications, operation, rule_id, search, severity, state, status, status_msg, tactic, technique, template_id, type, updated_by_api_client_id, updated_by_user_id, updated_by_user_uuid, user_id, user_uuid, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 345

def list_invalid_properties
  invalid_properties = Array.new
  if @api_client_id.nil?
    invalid_properties.push('invalid value for "api_client_id", api_client_id cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_updated_on.nil?
    invalid_properties.push('invalid value for "last_updated_on", last_updated_on cannot be nil.')
  end

  if @mitre_attack.nil?
    invalid_properties.push('invalid value for "mitre_attack", mitre_attack cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @operation.nil?
    invalid_properties.push('invalid value for "operation", operation cannot be nil.')
  end

  if @search.nil?
    invalid_properties.push('invalid value for "search", search cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @status_msg.nil?
    invalid_properties.push('invalid value for "status_msg", status_msg cannot be nil.')
  end

  if @tactic.nil?
    invalid_properties.push('invalid value for "tactic", tactic cannot be nil.')
  end

  if @technique.nil?
    invalid_properties.push('invalid value for "technique", technique cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @updated_by_api_client_id.nil?
    invalid_properties.push('invalid value for "updated_by_api_client_id", updated_by_api_client_id cannot be nil.')
  end

  if @updated_by_user_id.nil?
    invalid_properties.push('invalid value for "updated_by_user_id", updated_by_user_id cannot be nil.')
  end

  if @updated_by_user_uuid.nil?
    invalid_properties.push('invalid value for "updated_by_user_uuid", updated_by_user_uuid cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @user_uuid.nil?
    invalid_properties.push('invalid value for "user_uuid", user_uuid cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



589
590
591
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 589

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 595

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



583
584
585
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 583

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_v1.rb', line 432

def valid?
  return false if @api_client_id.nil?
  return false if @created_on.nil?
  return false if @customer_id.nil?
  return false if @id.nil?
  return false if @last_updated_on.nil?
  return false if @mitre_attack.nil?
  return false if @name.nil?
  return false if @operation.nil?
  return false if @search.nil?
  return false if @severity.nil?
  return false if @status.nil?
  return false if @status_msg.nil?
  return false if @tactic.nil?
  return false if @technique.nil?
  return false if @template_id.nil?
  return false if @updated_by_api_client_id.nil?
  return false if @updated_by_user_id.nil?
  return false if @updated_by_user_uuid.nil?
  return false if @user_id.nil?
  return false if @user_uuid.nil?
  true
end