Class: Falcon::DetectsDeviceDetailIndexed
- Inherits:
-
Object
- Object
- Falcon::DetectsDeviceDetailIndexed
- Defined in:
- lib/crimson-falcon/models/detects_device_detail_indexed.rb
Instance Attribute Summary collapse
-
#agent_load_flags ⇒ Object
Returns the value of attribute agent_load_flags.
-
#agent_local_time ⇒ Object
Returns the value of attribute agent_local_time.
-
#agent_version ⇒ Object
Returns the value of attribute agent_version.
-
#bios_manufacturer ⇒ Object
Returns the value of attribute bios_manufacturer.
-
#bios_version ⇒ Object
Returns the value of attribute bios_version.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#config_id_base ⇒ Object
Returns the value of attribute config_id_base.
-
#config_id_build ⇒ Object
Returns the value of attribute config_id_build.
-
#config_id_platform ⇒ Object
Returns the value of attribute config_id_platform.
-
#device_id ⇒ Object
Returns the value of attribute device_id.
-
#external_ip ⇒ Object
Returns the value of attribute external_ip.
-
#first_login_timestamp ⇒ Object
Returns the value of attribute first_login_timestamp.
-
#first_login_user ⇒ Object
Returns the value of attribute first_login_user.
-
#first_seen ⇒ Object
Returns the value of attribute first_seen.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#instance_id ⇒ Object
Returns the value of attribute instance_id.
-
#last_login_timestamp ⇒ Object
Returns the value of attribute last_login_timestamp.
-
#last_login_user ⇒ Object
Returns the value of attribute last_login_user.
-
#last_seen ⇒ Object
Returns the value of attribute last_seen.
-
#local_ip ⇒ Object
Returns the value of attribute local_ip.
-
#mac_address ⇒ Object
Returns the value of attribute mac_address.
-
#machine_domain ⇒ Object
Returns the value of attribute machine_domain.
-
#major_version ⇒ Object
Returns the value of attribute major_version.
-
#minor_version ⇒ Object
Returns the value of attribute minor_version.
-
#modified_timestamp ⇒ Object
Returns the value of attribute modified_timestamp.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#os_version ⇒ Object
Returns the value of attribute os_version.
-
#ou ⇒ Object
Returns the value of attribute ou.
-
#platform_id ⇒ Object
Returns the value of attribute platform_id.
-
#platform_name ⇒ Object
Returns the value of attribute platform_name.
-
#pod_id ⇒ Object
Returns the value of attribute pod_id.
-
#pod_labels ⇒ Object
Returns the value of attribute pod_labels.
-
#pod_name ⇒ Object
Returns the value of attribute pod_name.
-
#pod_namespace ⇒ Object
Returns the value of attribute pod_namespace.
-
#pod_service_account_name ⇒ Object
Returns the value of attribute pod_service_account_name.
-
#product_type ⇒ Object
Returns the value of attribute product_type.
-
#product_type_desc ⇒ Object
Returns the value of attribute product_type_desc.
-
#release_group ⇒ Object
Returns the value of attribute release_group.
-
#service_provider ⇒ Object
Returns the value of attribute service_provider.
-
#service_provider_account_id ⇒ Object
Returns the value of attribute service_provider_account_id.
-
#site_name ⇒ Object
Returns the value of attribute site_name.
-
#status ⇒ Object
Returns the value of attribute status.
-
#system_manufacturer ⇒ Object
Returns the value of attribute system_manufacturer.
-
#system_product_name ⇒ Object
Returns the value of attribute system_product_name.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DetectsDeviceDetailIndexed
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DetectsDeviceDetailIndexed
Initializes the object
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 243 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DetectsDeviceDetailIndexed` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DetectsDeviceDetailIndexed`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agent_load_flags') self.agent_load_flags = attributes[:'agent_load_flags'] end if attributes.key?(:'agent_local_time') self.agent_local_time = attributes[:'agent_local_time'] end if attributes.key?(:'agent_version') self.agent_version = attributes[:'agent_version'] end if attributes.key?(:'bios_manufacturer') self.bios_manufacturer = attributes[:'bios_manufacturer'] end if attributes.key?(:'bios_version') self.bios_version = attributes[:'bios_version'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'config_id_base') self.config_id_base = attributes[:'config_id_base'] end if attributes.key?(:'config_id_build') self.config_id_build = attributes[:'config_id_build'] end if attributes.key?(:'config_id_platform') self.config_id_platform = attributes[:'config_id_platform'] end if attributes.key?(:'device_id') self.device_id = attributes[:'device_id'] end if attributes.key?(:'external_ip') self.external_ip = attributes[:'external_ip'] end if attributes.key?(:'first_login_timestamp') self. = attributes[:'first_login_timestamp'] end if attributes.key?(:'first_login_user') self.first_login_user = attributes[:'first_login_user'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] end if attributes.key?(:'last_login_timestamp') self. = attributes[:'last_login_timestamp'] end if attributes.key?(:'last_login_user') self.last_login_user = attributes[:'last_login_user'] end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'local_ip') self.local_ip = attributes[:'local_ip'] end if attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] end if attributes.key?(:'machine_domain') self.machine_domain = attributes[:'machine_domain'] end if attributes.key?(:'major_version') self.major_version = attributes[:'major_version'] end if attributes.key?(:'minor_version') self.minor_version = attributes[:'minor_version'] end if attributes.key?(:'modified_timestamp') self. = attributes[:'modified_timestamp'] end if attributes.key?(:'notes') if (value = attributes[:'notes']).is_a?(Array) self.notes = value end end if attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] end if attributes.key?(:'ou') if (value = attributes[:'ou']).is_a?(Array) self.ou = value end end if attributes.key?(:'platform_id') self.platform_id = attributes[:'platform_id'] end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'pod_id') self.pod_id = attributes[:'pod_id'] end if attributes.key?(:'pod_labels') if (value = attributes[:'pod_labels']).is_a?(Array) self.pod_labels = value end end if attributes.key?(:'pod_name') self.pod_name = attributes[:'pod_name'] end if attributes.key?(:'pod_namespace') self.pod_namespace = attributes[:'pod_namespace'] end if attributes.key?(:'pod_service_account_name') self.pod_service_account_name = attributes[:'pod_service_account_name'] end if attributes.key?(:'product_type') self.product_type = attributes[:'product_type'] end if attributes.key?(:'product_type_desc') self.product_type_desc = attributes[:'product_type_desc'] end if attributes.key?(:'release_group') self.release_group = attributes[:'release_group'] end if attributes.key?(:'service_provider') self.service_provider = attributes[:'service_provider'] end if attributes.key?(:'service_provider_account_id') self.service_provider_account_id = attributes[:'service_provider_account_id'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'system_manufacturer') self.system_manufacturer = attributes[:'system_manufacturer'] end if attributes.key?(:'system_product_name') self.system_product_name = attributes[:'system_product_name'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#agent_load_flags ⇒ Object
Returns the value of attribute agent_load_flags.
34 35 36 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 34 def agent_load_flags @agent_load_flags end |
#agent_local_time ⇒ Object
Returns the value of attribute agent_local_time.
36 37 38 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 36 def agent_local_time @agent_local_time end |
#agent_version ⇒ Object
Returns the value of attribute agent_version.
38 39 40 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 38 def agent_version @agent_version end |
#bios_manufacturer ⇒ Object
Returns the value of attribute bios_manufacturer.
40 41 42 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 40 def bios_manufacturer @bios_manufacturer end |
#bios_version ⇒ Object
Returns the value of attribute bios_version.
42 43 44 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 42 def bios_version @bios_version end |
#cid ⇒ Object
Returns the value of attribute cid.
44 45 46 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 44 def cid @cid end |
#config_id_base ⇒ Object
Returns the value of attribute config_id_base.
46 47 48 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 46 def config_id_base @config_id_base end |
#config_id_build ⇒ Object
Returns the value of attribute config_id_build.
48 49 50 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 48 def config_id_build @config_id_build end |
#config_id_platform ⇒ Object
Returns the value of attribute config_id_platform.
50 51 52 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 50 def config_id_platform @config_id_platform end |
#device_id ⇒ Object
Returns the value of attribute device_id.
52 53 54 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 52 def device_id @device_id end |
#external_ip ⇒ Object
Returns the value of attribute external_ip.
54 55 56 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 54 def external_ip @external_ip end |
#first_login_timestamp ⇒ Object
Returns the value of attribute first_login_timestamp.
56 57 58 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 56 def @first_login_timestamp end |
#first_login_user ⇒ Object
Returns the value of attribute first_login_user.
58 59 60 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 58 def first_login_user @first_login_user end |
#first_seen ⇒ Object
Returns the value of attribute first_seen.
60 61 62 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 60 def first_seen @first_seen end |
#groups ⇒ Object
Returns the value of attribute groups.
62 63 64 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 62 def groups @groups end |
#hostname ⇒ Object
Returns the value of attribute hostname.
64 65 66 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 64 def hostname @hostname end |
#instance_id ⇒ Object
Returns the value of attribute instance_id.
66 67 68 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 66 def instance_id @instance_id end |
#last_login_timestamp ⇒ Object
Returns the value of attribute last_login_timestamp.
68 69 70 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 68 def @last_login_timestamp end |
#last_login_user ⇒ Object
Returns the value of attribute last_login_user.
70 71 72 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 70 def last_login_user @last_login_user end |
#last_seen ⇒ Object
Returns the value of attribute last_seen.
72 73 74 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 72 def last_seen @last_seen end |
#local_ip ⇒ Object
Returns the value of attribute local_ip.
74 75 76 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 74 def local_ip @local_ip end |
#mac_address ⇒ Object
Returns the value of attribute mac_address.
76 77 78 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 76 def mac_address @mac_address end |
#machine_domain ⇒ Object
Returns the value of attribute machine_domain.
78 79 80 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 78 def machine_domain @machine_domain end |
#major_version ⇒ Object
Returns the value of attribute major_version.
80 81 82 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 80 def major_version @major_version end |
#minor_version ⇒ Object
Returns the value of attribute minor_version.
82 83 84 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 82 def minor_version @minor_version end |
#modified_timestamp ⇒ Object
Returns the value of attribute modified_timestamp.
84 85 86 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 84 def @modified_timestamp end |
#notes ⇒ Object
Returns the value of attribute notes.
86 87 88 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 86 def notes @notes end |
#os_version ⇒ Object
Returns the value of attribute os_version.
88 89 90 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 88 def os_version @os_version end |
#ou ⇒ Object
Returns the value of attribute ou.
90 91 92 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 90 def ou @ou end |
#platform_id ⇒ Object
Returns the value of attribute platform_id.
92 93 94 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 92 def platform_id @platform_id end |
#platform_name ⇒ Object
Returns the value of attribute platform_name.
94 95 96 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 94 def platform_name @platform_name end |
#pod_id ⇒ Object
Returns the value of attribute pod_id.
96 97 98 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 96 def pod_id @pod_id end |
#pod_labels ⇒ Object
Returns the value of attribute pod_labels.
98 99 100 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 98 def pod_labels @pod_labels end |
#pod_name ⇒ Object
Returns the value of attribute pod_name.
100 101 102 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 100 def pod_name @pod_name end |
#pod_namespace ⇒ Object
Returns the value of attribute pod_namespace.
102 103 104 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 102 def pod_namespace @pod_namespace end |
#pod_service_account_name ⇒ Object
Returns the value of attribute pod_service_account_name.
104 105 106 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 104 def pod_service_account_name @pod_service_account_name end |
#product_type ⇒ Object
Returns the value of attribute product_type.
106 107 108 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 106 def product_type @product_type end |
#product_type_desc ⇒ Object
Returns the value of attribute product_type_desc.
108 109 110 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 108 def product_type_desc @product_type_desc end |
#release_group ⇒ Object
Returns the value of attribute release_group.
110 111 112 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 110 def release_group @release_group end |
#service_provider ⇒ Object
Returns the value of attribute service_provider.
112 113 114 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 112 def service_provider @service_provider end |
#service_provider_account_id ⇒ Object
Returns the value of attribute service_provider_account_id.
114 115 116 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 114 def service_provider_account_id @service_provider_account_id end |
#site_name ⇒ Object
Returns the value of attribute site_name.
116 117 118 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 116 def site_name @site_name end |
#status ⇒ Object
Returns the value of attribute status.
118 119 120 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 118 def status @status end |
#system_manufacturer ⇒ Object
Returns the value of attribute system_manufacturer.
120 121 122 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 120 def system_manufacturer @system_manufacturer end |
#system_product_name ⇒ Object
Returns the value of attribute system_product_name.
122 123 124 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 122 def system_product_name @system_product_name end |
#tags ⇒ Object
Returns the value of attribute tags.
124 125 126 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 124 def @tags end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
179 180 181 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 179 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 127 def self.attribute_map { :'agent_load_flags' => :'agent_load_flags', :'agent_local_time' => :'agent_local_time', :'agent_version' => :'agent_version', :'bios_manufacturer' => :'bios_manufacturer', :'bios_version' => :'bios_version', :'cid' => :'cid', :'config_id_base' => :'config_id_base', :'config_id_build' => :'config_id_build', :'config_id_platform' => :'config_id_platform', :'device_id' => :'device_id', :'external_ip' => :'external_ip', :'first_login_timestamp' => :'first_login_timestamp', :'first_login_user' => :'first_login_user', :'first_seen' => :'first_seen', :'groups' => :'groups', :'hostname' => :'hostname', :'instance_id' => :'instance_id', :'last_login_timestamp' => :'last_login_timestamp', :'last_login_user' => :'last_login_user', :'last_seen' => :'last_seen', :'local_ip' => :'local_ip', :'mac_address' => :'mac_address', :'machine_domain' => :'machine_domain', :'major_version' => :'major_version', :'minor_version' => :'minor_version', :'modified_timestamp' => :'modified_timestamp', :'notes' => :'notes', :'os_version' => :'os_version', :'ou' => :'ou', :'platform_id' => :'platform_id', :'platform_name' => :'platform_name', :'pod_id' => :'pod_id', :'pod_labels' => :'pod_labels', :'pod_name' => :'pod_name', :'pod_namespace' => :'pod_namespace', :'pod_service_account_name' => :'pod_service_account_name', :'product_type' => :'product_type', :'product_type_desc' => :'product_type_desc', :'release_group' => :'release_group', :'service_provider' => :'service_provider', :'service_provider_account_id' => :'service_provider_account_id', :'site_name' => :'site_name', :'status' => :'status', :'system_manufacturer' => :'system_manufacturer', :'system_product_name' => :'system_product_name', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
542 543 544 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 542 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
236 237 238 239 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 236 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 184 def self.openapi_types { :'agent_load_flags' => :'String', :'agent_local_time' => :'String', :'agent_version' => :'String', :'bios_manufacturer' => :'String', :'bios_version' => :'String', :'cid' => :'String', :'config_id_base' => :'String', :'config_id_build' => :'String', :'config_id_platform' => :'String', :'device_id' => :'String', :'external_ip' => :'String', :'first_login_timestamp' => :'String', :'first_login_user' => :'String', :'first_seen' => :'String', :'groups' => :'Array<String>', :'hostname' => :'String', :'instance_id' => :'String', :'last_login_timestamp' => :'String', :'last_login_user' => :'String', :'last_seen' => :'String', :'local_ip' => :'String', :'mac_address' => :'String', :'machine_domain' => :'String', :'major_version' => :'String', :'minor_version' => :'String', :'modified_timestamp' => :'String', :'notes' => :'Array<String>', :'os_version' => :'String', :'ou' => :'Array<String>', :'platform_id' => :'String', :'platform_name' => :'String', :'pod_id' => :'String', :'pod_labels' => :'Array<String>', :'pod_name' => :'String', :'pod_namespace' => :'String', :'pod_service_account_name' => :'String', :'product_type' => :'String', :'product_type_desc' => :'String', :'release_group' => :'String', :'service_provider' => :'String', :'service_provider_account_id' => :'String', :'site_name' => :'String', :'status' => :'String', :'system_manufacturer' => :'String', :'system_product_name' => :'String', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 476 def ==(o) return true if self.equal?(o) self.class == o.class && agent_load_flags == o.agent_load_flags && agent_local_time == o.agent_local_time && agent_version == o.agent_version && bios_manufacturer == o.bios_manufacturer && bios_version == o.bios_version && cid == o.cid && config_id_base == o.config_id_base && config_id_build == o.config_id_build && config_id_platform == o.config_id_platform && device_id == o.device_id && external_ip == o.external_ip && == o. && first_login_user == o.first_login_user && first_seen == o.first_seen && groups == o.groups && hostname == o.hostname && instance_id == o.instance_id && == o. && last_login_user == o.last_login_user && last_seen == o.last_seen && local_ip == o.local_ip && mac_address == o.mac_address && machine_domain == o.machine_domain && major_version == o.major_version && minor_version == o.minor_version && == o. && notes == o.notes && os_version == o.os_version && ou == o.ou && platform_id == o.platform_id && platform_name == o.platform_name && pod_id == o.pod_id && pod_labels == o.pod_labels && pod_name == o.pod_name && pod_namespace == o.pod_namespace && pod_service_account_name == o.pod_service_account_name && product_type == o.product_type && product_type_desc == o.product_type_desc && release_group == o.release_group && service_provider == o.service_provider && service_provider_account_id == o.service_provider_account_id && site_name == o.site_name && status == o.status && system_manufacturer == o.system_manufacturer && system_product_name == o.system_product_name && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 573 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 644 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 549 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
529 530 531 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 529 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
535 536 537 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 535 def hash [agent_load_flags, agent_local_time, agent_version, bios_manufacturer, bios_version, cid, config_id_base, config_id_build, config_id_platform, device_id, external_ip, , first_login_user, first_seen, groups, hostname, instance_id, , last_login_user, last_seen, local_ip, mac_address, machine_domain, major_version, minor_version, , notes, os_version, ou, platform_id, platform_name, pod_id, pod_labels, pod_name, pod_namespace, pod_service_account_name, product_type, product_type_desc, release_group, service_provider, service_provider_account_id, site_name, status, system_manufacturer, system_product_name, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 453 def list_invalid_properties invalid_properties = Array.new if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @device_id.nil? invalid_properties.push('invalid value for "device_id", device_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
620 621 622 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 620 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 626 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
614 615 616 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 614 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
468 469 470 471 472 |
# File 'lib/crimson-falcon/models/detects_device_detail_indexed.rb', line 468 def valid? return false if @cid.nil? return false if @device_id.nil? true end |