Class: Falcon::DetectsapiAggregateAlertQueryRequest
- Inherits:
-
Object
- Object
- Falcon::DetectsapiAggregateAlertQueryRequest
- Defined in:
- lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb
Instance Attribute Summary collapse
-
#date_ranges ⇒ Object
DateRanges applies to date_range aggregations.
-
#exclude ⇒ Object
Exclude Post-filtering on queried fields.
-
#field ⇒ Object
Field applies for example to date_histogram and range aggregations.
-
#filter ⇒ Object
FQL query specifying the filter parameters.
-
#from ⇒ Object
used in bucket sort aggregations as an offset.
-
#include ⇒ Object
Include Post-filtering on queried fields.
-
#interval ⇒ Object
Interval applies for example to date_histogram aggregations (uses calendar_interval).
-
#max_doc_count ⇒ Object
only return terms that match less than a configured number of hits.
-
#min_doc_count ⇒ Object
only return terms that match more than a configured number of hits.
-
#missing ⇒ Object
Missing is a value for missing term field.
-
#name ⇒ Object
Name of the aggregate query.
-
#q ⇒ Object
represents full text query.
-
#ranges ⇒ Object
Ranges applies to range aggregations.
-
#size ⇒ Object
how many term buckets should be returned.
-
#sort ⇒ Object
Sort spec, ex: ‘pattern_id|desc’.
-
#sub_aggregates ⇒ Object
sub aggregate alert query.
-
#time_zone ⇒ Object
TimeZone timezone to specify when bucketing results.
-
#type ⇒ Object
Datastore supported value types: term, terms, date_histogram, facet, range, cardinality.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DetectsapiAggregateAlertQueryRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DetectsapiAggregateAlertQueryRequest
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 149 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DetectsapiAggregateAlertQueryRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DetectsapiAggregateAlertQueryRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_ranges') if (value = attributes[:'date_ranges']).is_a?(Array) self.date_ranges = value end end if attributes.key?(:'exclude') self.exclude = attributes[:'exclude'] end if attributes.key?(:'field') self.field = attributes[:'field'] end if attributes.key?(:'filter') self.filter = attributes[:'filter'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'include') self.include = attributes[:'include'] end if attributes.key?(:'interval') self.interval = attributes[:'interval'] end if attributes.key?(:'max_doc_count') self.max_doc_count = attributes[:'max_doc_count'] end if attributes.key?(:'min_doc_count') self.min_doc_count = attributes[:'min_doc_count'] end if attributes.key?(:'missing') self.missing = attributes[:'missing'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'q') self.q = attributes[:'q'] end if attributes.key?(:'ranges') if (value = attributes[:'ranges']).is_a?(Array) self.ranges = value end end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'sort') self.sort = attributes[:'sort'] end if attributes.key?(:'sub_aggregates') if (value = attributes[:'sub_aggregates']).is_a?(Array) self.sub_aggregates = value end end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#date_ranges ⇒ Object
DateRanges applies to date_range aggregations.
35 36 37 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 35 def date_ranges @date_ranges end |
#exclude ⇒ Object
Exclude Post-filtering on queried fields
38 39 40 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 38 def exclude @exclude end |
#field ⇒ Object
Field applies for example to date_histogram and range aggregations.
41 42 43 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 41 def field @field end |
#filter ⇒ Object
FQL query specifying the filter parameters.
44 45 46 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 44 def filter @filter end |
#from ⇒ Object
used in bucket sort aggregations as an offset
47 48 49 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 47 def from @from end |
#include ⇒ Object
Include Post-filtering on queried fields
50 51 52 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 50 def include @include end |
#interval ⇒ Object
Interval applies for example to date_histogram aggregations (uses calendar_interval). Possible values: year, month, week, day, hour, minute.
53 54 55 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 53 def interval @interval end |
#max_doc_count ⇒ Object
only return terms that match less than a configured number of hits.
56 57 58 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 56 def max_doc_count @max_doc_count end |
#min_doc_count ⇒ Object
only return terms that match more than a configured number of hits.
59 60 61 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 59 def min_doc_count @min_doc_count end |
#missing ⇒ Object
Missing is a value for missing term field. The behavior that query should return if the document does not have the field in the query
62 63 64 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 62 def missing @missing end |
#name ⇒ Object
Name of the aggregate query
65 66 67 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 65 def name @name end |
#q ⇒ Object
represents full text query
68 69 70 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 68 def q @q end |
#ranges ⇒ Object
Ranges applies to range aggregations.
71 72 73 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 71 def ranges @ranges end |
#size ⇒ Object
how many term buckets should be returned.
74 75 76 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 74 def size @size end |
#sort ⇒ Object
Sort spec, ex: ‘pattern_id|desc’.
77 78 79 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 77 def sort @sort end |
#sub_aggregates ⇒ Object
sub aggregate alert query.
80 81 82 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 80 def sub_aggregates @sub_aggregates end |
#time_zone ⇒ Object
TimeZone timezone to specify when bucketing results.
83 84 85 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 83 def time_zone @time_zone end |
#type ⇒ Object
Datastore supported value types: term, terms, date_histogram, facet, range, cardinality. Exact allowed values specific to endpoint.
86 87 88 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 86 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 113 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 89 def self.attribute_map { :'date_ranges' => :'date_ranges', :'exclude' => :'exclude', :'field' => :'field', :'filter' => :'filter', :'from' => :'from', :'include' => :'include', :'interval' => :'interval', :'max_doc_count' => :'max_doc_count', :'min_doc_count' => :'min_doc_count', :'missing' => :'missing', :'name' => :'name', :'q' => :'q', :'ranges' => :'ranges', :'size' => :'size', :'sort' => :'sort', :'sub_aggregates' => :'sub_aggregates', :'time_zone' => :'time_zone', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
374 375 376 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 374 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 142 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 118 def self.openapi_types { :'date_ranges' => :'Array<MsaDateRangeSpec>', :'exclude' => :'String', :'field' => :'String', :'filter' => :'String', :'from' => :'Integer', :'include' => :'String', :'interval' => :'String', :'max_doc_count' => :'Integer', :'min_doc_count' => :'Integer', :'missing' => :'String', :'name' => :'String', :'q' => :'String', :'ranges' => :'Array<MsaRangeSpec>', :'size' => :'Integer', :'sort' => :'String', :'sub_aggregates' => :'Array<DetectsapiAggregateAlertQueryRequest>', :'time_zone' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 336 def ==(o) return true if self.equal?(o) self.class == o.class && date_ranges == o.date_ranges && exclude == o.exclude && field == o.field && filter == o.filter && from == o.from && include == o.include && interval == o.interval && max_doc_count == o.max_doc_count && min_doc_count == o.min_doc_count && missing == o.missing && name == o.name && q == o.q && ranges == o.ranges && size == o.size && sort == o.sort && sub_aggregates == o.sub_aggregates && time_zone == o.time_zone && type == o.type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 405 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 476 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 381 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
361 362 363 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 361 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 367 def hash [date_ranges, exclude, field, filter, from, include, interval, max_doc_count, min_doc_count, missing, name, q, ranges, size, sort, sub_aggregates, time_zone, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 243 def list_invalid_properties invalid_properties = Array.new if @date_ranges.nil? invalid_properties.push('invalid value for "date_ranges", date_ranges cannot be nil.') end if @exclude.nil? invalid_properties.push('invalid value for "exclude", exclude cannot be nil.') end if @field.nil? invalid_properties.push('invalid value for "field", field cannot be nil.') end if @filter.nil? invalid_properties.push('invalid value for "filter", filter cannot be nil.') end if @from.nil? invalid_properties.push('invalid value for "from", from cannot be nil.') end if @include.nil? invalid_properties.push('invalid value for "include", include cannot be nil.') end if @interval.nil? invalid_properties.push('invalid value for "interval", interval cannot be nil.') end if @missing.nil? invalid_properties.push('invalid value for "missing", missing cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @q.nil? invalid_properties.push('invalid value for "q", q cannot be nil.') end if @ranges.nil? invalid_properties.push('invalid value for "ranges", ranges cannot be nil.') end if @size.nil? invalid_properties.push('invalid value for "size", size cannot be nil.') end if @sort.nil? invalid_properties.push('invalid value for "sort", sort cannot be nil.') end if @sub_aggregates.nil? invalid_properties.push('invalid value for "sub_aggregates", sub_aggregates cannot be nil.') end if @time_zone.nil? invalid_properties.push('invalid value for "time_zone", time_zone cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
452 453 454 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 452 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 458 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
446 447 448 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 446 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/crimson-falcon/models/detectsapi_aggregate_alert_query_request.rb', line 314 def valid? return false if @date_ranges.nil? return false if @exclude.nil? return false if @field.nil? return false if @filter.nil? return false if @from.nil? return false if @include.nil? return false if @interval.nil? return false if @missing.nil? return false if @name.nil? return false if @q.nil? return false if @ranges.nil? return false if @size.nil? return false if @sort.nil? return false if @sub_aggregates.nil? return false if @time_zone.nil? return false if @type.nil? true end |