Class: Falcon::DeviceMappedDevicePolicies

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/device_mapped_device_policies.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeviceMappedDevicePolicies

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 167

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DeviceMappedDevicePolicies` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DeviceMappedDevicePolicies`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'airlock')
    self.airlock = attributes[:'airlock']
  end

  if attributes.key?(:'automox')
    self.automox = attributes[:'automox']
  end

  if attributes.key?(:'aws_verified_access')
    self.aws_verified_access = attributes[:'aws_verified_access']
  end

  if attributes.key?(:'browser_extension')
    self.browser_extension = attributes[:'browser_extension']
  end

  if attributes.key?(:'consumer_subscription')
    self.consumer_subscription = attributes[:'consumer_subscription']
  end

  if attributes.key?(:'content_update')
    self.content_update = attributes[:'content_update']
  end

  if attributes.key?(:'customer_entitlements')
    self.customer_entitlements = attributes[:'customer_entitlements']
  end

  if attributes.key?(:'data_protection')
    self.data_protection = attributes[:'data_protection']
  end

  if attributes.key?(:'device_control')
    self.device_control = attributes[:'device_control']
  end

  if attributes.key?(:'fim')
    self.fim = attributes[:'fim']
  end

  if attributes.key?(:'firewall')
    self.firewall = attributes[:'firewall']
  end

  if attributes.key?(:'global_config')
    self.global_config = attributes[:'global_config']
  end

  if attributes.key?(:'host_retention')
    self.host_retention = attributes[:'host_retention']
  end

  if attributes.key?(:'identity_protection')
    self.identity_protection = attributes[:'identity_protection']
  end

  if attributes.key?(:'it_automation')
    self.it_automation = attributes[:'it_automation']
  end

  if attributes.key?(:'jumpcloud')
    self.jumpcloud = attributes[:'jumpcloud']
  end

  if attributes.key?(:'kubernetes_admission_control')
    self.kubernetes_admission_control = attributes[:'kubernetes_admission_control']
  end

  if attributes.key?(:'mobile')
    self.mobile = attributes[:'mobile']
  end

  if attributes.key?(:'netskope')
    self.netskope = attributes[:'netskope']
  end

  if attributes.key?(:'network_scan_content')
    self.network_scan_content = attributes[:'network_scan_content']
  end

  if attributes.key?(:'prevention')
    self.prevention = attributes[:'prevention']
  end

  if attributes.key?(:'remote_response')
    self.remote_response = attributes[:'remote_response']
  end

  if attributes.key?(:'sca')
    self.sca = attributes[:'sca']
  end

  if attributes.key?(:'sensor_update')
    self.sensor_update = attributes[:'sensor_update']
  end

  if attributes.key?(:'system_tray')
    self.system_tray = attributes[:'system_tray']
  end

  if attributes.key?(:'vulnerability_management')
    self.vulnerability_management = attributes[:'vulnerability_management']
  end

  if attributes.key?(:'ztl')
    self.ztl = attributes[:'ztl']
  end
end

Instance Attribute Details

#airlockObject

Returns the value of attribute airlock.



34
35
36
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 34

def airlock
  @airlock
end

#automoxObject

Returns the value of attribute automox.



36
37
38
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 36

def automox
  @automox
end

#aws_verified_accessObject

Returns the value of attribute aws_verified_access.



38
39
40
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 38

def aws_verified_access
  @aws_verified_access
end

#browser_extensionObject

Returns the value of attribute browser_extension.



40
41
42
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 40

def browser_extension
  @browser_extension
end

#consumer_subscriptionObject

Returns the value of attribute consumer_subscription.



42
43
44
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 42

def consumer_subscription
  @consumer_subscription
end

#content_updateObject

Returns the value of attribute content_update.



44
45
46
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 44

def content_update
  @content_update
end

#customer_entitlementsObject

Returns the value of attribute customer_entitlements.



46
47
48
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 46

def customer_entitlements
  @customer_entitlements
end

#data_protectionObject

Returns the value of attribute data_protection.



48
49
50
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 48

def data_protection
  @data_protection
end

#device_controlObject

Returns the value of attribute device_control.



50
51
52
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 50

def device_control
  @device_control
end

#fimObject

Returns the value of attribute fim.



52
53
54
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 52

def fim
  @fim
end

#firewallObject

Returns the value of attribute firewall.



54
55
56
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 54

def firewall
  @firewall
end

#global_configObject

Returns the value of attribute global_config.



56
57
58
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 56

def global_config
  @global_config
end

#host_retentionObject

Returns the value of attribute host_retention.



58
59
60
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 58

def host_retention
  @host_retention
end

#identity_protectionObject

Returns the value of attribute identity_protection.



60
61
62
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 60

def identity_protection
  @identity_protection
end

#it_automationObject

Returns the value of attribute it_automation.



62
63
64
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 62

def it_automation
  @it_automation
end

#jumpcloudObject

Returns the value of attribute jumpcloud.



64
65
66
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 64

def jumpcloud
  @jumpcloud
end

#kubernetes_admission_controlObject

Returns the value of attribute kubernetes_admission_control.



66
67
68
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 66

def kubernetes_admission_control
  @kubernetes_admission_control
end

#mobileObject

Returns the value of attribute mobile.



68
69
70
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 68

def mobile
  @mobile
end

#netskopeObject

Returns the value of attribute netskope.



70
71
72
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 70

def netskope
  @netskope
end

#network_scan_contentObject

Returns the value of attribute network_scan_content.



72
73
74
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 72

def network_scan_content
  @network_scan_content
end

#preventionObject

Returns the value of attribute prevention.



74
75
76
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 74

def prevention
  @prevention
end

#remote_responseObject

Returns the value of attribute remote_response.



76
77
78
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 76

def remote_response
  @remote_response
end

#scaObject

Returns the value of attribute sca.



78
79
80
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 78

def sca
  @sca
end

#sensor_updateObject

Returns the value of attribute sensor_update.



80
81
82
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 80

def sensor_update
  @sensor_update
end

#system_trayObject

Returns the value of attribute system_tray.



82
83
84
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 82

def system_tray
  @system_tray
end

#vulnerability_managementObject

Returns the value of attribute vulnerability_management.



84
85
86
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 84

def vulnerability_management
  @vulnerability_management
end

#ztlObject

Returns the value of attribute ztl.



86
87
88
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 86

def ztl
  @ztl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



122
123
124
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 122

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 89

def self.attribute_map
  {
    :'airlock' => :'airlock',
    :'automox' => :'automox',
    :'aws_verified_access' => :'aws-verified-access',
    :'browser_extension' => :'browser-extension',
    :'consumer_subscription' => :'consumer-subscription',
    :'content_update' => :'content-update',
    :'customer_entitlements' => :'customer-entitlements',
    :'data_protection' => :'data-protection',
    :'device_control' => :'device_control',
    :'fim' => :'fim',
    :'firewall' => :'firewall',
    :'global_config' => :'global_config',
    :'host_retention' => :'host-retention',
    :'identity_protection' => :'identity-protection',
    :'it_automation' => :'it-automation',
    :'jumpcloud' => :'jumpcloud',
    :'kubernetes_admission_control' => :'kubernetes-admission-control',
    :'mobile' => :'mobile',
    :'netskope' => :'netskope',
    :'network_scan_content' => :'network-scan-content',
    :'prevention' => :'prevention',
    :'remote_response' => :'remote_response',
    :'sca' => :'sca',
    :'sensor_update' => :'sensor_update',
    :'system_tray' => :'system-tray',
    :'vulnerability_management' => :'vulnerability-management',
    :'ztl' => :'ztl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



351
352
353
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 351

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



160
161
162
163
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 160

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 127

def self.openapi_types
  {
    :'airlock' => :'DeviceDevicePolicy',
    :'automox' => :'DeviceDevicePolicy',
    :'aws_verified_access' => :'DeviceDevicePolicy',
    :'browser_extension' => :'DeviceDevicePolicy',
    :'consumer_subscription' => :'DeviceDevicePolicy',
    :'content_update' => :'DeviceDevicePolicy',
    :'customer_entitlements' => :'DeviceDevicePolicy',
    :'data_protection' => :'DeviceDevicePolicy',
    :'device_control' => :'DeviceDevicePolicy',
    :'fim' => :'DeviceDevicePolicy',
    :'firewall' => :'DeviceDevicePolicy',
    :'global_config' => :'DeviceDevicePolicy',
    :'host_retention' => :'DeviceDevicePolicy',
    :'identity_protection' => :'DeviceDevicePolicy',
    :'it_automation' => :'DeviceDevicePolicy',
    :'jumpcloud' => :'DeviceDevicePolicy',
    :'kubernetes_admission_control' => :'DeviceDevicePolicy',
    :'mobile' => :'DeviceDevicePolicy',
    :'netskope' => :'DeviceDevicePolicy',
    :'network_scan_content' => :'DeviceDevicePolicy',
    :'prevention' => :'DeviceDevicePolicy',
    :'remote_response' => :'DeviceDevicePolicy',
    :'sca' => :'DeviceDevicePolicy',
    :'sensor_update' => :'DeviceDevicePolicy',
    :'system_tray' => :'DeviceDevicePolicy',
    :'vulnerability_management' => :'DeviceDevicePolicy',
    :'ztl' => :'DeviceDevicePolicy'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      airlock == o.airlock &&
      automox == o.automox &&
      aws_verified_access == o.aws_verified_access &&
      browser_extension == o.browser_extension &&
      consumer_subscription == o.consumer_subscription &&
      content_update == o.content_update &&
      customer_entitlements == o.customer_entitlements &&
      data_protection == o.data_protection &&
      device_control == o.device_control &&
      fim == o.fim &&
      firewall == o.firewall &&
      global_config == o.global_config &&
      host_retention == o.host_retention &&
      identity_protection == o.identity_protection &&
      it_automation == o.it_automation &&
      jumpcloud == o.jumpcloud &&
      kubernetes_admission_control == o.kubernetes_admission_control &&
      mobile == o.mobile &&
      netskope == o.netskope &&
      network_scan_content == o.network_scan_content &&
      prevention == o.prevention &&
      remote_response == o.remote_response &&
      sca == o.sca &&
      sensor_update == o.sensor_update &&
      system_tray == o.system_tray &&
      vulnerability_management == o.vulnerability_management &&
      ztl == o.ztl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 382

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 453

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 358

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 338

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



344
345
346
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 344

def hash
  [airlock, automox, aws_verified_access, browser_extension, consumer_subscription, content_update, customer_entitlements, data_protection, device_control, fim, firewall, global_config, host_retention, identity_protection, it_automation, jumpcloud, kubernetes_admission_control, mobile, netskope, network_scan_content, prevention, remote_response, sca, sensor_update, system_tray, vulnerability_management, ztl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



291
292
293
294
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 291

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 429

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 435

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



423
424
425
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 423

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



298
299
300
# File 'lib/crimson-falcon/models/device_mapped_device_policies.rb', line 298

def valid?
  true
end