Class: Falcon::DeviceapiDeviceSwagger

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/deviceapi_device_swagger.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeviceapiDeviceSwagger

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 431

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DeviceapiDeviceSwagger` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DeviceapiDeviceSwagger`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agent_load_flags')
    self.agent_load_flags = attributes[:'agent_load_flags']
  end

  if attributes.key?(:'agent_local_time')
    self.agent_local_time = attributes[:'agent_local_time']
  end

  if attributes.key?(:'agent_version')
    self.agent_version = attributes[:'agent_version']
  end

  if attributes.key?(:'base_image_version')
    self.base_image_version = attributes[:'base_image_version']
  end

  if attributes.key?(:'bios_manufacturer')
    self.bios_manufacturer = attributes[:'bios_manufacturer']
  end

  if attributes.key?(:'bios_version')
    self.bios_version = attributes[:'bios_version']
  end

  if attributes.key?(:'build_number')
    self.build_number = attributes[:'build_number']
  end

  if attributes.key?(:'chassis_type')
    self.chassis_type = attributes[:'chassis_type']
  end

  if attributes.key?(:'chassis_type_desc')
    self.chassis_type_desc = attributes[:'chassis_type_desc']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'config_id_base')
    self.config_id_base = attributes[:'config_id_base']
  end

  if attributes.key?(:'config_id_build')
    self.config_id_build = attributes[:'config_id_build']
  end

  if attributes.key?(:'config_id_platform')
    self.config_id_platform = attributes[:'config_id_platform']
  end

  if attributes.key?(:'connection_ip')
    self.connection_ip = attributes[:'connection_ip']
  end

  if attributes.key?(:'connection_mac_address')
    self.connection_mac_address = attributes[:'connection_mac_address']
  end

  if attributes.key?(:'cpu_signature')
    self.cpu_signature = attributes[:'cpu_signature']
  end

  if attributes.key?(:'cpu_vendor')
    self.cpu_vendor = attributes[:'cpu_vendor']
  end

  if attributes.key?(:'criticality')
    self.criticality = attributes[:'criticality']
  end

  if attributes.key?(:'default_gateway_ip')
    self.default_gateway_ip = attributes[:'default_gateway_ip']
  end

  if attributes.key?(:'deployment_type')
    self.deployment_type = attributes[:'deployment_type']
  end

  if attributes.key?(:'detection_suppression_status')
    self.detection_suppression_status = attributes[:'detection_suppression_status']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'device_policies')
    self.device_policies = attributes[:'device_policies']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'external_ip')
    self.external_ip = attributes[:'external_ip']
  end

  if attributes.key?(:'filesystem_containment_status')
    self.filesystem_containment_status = attributes[:'filesystem_containment_status']
  end

  if attributes.key?(:'first_login_timestamp')
    self. = attributes[:'first_login_timestamp']
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  end

  if attributes.key?(:'group_hash')
    self.group_hash = attributes[:'group_hash']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'host_hidden_status')
    self.host_hidden_status = attributes[:'host_hidden_status']
  end

  if attributes.key?(:'host_utc_offset')
    self.host_utc_offset = attributes[:'host_utc_offset']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'instance_id')
    self.instance_id = attributes[:'instance_id']
  end

  if attributes.key?(:'internet_exposure')
    self.internet_exposure = attributes[:'internet_exposure']
  end

  if attributes.key?(:'k8s_cluster_git_version')
    self.k8s_cluster_git_version = attributes[:'k8s_cluster_git_version']
  end

  if attributes.key?(:'k8s_cluster_id')
    self.k8s_cluster_id = attributes[:'k8s_cluster_id']
  end

  if attributes.key?(:'k8s_cluster_version')
    self.k8s_cluster_version = attributes[:'k8s_cluster_version']
  end

  if attributes.key?(:'kernel_version')
    self.kernel_version = attributes[:'kernel_version']
  end

  if attributes.key?(:'last_login_timestamp')
    self. = attributes[:'last_login_timestamp']
  end

  if attributes.key?(:'last_login_uid')
    self. = attributes[:'last_login_uid']
  end

  if attributes.key?(:'last_login_user')
    self. = attributes[:'last_login_user']
  end

  if attributes.key?(:'last_login_user_sid')
    self. = attributes[:'last_login_user_sid']
  end

  if attributes.key?(:'last_reboot')
    self.last_reboot = attributes[:'last_reboot']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'linux_sensor_mode')
    self.linux_sensor_mode = attributes[:'linux_sensor_mode']
  end

  if attributes.key?(:'local_ip')
    self.local_ip = attributes[:'local_ip']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'machine_domain')
    self.machine_domain = attributes[:'machine_domain']
  end

  if attributes.key?(:'major_version')
    self.major_version = attributes[:'major_version']
  end

  if attributes.key?(:'managed_apps')
    self.managed_apps = attributes[:'managed_apps']
  end

  if attributes.key?(:'meta')
    self.meta = attributes[:'meta']
  end

  if attributes.key?(:'migration_completed_time')
    self.migration_completed_time = attributes[:'migration_completed_time']
  end

  if attributes.key?(:'minor_version')
    self.minor_version = attributes[:'minor_version']
  end

  if attributes.key?(:'modified_timestamp')
    self.modified_timestamp = attributes[:'modified_timestamp']
  end

  if attributes.key?(:'notes')
    if (value = attributes[:'notes']).is_a?(Array)
      self.notes = value
    end
  end

  if attributes.key?(:'os_build')
    self.os_build = attributes[:'os_build']
  end

  if attributes.key?(:'os_product_name')
    self.os_product_name = attributes[:'os_product_name']
  end

  if attributes.key?(:'os_version')
    self.os_version = attributes[:'os_version']
  end

  if attributes.key?(:'ou')
    if (value = attributes[:'ou']).is_a?(Array)
      self.ou = value
    end
  end

  if attributes.key?(:'platform_id')
    self.platform_id = attributes[:'platform_id']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'pod_annotations')
    if (value = attributes[:'pod_annotations']).is_a?(Array)
      self.pod_annotations = value
    end
  end

  if attributes.key?(:'pod_host_ip4')
    self.pod_host_ip4 = attributes[:'pod_host_ip4']
  end

  if attributes.key?(:'pod_host_ip6')
    self.pod_host_ip6 = attributes[:'pod_host_ip6']
  end

  if attributes.key?(:'pod_hostname')
    self.pod_hostname = attributes[:'pod_hostname']
  end

  if attributes.key?(:'pod_id')
    self.pod_id = attributes[:'pod_id']
  end

  if attributes.key?(:'pod_ip4')
    self.pod_ip4 = attributes[:'pod_ip4']
  end

  if attributes.key?(:'pod_ip6')
    self.pod_ip6 = attributes[:'pod_ip6']
  end

  if attributes.key?(:'pod_labels')
    if (value = attributes[:'pod_labels']).is_a?(Array)
      self.pod_labels = value
    end
  end

  if attributes.key?(:'pod_name')
    self.pod_name = attributes[:'pod_name']
  end

  if attributes.key?(:'pod_namespace')
    self.pod_namespace = attributes[:'pod_namespace']
  end

  if attributes.key?(:'pod_service_account_name')
    self. = attributes[:'pod_service_account_name']
  end

  if attributes.key?(:'pointer_size')
    self.pointer_size = attributes[:'pointer_size']
  end

  if attributes.key?(:'policies')
    if (value = attributes[:'policies']).is_a?(Array)
      self.policies = value
    end
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  end

  if attributes.key?(:'product_type_desc')
    self.product_type_desc = attributes[:'product_type_desc']
  end

  if attributes.key?(:'provision_status')
    self.provision_status = attributes[:'provision_status']
  end

  if attributes.key?(:'reduced_functionality_mode')
    self.reduced_functionality_mode = attributes[:'reduced_functionality_mode']
  end

  if attributes.key?(:'release_group')
    self.release_group = attributes[:'release_group']
  end

  if attributes.key?(:'rtr_state')
    self.rtr_state = attributes[:'rtr_state']
  end

  if attributes.key?(:'safe_mode')
    self.safe_mode = attributes[:'safe_mode']
  end

  if attributes.key?(:'serial_number')
    self.serial_number = attributes[:'serial_number']
  end

  if attributes.key?(:'service_pack_major')
    self.service_pack_major = attributes[:'service_pack_major']
  end

  if attributes.key?(:'service_pack_minor')
    self.service_pack_minor = attributes[:'service_pack_minor']
  end

  if attributes.key?(:'service_provider')
    self.service_provider = attributes[:'service_provider']
  end

  if attributes.key?(:'service_provider_account_id')
    self. = attributes[:'service_provider_account_id']
  end

  if attributes.key?(:'site_name')
    self.site_name = attributes[:'site_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'system_manufacturer')
    self.system_manufacturer = attributes[:'system_manufacturer']
  end

  if attributes.key?(:'system_product_name')
    self.system_product_name = attributes[:'system_product_name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'zone_group')
    self.zone_group = attributes[:'zone_group']
  end
end

Instance Attribute Details

#agent_load_flagsObject

Returns the value of attribute agent_load_flags.



34
35
36
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 34

def agent_load_flags
  @agent_load_flags
end

#agent_local_timeObject

Returns the value of attribute agent_local_time.



36
37
38
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 36

def agent_local_time
  @agent_local_time
end

#agent_versionObject

Returns the value of attribute agent_version.



38
39
40
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 38

def agent_version
  @agent_version
end

#base_image_versionObject

Returns the value of attribute base_image_version.



40
41
42
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 40

def base_image_version
  @base_image_version
end

#bios_manufacturerObject

Returns the value of attribute bios_manufacturer.



42
43
44
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 42

def bios_manufacturer
  @bios_manufacturer
end

#bios_versionObject

Returns the value of attribute bios_version.



44
45
46
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 44

def bios_version
  @bios_version
end

#build_numberObject

Returns the value of attribute build_number.



46
47
48
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 46

def build_number
  @build_number
end

#chassis_typeObject

Returns the value of attribute chassis_type.



48
49
50
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 48

def chassis_type
  @chassis_type
end

#chassis_type_descObject

Returns the value of attribute chassis_type_desc.



50
51
52
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 50

def chassis_type_desc
  @chassis_type_desc
end

#cidObject

Returns the value of attribute cid.



52
53
54
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 52

def cid
  @cid
end

#config_id_baseObject

Returns the value of attribute config_id_base.



54
55
56
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 54

def config_id_base
  @config_id_base
end

#config_id_buildObject

Returns the value of attribute config_id_build.



56
57
58
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 56

def config_id_build
  @config_id_build
end

#config_id_platformObject

Returns the value of attribute config_id_platform.



58
59
60
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 58

def config_id_platform
  @config_id_platform
end

#connection_ipObject

Returns the value of attribute connection_ip.



60
61
62
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 60

def connection_ip
  @connection_ip
end

#connection_mac_addressObject

Returns the value of attribute connection_mac_address.



62
63
64
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 62

def connection_mac_address
  @connection_mac_address
end

#cpu_signatureObject

Returns the value of attribute cpu_signature.



64
65
66
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 64

def cpu_signature
  @cpu_signature
end

#cpu_vendorObject

Returns the value of attribute cpu_vendor.



66
67
68
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 66

def cpu_vendor
  @cpu_vendor
end

#criticalityObject

Returns the value of attribute criticality.



68
69
70
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 68

def criticality
  @criticality
end

#default_gateway_ipObject

Returns the value of attribute default_gateway_ip.



70
71
72
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 70

def default_gateway_ip
  @default_gateway_ip
end

#deployment_typeObject

Returns the value of attribute deployment_type.



72
73
74
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 72

def deployment_type
  @deployment_type
end

#detection_suppression_statusObject

Returns the value of attribute detection_suppression_status.



74
75
76
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 74

def detection_suppression_status
  @detection_suppression_status
end

#device_idObject

Returns the value of attribute device_id.



76
77
78
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 76

def device_id
  @device_id
end

#device_policiesObject

Returns the value of attribute device_policies.



78
79
80
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 78

def device_policies
  @device_policies
end

#emailObject

Returns the value of attribute email.



80
81
82
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 80

def email
  @email
end

#external_ipObject

Returns the value of attribute external_ip.



82
83
84
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 82

def external_ip
  @external_ip
end

#filesystem_containment_statusObject

Returns the value of attribute filesystem_containment_status.



84
85
86
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 84

def filesystem_containment_status
  @filesystem_containment_status
end

#first_login_timestampObject

Returns the value of attribute first_login_timestamp.



86
87
88
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 86

def 
  @first_login_timestamp
end

#first_seenObject

Returns the value of attribute first_seen.



88
89
90
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 88

def first_seen
  @first_seen
end

#group_hashObject

Returns the value of attribute group_hash.



90
91
92
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 90

def group_hash
  @group_hash
end

#groupsObject

Returns the value of attribute groups.



92
93
94
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 92

def groups
  @groups
end

#host_hidden_statusObject

Returns the value of attribute host_hidden_status.



94
95
96
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 94

def host_hidden_status
  @host_hidden_status
end

#host_utc_offsetObject

Returns the value of attribute host_utc_offset.



96
97
98
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 96

def host_utc_offset
  @host_utc_offset
end

#hostnameObject

Returns the value of attribute hostname.



98
99
100
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 98

def hostname
  @hostname
end

#instance_idObject

Returns the value of attribute instance_id.



100
101
102
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 100

def instance_id
  @instance_id
end

#internet_exposureObject

Returns the value of attribute internet_exposure.



102
103
104
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 102

def internet_exposure
  @internet_exposure
end

#k8s_cluster_git_versionObject

Returns the value of attribute k8s_cluster_git_version.



104
105
106
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 104

def k8s_cluster_git_version
  @k8s_cluster_git_version
end

#k8s_cluster_idObject

Returns the value of attribute k8s_cluster_id.



106
107
108
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 106

def k8s_cluster_id
  @k8s_cluster_id
end

#k8s_cluster_versionObject

Returns the value of attribute k8s_cluster_version.



108
109
110
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 108

def k8s_cluster_version
  @k8s_cluster_version
end

#kernel_versionObject

Returns the value of attribute kernel_version.



110
111
112
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 110

def kernel_version
  @kernel_version
end

#last_login_timestampObject

Returns the value of attribute last_login_timestamp.



112
113
114
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 112

def 
  @last_login_timestamp
end

#last_login_uidObject

Returns the value of attribute last_login_uid.



114
115
116
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 114

def 
  @last_login_uid
end

#last_login_userObject

Returns the value of attribute last_login_user.



116
117
118
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 116

def 
  @last_login_user
end

#last_login_user_sidObject

Returns the value of attribute last_login_user_sid.



118
119
120
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 118

def 
  @last_login_user_sid
end

#last_rebootObject

Returns the value of attribute last_reboot.



120
121
122
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 120

def last_reboot
  @last_reboot
end

#last_seenObject

Returns the value of attribute last_seen.



122
123
124
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 122

def last_seen
  @last_seen
end

#linux_sensor_modeObject

Returns the value of attribute linux_sensor_mode.



124
125
126
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 124

def linux_sensor_mode
  @linux_sensor_mode
end

#local_ipObject

Returns the value of attribute local_ip.



126
127
128
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 126

def local_ip
  @local_ip
end

#mac_addressObject

Returns the value of attribute mac_address.



128
129
130
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 128

def mac_address
  @mac_address
end

#machine_domainObject

Returns the value of attribute machine_domain.



130
131
132
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 130

def machine_domain
  @machine_domain
end

#major_versionObject

Returns the value of attribute major_version.



132
133
134
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 132

def major_version
  @major_version
end

#managed_appsObject

Returns the value of attribute managed_apps.



134
135
136
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 134

def managed_apps
  @managed_apps
end

#metaObject

Returns the value of attribute meta.



136
137
138
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 136

def meta
  @meta
end

#migration_completed_timeObject

Returns the value of attribute migration_completed_time.



138
139
140
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 138

def migration_completed_time
  @migration_completed_time
end

#minor_versionObject

Returns the value of attribute minor_version.



140
141
142
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 140

def minor_version
  @minor_version
end

#modified_timestampObject

Returns the value of attribute modified_timestamp.



142
143
144
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 142

def modified_timestamp
  @modified_timestamp
end

#notesObject

Returns the value of attribute notes.



144
145
146
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 144

def notes
  @notes
end

#os_buildObject

Returns the value of attribute os_build.



146
147
148
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 146

def os_build
  @os_build
end

#os_product_nameObject

Returns the value of attribute os_product_name.



148
149
150
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 148

def os_product_name
  @os_product_name
end

#os_versionObject

Returns the value of attribute os_version.



150
151
152
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 150

def os_version
  @os_version
end

#ouObject

Returns the value of attribute ou.



152
153
154
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 152

def ou
  @ou
end

#platform_idObject

Returns the value of attribute platform_id.



154
155
156
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 154

def platform_id
  @platform_id
end

#platform_nameObject

Returns the value of attribute platform_name.



156
157
158
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 156

def platform_name
  @platform_name
end

#pod_annotationsObject

Returns the value of attribute pod_annotations.



158
159
160
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 158

def pod_annotations
  @pod_annotations
end

#pod_host_ip4Object

Returns the value of attribute pod_host_ip4.



160
161
162
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 160

def pod_host_ip4
  @pod_host_ip4
end

#pod_host_ip6Object

Returns the value of attribute pod_host_ip6.



162
163
164
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 162

def pod_host_ip6
  @pod_host_ip6
end

#pod_hostnameObject

Returns the value of attribute pod_hostname.



164
165
166
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 164

def pod_hostname
  @pod_hostname
end

#pod_idObject

Returns the value of attribute pod_id.



166
167
168
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 166

def pod_id
  @pod_id
end

#pod_ip4Object

Returns the value of attribute pod_ip4.



168
169
170
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 168

def pod_ip4
  @pod_ip4
end

#pod_ip6Object

Returns the value of attribute pod_ip6.



170
171
172
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 170

def pod_ip6
  @pod_ip6
end

#pod_labelsObject

Returns the value of attribute pod_labels.



172
173
174
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 172

def pod_labels
  @pod_labels
end

#pod_nameObject

Returns the value of attribute pod_name.



174
175
176
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 174

def pod_name
  @pod_name
end

#pod_namespaceObject

Returns the value of attribute pod_namespace.



176
177
178
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 176

def pod_namespace
  @pod_namespace
end

#pod_service_account_nameObject

Returns the value of attribute pod_service_account_name.



178
179
180
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 178

def 
  @pod_service_account_name
end

#pointer_sizeObject

Returns the value of attribute pointer_size.



180
181
182
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 180

def pointer_size
  @pointer_size
end

#policiesObject

Returns the value of attribute policies.



182
183
184
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 182

def policies
  @policies
end

#product_typeObject

Returns the value of attribute product_type.



184
185
186
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 184

def product_type
  @product_type
end

#product_type_descObject

Returns the value of attribute product_type_desc.



186
187
188
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 186

def product_type_desc
  @product_type_desc
end

#provision_statusObject

Returns the value of attribute provision_status.



188
189
190
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 188

def provision_status
  @provision_status
end

#reduced_functionality_modeObject

Returns the value of attribute reduced_functionality_mode.



190
191
192
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 190

def reduced_functionality_mode
  @reduced_functionality_mode
end

#release_groupObject

Returns the value of attribute release_group.



192
193
194
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 192

def release_group
  @release_group
end

#rtr_stateObject

Returns the value of attribute rtr_state.



194
195
196
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 194

def rtr_state
  @rtr_state
end

#safe_modeObject

Returns the value of attribute safe_mode.



196
197
198
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 196

def safe_mode
  @safe_mode
end

#serial_numberObject

Returns the value of attribute serial_number.



198
199
200
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 198

def serial_number
  @serial_number
end

#service_pack_majorObject

Returns the value of attribute service_pack_major.



200
201
202
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 200

def service_pack_major
  @service_pack_major
end

#service_pack_minorObject

Returns the value of attribute service_pack_minor.



202
203
204
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 202

def service_pack_minor
  @service_pack_minor
end

#service_providerObject

Returns the value of attribute service_provider.



204
205
206
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 204

def service_provider
  @service_provider
end

#service_provider_account_idObject

Returns the value of attribute service_provider_account_id.



206
207
208
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 206

def 
  @service_provider_account_id
end

#site_nameObject

Returns the value of attribute site_name.



208
209
210
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 208

def site_name
  @site_name
end

#statusObject

Returns the value of attribute status.



210
211
212
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 210

def status
  @status
end

#system_manufacturerObject

Returns the value of attribute system_manufacturer.



212
213
214
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 212

def system_manufacturer
  @system_manufacturer
end

#system_product_nameObject

Returns the value of attribute system_product_name.



214
215
216
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 214

def system_product_name
  @system_product_name
end

#tagsObject

Returns the value of attribute tags.



216
217
218
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 216

def tags
  @tags
end

#zone_groupObject

Returns the value of attribute zone_group.



218
219
220
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 218

def zone_group
  @zone_group
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



320
321
322
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 320

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 221

def self.attribute_map
  {
    :'agent_load_flags' => :'agent_load_flags',
    :'agent_local_time' => :'agent_local_time',
    :'agent_version' => :'agent_version',
    :'base_image_version' => :'base_image_version',
    :'bios_manufacturer' => :'bios_manufacturer',
    :'bios_version' => :'bios_version',
    :'build_number' => :'build_number',
    :'chassis_type' => :'chassis_type',
    :'chassis_type_desc' => :'chassis_type_desc',
    :'cid' => :'cid',
    :'config_id_base' => :'config_id_base',
    :'config_id_build' => :'config_id_build',
    :'config_id_platform' => :'config_id_platform',
    :'connection_ip' => :'connection_ip',
    :'connection_mac_address' => :'connection_mac_address',
    :'cpu_signature' => :'cpu_signature',
    :'cpu_vendor' => :'cpu_vendor',
    :'criticality' => :'criticality',
    :'default_gateway_ip' => :'default_gateway_ip',
    :'deployment_type' => :'deployment_type',
    :'detection_suppression_status' => :'detection_suppression_status',
    :'device_id' => :'device_id',
    :'device_policies' => :'device_policies',
    :'email' => :'email',
    :'external_ip' => :'external_ip',
    :'filesystem_containment_status' => :'filesystem_containment_status',
    :'first_login_timestamp' => :'first_login_timestamp',
    :'first_seen' => :'first_seen',
    :'group_hash' => :'group_hash',
    :'groups' => :'groups',
    :'host_hidden_status' => :'host_hidden_status',
    :'host_utc_offset' => :'host_utc_offset',
    :'hostname' => :'hostname',
    :'instance_id' => :'instance_id',
    :'internet_exposure' => :'internet_exposure',
    :'k8s_cluster_git_version' => :'k8s_cluster_git_version',
    :'k8s_cluster_id' => :'k8s_cluster_id',
    :'k8s_cluster_version' => :'k8s_cluster_version',
    :'kernel_version' => :'kernel_version',
    :'last_login_timestamp' => :'last_login_timestamp',
    :'last_login_uid' => :'last_login_uid',
    :'last_login_user' => :'last_login_user',
    :'last_login_user_sid' => :'last_login_user_sid',
    :'last_reboot' => :'last_reboot',
    :'last_seen' => :'last_seen',
    :'linux_sensor_mode' => :'linux_sensor_mode',
    :'local_ip' => :'local_ip',
    :'mac_address' => :'mac_address',
    :'machine_domain' => :'machine_domain',
    :'major_version' => :'major_version',
    :'managed_apps' => :'managed_apps',
    :'meta' => :'meta',
    :'migration_completed_time' => :'migration_completed_time',
    :'minor_version' => :'minor_version',
    :'modified_timestamp' => :'modified_timestamp',
    :'notes' => :'notes',
    :'os_build' => :'os_build',
    :'os_product_name' => :'os_product_name',
    :'os_version' => :'os_version',
    :'ou' => :'ou',
    :'platform_id' => :'platform_id',
    :'platform_name' => :'platform_name',
    :'pod_annotations' => :'pod_annotations',
    :'pod_host_ip4' => :'pod_host_ip4',
    :'pod_host_ip6' => :'pod_host_ip6',
    :'pod_hostname' => :'pod_hostname',
    :'pod_id' => :'pod_id',
    :'pod_ip4' => :'pod_ip4',
    :'pod_ip6' => :'pod_ip6',
    :'pod_labels' => :'pod_labels',
    :'pod_name' => :'pod_name',
    :'pod_namespace' => :'pod_namespace',
    :'pod_service_account_name' => :'pod_service_account_name',
    :'pointer_size' => :'pointer_size',
    :'policies' => :'policies',
    :'product_type' => :'product_type',
    :'product_type_desc' => :'product_type_desc',
    :'provision_status' => :'provision_status',
    :'reduced_functionality_mode' => :'reduced_functionality_mode',
    :'release_group' => :'release_group',
    :'rtr_state' => :'rtr_state',
    :'safe_mode' => :'safe_mode',
    :'serial_number' => :'serial_number',
    :'service_pack_major' => :'service_pack_major',
    :'service_pack_minor' => :'service_pack_minor',
    :'service_provider' => :'service_provider',
    :'service_provider_account_id' => :'service_provider_account_id',
    :'site_name' => :'site_name',
    :'status' => :'status',
    :'system_manufacturer' => :'system_manufacturer',
    :'system_product_name' => :'system_product_name',
    :'tags' => :'tags',
    :'zone_group' => :'zone_group'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



969
970
971
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 969

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



424
425
426
427
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 424

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 325

def self.openapi_types
  {
    :'agent_load_flags' => :'String',
    :'agent_local_time' => :'String',
    :'agent_version' => :'String',
    :'base_image_version' => :'String',
    :'bios_manufacturer' => :'String',
    :'bios_version' => :'String',
    :'build_number' => :'String',
    :'chassis_type' => :'String',
    :'chassis_type_desc' => :'String',
    :'cid' => :'String',
    :'config_id_base' => :'String',
    :'config_id_build' => :'String',
    :'config_id_platform' => :'String',
    :'connection_ip' => :'String',
    :'connection_mac_address' => :'String',
    :'cpu_signature' => :'String',
    :'cpu_vendor' => :'String',
    :'criticality' => :'String',
    :'default_gateway_ip' => :'String',
    :'deployment_type' => :'String',
    :'detection_suppression_status' => :'String',
    :'device_id' => :'String',
    :'device_policies' => :'DeviceapiMappedDevicePoliciesSwagger',
    :'email' => :'String',
    :'external_ip' => :'String',
    :'filesystem_containment_status' => :'String',
    :'first_login_timestamp' => :'String',
    :'first_seen' => :'String',
    :'group_hash' => :'String',
    :'groups' => :'Array<String>',
    :'host_hidden_status' => :'String',
    :'host_utc_offset' => :'String',
    :'hostname' => :'String',
    :'instance_id' => :'String',
    :'internet_exposure' => :'String',
    :'k8s_cluster_git_version' => :'String',
    :'k8s_cluster_id' => :'String',
    :'k8s_cluster_version' => :'String',
    :'kernel_version' => :'String',
    :'last_login_timestamp' => :'String',
    :'last_login_uid' => :'String',
    :'last_login_user' => :'String',
    :'last_login_user_sid' => :'String',
    :'last_reboot' => :'String',
    :'last_seen' => :'String',
    :'linux_sensor_mode' => :'String',
    :'local_ip' => :'String',
    :'mac_address' => :'String',
    :'machine_domain' => :'String',
    :'major_version' => :'String',
    :'managed_apps' => :'DeviceManagedApps',
    :'meta' => :'DeviceDeviceMeta',
    :'migration_completed_time' => :'String',
    :'minor_version' => :'String',
    :'modified_timestamp' => :'String',
    :'notes' => :'Array<String>',
    :'os_build' => :'String',
    :'os_product_name' => :'String',
    :'os_version' => :'String',
    :'ou' => :'Array<String>',
    :'platform_id' => :'String',
    :'platform_name' => :'String',
    :'pod_annotations' => :'Array<String>',
    :'pod_host_ip4' => :'String',
    :'pod_host_ip6' => :'String',
    :'pod_hostname' => :'String',
    :'pod_id' => :'String',
    :'pod_ip4' => :'String',
    :'pod_ip6' => :'String',
    :'pod_labels' => :'Array<String>',
    :'pod_name' => :'String',
    :'pod_namespace' => :'String',
    :'pod_service_account_name' => :'String',
    :'pointer_size' => :'String',
    :'policies' => :'Array<DeviceDevicePolicy>',
    :'product_type' => :'String',
    :'product_type_desc' => :'String',
    :'provision_status' => :'String',
    :'reduced_functionality_mode' => :'String',
    :'release_group' => :'String',
    :'rtr_state' => :'String',
    :'safe_mode' => :'String',
    :'serial_number' => :'String',
    :'service_pack_major' => :'String',
    :'service_pack_minor' => :'String',
    :'service_provider' => :'String',
    :'service_provider_account_id' => :'String',
    :'site_name' => :'String',
    :'status' => :'String',
    :'system_manufacturer' => :'String',
    :'system_product_name' => :'String',
    :'tags' => :'Array<String>',
    :'zone_group' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 856

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agent_load_flags == o.agent_load_flags &&
      agent_local_time == o.agent_local_time &&
      agent_version == o.agent_version &&
      base_image_version == o.base_image_version &&
      bios_manufacturer == o.bios_manufacturer &&
      bios_version == o.bios_version &&
      build_number == o.build_number &&
      chassis_type == o.chassis_type &&
      chassis_type_desc == o.chassis_type_desc &&
      cid == o.cid &&
      config_id_base == o.config_id_base &&
      config_id_build == o.config_id_build &&
      config_id_platform == o.config_id_platform &&
      connection_ip == o.connection_ip &&
      connection_mac_address == o.connection_mac_address &&
      cpu_signature == o.cpu_signature &&
      cpu_vendor == o.cpu_vendor &&
      criticality == o.criticality &&
      default_gateway_ip == o.default_gateway_ip &&
      deployment_type == o.deployment_type &&
      detection_suppression_status == o.detection_suppression_status &&
      device_id == o.device_id &&
      device_policies == o.device_policies &&
      email == o.email &&
      external_ip == o.external_ip &&
      filesystem_containment_status == o.filesystem_containment_status &&
       == o. &&
      first_seen == o.first_seen &&
      group_hash == o.group_hash &&
      groups == o.groups &&
      host_hidden_status == o.host_hidden_status &&
      host_utc_offset == o.host_utc_offset &&
      hostname == o.hostname &&
      instance_id == o.instance_id &&
      internet_exposure == o.internet_exposure &&
      k8s_cluster_git_version == o.k8s_cluster_git_version &&
      k8s_cluster_id == o.k8s_cluster_id &&
      k8s_cluster_version == o.k8s_cluster_version &&
      kernel_version == o.kernel_version &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
      last_reboot == o.last_reboot &&
      last_seen == o.last_seen &&
      linux_sensor_mode == o.linux_sensor_mode &&
      local_ip == o.local_ip &&
      mac_address == o.mac_address &&
      machine_domain == o.machine_domain &&
      major_version == o.major_version &&
      managed_apps == o.managed_apps &&
      meta == o.meta &&
      migration_completed_time == o.migration_completed_time &&
      minor_version == o.minor_version &&
      modified_timestamp == o.modified_timestamp &&
      notes == o.notes &&
      os_build == o.os_build &&
      os_product_name == o.os_product_name &&
      os_version == o.os_version &&
      ou == o.ou &&
      platform_id == o.platform_id &&
      platform_name == o.platform_name &&
      pod_annotations == o.pod_annotations &&
      pod_host_ip4 == o.pod_host_ip4 &&
      pod_host_ip6 == o.pod_host_ip6 &&
      pod_hostname == o.pod_hostname &&
      pod_id == o.pod_id &&
      pod_ip4 == o.pod_ip4 &&
      pod_ip6 == o.pod_ip6 &&
      pod_labels == o.pod_labels &&
      pod_name == o.pod_name &&
      pod_namespace == o.pod_namespace &&
       == o. &&
      pointer_size == o.pointer_size &&
      policies == o.policies &&
      product_type == o.product_type &&
      product_type_desc == o.product_type_desc &&
      provision_status == o.provision_status &&
      reduced_functionality_mode == o.reduced_functionality_mode &&
      release_group == o.release_group &&
      rtr_state == o.rtr_state &&
      safe_mode == o.safe_mode &&
      serial_number == o.serial_number &&
      service_pack_major == o.service_pack_major &&
      service_pack_minor == o.service_pack_minor &&
      service_provider == o.service_provider &&
       == o. &&
      site_name == o.site_name &&
      status == o.status &&
      system_manufacturer == o.system_manufacturer &&
      system_product_name == o.system_product_name &&
      tags == o.tags &&
      zone_group == o.zone_group
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 1000

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 1071

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 976

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


956
957
958
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 956

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



962
963
964
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 962

def hash
  [agent_load_flags, agent_local_time, agent_version, base_image_version, bios_manufacturer, bios_version, build_number, chassis_type, chassis_type_desc, cid, config_id_base, config_id_build, config_id_platform, connection_ip, connection_mac_address, cpu_signature, cpu_vendor, criticality, default_gateway_ip, deployment_type, detection_suppression_status, device_id, device_policies, email, external_ip, filesystem_containment_status, , first_seen, group_hash, groups, host_hidden_status, host_utc_offset, hostname, instance_id, internet_exposure, k8s_cluster_git_version, k8s_cluster_id, k8s_cluster_version, kernel_version, , , , , last_reboot, last_seen, linux_sensor_mode, local_ip, mac_address, machine_domain, major_version, managed_apps, meta, migration_completed_time, minor_version, modified_timestamp, notes, os_build, os_product_name, os_version, ou, platform_id, platform_name, pod_annotations, pod_host_ip4, pod_host_ip6, pod_hostname, pod_id, pod_ip4, pod_ip6, pod_labels, pod_name, pod_namespace, , pointer_size, policies, product_type, product_type_desc, provision_status, reduced_functionality_mode, release_group, rtr_state, safe_mode, serial_number, service_pack_major, service_pack_minor, service_provider, , site_name, status, system_manufacturer, system_product_name, tags, zone_group].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 833

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @device_id.nil?
    invalid_properties.push('invalid value for "device_id", device_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



1047
1048
1049
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 1047

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 1053

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



1041
1042
1043
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 1041

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



848
849
850
851
852
# File 'lib/crimson-falcon/models/deviceapi_device_swagger.rb', line 848

def valid?
  return false if @cid.nil?
  return false if @device_id.nil?
  true
end