Class: Falcon::DevicecontrolapiReqUpdateUSBBaseV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DevicecontrolapiReqUpdateUSBBaseV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DevicecontrolapiReqUpdateUSBBaseV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DevicecontrolapiReqUpdateUSBBaseV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'custom_notifications')
    self.custom_notifications = attributes[:'custom_notifications']
  end

  if attributes.key?(:'end_user_notification')
    self.end_user_notification = attributes[:'end_user_notification']
  end

  if attributes.key?(:'enforcement_mode')
    self.enforcement_mode = attributes[:'enforcement_mode']
  end

  if attributes.key?(:'enhanced_file_metadata')
    self. = attributes[:'enhanced_file_metadata']
  end

  if attributes.key?(:'whitelist_mode')
    self.whitelist_mode = attributes[:'whitelist_mode']
  end
end

Instance Attribute Details

#custom_notificationsObject

Returns the value of attribute custom_notifications.



34
35
36
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 34

def custom_notifications
  @custom_notifications
end

#end_user_notificationObject

Determines if a notification will be shown to the end user (omit to keep current)



37
38
39
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 37

def end_user_notification
  @end_user_notification
end

#enforcement_modeObject

Enforcement for the USB policy (omit to keep current)



40
41
42
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 40

def enforcement_mode
  @enforcement_mode
end

#enhanced_file_metadataObject

Returns the value of attribute enhanced_file_metadata.



42
43
44
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 42

def 
  @enhanced_file_metadata
end

#whitelist_modeObject

Determines if the policy will include whitelist exceptions



45
46
47
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 45

def whitelist_mode
  @whitelist_mode
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 70

def self.attribute_map
  {
    :'custom_notifications' => :'custom_notifications',
    :'end_user_notification' => :'end_user_notification',
    :'enforcement_mode' => :'enforcement_mode',
    :'enhanced_file_metadata' => :'enhanced_file_metadata',
    :'whitelist_mode' => :'whitelist_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 214

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 86

def self.openapi_types
  {
    :'custom_notifications' => :'DevicecontrolapiUSBCustomNotifications',
    :'end_user_notification' => :'String',
    :'enforcement_mode' => :'String',
    :'enhanced_file_metadata' => :'Boolean',
    :'whitelist_mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      custom_notifications == o.custom_notifications &&
      end_user_notification == o.end_user_notification &&
      enforcement_mode == o.enforcement_mode &&
       == o. &&
      whitelist_mode == o.whitelist_mode
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 245

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 316

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 207

def hash
  [custom_notifications, end_user_notification, enforcement_mode, , whitelist_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 292

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



286
287
288
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 286

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1.rb', line 147

def valid?
  end_user_notification_validator = EnumAttributeValidator.new('String', ["NOTIFY_USER,SILENT"])
  return false unless end_user_notification_validator.valid?(@end_user_notification)
  enforcement_mode_validator = EnumAttributeValidator.new('String', ["MONITOR_ONLY,MONITOR_ENFORCE,OFF"])
  return false unless enforcement_mode_validator.valid?(@enforcement_mode)
  whitelist_mode_validator = EnumAttributeValidator.new('String', ["ENABLE_ALWAYS,DISABLE_VIRTUAL"])
  return false unless whitelist_mode_validator.valid?(@whitelist_mode)
  true
end