Class: Falcon::DevicecontrolapiReqUpdateUSBBaseV1External

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DevicecontrolapiReqUpdateUSBBaseV1External

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DevicecontrolapiReqUpdateUSBBaseV1External` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DevicecontrolapiReqUpdateUSBBaseV1External`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'custom_notifications')
    self.custom_notifications = attributes[:'custom_notifications']
  end

  if attributes.key?(:'end_user_notification')
    self.end_user_notification = attributes[:'end_user_notification']
  end

  if attributes.key?(:'enforcement_mode')
    self.enforcement_mode = attributes[:'enforcement_mode']
  end

  if attributes.key?(:'enhanced_file_metadata')
    self. = attributes[:'enhanced_file_metadata']
  end

  if attributes.key?(:'pcie_enforcement_mode')
    self.pcie_enforcement_mode = attributes[:'pcie_enforcement_mode']
  end

  if attributes.key?(:'storage_space_enforcement_mode')
    self.storage_space_enforcement_mode = attributes[:'storage_space_enforcement_mode']
  end

  if attributes.key?(:'user_based_enforcement_mode')
    self.user_based_enforcement_mode = attributes[:'user_based_enforcement_mode']
  end
end

Instance Attribute Details

#custom_notificationsObject

Returns the value of attribute custom_notifications.



34
35
36
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 34

def custom_notifications
  @custom_notifications
end

#end_user_notificationObject

Determines if a notification will be shown to the end user (omit to keep current)



37
38
39
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 37

def end_user_notification
  @end_user_notification
end

#enforcement_modeObject

Enforcement for the USB policy (omit to keep current). Note: OFF only supported for Mac platform



40
41
42
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 40

def enforcement_mode
  @enforcement_mode
end

#enhanced_file_metadataObject

Boolean value to enable enhanced file metadata collection



43
44
45
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 43

def 
  @enhanced_file_metadata
end

#pcie_enforcement_modeObject

Enforcement for PCIe/SD devices (omit to keep current). Note: OFF only supported for Mac platform



46
47
48
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 46

def pcie_enforcement_mode
  @pcie_enforcement_mode
end

#storage_space_enforcement_modeObject

Enforcement for Windows Storage Spaces (omit to keep current).



49
50
51
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 49

def storage_space_enforcement_mode
  @storage_space_enforcement_mode
end

#user_based_enforcement_modeObject

Enforcement mode for User Based exceptions



52
53
54
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 52

def user_based_enforcement_mode
  @user_based_enforcement_mode
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 90

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 77

def self.attribute_map
  {
    :'custom_notifications' => :'custom_notifications',
    :'end_user_notification' => :'end_user_notification',
    :'enforcement_mode' => :'enforcement_mode',
    :'enhanced_file_metadata' => :'enhanced_file_metadata',
    :'pcie_enforcement_mode' => :'pcie_enforcement_mode',
    :'storage_space_enforcement_mode' => :'storage_space_enforcement_mode',
    :'user_based_enforcement_mode' => :'user_based_enforcement_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 259

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 95

def self.openapi_types
  {
    :'custom_notifications' => :'DevicecontrolapiUSBCustomNotifications',
    :'end_user_notification' => :'String',
    :'enforcement_mode' => :'String',
    :'enhanced_file_metadata' => :'Boolean',
    :'pcie_enforcement_mode' => :'String',
    :'storage_space_enforcement_mode' => :'String',
    :'user_based_enforcement_mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      custom_notifications == o.custom_notifications &&
      end_user_notification == o.end_user_notification &&
      enforcement_mode == o.enforcement_mode &&
       == o. &&
      pcie_enforcement_mode == o.pcie_enforcement_mode &&
      storage_space_enforcement_mode == o.storage_space_enforcement_mode &&
      user_based_enforcement_mode == o.user_based_enforcement_mode
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 290

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 266

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 252

def hash
  [custom_notifications, end_user_notification, enforcement_mode, , pcie_enforcement_mode, storage_space_enforcement_mode, user_based_enforcement_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 159

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 337

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



331
332
333
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 331

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/crimson-falcon/models/devicecontrolapi_req_update_usb_base_v1_external.rb', line 166

def valid?
  end_user_notification_validator = EnumAttributeValidator.new('String', ["NOTIFY_USER", "SILENT"])
  return false unless end_user_notification_validator.valid?(@end_user_notification)
  enforcement_mode_validator = EnumAttributeValidator.new('String', ["MONITOR_ONLY", "MONITOR_ENFORCE", "OFF"])
  return false unless enforcement_mode_validator.valid?(@enforcement_mode)
  pcie_enforcement_mode_validator = EnumAttributeValidator.new('String', ["MONITOR_ONLY", "MONITOR_ENFORCE"])
  return false unless pcie_enforcement_mode_validator.valid?(@pcie_enforcement_mode)
  storage_space_enforcement_mode_validator = EnumAttributeValidator.new('String', ["MONITOR_ONLY", "MONITOR_ENFORCE"])
  return false unless storage_space_enforcement_mode_validator.valid?(@storage_space_enforcement_mode)
  user_based_enforcement_mode_validator = EnumAttributeValidator.new('String', ["MONITOR_ONLY", "MONITOR_ENFORCE"])
  return false unless user_based_enforcement_mode_validator.valid?(@user_based_enforcement_mode)
  true
end