Class: Falcon::Discover
- Inherits:
-
Object
- Object
- Falcon::Discover
- Defined in:
- lib/crimson-falcon/api/discover.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#combined_applications(filter, opts = {}) ⇒ DomainDiscoverAPICombinedApplicationsResponse
Search for applications in your environment by providing an FQL filter and paging details.
-
#combined_applications_with_http_info(filter, opts = {}) ⇒ Array<(DomainDiscoverAPICombinedApplicationsResponse, Integer, Hash)>
Search for applications in your environment by providing an FQL filter and paging details.
-
#combined_hosts(filter, opts = {}) ⇒ DomainDiscoverAPICombinedHostsResponse
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#combined_hosts_with_http_info(filter, opts = {}) ⇒ Array<(DomainDiscoverAPICombinedHostsResponse, Integer, Hash)>
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#get_accounts(ids, opts = {}) ⇒ DomainDiscoverAPIAccountEntitiesResponse
Get details on accounts by providing one or more IDs.
-
#get_accounts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIAccountEntitiesResponse, Integer, Hash)>
Get details on accounts by providing one or more IDs.
-
#get_applications(ids, opts = {}) ⇒ DomainDiscoverAPIApplicationEntitiesResponse
Get details on applications by providing one or more IDs.
-
#get_applications_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIApplicationEntitiesResponse, Integer, Hash)>
Get details on applications by providing one or more IDs.
-
#get_hosts(ids, opts = {}) ⇒ DomainDiscoverAPIHostEntitiesResponse
Get details on assets by providing one or more IDs.
-
#get_hosts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIHostEntitiesResponse, Integer, Hash)>
Get details on assets by providing one or more IDs.
-
#get_logins(ids, opts = {}) ⇒ DomainDiscoverAPILoginEntitiesResponse
Get details on logins by providing one or more IDs.
-
#get_logins_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPILoginEntitiesResponse, Integer, Hash)>
Get details on logins by providing one or more IDs.
-
#initialize(api_client = ApiClient.default) ⇒ Discover
constructor
A new instance of Discover.
-
#query_accounts(opts = {}) ⇒ MsaQueryResponse
Search for accounts in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_accounts_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for accounts in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_applications(opts = {}) ⇒ MsaspecQueryResponse
Search for applications in your environment by providing an FQL filter and paging details.
-
#query_applications_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for applications in your environment by providing an FQL filter and paging details.
-
#query_hosts(opts = {}) ⇒ MsaspecQueryResponse
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_hosts_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_logins(opts = {}) ⇒ MsaQueryResponse
Search for logins in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_logins_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for logins in your environment by providing an FQL (Falcon Query Language) filter and paging details.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/discover.rb', line 33 def api_client @api_client end |
Instance Method Details
#combined_applications(filter, opts = {}) ⇒ DomainDiscoverAPICombinedApplicationsResponse
Search for applications in your environment by providing an FQL filter and paging details. Returns details on applications which match the filter criteria.
46 47 48 49 |
# File 'lib/crimson-falcon/api/discover.rb', line 46 def combined_applications(filter, opts = {}) data, _status_code, _headers = combined_applications_with_http_info(filter, opts) data end |
#combined_applications_with_http_info(filter, opts = {}) ⇒ Array<(DomainDiscoverAPICombinedApplicationsResponse, Integer, Hash)>
Search for applications in your environment by providing an FQL filter and paging details. Returns details on applications which match the filter criteria.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/crimson-falcon/api/discover.rb', line 59 def combined_applications_with_http_info(filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.combined_applications ...' end # verify the required parameter 'filter' is set if @api_client.config.client_side_validation && filter.nil? fail ArgumentError, "Missing the required parameter 'filter' when calling Discover.combined_applications" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.combined_applications, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.combined_applications, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/combined/applications/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = filter query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'facet'] = @api_client.build_collection_param(opts[:'facet'], :multi) if !opts[:'facet'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPICombinedApplicationsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.combined_applications", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#combined_applications\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#combined_hosts(filter, opts = {}) ⇒ DomainDiscoverAPICombinedHostsResponse
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns details on assets which match the filter criteria.
128 129 130 131 |
# File 'lib/crimson-falcon/api/discover.rb', line 128 def combined_hosts(filter, opts = {}) data, _status_code, _headers = combined_hosts_with_http_info(filter, opts) data end |
#combined_hosts_with_http_info(filter, opts = {}) ⇒ Array<(DomainDiscoverAPICombinedHostsResponse, Integer, Hash)>
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns details on assets which match the filter criteria.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/crimson-falcon/api/discover.rb', line 141 def combined_hosts_with_http_info(filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.combined_hosts ...' end # verify the required parameter 'filter' is set if @api_client.config.client_side_validation && filter.nil? fail ArgumentError, "Missing the required parameter 'filter' when calling Discover.combined_hosts" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.combined_hosts, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.combined_hosts, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/combined/hosts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = filter query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'facet'] = @api_client.build_collection_param(opts[:'facet'], :multi) if !opts[:'facet'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPICombinedHostsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.combined_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#combined_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_accounts(ids, opts = {}) ⇒ DomainDiscoverAPIAccountEntitiesResponse
Get details on accounts by providing one or more IDs.
206 207 208 209 |
# File 'lib/crimson-falcon/api/discover.rb', line 206 def get_accounts(ids, opts = {}) data, _status_code, _headers = get_accounts_with_http_info(ids, opts) data end |
#get_accounts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIAccountEntitiesResponse, Integer, Hash)>
Get details on accounts by providing one or more IDs.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/crimson-falcon/api/discover.rb', line 215 def get_accounts_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.get_accounts ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling Discover.get_accounts" end # resource path local_var_path = '/discover/entities/accounts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPIAccountEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.get_accounts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#get_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_applications(ids, opts = {}) ⇒ DomainDiscoverAPIApplicationEntitiesResponse
Get details on applications by providing one or more IDs.
268 269 270 271 |
# File 'lib/crimson-falcon/api/discover.rb', line 268 def get_applications(ids, opts = {}) data, _status_code, _headers = get_applications_with_http_info(ids, opts) data end |
#get_applications_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIApplicationEntitiesResponse, Integer, Hash)>
Get details on applications by providing one or more IDs.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/crimson-falcon/api/discover.rb', line 277 def get_applications_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.get_applications ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling Discover.get_applications" end # resource path local_var_path = '/discover/entities/applications/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPIApplicationEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.get_applications", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#get_applications\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_hosts(ids, opts = {}) ⇒ DomainDiscoverAPIHostEntitiesResponse
Get details on assets by providing one or more IDs.
330 331 332 333 |
# File 'lib/crimson-falcon/api/discover.rb', line 330 def get_hosts(ids, opts = {}) data, _status_code, _headers = get_hosts_with_http_info(ids, opts) data end |
#get_hosts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIHostEntitiesResponse, Integer, Hash)>
Get details on assets by providing one or more IDs.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/crimson-falcon/api/discover.rb', line 339 def get_hosts_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.get_hosts ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling Discover.get_hosts" end # resource path local_var_path = '/discover/entities/hosts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPIHostEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.get_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#get_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_logins(ids, opts = {}) ⇒ DomainDiscoverAPILoginEntitiesResponse
Get details on logins by providing one or more IDs.
392 393 394 395 |
# File 'lib/crimson-falcon/api/discover.rb', line 392 def get_logins(ids, opts = {}) data, _status_code, _headers = get_logins_with_http_info(ids, opts) data end |
#get_logins_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPILoginEntitiesResponse, Integer, Hash)>
Get details on logins by providing one or more IDs.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/crimson-falcon/api/discover.rb', line 401 def get_logins_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.get_logins ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling Discover.get_logins" end # resource path local_var_path = '/discover/entities/logins/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPILoginEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.get_logins", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#get_logins\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_accounts(opts = {}) ⇒ MsaQueryResponse
Search for accounts in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of account IDs which match the filter criteria.
457 458 459 460 |
# File 'lib/crimson-falcon/api/discover.rb', line 457 def query_accounts(opts = {}) data, _status_code, _headers = query_accounts_with_http_info(opts) data end |
#query_accounts_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for accounts in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of account IDs which match the filter criteria.
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/crimson-falcon/api/discover.rb', line 469 def query_accounts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.query_accounts ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling Discover.query_accounts, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_accounts, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_accounts, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/accounts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.query_accounts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#query_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_applications(opts = {}) ⇒ MsaspecQueryResponse
Search for applications in your environment by providing an FQL filter and paging details. returns a set of application IDs which match the filter criteria.
536 537 538 539 |
# File 'lib/crimson-falcon/api/discover.rb', line 536 def query_applications(opts = {}) data, _status_code, _headers = query_applications_with_http_info(opts) data end |
#query_applications_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for applications in your environment by providing an FQL filter and paging details. returns a set of application IDs which match the filter criteria.
548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/crimson-falcon/api/discover.rb', line 548 def query_applications_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.query_applications ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling Discover.query_applications, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_applications, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_applications, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/applications/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.query_applications", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#query_applications\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_hosts(opts = {}) ⇒ MsaspecQueryResponse
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
615 616 617 618 |
# File 'lib/crimson-falcon/api/discover.rb', line 615 def query_hosts(opts = {}) data, _status_code, _headers = query_hosts_with_http_info(opts) data end |
#query_hosts_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/crimson-falcon/api/discover.rb', line 627 def query_hosts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.query_hosts ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling Discover.query_hosts, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_hosts, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_hosts, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/hosts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.query_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#query_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_logins(opts = {}) ⇒ MsaQueryResponse
Search for logins in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of login IDs which match the filter criteria. The API endpoint returns data only if the response set includes 10,000 or fewer items. This limit applies to the total API response size, regardless of your pagination sizes with the ‘limit` and `offset` parameters. If your response set includes more than 10,000 items, the CrowdStrike API returns an HTML 400 response instead. To avoid this issue, use the filter parameter to reduce the total number of items in the API response.
695 696 697 698 |
# File 'lib/crimson-falcon/api/discover.rb', line 695 def query_logins(opts = {}) data, _status_code, _headers = query_logins_with_http_info(opts) data end |
#query_logins_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for logins in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of login IDs which match the filter criteria. The API endpoint returns data only if the response set includes 10,000 or fewer items. This limit applies to the total API response size, regardless of your pagination sizes with the `limit` and `offset` parameters. If your response set includes more than 10,000 items, the CrowdStrike API returns an HTML 400 response instead. To avoid this issue, use the filter parameter to reduce the total number of items in the API response.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 |
# File 'lib/crimson-falcon/api/discover.rb', line 708 def query_logins_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Discover.query_logins ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling Discover.query_logins, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_logins, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Discover.query_logins, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/logins/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Discover.query_logins", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Discover#query_logins\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |