Class: Falcon::DomainAPIAggregateTopFailedImagesV1
- Inherits:
-
Object
- Object
- Falcon::DomainAPIAggregateTopFailedImagesV1
- Defined in:
- lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb
Instance Attribute Summary collapse
-
#asset_uid ⇒ Object
Returns the value of attribute asset_uid.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#failed_rules_count ⇒ Object
Returns the value of attribute failed_rules_count.
-
#failed_rules_count_by_severity ⇒ Object
Returns the value of attribute failed_rules_count_by_severity.
-
#image_digest ⇒ Object
Returns the value of attribute image_digest.
-
#image_registry ⇒ Object
Returns the value of attribute image_registry.
-
#image_repository ⇒ Object
Returns the value of attribute image_repository.
-
#image_tag ⇒ Object
Returns the value of attribute image_tag.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainAPIAggregateTopFailedImagesV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainAPIAggregateTopFailedImagesV1
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIAggregateTopFailedImagesV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIAggregateTopFailedImagesV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_uid') self.asset_uid = attributes[:'asset_uid'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'failed_rules_count') self.failed_rules_count = attributes[:'failed_rules_count'] end if attributes.key?(:'failed_rules_count_by_severity') self.failed_rules_count_by_severity = attributes[:'failed_rules_count_by_severity'] end if attributes.key?(:'image_digest') self.image_digest = attributes[:'image_digest'] end if attributes.key?(:'image_registry') self.image_registry = attributes[:'image_registry'] end if attributes.key?(:'image_repository') self.image_repository = attributes[:'image_repository'] end if attributes.key?(:'image_tag') self.image_tag = attributes[:'image_tag'] end end |
Instance Attribute Details
#asset_uid ⇒ Object
Returns the value of attribute asset_uid.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 34 def asset_uid @asset_uid end |
#cid ⇒ Object
Returns the value of attribute cid.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 36 def cid @cid end |
#failed_rules_count ⇒ Object
Returns the value of attribute failed_rules_count.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 38 def failed_rules_count @failed_rules_count end |
#failed_rules_count_by_severity ⇒ Object
Returns the value of attribute failed_rules_count_by_severity.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 40 def failed_rules_count_by_severity @failed_rules_count_by_severity end |
#image_digest ⇒ Object
Returns the value of attribute image_digest.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 42 def image_digest @image_digest end |
#image_registry ⇒ Object
Returns the value of attribute image_registry.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 44 def image_registry @image_registry end |
#image_repository ⇒ Object
Returns the value of attribute image_repository.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 46 def image_repository @image_repository end |
#image_tag ⇒ Object
Returns the value of attribute image_tag.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 48 def image_tag @image_tag end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 65 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 51 def self.attribute_map { :'asset_uid' => :'asset_uid', :'cid' => :'cid', :'failed_rules_count' => :'failed_rules_count', :'failed_rules_count_by_severity' => :'failed_rules_count_by_severity', :'image_digest' => :'image_digest', :'image_registry' => :'image_registry', :'image_repository' => :'image_repository', :'image_tag' => :'image_tag' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 220 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 70 def self.openapi_types { :'asset_uid' => :'String', :'cid' => :'String', :'failed_rules_count' => :'Integer', :'failed_rules_count_by_severity' => :'DomainCountBySeverity', :'image_digest' => :'String', :'image_registry' => :'String', :'image_repository' => :'String', :'image_tag' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 192 def ==(o) return true if self.equal?(o) self.class == o.class && asset_uid == o.asset_uid && cid == o.cid && failed_rules_count == o.failed_rules_count && failed_rules_count_by_severity == o.failed_rules_count_by_severity && image_digest == o.image_digest && image_registry == o.image_registry && image_repository == o.image_repository && image_tag == o.image_tag end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 251 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 322 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 213 def hash [asset_uid, cid, failed_rules_count, failed_rules_count_by_severity, image_digest, image_registry, image_repository, image_tag].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 139 def list_invalid_properties invalid_properties = Array.new if @asset_uid.nil? invalid_properties.push('invalid value for "asset_uid", asset_uid cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @failed_rules_count.nil? invalid_properties.push('invalid value for "failed_rules_count", failed_rules_count cannot be nil.') end if @failed_rules_count_by_severity.nil? invalid_properties.push('invalid value for "failed_rules_count_by_severity", failed_rules_count_by_severity cannot be nil.') end if @image_digest.nil? invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.') end if @image_registry.nil? invalid_properties.push('invalid value for "image_registry", image_registry cannot be nil.') end if @image_repository.nil? invalid_properties.push('invalid value for "image_repository", image_repository cannot be nil.') end if @image_tag.nil? invalid_properties.push('invalid value for "image_tag", image_tag cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/crimson-falcon/models/domain_api_aggregate_top_failed_images_v1.rb', line 178 def valid? return false if @asset_uid.nil? return false if @cid.nil? return false if @failed_rules_count.nil? return false if @failed_rules_count_by_severity.nil? return false if @image_digest.nil? return false if @image_registry.nil? return false if @image_repository.nil? return false if @image_tag.nil? true end |