Class: Falcon::DomainAPIFindingRuleV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_api_finding_rule_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainAPIFindingRuleV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIFindingRuleV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIFindingRuleV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'authority')
    self.authority = attributes[:'authority']
  end

  if attributes.key?(:'benchmark_type')
    self.benchmark_type = attributes[:'benchmark_type']
  end

  if attributes.key?(:'cce')
    self.cce = attributes[:'cce']
  end

  if attributes.key?(:'compliance_mappings')
    if (value = attributes[:'compliance_mappings']).is_a?(Array)
      self.compliance_mappings = value
    end
  end

  if attributes.key?(:'edited')
    self.edited = attributes[:'edited']
  end

  if attributes.key?(:'group_id')
    self.group_id = attributes[:'group_id']
  end

  if attributes.key?(:'group_name')
    self.group_name = attributes[:'group_name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_edited_timestamp')
    self.last_edited_timestamp = attributes[:'last_edited_timestamp']
  end

  if attributes.key?(:'mitre_attack_tactics')
    if (value = attributes[:'mitre_attack_tactics']).is_a?(Array)
      self.mitre_attack_tactics = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'policy_id')
    self.policy_id = attributes[:'policy_id']
  end

  if attributes.key?(:'policy_name')
    self.policy_name = attributes[:'policy_name']
  end

  if attributes.key?(:'recommendation_id')
    self.recommendation_id = attributes[:'recommendation_id']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end
end

Instance Attribute Details

#authorityObject

Returns the value of attribute authority.



34
35
36
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 34

def authority
  @authority
end

#benchmark_typeObject

Returns the value of attribute benchmark_type.



36
37
38
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 36

def benchmark_type
  @benchmark_type
end

#cceObject

Returns the value of attribute cce.



38
39
40
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 38

def cce
  @cce
end

#compliance_mappingsObject

Returns the value of attribute compliance_mappings.



40
41
42
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 40

def compliance_mappings
  @compliance_mappings
end

#editedObject

Returns the value of attribute edited.



42
43
44
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 42

def edited
  @edited
end

#group_idObject

Returns the value of attribute group_id.



44
45
46
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 44

def group_id
  @group_id
end

#group_nameObject

Returns the value of attribute group_name.



46
47
48
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 46

def group_name
  @group_name
end

#idObject

Returns the value of attribute id.



48
49
50
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 48

def id
  @id
end

#last_edited_timestampObject

Returns the value of attribute last_edited_timestamp.



50
51
52
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 50

def last_edited_timestamp
  @last_edited_timestamp
end

#mitre_attack_tacticsObject

Returns the value of attribute mitre_attack_tactics.



52
53
54
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 52

def mitre_attack_tactics
  @mitre_attack_tactics
end

#nameObject

Returns the value of attribute name.



54
55
56
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 54

def name
  @name
end

#platform_nameObject

Returns the value of attribute platform_name.



56
57
58
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 56

def platform_name
  @platform_name
end

#policy_idObject

Returns the value of attribute policy_id.



58
59
60
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 58

def policy_id
  @policy_id
end

#policy_nameObject

Returns the value of attribute policy_name.



60
61
62
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 60

def policy_name
  @policy_name
end

#recommendation_idObject

Returns the value of attribute recommendation_id.



62
63
64
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 62

def recommendation_id
  @recommendation_id
end

#severityObject

Returns the value of attribute severity.



64
65
66
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 64

def severity
  @severity
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 67

def self.attribute_map
  {
    :'authority' => :'authority',
    :'benchmark_type' => :'benchmark_type',
    :'cce' => :'cce',
    :'compliance_mappings' => :'compliance_mappings',
    :'edited' => :'edited',
    :'group_id' => :'group_id',
    :'group_name' => :'group_name',
    :'id' => :'id',
    :'last_edited_timestamp' => :'last_edited_timestamp',
    :'mitre_attack_tactics' => :'mitre_attack_tactics',
    :'name' => :'name',
    :'platform_name' => :'platform_name',
    :'policy_id' => :'policy_id',
    :'policy_name' => :'policy_name',
    :'recommendation_id' => :'recommendation_id',
    :'severity' => :'severity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 266

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 94

def self.openapi_types
  {
    :'authority' => :'String',
    :'benchmark_type' => :'String',
    :'cce' => :'String',
    :'compliance_mappings' => :'Array<DomainAPIComplianceMappingV1>',
    :'edited' => :'Boolean',
    :'group_id' => :'String',
    :'group_name' => :'String',
    :'id' => :'String',
    :'last_edited_timestamp' => :'String',
    :'mitre_attack_tactics' => :'Array<DomainAPIMitreAttackTacticV1>',
    :'name' => :'String',
    :'platform_name' => :'String',
    :'policy_id' => :'String',
    :'policy_name' => :'String',
    :'recommendation_id' => :'String',
    :'severity' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authority == o.authority &&
      benchmark_type == o.benchmark_type &&
      cce == o.cce &&
      compliance_mappings == o.compliance_mappings &&
      edited == o.edited &&
      group_id == o.group_id &&
      group_name == o.group_name &&
      id == o.id &&
      last_edited_timestamp == o.last_edited_timestamp &&
      mitre_attack_tactics == o.mitre_attack_tactics &&
      name == o.name &&
      platform_name == o.platform_name &&
      policy_id == o.policy_id &&
      policy_name == o.policy_name &&
      recommendation_id == o.recommendation_id &&
      severity == o.severity
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 297

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 368

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 273

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 259

def hash
  [authority, benchmark_type, cce, compliance_mappings, edited, group_id, group_name, id, last_edited_timestamp, mitre_attack_tactics, name, platform_name, policy_id, policy_name, recommendation_id, severity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 207

def list_invalid_properties
  invalid_properties = Array.new
  if @edited.nil?
    invalid_properties.push('invalid value for "edited", edited cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 344

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 338

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
# File 'lib/crimson-falcon/models/domain_api_finding_rule_v1.rb', line 222

def valid?
  return false if @edited.nil?
  return false if @id.nil?
  true
end