Class: Falcon::DomainAPIRemediationV2

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_api_remediation_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainAPIRemediationV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIRemediationV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIRemediationV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'patch_publication_date')
    self.patch_publication_date = attributes[:'patch_publication_date']
  end

  if attributes.key?(:'recommendation_type')
    self.recommendation_type = attributes[:'recommendation_type']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'vendor_url')
    self.vendor_url = attributes[:'vendor_url']
  end
end

Instance Attribute Details

#actionObject

Expanded description of the remediation



35
36
37
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 35

def action
  @action
end

#idObject

Refers to an unique identifier for a given remediation



38
39
40
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 38

def id
  @id
end

Link to the remediation page for the vendor



41
42
43
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 41

def link
  @link
end

#patch_publication_dateObject

The timestamp that this remediation was published



44
45
46
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 44

def patch_publication_date
  @patch_publication_date
end

#recommendation_typeObject

The type of recommendation for this remediation, usually either ‘recommended’ or ‘minimum’



47
48
49
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 47

def recommendation_type
  @recommendation_type
end

#referenceObject

Relevant reference for the remediation that can be used to get additional details for the remediation. For example, a KB number that needs to be installed for a KB_SECURITY_UPDATE



50
51
52
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 50

def reference
  @reference
end

#titleObject

Short description of the remediation



53
54
55
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 53

def title
  @title
end

#vendor_urlObject

Link to the vendor advisory - Note: This field is populated if there are extra steps that are required to complete the remediation



56
57
58
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 56

def vendor_url
  @vendor_url
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 59

def self.attribute_map
  {
    :'action' => :'action',
    :'id' => :'id',
    :'link' => :'link',
    :'patch_publication_date' => :'patch_publication_date',
    :'recommendation_type' => :'recommendation_type',
    :'reference' => :'reference',
    :'title' => :'title',
    :'vendor_url' => :'vendor_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 218

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 78

def self.openapi_types
  {
    :'action' => :'String',
    :'id' => :'String',
    :'link' => :'String',
    :'patch_publication_date' => :'String',
    :'recommendation_type' => :'String',
    :'reference' => :'String',
    :'title' => :'String',
    :'vendor_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      id == o.id &&
      link == o.link &&
      patch_publication_date == o.patch_publication_date &&
      recommendation_type == o.recommendation_type &&
      reference == o.reference &&
      title == o.title &&
      vendor_url == o.vendor_url
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 249

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 320

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 211

def hash
  [action, id, link, patch_publication_date, recommendation_type, reference, title, vendor_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 147

def list_invalid_properties
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @link.nil?
    invalid_properties.push('invalid value for "link", link cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @vendor_url.nil?
    invalid_properties.push('invalid value for "vendor_url", vendor_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 296

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



290
291
292
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 290

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
# File 'lib/crimson-falcon/models/domain_api_remediation_v2.rb', line 178

def valid?
  return false if @action.nil?
  return false if @id.nil?
  return false if @link.nil?
  return false if @reference.nil?
  return false if @title.nil?
  return false if @vendor_url.nil?
  true
end