Class: Falcon::DomainAPIRuleDetailsV1
- Inherits:
-
Object
- Object
- Falcon::DomainAPIRuleDetailsV1
- Defined in:
- lib/crimson-falcon/models/domain_api_rule_details_v1.rb
Instance Attribute Summary collapse
-
#additional_information ⇒ Object
Returns the value of attribute additional_information.
-
#applicable_profiles ⇒ Object
Returns the value of attribute applicable_profiles.
-
#assessment_status ⇒ Object
Returns the value of attribute assessment_status.
-
#audit_procedure ⇒ Object
Returns the value of attribute audit_procedure.
-
#authority ⇒ Object
Returns the value of attribute authority.
-
#benchmark_title ⇒ Object
Returns the value of attribute benchmark_title.
-
#compliance_mappings ⇒ Object
Returns the value of attribute compliance_mappings.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#impact_statement ⇒ Object
Returns the value of attribute impact_statement.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#rationale_statement ⇒ Object
Returns the value of attribute rationale_statement.
-
#recommendation_id ⇒ Object
Returns the value of attribute recommendation_id.
-
#references ⇒ Object
Returns the value of attribute references.
-
#remediation_procedure ⇒ Object
Returns the value of attribute remediation_procedure.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainAPIRuleDetailsV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainAPIRuleDetailsV1
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIRuleDetailsV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIRuleDetailsV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'additional_information') self.additional_information = attributes[:'additional_information'] end if attributes.key?(:'applicable_profiles') if (value = attributes[:'applicable_profiles']).is_a?(Array) self.applicable_profiles = value end end if attributes.key?(:'assessment_status') self.assessment_status = attributes[:'assessment_status'] end if attributes.key?(:'audit_procedure') self.audit_procedure = attributes[:'audit_procedure'] end if attributes.key?(:'authority') self. = attributes[:'authority'] end if attributes.key?(:'benchmark_title') self.benchmark_title = attributes[:'benchmark_title'] end if attributes.key?(:'compliance_mappings') if (value = attributes[:'compliance_mappings']).is_a?(Array) self.compliance_mappings = value end end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'impact_statement') self.impact_statement = attributes[:'impact_statement'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'rationale_statement') self.rationale_statement = attributes[:'rationale_statement'] end if attributes.key?(:'recommendation_id') self.recommendation_id = attributes[:'recommendation_id'] end if attributes.key?(:'references') if (value = attributes[:'references']).is_a?(Array) self.references = value end end if attributes.key?(:'remediation_procedure') self.remediation_procedure = attributes[:'remediation_procedure'] end if attributes.key?(:'title') self.title = attributes[:'title'] end end |
Instance Attribute Details
#additional_information ⇒ Object
Returns the value of attribute additional_information.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 34 def additional_information @additional_information end |
#applicable_profiles ⇒ Object
Returns the value of attribute applicable_profiles.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 36 def applicable_profiles @applicable_profiles end |
#assessment_status ⇒ Object
Returns the value of attribute assessment_status.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 38 def assessment_status @assessment_status end |
#audit_procedure ⇒ Object
Returns the value of attribute audit_procedure.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 40 def audit_procedure @audit_procedure end |
#authority ⇒ Object
Returns the value of attribute authority.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 42 def @authority end |
#benchmark_title ⇒ Object
Returns the value of attribute benchmark_title.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 44 def benchmark_title @benchmark_title end |
#compliance_mappings ⇒ Object
Returns the value of attribute compliance_mappings.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 46 def compliance_mappings @compliance_mappings end |
#description ⇒ Object
Returns the value of attribute description.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 48 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 50 def id @id end |
#impact_statement ⇒ Object
Returns the value of attribute impact_statement.
52 53 54 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 52 def impact_statement @impact_statement end |
#platform ⇒ Object
Returns the value of attribute platform.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 54 def platform @platform end |
#rationale_statement ⇒ Object
Returns the value of attribute rationale_statement.
56 57 58 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 56 def rationale_statement @rationale_statement end |
#recommendation_id ⇒ Object
Returns the value of attribute recommendation_id.
58 59 60 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 58 def recommendation_id @recommendation_id end |
#references ⇒ Object
Returns the value of attribute references.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 60 def references @references end |
#remediation_procedure ⇒ Object
Returns the value of attribute remediation_procedure.
62 63 64 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 62 def remediation_procedure @remediation_procedure end |
#title ⇒ Object
Returns the value of attribute title.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 64 def title @title end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 67 def self.attribute_map { :'additional_information' => :'additional_information', :'applicable_profiles' => :'applicable_profiles', :'assessment_status' => :'assessment_status', :'audit_procedure' => :'audit_procedure', :'authority' => :'authority', :'benchmark_title' => :'benchmark_title', :'compliance_mappings' => :'compliance_mappings', :'description' => :'description', :'id' => :'id', :'impact_statement' => :'impact_statement', :'platform' => :'platform', :'rationale_statement' => :'rationale_statement', :'recommendation_id' => :'recommendation_id', :'references' => :'references', :'remediation_procedure' => :'remediation_procedure', :'title' => :'title' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 328 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 94 def self.openapi_types { :'additional_information' => :'String', :'applicable_profiles' => :'Array<String>', :'assessment_status' => :'String', :'audit_procedure' => :'String', :'authority' => :'String', :'benchmark_title' => :'String', :'compliance_mappings' => :'Array<DomainAPIComplianceMappingV1>', :'description' => :'String', :'id' => :'String', :'impact_statement' => :'String', :'platform' => :'String', :'rationale_statement' => :'String', :'recommendation_id' => :'String', :'references' => :'Array<String>', :'remediation_procedure' => :'String', :'title' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && additional_information == o.additional_information && applicable_profiles == o.applicable_profiles && assessment_status == o.assessment_status && audit_procedure == o.audit_procedure && == o. && benchmark_title == o.benchmark_title && compliance_mappings == o.compliance_mappings && description == o.description && id == o.id && impact_statement == o.impact_statement && platform == o.platform && rationale_statement == o.rationale_statement && recommendation_id == o.recommendation_id && references == o.references && remediation_procedure == o.remediation_procedure && title == o.title end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 359 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 430 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 335 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
315 316 317 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 315 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 321 def hash [additional_information, applicable_profiles, assessment_status, audit_procedure, , benchmark_title, compliance_mappings, description, id, impact_statement, platform, rationale_statement, recommendation_id, references, remediation_procedure, title].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 209 def list_invalid_properties invalid_properties = Array.new if @additional_information.nil? invalid_properties.push('invalid value for "additional_information", additional_information cannot be nil.') end if @applicable_profiles.nil? invalid_properties.push('invalid value for "applicable_profiles", applicable_profiles cannot be nil.') end if @assessment_status.nil? invalid_properties.push('invalid value for "assessment_status", assessment_status cannot be nil.') end if @audit_procedure.nil? invalid_properties.push('invalid value for "audit_procedure", audit_procedure cannot be nil.') end if @authority.nil? invalid_properties.push('invalid value for "authority", authority cannot be nil.') end if @benchmark_title.nil? invalid_properties.push('invalid value for "benchmark_title", benchmark_title cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @impact_statement.nil? invalid_properties.push('invalid value for "impact_statement", impact_statement cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @rationale_statement.nil? invalid_properties.push('invalid value for "rationale_statement", rationale_statement cannot be nil.') end if @recommendation_id.nil? invalid_properties.push('invalid value for "recommendation_id", recommendation_id cannot be nil.') end if @remediation_procedure.nil? invalid_properties.push('invalid value for "remediation_procedure", remediation_procedure cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
406 407 408 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 406 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 412 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
400 401 402 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 400 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/crimson-falcon/models/domain_api_rule_details_v1.rb', line 272 def valid? return false if @additional_information.nil? return false if @applicable_profiles.nil? return false if @assessment_status.nil? return false if @audit_procedure.nil? return false if @authority.nil? return false if @benchmark_title.nil? return false if @description.nil? return false if @id.nil? return false if @impact_statement.nil? return false if @platform.nil? return false if @rationale_statement.nil? return false if @recommendation_id.nil? return false if @remediation_procedure.nil? return false if @title.nil? true end |