Class: Falcon::DomainAPIVulnerabilityCVEDetailsFacetV2

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainAPIVulnerabilityCVEDetailsFacetV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIVulnerabilityCVEDetailsFacetV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIVulnerabilityCVEDetailsFacetV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'actors')
    if (value = attributes[:'actors']).is_a?(Array)
      self.actors = value
    end
  end

  if attributes.key?(:'base_score')
    self.base_score = attributes[:'base_score']
  end

  if attributes.key?(:'cisa_info')
    self.cisa_info = attributes[:'cisa_info']
  end

  if attributes.key?(:'cwes')
    if (value = attributes[:'cwes']).is_a?(Array)
      self.cwes = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'exploit_status')
    self.exploit_status = attributes[:'exploit_status']
  end

  if attributes.key?(:'exploitability_score')
    self.exploitability_score = attributes[:'exploitability_score']
  end

  if attributes.key?(:'exprt_rating')
    self.exprt_rating = attributes[:'exprt_rating']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'impact_score')
    self.impact_score = attributes[:'impact_score']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'original_description')
    self.original_description = attributes[:'original_description']
  end

  if attributes.key?(:'published_date')
    self.published_date = attributes[:'published_date']
  end

  if attributes.key?(:'references')
    if (value = attributes[:'references']).is_a?(Array)
      self.references = value
    end
  end

  if attributes.key?(:'remediation_level')
    self.remediation_level = attributes[:'remediation_level']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'spotlight_published_date')
    self.spotlight_published_date = attributes[:'spotlight_published_date']
  end

  if attributes.key?(:'types')
    if (value = attributes[:'types']).is_a?(Array)
      self.types = value
    end
  end

  if attributes.key?(:'vector')
    self.vector = attributes[:'vector']
  end

  if attributes.key?(:'vendor_advisory')
    if (value = attributes[:'vendor_advisory']).is_a?(Array)
      self.vendor_advisory = value
    end
  end
end

Instance Attribute Details

#actorsObject

Contains a list of actors that are known for exploiting this vulnerability ot in the wild



35
36
37
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 35

def actors
  @actors
end

#base_scoreObject

The base score for a Common Vulnerability Enumeration (CVE) is a numerical value that represents the intrinsic severity and impact of a security vulnerability.



38
39
40
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 38

def base_score
  @base_score
end

#cisa_infoObject

Returns the value of attribute cisa_info.



40
41
42
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 40

def cisa_info
  @cisa_info
end

#cwesObject

The CWE ids corresponding to this vulnerability instance



43
44
45
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 43

def cwes
  @cwes
end

#descriptionObject

Refers to description of the vulnerability



46
47
48
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 46

def description
  @description
end

#exploit_statusObject

Exploit status refers to the current state or availability of known exploits for a specific vulnerability, indicating whether there are known techniques or tools to leverage the vulnerability in an attack.



49
50
51
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 49

def exploit_status
  @exploit_status
end

#exploitability_scoreObject

Represents a numerical value that indicates the relative ease or difficulty for an attacker to exploit a vulnerability



52
53
54
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 52

def exploitability_score
  @exploitability_score
end

#exprt_ratingObject

Expert.AI score on the vulnerability



55
56
57
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 55

def exprt_rating
  @exprt_rating
end

#idObject

Returns the value of attribute id.



57
58
59
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 57

def id
  @id
end

#impact_scoreObject

Refers to a numerical value that represents the potential impact or severity of a vulnerability when it is successfully exploited



60
61
62
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 60

def impact_score
  @impact_score
end

#nameObject

Vulnerability name



63
64
65
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 63

def name
  @name
end

#original_descriptionObject

Refers to the original description of the vulnerability



66
67
68
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 66

def original_description
  @original_description
end

#published_dateObject

Refers to a point in time when the vulnerability has been disclosed



69
70
71
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 69

def published_date
  @published_date
end

#referencesObject

Refers to one or more references with more details about the vulnerability



72
73
74
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 72

def references
  @references
end

#remediation_levelObject

Remediation level indicates the required effort to mitigate a security vulnerability, ranging from official fixes to unavailable remedies



75
76
77
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 75

def remediation_level
  @remediation_level
end

#severityObject

Severity refers to the level of impact or potential harm caused by a security vulnerability. It is often assessed using metrics such as the CVSS base score, which takes into account factors such as exploitability, impact on confidentiality, integrity, and availability, and other relevant parameters to determine the severity level of a vulnerability.



78
79
80
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 78

def severity
  @severity
end

#spotlight_published_dateObject

Corresponds to a point in time when Spotlight offered support for detecting a specific vulnerability



81
82
83
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 81

def spotlight_published_date
  @spotlight_published_date
end

#typesObject

The types of vulnerability. Can be of: Vulnerability, Misconfiguration, and Unsupported software



84
85
86
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 84

def types
  @types
end

#vectorObject

Refers to the vector of attack or the specific method or path through which an attacker can exploit a vulnerability



87
88
89
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 87

def vector
  @vector
end

#vendor_advisoryObject

Refers to one or more URLs that points to vendor advisories



90
91
92
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 90

def vendor_advisory
  @vendor_advisory
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 119

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 93

def self.attribute_map
  {
    :'actors' => :'actors',
    :'base_score' => :'base_score',
    :'cisa_info' => :'cisa_info',
    :'cwes' => :'cwes',
    :'description' => :'description',
    :'exploit_status' => :'exploit_status',
    :'exploitability_score' => :'exploitability_score',
    :'exprt_rating' => :'exprt_rating',
    :'id' => :'id',
    :'impact_score' => :'impact_score',
    :'name' => :'name',
    :'original_description' => :'original_description',
    :'published_date' => :'published_date',
    :'references' => :'references',
    :'remediation_level' => :'remediation_level',
    :'severity' => :'severity',
    :'spotlight_published_date' => :'spotlight_published_date',
    :'types' => :'types',
    :'vector' => :'vector',
    :'vendor_advisory' => :'vendor_advisory'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 321

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 150

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 124

def self.openapi_types
  {
    :'actors' => :'Array<String>',
    :'base_score' => :'Float',
    :'cisa_info' => :'DomainAPIVulnerabilityCVECISAInfo',
    :'cwes' => :'Array<String>',
    :'description' => :'String',
    :'exploit_status' => :'Integer',
    :'exploitability_score' => :'Float',
    :'exprt_rating' => :'String',
    :'id' => :'String',
    :'impact_score' => :'Float',
    :'name' => :'String',
    :'original_description' => :'String',
    :'published_date' => :'String',
    :'references' => :'Array<String>',
    :'remediation_level' => :'String',
    :'severity' => :'String',
    :'spotlight_published_date' => :'String',
    :'types' => :'Array<String>',
    :'vector' => :'String',
    :'vendor_advisory' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      actors == o.actors &&
      base_score == o.base_score &&
      cisa_info == o.cisa_info &&
      cwes == o.cwes &&
      description == o.description &&
      exploit_status == o.exploit_status &&
      exploitability_score == o.exploitability_score &&
      exprt_rating == o.exprt_rating &&
      id == o.id &&
      impact_score == o.impact_score &&
      name == o.name &&
      original_description == o.original_description &&
      published_date == o.published_date &&
      references == o.references &&
      remediation_level == o.remediation_level &&
      severity == o.severity &&
      spotlight_published_date == o.spotlight_published_date &&
      types == o.types &&
      vector == o.vector &&
      vendor_advisory == o.vendor_advisory
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 352

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 423

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 328

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 314

def hash
  [actors, base_score, cisa_info, cwes, description, exploit_status, exploitability_score, exprt_rating, id, impact_score, name, original_description, published_date, references, remediation_level, severity, spotlight_published_date, types, vector, vendor_advisory].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



263
264
265
266
267
268
269
270
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 263

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 399

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 405

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



393
394
395
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 393

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
# File 'lib/crimson-falcon/models/domain_api_vulnerability_cve_details_facet_v2.rb', line 274

def valid?
  return false if @id.nil?
  true
end