Class: Falcon::DomainAPIVulnerabilityDataProviderV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainAPIVulnerabilityDataProviderV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIVulnerabilityDataProviderV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIVulnerabilityDataProviderV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ports')
    if (value = attributes[:'ports']).is_a?(Array)
      self.ports = value
    end
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'rating')
    self.rating = attributes[:'rating']
  end

  if attributes.key?(:'scan_config_id')
    self.scan_config_id = attributes[:'scan_config_id']
  end

  if attributes.key?(:'scan_id')
    self.scan_id = attributes[:'scan_id']
  end

  if attributes.key?(:'scan_time')
    self.scan_time = attributes[:'scan_time']
  end

  if attributes.key?(:'scanner_id')
    self.scanner_id = attributes[:'scanner_id']
  end
end

Instance Attribute Details

#portsObject

Ports that the vulnerability affects



35
36
37
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 35

def ports
  @ports
end

#providerObject

Label for the provider



38
39
40
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 38

def provider
  @provider
end

#ratingObject

Rating provided by the vulnerability provider



41
42
43
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 41

def rating
  @rating
end

#scan_config_idObject

Provider Scan Config ID that identified the detection



44
45
46
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 44

def scan_config_id
  @scan_config_id
end

#scan_idObject

Provider Scan ID that identified the detection



47
48
49
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 47

def scan_id
  @scan_id
end

#scan_timeObject

Time when the detection occurred



50
51
52
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 50

def scan_time
  @scan_time
end

#scanner_idObject

Scanner ID of the vulnerability provider



53
54
55
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 53

def scanner_id
  @scanner_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 56

def self.attribute_map
  {
    :'ports' => :'ports',
    :'provider' => :'provider',
    :'rating' => :'rating',
    :'scan_config_id' => :'scan_config_id',
    :'scan_id' => :'scan_id',
    :'scan_time' => :'scan_time',
    :'scanner_id' => :'scanner_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 180

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 74

def self.openapi_types
  {
    :'ports' => :'Array<Integer>',
    :'provider' => :'String',
    :'rating' => :'String',
    :'scan_config_id' => :'String',
    :'scan_id' => :'String',
    :'scan_time' => :'String',
    :'scanner_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
163
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ports == o.ports &&
      provider == o.provider &&
      rating == o.rating &&
      scan_config_id == o.scan_config_id &&
      scan_id == o.scan_id &&
      scan_time == o.scan_time &&
      scanner_id == o.scanner_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 211

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 282

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 173

def hash
  [ports, provider, rating, scan_config_id, scan_id, scan_time, scanner_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 258

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



252
253
254
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 252

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
# File 'lib/crimson-falcon/models/domain_api_vulnerability_data_provider_v1.rb', line 147

def valid?
  true
end