Class: Falcon::DomainAPIVulnerabilityHostFacetV2
- Inherits:
-
Object
- Object
- Falcon::DomainAPIVulnerabilityHostFacetV2
- Defined in:
- lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb
Instance Attribute Summary collapse
-
#asset_criticality ⇒ Object
Refers to how critical an asset has been evaluated to be.
-
#asset_roles ⇒ Object
Refers to one or more roles that have been assigned to the assets.
-
#confidence_label ⇒ Object
Confidence level of the asset association to the CID.
-
#groups ⇒ Object
Refers to a logic grouping of assets.
-
#has_run_container ⇒ Object
Indicates whether the asset has run containers.
-
#host_last_seen_timestamp ⇒ Object
A timestamp corresponding to the last day when we detected activity coming from an asset.
-
#hostname ⇒ Object
Refers to the hostname used by the asset on which the vulnerability was detected.
-
#instance_id ⇒ Object
Refers to a unique identifier assigned to an asset.
-
#instance_state ⇒ Object
Refers to the state of an asset.
-
#internet_exposure ⇒ Object
Refers to the level of exposure an asset has to the internet.
-
#local_ip ⇒ Object
Refers to the local IP used by the asset on which the vulnerability was detected.
-
#machine_domain ⇒ Object
The machine domain of an asset is the network identity within a network infrastructure.
-
#managed_by ⇒ Object
Name of the entity that is managing the asset.
-
#os_build ⇒ Object
Refers to the specific build or version number of an operating system, indicating a particular release or revision of the operating system.
-
#os_version ⇒ Object
Refers to the operating system version used by the asset on which the vulnerability was detected.
-
#ou ⇒ Object
Refers to the specific organizational grouping or container within an Active Directory (AD) or directory service where the host is located or categorized.
-
#platform ⇒ Object
Refers to the name or designation of the specific software platform or operating system on which the asset is running.
-
#product_type_desc ⇒ Object
Refers to the descriptive label or category that identifies the type or edition of the operating system product installed on the asset.
-
#service_provider ⇒ Object
Refers to a company, organization, or entity that offers or provided this specific asset.
-
#service_provider_account_id ⇒ Object
Refers to the unique identifier associated with a service provider account, typically used in cloud computing or managed service environments.
-
#site_name ⇒ Object
Refers to the name or label assigned to the physical or logical location within a network infrastructure where the host is situated.
-
#subsidiaries ⇒ Object
The list of subsidiaries associated with the asset.
-
#system_manufacturer ⇒ Object
Refers to the company or organization that designed and produced the hardware system or device.
-
#tags ⇒ Object
Refers to a logical grouping of assets via tags.
-
#third_party_asset_ids ⇒ Object
zero or more unique identifiers assigned by third party entities which provided data for the asset.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainAPIVulnerabilityHostFacetV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainAPIVulnerabilityHostFacetV2
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 184 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAPIVulnerabilityHostFacetV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAPIVulnerabilityHostFacetV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_criticality') self.asset_criticality = attributes[:'asset_criticality'] end if attributes.key?(:'asset_roles') if (value = attributes[:'asset_roles']).is_a?(Array) self.asset_roles = value end end if attributes.key?(:'confidence_label') self.confidence_label = attributes[:'confidence_label'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'has_run_container') self.has_run_container = attributes[:'has_run_container'] end if attributes.key?(:'host_last_seen_timestamp') self. = attributes[:'host_last_seen_timestamp'] end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] end if attributes.key?(:'instance_state') self.instance_state = attributes[:'instance_state'] end if attributes.key?(:'internet_exposure') self.internet_exposure = attributes[:'internet_exposure'] end if attributes.key?(:'local_ip') self.local_ip = attributes[:'local_ip'] end if attributes.key?(:'machine_domain') self.machine_domain = attributes[:'machine_domain'] end if attributes.key?(:'managed_by') self.managed_by = attributes[:'managed_by'] end if attributes.key?(:'os_build') self.os_build = attributes[:'os_build'] end if attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] end if attributes.key?(:'ou') self.ou = attributes[:'ou'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'product_type_desc') self.product_type_desc = attributes[:'product_type_desc'] end if attributes.key?(:'service_provider') self.service_provider = attributes[:'service_provider'] end if attributes.key?(:'service_provider_account_id') self.service_provider_account_id = attributes[:'service_provider_account_id'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'subsidiaries') if (value = attributes[:'subsidiaries']).is_a?(Array) self.subsidiaries = value end end if attributes.key?(:'system_manufacturer') self.system_manufacturer = attributes[:'system_manufacturer'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'third_party_asset_ids') if (value = attributes[:'third_party_asset_ids']).is_a?(Array) self.third_party_asset_ids = value end end end |
Instance Attribute Details
#asset_criticality ⇒ Object
Refers to how critical an asset has been evaluated to be
35 36 37 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 35 def asset_criticality @asset_criticality end |
#asset_roles ⇒ Object
Refers to one or more roles that have been assigned to the assets
38 39 40 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 38 def asset_roles @asset_roles end |
#confidence_label ⇒ Object
Confidence level of the asset association to the CID
41 42 43 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 41 def confidence_label @confidence_label end |
#groups ⇒ Object
Refers to a logic grouping of assets
44 45 46 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 44 def groups @groups end |
#has_run_container ⇒ Object
Indicates whether the asset has run containers
47 48 49 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 47 def has_run_container @has_run_container end |
#host_last_seen_timestamp ⇒ Object
A timestamp corresponding to the last day when we detected activity coming from an asset
50 51 52 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 50 def @host_last_seen_timestamp end |
#hostname ⇒ Object
Refers to the hostname used by the asset on which the vulnerability was detected
53 54 55 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 53 def hostname @hostname end |
#instance_id ⇒ Object
Refers to a unique identifier assigned to an asset
56 57 58 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 56 def instance_id @instance_id end |
#instance_state ⇒ Object
Refers to the state of an asset
59 60 61 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 59 def instance_state @instance_state end |
#internet_exposure ⇒ Object
Refers to the level of exposure an asset has to the internet
62 63 64 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 62 def internet_exposure @internet_exposure end |
#local_ip ⇒ Object
Refers to the local IP used by the asset on which the vulnerability was detected
65 66 67 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 65 def local_ip @local_ip end |
#machine_domain ⇒ Object
The machine domain of an asset is the network identity within a network infrastructure
68 69 70 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 68 def machine_domain @machine_domain end |
#managed_by ⇒ Object
Name of the entity that is managing the asset
71 72 73 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 71 def managed_by @managed_by end |
#os_build ⇒ Object
Refers to the specific build or version number of an operating system, indicating a particular release or revision of the operating system
74 75 76 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 74 def os_build @os_build end |
#os_version ⇒ Object
Refers to the operating system version used by the asset on which the vulnerability was detected
77 78 79 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 77 def os_version @os_version end |
#ou ⇒ Object
Refers to the specific organizational grouping or container within an Active Directory (AD) or directory service where the host is located or categorized.
80 81 82 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 80 def ou @ou end |
#platform ⇒ Object
Refers to the name or designation of the specific software platform or operating system on which the asset is running
83 84 85 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 83 def platform @platform end |
#product_type_desc ⇒ Object
Refers to the descriptive label or category that identifies the type or edition of the operating system product installed on the asset
86 87 88 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 86 def product_type_desc @product_type_desc end |
#service_provider ⇒ Object
Refers to a company, organization, or entity that offers or provided this specific asset
89 90 91 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 89 def service_provider @service_provider end |
#service_provider_account_id ⇒ Object
Refers to the unique identifier associated with a service provider account, typically used in cloud computing or managed service environments
92 93 94 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 92 def service_provider_account_id @service_provider_account_id end |
#site_name ⇒ Object
Refers to the name or label assigned to the physical or logical location within a network infrastructure where the host is situated
95 96 97 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 95 def site_name @site_name end |
#subsidiaries ⇒ Object
The list of subsidiaries associated with the asset
98 99 100 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 98 def subsidiaries @subsidiaries end |
#system_manufacturer ⇒ Object
Refers to the company or organization that designed and produced the hardware system or device
101 102 103 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 101 def system_manufacturer @system_manufacturer end |
#tags ⇒ Object
Refers to a logical grouping of assets via tags
104 105 106 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 104 def @tags end |
#third_party_asset_ids ⇒ Object
zero or more unique identifiers assigned by third party entities which provided data for the asset
107 108 109 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 107 def third_party_asset_ids @third_party_asset_ids end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
141 142 143 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 141 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 110 def self.attribute_map { :'asset_criticality' => :'asset_criticality', :'asset_roles' => :'asset_roles', :'confidence_label' => :'confidence_label', :'groups' => :'groups', :'has_run_container' => :'has_run_container', :'host_last_seen_timestamp' => :'host_last_seen_timestamp', :'hostname' => :'hostname', :'instance_id' => :'instance_id', :'instance_state' => :'instance_state', :'internet_exposure' => :'internet_exposure', :'local_ip' => :'local_ip', :'machine_domain' => :'machine_domain', :'managed_by' => :'managed_by', :'os_build' => :'os_build', :'os_version' => :'os_version', :'ou' => :'ou', :'platform' => :'platform', :'product_type_desc' => :'product_type_desc', :'service_provider' => :'service_provider', :'service_provider_account_id' => :'service_provider_account_id', :'site_name' => :'site_name', :'subsidiaries' => :'subsidiaries', :'system_manufacturer' => :'system_manufacturer', :'tags' => :'tags', :'third_party_asset_ids' => :'third_party_asset_ids' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
403 404 405 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 403 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
177 178 179 180 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 177 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 146 def self.openapi_types { :'asset_criticality' => :'String', :'asset_roles' => :'Array<String>', :'confidence_label' => :'String', :'groups' => :'Array<DomainAPIHostGroup>', :'has_run_container' => :'Boolean', :'host_last_seen_timestamp' => :'String', :'hostname' => :'String', :'instance_id' => :'String', :'instance_state' => :'String', :'internet_exposure' => :'String', :'local_ip' => :'String', :'machine_domain' => :'String', :'managed_by' => :'String', :'os_build' => :'String', :'os_version' => :'String', :'ou' => :'String', :'platform' => :'String', :'product_type_desc' => :'String', :'service_provider' => :'String', :'service_provider_account_id' => :'String', :'site_name' => :'String', :'subsidiaries' => :'Array<String>', :'system_manufacturer' => :'String', :'tags' => :'Array<String>', :'third_party_asset_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 358 def ==(o) return true if self.equal?(o) self.class == o.class && asset_criticality == o.asset_criticality && asset_roles == o.asset_roles && confidence_label == o.confidence_label && groups == o.groups && has_run_container == o.has_run_container && == o. && hostname == o.hostname && instance_id == o.instance_id && instance_state == o.instance_state && internet_exposure == o.internet_exposure && local_ip == o.local_ip && machine_domain == o.machine_domain && managed_by == o.managed_by && os_build == o.os_build && os_version == o.os_version && ou == o.ou && platform == o.platform && product_type_desc == o.product_type_desc && service_provider == o.service_provider && service_provider_account_id == o.service_provider_account_id && site_name == o.site_name && subsidiaries == o.subsidiaries && system_manufacturer == o.system_manufacturer && == o. && third_party_asset_ids == o.third_party_asset_ids end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 434 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 505 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 410 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
390 391 392 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 390 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
396 397 398 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 396 def hash [asset_criticality, asset_roles, confidence_label, groups, has_run_container, , hostname, instance_id, instance_state, internet_exposure, local_ip, machine_domain, managed_by, os_build, os_version, ou, platform, product_type_desc, service_provider, service_provider_account_id, site_name, subsidiaries, system_manufacturer, , third_party_asset_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 310 def list_invalid_properties invalid_properties = Array.new if @hostname.nil? invalid_properties.push('invalid value for "hostname", hostname cannot be nil.') end if @local_ip.nil? invalid_properties.push('invalid value for "local_ip", local_ip cannot be nil.') end if @machine_domain.nil? invalid_properties.push('invalid value for "machine_domain", machine_domain cannot be nil.') end if @os_version.nil? invalid_properties.push('invalid value for "os_version", os_version cannot be nil.') end if @ou.nil? invalid_properties.push('invalid value for "ou", ou cannot be nil.') end if @site_name.nil? invalid_properties.push('invalid value for "site_name", site_name cannot be nil.') end if @system_manufacturer.nil? invalid_properties.push('invalid value for "system_manufacturer", system_manufacturer cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
481 482 483 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 481 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
487 488 489 490 491 492 493 494 495 496 497 498 499 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 487 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
475 476 477 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 475 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
345 346 347 348 349 350 351 352 353 354 |
# File 'lib/crimson-falcon/models/domain_api_vulnerability_host_facet_v2.rb', line 345 def valid? return false if @hostname.nil? return false if @local_ip.nil? return false if @machine_domain.nil? return false if @os_version.nil? return false if @ou.nil? return false if @site_name.nil? return false if @system_manufacturer.nil? true end |