Class: Falcon::DomainBaseAPIVulnerabilityV2
- Inherits:
-
Object
- Object
- Falcon::DomainBaseAPIVulnerabilityV2
- Defined in:
- lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb
Instance Attribute Summary collapse
-
#aid ⇒ Object
Asset ID for which the vulnerability has been detected.
-
#app ⇒ Object
Returns the value of attribute app.
-
#apps ⇒ Object
Provide details related to the products for which a the vulnerability has been detected.
-
#cid ⇒ Object
Contains the customer identifier associated with the asset for which the vulnerability has been detected.
-
#closed_timestamp ⇒ Object
A timestamp corresponding to the point in time when the vulnerability has no longer been detected (eg: it got fixed).
-
#confidence ⇒ Object
Represents the confidence level of a vulnerability.
-
#created_timestamp ⇒ Object
A timestamp corresponding to the point in time when the vulnerability has been created (detected) in our system.
-
#cve ⇒ Object
Returns the value of attribute cve.
-
#data_providers ⇒ Object
Contains information about the vulnerability data providers of this entity.
-
#host_info ⇒ Object
Returns the value of attribute host_info.
-
#id ⇒ Object
Vulnerability unique ID.
-
#remediation ⇒ Object
Returns the value of attribute remediation.
-
#services ⇒ Object
Contains details about the vulnerable services.
-
#status ⇒ Object
Current status of a vulnerability (open, closed, reopen).
-
#suppression_info ⇒ Object
Returns the value of attribute suppression_info.
-
#updated_timestamp ⇒ Object
A timestamp corresponding to the point in time when a vulnerability’s information or status have been updated.
-
#vulnerability_id ⇒ Object
Dynamic label that contains the CVE ID if applicable, otherwise the vulnerability metadata ID or label from the provider.
-
#vulnerability_metadata_id ⇒ Object
Unique identifier for the vulnerability metadata.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainBaseAPIVulnerabilityV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainBaseAPIVulnerabilityV2
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainBaseAPIVulnerabilityV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainBaseAPIVulnerabilityV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'apps') if (value = attributes[:'apps']).is_a?(Array) self.apps = value end end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'closed_timestamp') self. = attributes[:'closed_timestamp'] end if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] end if attributes.key?(:'created_timestamp') self. = attributes[:'created_timestamp'] end if attributes.key?(:'cve') self.cve = attributes[:'cve'] end if attributes.key?(:'data_providers') if (value = attributes[:'data_providers']).is_a?(Array) self.data_providers = value end end if attributes.key?(:'host_info') self.host_info = attributes[:'host_info'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'remediation') self.remediation = attributes[:'remediation'] end if attributes.key?(:'services') if (value = attributes[:'services']).is_a?(Array) self.services = value end end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'suppression_info') self.suppression_info = attributes[:'suppression_info'] end if attributes.key?(:'updated_timestamp') self. = attributes[:'updated_timestamp'] end if attributes.key?(:'vulnerability_id') self.vulnerability_id = attributes[:'vulnerability_id'] end if attributes.key?(:'vulnerability_metadata_id') self. = attributes[:'vulnerability_metadata_id'] end end |
Instance Attribute Details
#aid ⇒ Object
Asset ID for which the vulnerability has been detected. For managed assets it can correspond to the sensor ID, for unmanaged assets can be a stand alone ID
35 36 37 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 35 def aid @aid end |
#app ⇒ Object
Returns the value of attribute app.
37 38 39 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 37 def app @app end |
#apps ⇒ Object
Provide details related to the products for which a the vulnerability has been detected
40 41 42 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 40 def apps @apps end |
#cid ⇒ Object
Contains the customer identifier associated with the asset for which the vulnerability has been detected
43 44 45 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 43 def cid @cid end |
#closed_timestamp ⇒ Object
A timestamp corresponding to the point in time when the vulnerability has no longer been detected (eg: it got fixed)
46 47 48 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 46 def @closed_timestamp end |
#confidence ⇒ Object
Represents the confidence level of a vulnerability
49 50 51 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 49 def confidence @confidence end |
#created_timestamp ⇒ Object
A timestamp corresponding to the point in time when the vulnerability has been created (detected) in our system
52 53 54 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 52 def @created_timestamp end |
#cve ⇒ Object
Returns the value of attribute cve.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 54 def cve @cve end |
#data_providers ⇒ Object
Contains information about the vulnerability data providers of this entity
57 58 59 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 57 def data_providers @data_providers end |
#host_info ⇒ Object
Returns the value of attribute host_info.
59 60 61 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 59 def host_info @host_info end |
#id ⇒ Object
Vulnerability unique ID
62 63 64 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 62 def id @id end |
#remediation ⇒ Object
Returns the value of attribute remediation.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 64 def remediation @remediation end |
#services ⇒ Object
Contains details about the vulnerable services
67 68 69 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 67 def services @services end |
#status ⇒ Object
Current status of a vulnerability (open, closed, reopen)
70 71 72 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 70 def status @status end |
#suppression_info ⇒ Object
Returns the value of attribute suppression_info.
72 73 74 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 72 def suppression_info @suppression_info end |
#updated_timestamp ⇒ Object
A timestamp corresponding to the point in time when a vulnerability’s information or status have been updated
75 76 77 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 75 def @updated_timestamp end |
#vulnerability_id ⇒ Object
Dynamic label that contains the CVE ID if applicable, otherwise the vulnerability metadata ID or label from the provider
78 79 80 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 78 def vulnerability_id @vulnerability_id end |
#vulnerability_metadata_id ⇒ Object
Unique identifier for the vulnerability metadata
81 82 83 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 81 def @vulnerability_metadata_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
108 109 110 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 108 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 84 def self.attribute_map { :'aid' => :'aid', :'app' => :'app', :'apps' => :'apps', :'cid' => :'cid', :'closed_timestamp' => :'closed_timestamp', :'confidence' => :'confidence', :'created_timestamp' => :'created_timestamp', :'cve' => :'cve', :'data_providers' => :'data_providers', :'host_info' => :'host_info', :'id' => :'id', :'remediation' => :'remediation', :'services' => :'services', :'status' => :'status', :'suppression_info' => :'suppression_info', :'updated_timestamp' => :'updated_timestamp', :'vulnerability_id' => :'vulnerability_id', :'vulnerability_metadata_id' => :'vulnerability_metadata_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 319 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 137 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 113 def self.openapi_types { :'aid' => :'String', :'app' => :'DomainAPIVulnerabilityAppV2', :'apps' => :'Array<DomainAPIVulnerabilityExtendedAppV2>', :'cid' => :'String', :'closed_timestamp' => :'String', :'confidence' => :'String', :'created_timestamp' => :'String', :'cve' => :'DomainAPIVulnerabilityCVEDetailsFacetV2', :'data_providers' => :'Array<DomainAPIVulnerabilityDataProviderV1>', :'host_info' => :'DomainAPIVulnerabilityHostFacetV2', :'id' => :'String', :'remediation' => :'DomainAPIVulnerabilityRemediationFacetV2', :'services' => :'Array<DomainAPIVulnerabilityServiceV2>', :'status' => :'String', :'suppression_info' => :'DomainAPIVulnerabilitySuppressionInfoV2', :'updated_timestamp' => :'String', :'vulnerability_id' => :'String', :'vulnerability_metadata_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && aid == o.aid && app == o.app && apps == o.apps && cid == o.cid && == o. && confidence == o.confidence && == o. && cve == o.cve && data_providers == o.data_providers && host_info == o.host_info && id == o.id && remediation == o.remediation && services == o.services && status == o.status && suppression_info == o.suppression_info && == o. && vulnerability_id == o.vulnerability_id && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 350 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 421 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 326 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 312 def hash [aid, app, apps, cid, , confidence, , cve, data_providers, host_info, id, remediation, services, status, suppression_info, , vulnerability_id, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 238 def list_invalid_properties invalid_properties = Array.new if @aid.nil? invalid_properties.push('invalid value for "aid", aid cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @created_timestamp.nil? invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @updated_timestamp.nil? invalid_properties.push('invalid value for "updated_timestamp", updated_timestamp cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
397 398 399 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 397 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 403 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
391 392 393 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 391 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
269 270 271 272 273 274 275 276 277 |
# File 'lib/crimson-falcon/models/domain_base_api_vulnerability_v2.rb', line 269 def valid? return false if @aid.nil? return false if @cid.nil? return false if @created_timestamp.nil? return false if @id.nil? return false if @status.nil? return false if @updated_timestamp.nil? true end |