Class: Falcon::DomainCIDPolicyAssignments
- Inherits:
-
Object
- Object
- Falcon::DomainCIDPolicyAssignments
- Defined in:
- lib/crimson-falcon/models/domain_cid_policy_assignments.rb
Instance Attribute Summary collapse
-
#account_scope ⇒ Object
Returns the value of attribute account_scope.
-
#attack_types ⇒ Object
Returns the value of attribute attack_types.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cis_benchmark ⇒ Object
Returns the value of attribute cis_benchmark.
-
#cisa_benchmark ⇒ Object
Returns the value of attribute cisa_benchmark.
-
#cloud_asset_type ⇒ Object
Returns the value of attribute cloud_asset_type.
-
#cloud_asset_type_id ⇒ Object
Returns the value of attribute cloud_asset_type_id.
-
#cloud_provider ⇒ Object
Returns the value of attribute cloud_provider.
-
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
-
#cloud_service_friendly ⇒ Object
Returns the value of attribute cloud_service_friendly.
-
#cloud_service_id ⇒ Object
Returns the value of attribute cloud_service_id.
-
#cloud_service_subtype ⇒ Object
Returns the value of attribute cloud_service_subtype.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default_severity ⇒ Object
Returns the value of attribute default_severity.
-
#fql_policy ⇒ Object
Returns the value of attribute fql_policy.
-
#hipaa_benchmark ⇒ Object
Returns the value of attribute hipaa_benchmark.
-
#hitrust_benchmark ⇒ Object
Returns the value of attribute hitrust_benchmark.
-
#is_global ⇒ Object
Returns the value of attribute is_global.
-
#is_remediable ⇒ Object
Returns the value of attribute is_remediable.
-
#iso_benchmark ⇒ Object
Returns the value of attribute iso_benchmark.
-
#name ⇒ Object
Returns the value of attribute name.
-
#nist_benchmark ⇒ Object
Returns the value of attribute nist_benchmark.
-
#pci_benchmark ⇒ Object
Returns the value of attribute pci_benchmark.
-
#policy_id ⇒ Object
Returns the value of attribute policy_id.
-
#policy_settings ⇒ Object
Returns the value of attribute policy_settings.
-
#policy_timestamp ⇒ Object
Returns the value of attribute policy_timestamp.
-
#policy_type ⇒ Object
Returns the value of attribute policy_type.
-
#remediation_summary ⇒ Object
Returns the value of attribute remediation_summary.
-
#soc2_benchmark ⇒ Object
Returns the value of attribute soc2_benchmark.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainCIDPolicyAssignments
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainCIDPolicyAssignments
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 179 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainCIDPolicyAssignments` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainCIDPolicyAssignments`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_scope') self.account_scope = attributes[:'account_scope'] end if attributes.key?(:'attack_types') if (value = attributes[:'attack_types']).is_a?(Array) self.attack_types = value end end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cis_benchmark') if (value = attributes[:'cis_benchmark']).is_a?(Array) self.cis_benchmark = value end end if attributes.key?(:'cisa_benchmark') if (value = attributes[:'cisa_benchmark']).is_a?(Array) self.cisa_benchmark = value end end if attributes.key?(:'cloud_asset_type') self.cloud_asset_type = attributes[:'cloud_asset_type'] end if attributes.key?(:'cloud_asset_type_id') self.cloud_asset_type_id = attributes[:'cloud_asset_type_id'] end if attributes.key?(:'cloud_provider') self.cloud_provider = attributes[:'cloud_provider'] end if attributes.key?(:'cloud_service') self.cloud_service = attributes[:'cloud_service'] end if attributes.key?(:'cloud_service_friendly') self.cloud_service_friendly = attributes[:'cloud_service_friendly'] end if attributes.key?(:'cloud_service_id') self.cloud_service_id = attributes[:'cloud_service_id'] end if attributes.key?(:'cloud_service_subtype') self.cloud_service_subtype = attributes[:'cloud_service_subtype'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'default_severity') self.default_severity = attributes[:'default_severity'] end if attributes.key?(:'fql_policy') self.fql_policy = attributes[:'fql_policy'] end if attributes.key?(:'hipaa_benchmark') if (value = attributes[:'hipaa_benchmark']).is_a?(Array) self.hipaa_benchmark = value end end if attributes.key?(:'hitrust_benchmark') if (value = attributes[:'hitrust_benchmark']).is_a?(Array) self.hitrust_benchmark = value end end if attributes.key?(:'is_global') self.is_global = attributes[:'is_global'] end if attributes.key?(:'is_remediable') self.is_remediable = attributes[:'is_remediable'] end if attributes.key?(:'iso_benchmark') if (value = attributes[:'iso_benchmark']).is_a?(Array) self.iso_benchmark = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'nist_benchmark') if (value = attributes[:'nist_benchmark']).is_a?(Array) self.nist_benchmark = value end end if attributes.key?(:'pci_benchmark') if (value = attributes[:'pci_benchmark']).is_a?(Array) self.pci_benchmark = value end end if attributes.key?(:'policy_id') self.policy_id = attributes[:'policy_id'] end if attributes.key?(:'policy_settings') if (value = attributes[:'policy_settings']).is_a?(Array) self.policy_settings = value end end if attributes.key?(:'policy_timestamp') self. = attributes[:'policy_timestamp'] end if attributes.key?(:'policy_type') self.policy_type = attributes[:'policy_type'] end if attributes.key?(:'remediation_summary') self.remediation_summary = attributes[:'remediation_summary'] end if attributes.key?(:'soc2_benchmark') if (value = attributes[:'soc2_benchmark']).is_a?(Array) self.soc2_benchmark = value end end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#account_scope ⇒ Object
Returns the value of attribute account_scope.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 34 def account_scope @account_scope end |
#attack_types ⇒ Object
Returns the value of attribute attack_types.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 36 def attack_types @attack_types end |
#cid ⇒ Object
Returns the value of attribute cid.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 38 def cid @cid end |
#cis_benchmark ⇒ Object
Returns the value of attribute cis_benchmark.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 40 def cis_benchmark @cis_benchmark end |
#cisa_benchmark ⇒ Object
Returns the value of attribute cisa_benchmark.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 42 def cisa_benchmark @cisa_benchmark end |
#cloud_asset_type ⇒ Object
Returns the value of attribute cloud_asset_type.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 44 def cloud_asset_type @cloud_asset_type end |
#cloud_asset_type_id ⇒ Object
Returns the value of attribute cloud_asset_type_id.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 46 def cloud_asset_type_id @cloud_asset_type_id end |
#cloud_provider ⇒ Object
Returns the value of attribute cloud_provider.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 48 def cloud_provider @cloud_provider end |
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 50 def cloud_service @cloud_service end |
#cloud_service_friendly ⇒ Object
Returns the value of attribute cloud_service_friendly.
52 53 54 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 52 def cloud_service_friendly @cloud_service_friendly end |
#cloud_service_id ⇒ Object
Returns the value of attribute cloud_service_id.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 54 def cloud_service_id @cloud_service_id end |
#cloud_service_subtype ⇒ Object
Returns the value of attribute cloud_service_subtype.
56 57 58 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 56 def cloud_service_subtype @cloud_service_subtype end |
#created_at ⇒ Object
Returns the value of attribute created_at.
58 59 60 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 58 def created_at @created_at end |
#default_severity ⇒ Object
Returns the value of attribute default_severity.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 60 def default_severity @default_severity end |
#fql_policy ⇒ Object
Returns the value of attribute fql_policy.
62 63 64 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 62 def fql_policy @fql_policy end |
#hipaa_benchmark ⇒ Object
Returns the value of attribute hipaa_benchmark.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 64 def hipaa_benchmark @hipaa_benchmark end |
#hitrust_benchmark ⇒ Object
Returns the value of attribute hitrust_benchmark.
66 67 68 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 66 def hitrust_benchmark @hitrust_benchmark end |
#is_global ⇒ Object
Returns the value of attribute is_global.
68 69 70 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 68 def is_global @is_global end |
#is_remediable ⇒ Object
Returns the value of attribute is_remediable.
70 71 72 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 70 def is_remediable @is_remediable end |
#iso_benchmark ⇒ Object
Returns the value of attribute iso_benchmark.
72 73 74 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 72 def iso_benchmark @iso_benchmark end |
#name ⇒ Object
Returns the value of attribute name.
74 75 76 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 74 def name @name end |
#nist_benchmark ⇒ Object
Returns the value of attribute nist_benchmark.
76 77 78 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 76 def nist_benchmark @nist_benchmark end |
#pci_benchmark ⇒ Object
Returns the value of attribute pci_benchmark.
78 79 80 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 78 def pci_benchmark @pci_benchmark end |
#policy_id ⇒ Object
Returns the value of attribute policy_id.
80 81 82 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 80 def policy_id @policy_id end |
#policy_settings ⇒ Object
Returns the value of attribute policy_settings.
82 83 84 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 82 def policy_settings @policy_settings end |
#policy_timestamp ⇒ Object
Returns the value of attribute policy_timestamp.
84 85 86 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 84 def @policy_timestamp end |
#policy_type ⇒ Object
Returns the value of attribute policy_type.
86 87 88 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 86 def policy_type @policy_type end |
#remediation_summary ⇒ Object
Returns the value of attribute remediation_summary.
88 89 90 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 88 def remediation_summary @remediation_summary end |
#soc2_benchmark ⇒ Object
Returns the value of attribute soc2_benchmark.
90 91 92 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 90 def soc2_benchmark @soc2_benchmark end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
92 93 94 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 92 def updated_at @updated_at end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
131 132 133 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 131 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 95 def self.attribute_map { :'account_scope' => :'account_scope', :'attack_types' => :'attack_types', :'cid' => :'cid', :'cis_benchmark' => :'cis_benchmark', :'cisa_benchmark' => :'cisa_benchmark', :'cloud_asset_type' => :'cloud_asset_type', :'cloud_asset_type_id' => :'cloud_asset_type_id', :'cloud_provider' => :'cloud_provider', :'cloud_service' => :'cloud_service', :'cloud_service_friendly' => :'cloud_service_friendly', :'cloud_service_id' => :'cloud_service_id', :'cloud_service_subtype' => :'cloud_service_subtype', :'created_at' => :'created_at', :'default_severity' => :'default_severity', :'fql_policy' => :'fql_policy', :'hipaa_benchmark' => :'hipaa_benchmark', :'hitrust_benchmark' => :'hitrust_benchmark', :'is_global' => :'is_global', :'is_remediable' => :'is_remediable', :'iso_benchmark' => :'iso_benchmark', :'name' => :'name', :'nist_benchmark' => :'nist_benchmark', :'pci_benchmark' => :'pci_benchmark', :'policy_id' => :'policy_id', :'policy_settings' => :'policy_settings', :'policy_timestamp' => :'policy_timestamp', :'policy_type' => :'policy_type', :'remediation_summary' => :'remediation_summary', :'soc2_benchmark' => :'soc2_benchmark', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
408 409 410 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 408 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
172 173 174 175 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 172 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 136 def self.openapi_types { :'account_scope' => :'String', :'attack_types' => :'Array<String>', :'cid' => :'String', :'cis_benchmark' => :'Array<DomainBenchmark>', :'cisa_benchmark' => :'Array<DomainBenchmark>', :'cloud_asset_type' => :'String', :'cloud_asset_type_id' => :'Integer', :'cloud_provider' => :'String', :'cloud_service' => :'String', :'cloud_service_friendly' => :'String', :'cloud_service_id' => :'Integer', :'cloud_service_subtype' => :'String', :'created_at' => :'Time', :'default_severity' => :'String', :'fql_policy' => :'String', :'hipaa_benchmark' => :'Array<DomainBenchmark>', :'hitrust_benchmark' => :'Array<DomainBenchmark>', :'is_global' => :'Boolean', :'is_remediable' => :'Boolean', :'iso_benchmark' => :'Array<DomainBenchmark>', :'name' => :'String', :'nist_benchmark' => :'Array<DomainBenchmark>', :'pci_benchmark' => :'Array<DomainBenchmark>', :'policy_id' => :'Integer', :'policy_settings' => :'Array<DomainPolicySettingByAccountAndRegion>', :'policy_timestamp' => :'Time', :'policy_type' => :'String', :'remediation_summary' => :'String', :'soc2_benchmark' => :'Array<DomainBenchmark>', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 358 def ==(o) return true if self.equal?(o) self.class == o.class && account_scope == o.account_scope && attack_types == o.attack_types && cid == o.cid && cis_benchmark == o.cis_benchmark && cisa_benchmark == o.cisa_benchmark && cloud_asset_type == o.cloud_asset_type && cloud_asset_type_id == o.cloud_asset_type_id && cloud_provider == o.cloud_provider && cloud_service == o.cloud_service && cloud_service_friendly == o.cloud_service_friendly && cloud_service_id == o.cloud_service_id && cloud_service_subtype == o.cloud_service_subtype && created_at == o.created_at && default_severity == o.default_severity && fql_policy == o.fql_policy && hipaa_benchmark == o.hipaa_benchmark && hitrust_benchmark == o.hitrust_benchmark && is_global == o.is_global && is_remediable == o.is_remediable && iso_benchmark == o.iso_benchmark && name == o.name && nist_benchmark == o.nist_benchmark && pci_benchmark == o.pci_benchmark && policy_id == o.policy_id && policy_settings == o.policy_settings && == o. && policy_type == o.policy_type && remediation_summary == o.remediation_summary && soc2_benchmark == o.soc2_benchmark && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 439 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 510 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 415 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
395 396 397 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 395 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
401 402 403 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 401 def hash [account_scope, attack_types, cid, cis_benchmark, cisa_benchmark, cloud_asset_type, cloud_asset_type_id, cloud_provider, cloud_service, cloud_service_friendly, cloud_service_id, cloud_service_subtype, created_at, default_severity, fql_policy, hipaa_benchmark, hitrust_benchmark, is_global, is_remediable, iso_benchmark, name, nist_benchmark, pci_benchmark, policy_id, policy_settings, , policy_type, remediation_summary, soc2_benchmark, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 335 def list_invalid_properties invalid_properties = Array.new if @is_global.nil? invalid_properties.push('invalid value for "is_global", is_global cannot be nil.') end if @is_remediable.nil? invalid_properties.push('invalid value for "is_remediable", is_remediable cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
486 487 488 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 486 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 492 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
480 481 482 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 480 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
350 351 352 353 354 |
# File 'lib/crimson-falcon/models/domain_cid_policy_assignments.rb', line 350 def valid? return false if @is_global.nil? return false if @is_remediable.nil? true end |