Class: Falcon::DomainCloudAWSAccountV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainCloudAWSAccountV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 227

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainCloudAWSAccountV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainCloudAWSAccountV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'account_name')
    self. = attributes[:'account_name']
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  end

  if attributes.key?(:'active_regions')
    if (value = attributes[:'active_regions']).is_a?(Array)
      self.active_regions = value
    end
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_registration_enabled')
    self.cloud_registration_enabled = attributes[:'cloud_registration_enabled']
  end

  if attributes.key?(:'cloudformation_stack_arn')
    self.cloudformation_stack_arn = attributes[:'cloudformation_stack_arn']
  end

  if attributes.key?(:'cloudformation_update_url')
    self.cloudformation_update_url = attributes[:'cloudformation_update_url']
  end

  if attributes.key?(:'cloudformation_url')
    self.cloudformation_url = attributes[:'cloudformation_url']
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'csp_events')
    self.csp_events = attributes[:'csp_events']
  end

  if attributes.key?(:'cspm_enabled')
    self.cspm_enabled = attributes[:'cspm_enabled']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'falcon_client_id')
    self.falcon_client_id = attributes[:'falcon_client_id']
  end

  if attributes.key?(:'iam_service_permissions_status')
    if (value = attributes[:'iam_service_permissions_status']).is_a?(Array)
      self.iam_service_permissions_status = value
    end
  end

  if attributes.key?(:'inventory_filter')
    if (value = attributes[:'inventory_filter']).is_a?(Array)
      self.inventory_filter = value
    end
  end

  if attributes.key?(:'is_cspm_lite')
    self.is_cspm_lite = attributes[:'is_cspm_lite']
  end

  if attributes.key?(:'is_custom_rolename')
    self.is_custom_rolename = attributes[:'is_custom_rolename']
  end

  if attributes.key?(:'is_delegated_admin')
    self.is_delegated_admin = attributes[:'is_delegated_admin']
  end

  if attributes.key?(:'is_master')
    self.is_master = attributes[:'is_master']
  end

  if attributes.key?(:'ngsiem_enabled')
    self.ngsiem_enabled = attributes[:'ngsiem_enabled']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'registration_status')
    self.registration_status = attributes[:'registration_status']
  end

  if attributes.key?(:'remediation_cloudformation_url')
    self.remediation_cloudformation_url = attributes[:'remediation_cloudformation_url']
  end

  if attributes.key?(:'resource_metadata')
    self. = attributes[:'resource_metadata']
  end

  if attributes.key?(:'resource_name_prefix')
    self.resource_name_prefix = attributes[:'resource_name_prefix']
  end

  if attributes.key?(:'resource_name_suffix')
    self.resource_name_suffix = attributes[:'resource_name_suffix']
  end

  if attributes.key?(:'root_account_id')
    self. = attributes[:'root_account_id']
  end

  if attributes.key?(:'root_iam_role')
    self.root_iam_role = attributes[:'root_iam_role']
  end

  if attributes.key?(:'s3_url')
    self.s3_url = attributes[:'s3_url']
  end

  if attributes.key?(:'settings')
    self.settings = attributes[:'settings']
  end

  if attributes.key?(:'status')
    if (value = attributes[:'status']).is_a?(Array)
      self.status = value
    end
  end

  if attributes.key?(:'target_ous')
    if (value = attributes[:'target_ous']).is_a?(Array)
      self.target_ous = value
    end
  end

  if attributes.key?(:'template_source_region')
    self.template_source_region = attributes[:'template_source_region']
  end

  if attributes.key?(:'use_existing_cloudtrail')
    self.use_existing_cloudtrail = attributes[:'use_existing_cloudtrail']
  end
end

Instance Attribute Details

#account_idObject

12 digit AWS provided unique identifier for the account.



43
44
45
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 43

def 
  @account_id
end

#account_nameObject

AWS account name



46
47
48
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 46

def 
  @account_name
end

#account_typeObject

Returns the value of attribute account_type.



48
49
50
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 48

def 
  @account_type
end

#active_regionsObject

Returns the value of attribute active_regions.



50
51
52
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 50

def active_regions
  @active_regions
end

#cidObject

Returns the value of attribute cid.



52
53
54
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 52

def cid
  @cid
end

#cloud_registration_enabledObject

Returns the value of attribute cloud_registration_enabled.



54
55
56
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 54

def cloud_registration_enabled
  @cloud_registration_enabled
end

#cloudformation_stack_arnObject

Returns the value of attribute cloudformation_stack_arn.



56
57
58
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 56

def cloudformation_stack_arn
  @cloudformation_stack_arn
end

#cloudformation_update_urlObject

Returns the value of attribute cloudformation_update_url.



58
59
60
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 58

def cloudformation_update_url
  @cloudformation_update_url
end

#cloudformation_urlObject

Returns the value of attribute cloudformation_url.



60
61
62
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 60

def cloudformation_url
  @cloudformation_url
end

#conditionsObject

Returns the value of attribute conditions.



62
63
64
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 62

def conditions
  @conditions
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 34

def created_at
  @created_at
end

#csp_eventsObject

csp live events are enabled



65
66
67
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 65

def csp_events
  @csp_events
end

#cspm_enabledObject

Returns the value of attribute cspm_enabled.



67
68
69
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 67

def cspm_enabled
  @cspm_enabled
end

#deleted_atObject

Returns the value of attribute deleted_at.



36
37
38
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 36

def deleted_at
  @deleted_at
end

#environmentObject

Returns the value of attribute environment.



69
70
71
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 69

def environment
  @environment
end

#falcon_client_idObject

Returns the value of attribute falcon_client_id.



71
72
73
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 71

def falcon_client_id
  @falcon_client_id
end

#iam_service_permissions_statusObject

Permissions status for each product returned via API.



74
75
76
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 74

def iam_service_permissions_status
  @iam_service_permissions_status
end

#idObject

Returns the value of attribute id.



38
39
40
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 38

def id
  @id
end

#inventory_filterObject

Returns the value of attribute inventory_filter.



76
77
78
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 76

def inventory_filter
  @inventory_filter
end

#is_cspm_liteObject

Is CSPM Lite enabled.



79
80
81
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 79

def is_cspm_lite
  @is_cspm_lite
end

#is_custom_rolenameObject

Returns the value of attribute is_custom_rolename.



81
82
83
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 81

def is_custom_rolename
  @is_custom_rolename
end

#is_delegated_adminObject

Returns the value of attribute is_delegated_admin.



83
84
85
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 83

def is_delegated_admin
  @is_delegated_admin
end

#is_masterObject

Returns the value of attribute is_master.



85
86
87
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 85

def is_master
  @is_master
end

#ngsiem_enabledObject

Returns the value of attribute ngsiem_enabled.



87
88
89
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 87

def ngsiem_enabled
  @ngsiem_enabled
end

#organization_idObject

Up to 34 character AWS provided unique identifier for the organization.



90
91
92
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 90

def organization_id
  @organization_id
end

#productsObject

Returns the value of attribute products.



92
93
94
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 92

def products
  @products
end

#registration_statusObject

Returns the value of attribute registration_status.



94
95
96
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 94

def registration_status
  @registration_status
end

#remediation_cloudformation_urlObject

Returns the value of attribute remediation_cloudformation_url.



96
97
98
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 96

def remediation_cloudformation_url
  @remediation_cloudformation_url
end

#resource_metadataObject

Returns the value of attribute resource_metadata.



98
99
100
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 98

def 
  @resource_metadata
end

#resource_name_prefixObject

Returns the value of attribute resource_name_prefix.



100
101
102
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 100

def resource_name_prefix
  @resource_name_prefix
end

#resource_name_suffixObject

Returns the value of attribute resource_name_suffix.



102
103
104
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 102

def resource_name_suffix
  @resource_name_suffix
end

#root_account_idObject

12 digit AWS provided unique identifier for the root account (of the organization this account belongs to).



105
106
107
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 105

def 
  @root_account_id
end

#root_iam_roleObject

Returns the value of attribute root_iam_role.



107
108
109
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 107

def root_iam_role
  @root_iam_role
end

#s3_urlObject

Returns the value of attribute s3_url.



109
110
111
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 109

def s3_url
  @s3_url
end

#settingsObject

Returns the value of attribute settings.



111
112
113
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 111

def settings
  @settings
end

#statusObject

Account registration status for each product and feature



114
115
116
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 114

def status
  @status
end

#target_ousObject

Returns the value of attribute target_ous.



116
117
118
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 116

def target_ous
  @target_ous
end

#template_source_regionObject

Returns the value of attribute template_source_region.



118
119
120
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 118

def template_source_region
  @template_source_region
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 40

def updated_at
  @updated_at
end

#use_existing_cloudtrailObject

Returns the value of attribute use_existing_cloudtrail.



120
121
122
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 120

def use_existing_cloudtrail
  @use_existing_cloudtrail
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



169
170
171
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 169

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 123

def self.attribute_map
  {
    :'created_at' => :'CreatedAt',
    :'deleted_at' => :'DeletedAt',
    :'id' => :'ID',
    :'updated_at' => :'UpdatedAt',
    :'account_id' => :'account_id',
    :'account_name' => :'account_name',
    :'account_type' => :'account_type',
    :'active_regions' => :'active_regions',
    :'cid' => :'cid',
    :'cloud_registration_enabled' => :'cloud_registration_enabled',
    :'cloudformation_stack_arn' => :'cloudformation_stack_arn',
    :'cloudformation_update_url' => :'cloudformation_update_url',
    :'cloudformation_url' => :'cloudformation_url',
    :'conditions' => :'conditions',
    :'csp_events' => :'csp_events',
    :'cspm_enabled' => :'cspm_enabled',
    :'environment' => :'environment',
    :'falcon_client_id' => :'falcon_client_id',
    :'iam_service_permissions_status' => :'iam_service_permissions_status',
    :'inventory_filter' => :'inventory_filter',
    :'is_cspm_lite' => :'is_cspm_lite',
    :'is_custom_rolename' => :'is_custom_rolename',
    :'is_delegated_admin' => :'is_delegated_admin',
    :'is_master' => :'is_master',
    :'ngsiem_enabled' => :'ngsiem_enabled',
    :'organization_id' => :'organization_id',
    :'products' => :'products',
    :'registration_status' => :'registration_status',
    :'remediation_cloudformation_url' => :'remediation_cloudformation_url',
    :'resource_metadata' => :'resource_metadata',
    :'resource_name_prefix' => :'resource_name_prefix',
    :'resource_name_suffix' => :'resource_name_suffix',
    :'root_account_id' => :'root_account_id',
    :'root_iam_role' => :'root_iam_role',
    :'s3_url' => :'s3_url',
    :'settings' => :'settings',
    :'status' => :'status',
    :'target_ous' => :'target_ous',
    :'template_source_region' => :'template_source_region',
    :'use_existing_cloudtrail' => :'use_existing_cloudtrail'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



535
536
537
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 535

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



220
221
222
223
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 220

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 174

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'id' => :'Integer',
    :'updated_at' => :'Time',
    :'account_id' => :'String',
    :'account_name' => :'String',
    :'account_type' => :'String',
    :'active_regions' => :'Array<String>',
    :'cid' => :'String',
    :'cloud_registration_enabled' => :'Boolean',
    :'cloudformation_stack_arn' => :'String',
    :'cloudformation_update_url' => :'String',
    :'cloudformation_url' => :'String',
    :'conditions' => :'Array<DomainCloudCondition>',
    :'csp_events' => :'Boolean',
    :'cspm_enabled' => :'Boolean',
    :'environment' => :'String',
    :'falcon_client_id' => :'String',
    :'iam_service_permissions_status' => :'Array<DomainProductPermission>',
    :'inventory_filter' => :'Array<DomainAWSInventoryFilterSetting>',
    :'is_cspm_lite' => :'Boolean',
    :'is_custom_rolename' => :'Boolean',
    :'is_delegated_admin' => :'Boolean',
    :'is_master' => :'Boolean',
    :'ngsiem_enabled' => :'Boolean',
    :'organization_id' => :'String',
    :'products' => :'Array<DomainProductFeatures>',
    :'registration_status' => :'String',
    :'remediation_cloudformation_url' => :'String',
    :'resource_metadata' => :'DomainAWSAccountResourceMetadata',
    :'resource_name_prefix' => :'String',
    :'resource_name_suffix' => :'String',
    :'root_account_id' => :'String',
    :'root_iam_role' => :'Boolean',
    :'s3_url' => :'String',
    :'settings' => :'Object',
    :'status' => :'Array<DomainProductFeaturesStatus>',
    :'target_ous' => :'Array<String>',
    :'template_source_region' => :'String',
    :'use_existing_cloudtrail' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 475

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      id == o.id &&
      updated_at == o.updated_at &&
       == o. &&
       == o. &&
       == o. &&
      active_regions == o.active_regions &&
      cid == o.cid &&
      cloud_registration_enabled == o.cloud_registration_enabled &&
      cloudformation_stack_arn == o.cloudformation_stack_arn &&
      cloudformation_update_url == o.cloudformation_update_url &&
      cloudformation_url == o.cloudformation_url &&
      conditions == o.conditions &&
      csp_events == o.csp_events &&
      cspm_enabled == o.cspm_enabled &&
      environment == o.environment &&
      falcon_client_id == o.falcon_client_id &&
      iam_service_permissions_status == o.iam_service_permissions_status &&
      inventory_filter == o.inventory_filter &&
      is_cspm_lite == o.is_cspm_lite &&
      is_custom_rolename == o.is_custom_rolename &&
      is_delegated_admin == o.is_delegated_admin &&
      is_master == o.is_master &&
      ngsiem_enabled == o.ngsiem_enabled &&
      organization_id == o.organization_id &&
      products == o.products &&
      registration_status == o.registration_status &&
      remediation_cloudformation_url == o.remediation_cloudformation_url &&
       == o. &&
      resource_name_prefix == o.resource_name_prefix &&
      resource_name_suffix == o.resource_name_suffix &&
       == o. &&
      root_iam_role == o.root_iam_role &&
      s3_url == o.s3_url &&
      settings == o.settings &&
      status == o.status &&
      target_ous == o.target_ous &&
      template_source_region == o.template_source_region &&
      use_existing_cloudtrail == o.use_existing_cloudtrail
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 566

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 637

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 542

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


522
523
524
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 522

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



528
529
530
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 528

def hash
  [created_at, deleted_at, id, updated_at, , , , active_regions, cid, cloud_registration_enabled, cloudformation_stack_arn, cloudformation_update_url, cloudformation_url, conditions, csp_events, cspm_enabled, environment, falcon_client_id, iam_service_permissions_status, inventory_filter, is_cspm_lite, is_custom_rolename, is_delegated_admin, is_master, ngsiem_enabled, organization_id, products, registration_status, remediation_cloudformation_url, , resource_name_prefix, resource_name_suffix, , root_iam_role, s3_url, settings, status, target_ous, template_source_region, use_existing_cloudtrail].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 417

def list_invalid_properties
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @deleted_at.nil?
    invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @iam_service_permissions_status.nil?
    invalid_properties.push('invalid value for "iam_service_permissions_status", iam_service_permissions_status cannot be nil.')
  end

  if @inventory_filter.nil?
    invalid_properties.push('invalid value for "inventory_filter", inventory_filter cannot be nil.')
  end

  if @is_custom_rolename.nil?
    invalid_properties.push('invalid value for "is_custom_rolename", is_custom_rolename cannot be nil.')
  end

  if @products.nil?
    invalid_properties.push('invalid value for "products", products cannot be nil.')
  end

  if @resource_metadata.nil?
    invalid_properties.push('invalid value for "resource_metadata", resource_metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



613
614
615
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 613

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 619

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



607
608
609
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 607

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/crimson-falcon/models/domain_cloud_aws_account_v1.rb', line 460

def valid?
  return false if @created_at.nil?
  return false if @deleted_at.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  return false if @iam_service_permissions_status.nil?
  return false if @inventory_filter.nil?
  return false if @is_custom_rolename.nil?
  return false if @products.nil?
  return false if @resource_metadata.nil?
  true
end