Class: Falcon::DomainDevice

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_device.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainDevice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/crimson-falcon/models/domain_device.rb', line 203

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDevice` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDevice`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_')
    self._ = attributes[:'_']
  end

  if attributes.key?(:'agent_version')
    self.agent_version = attributes[:'agent_version']
  end

  if attributes.key?(:'config_id_base')
    self.config_id_base = attributes[:'config_id_base']
  end

  if attributes.key?(:'config_id_build')
    self.config_id_build = attributes[:'config_id_build']
  end

  if attributes.key?(:'config_id_platform')
    self.config_id_platform = attributes[:'config_id_platform']
  end

  if attributes.key?(:'deployment_type')
    self.deployment_type = attributes[:'deployment_type']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'device_policies')
    self.device_policies = attributes[:'device_policies']
  end

  if attributes.key?(:'external_ip')
    self.external_ip = attributes[:'external_ip']
  end

  if attributes.key?(:'first_login_timestamp')
    self. = attributes[:'first_login_timestamp']
  end

  if attributes.key?(:'first_login_user')
    self. = attributes[:'first_login_user']
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'last_login_timestamp')
    self. = attributes[:'last_login_timestamp']
  end

  if attributes.key?(:'last_login_user')
    self. = attributes[:'last_login_user']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'last_seen_ago_seconds')
    self.last_seen_ago_seconds = attributes[:'last_seen_ago_seconds']
  end

  if attributes.key?(:'local_ip')
    self.local_ip = attributes[:'local_ip']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'machine_domain')
    self.machine_domain = attributes[:'machine_domain']
  end

  if attributes.key?(:'major_version')
    self.major_version = attributes[:'major_version']
  end

  if attributes.key?(:'minor_version')
    self.minor_version = attributes[:'minor_version']
  end

  if attributes.key?(:'modified_timestamp')
    self.modified_timestamp = attributes[:'modified_timestamp']
  end

  if attributes.key?(:'notes')
    if (value = attributes[:'notes']).is_a?(Array)
      self.notes = value
    end
  end

  if attributes.key?(:'os_version')
    self.os_version = attributes[:'os_version']
  end

  if attributes.key?(:'ou')
    if (value = attributes[:'ou']).is_a?(Array)
      self.ou = value
    end
  end

  if attributes.key?(:'platform_id')
    self.platform_id = attributes[:'platform_id']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  end

  if attributes.key?(:'product_type_desc')
    self.product_type_desc = attributes[:'product_type_desc']
  end

  if attributes.key?(:'release_group')
    self.release_group = attributes[:'release_group']
  end

  if attributes.key?(:'site_name')
    self.site_name = attributes[:'site_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'system_manufacturer')
    self.system_manufacturer = attributes[:'system_manufacturer']
  end

  if attributes.key?(:'system_product_name')
    self.system_product_name = attributes[:'system_product_name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end
end

Instance Attribute Details

#_Object

Returns the value of attribute _.



34
35
36
# File 'lib/crimson-falcon/models/domain_device.rb', line 34

def _
  @_
end

#agent_versionObject

Returns the value of attribute agent_version.



36
37
38
# File 'lib/crimson-falcon/models/domain_device.rb', line 36

def agent_version
  @agent_version
end

#config_id_baseObject

Returns the value of attribute config_id_base.



38
39
40
# File 'lib/crimson-falcon/models/domain_device.rb', line 38

def config_id_base
  @config_id_base
end

#config_id_buildObject

Returns the value of attribute config_id_build.



40
41
42
# File 'lib/crimson-falcon/models/domain_device.rb', line 40

def config_id_build
  @config_id_build
end

#config_id_platformObject

Returns the value of attribute config_id_platform.



42
43
44
# File 'lib/crimson-falcon/models/domain_device.rb', line 42

def config_id_platform
  @config_id_platform
end

#deployment_typeObject

Returns the value of attribute deployment_type.



44
45
46
# File 'lib/crimson-falcon/models/domain_device.rb', line 44

def deployment_type
  @deployment_type
end

#device_idObject

Returns the value of attribute device_id.



46
47
48
# File 'lib/crimson-falcon/models/domain_device.rb', line 46

def device_id
  @device_id
end

#device_policiesObject

Returns the value of attribute device_policies.



48
49
50
# File 'lib/crimson-falcon/models/domain_device.rb', line 48

def device_policies
  @device_policies
end

#external_ipObject

Returns the value of attribute external_ip.



50
51
52
# File 'lib/crimson-falcon/models/domain_device.rb', line 50

def external_ip
  @external_ip
end

#first_login_timestampObject

Returns the value of attribute first_login_timestamp.



52
53
54
# File 'lib/crimson-falcon/models/domain_device.rb', line 52

def 
  @first_login_timestamp
end

#first_login_userObject

Returns the value of attribute first_login_user.



54
55
56
# File 'lib/crimson-falcon/models/domain_device.rb', line 54

def 
  @first_login_user
end

#first_seenObject

Returns the value of attribute first_seen.



56
57
58
# File 'lib/crimson-falcon/models/domain_device.rb', line 56

def first_seen
  @first_seen
end

#hostnameObject

Returns the value of attribute hostname.



58
59
60
# File 'lib/crimson-falcon/models/domain_device.rb', line 58

def hostname
  @hostname
end

#last_login_timestampObject

Returns the value of attribute last_login_timestamp.



60
61
62
# File 'lib/crimson-falcon/models/domain_device.rb', line 60

def 
  @last_login_timestamp
end

#last_login_userObject

Returns the value of attribute last_login_user.



62
63
64
# File 'lib/crimson-falcon/models/domain_device.rb', line 62

def 
  @last_login_user
end

#last_seenObject

Returns the value of attribute last_seen.



64
65
66
# File 'lib/crimson-falcon/models/domain_device.rb', line 64

def last_seen
  @last_seen
end

#last_seen_ago_secondsObject

Returns the value of attribute last_seen_ago_seconds.



66
67
68
# File 'lib/crimson-falcon/models/domain_device.rb', line 66

def last_seen_ago_seconds
  @last_seen_ago_seconds
end

#local_ipObject

Returns the value of attribute local_ip.



68
69
70
# File 'lib/crimson-falcon/models/domain_device.rb', line 68

def local_ip
  @local_ip
end

#mac_addressObject

Returns the value of attribute mac_address.



70
71
72
# File 'lib/crimson-falcon/models/domain_device.rb', line 70

def mac_address
  @mac_address
end

#machine_domainObject

Returns the value of attribute machine_domain.



72
73
74
# File 'lib/crimson-falcon/models/domain_device.rb', line 72

def machine_domain
  @machine_domain
end

#major_versionObject

Returns the value of attribute major_version.



74
75
76
# File 'lib/crimson-falcon/models/domain_device.rb', line 74

def major_version
  @major_version
end

#minor_versionObject

Returns the value of attribute minor_version.



76
77
78
# File 'lib/crimson-falcon/models/domain_device.rb', line 76

def minor_version
  @minor_version
end

#modified_timestampObject

Returns the value of attribute modified_timestamp.



78
79
80
# File 'lib/crimson-falcon/models/domain_device.rb', line 78

def modified_timestamp
  @modified_timestamp
end

#notesObject

Returns the value of attribute notes.



80
81
82
# File 'lib/crimson-falcon/models/domain_device.rb', line 80

def notes
  @notes
end

#os_versionObject

Returns the value of attribute os_version.



82
83
84
# File 'lib/crimson-falcon/models/domain_device.rb', line 82

def os_version
  @os_version
end

#ouObject

Returns the value of attribute ou.



84
85
86
# File 'lib/crimson-falcon/models/domain_device.rb', line 84

def ou
  @ou
end

#platform_idObject

Returns the value of attribute platform_id.



86
87
88
# File 'lib/crimson-falcon/models/domain_device.rb', line 86

def platform_id
  @platform_id
end

#platform_nameObject

Returns the value of attribute platform_name.



88
89
90
# File 'lib/crimson-falcon/models/domain_device.rb', line 88

def platform_name
  @platform_name
end

#product_typeObject

Returns the value of attribute product_type.



90
91
92
# File 'lib/crimson-falcon/models/domain_device.rb', line 90

def product_type
  @product_type
end

#product_type_descObject

Returns the value of attribute product_type_desc.



92
93
94
# File 'lib/crimson-falcon/models/domain_device.rb', line 92

def product_type_desc
  @product_type_desc
end

#release_groupObject

Returns the value of attribute release_group.



94
95
96
# File 'lib/crimson-falcon/models/domain_device.rb', line 94

def release_group
  @release_group
end

#site_nameObject

Returns the value of attribute site_name.



96
97
98
# File 'lib/crimson-falcon/models/domain_device.rb', line 96

def site_name
  @site_name
end

#statusObject

Returns the value of attribute status.



98
99
100
# File 'lib/crimson-falcon/models/domain_device.rb', line 98

def status
  @status
end

#system_manufacturerObject

Returns the value of attribute system_manufacturer.



100
101
102
# File 'lib/crimson-falcon/models/domain_device.rb', line 100

def system_manufacturer
  @system_manufacturer
end

#system_product_nameObject

Returns the value of attribute system_product_name.



102
103
104
# File 'lib/crimson-falcon/models/domain_device.rb', line 102

def system_product_name
  @system_product_name
end

#tagsObject

Returns the value of attribute tags.



104
105
106
# File 'lib/crimson-falcon/models/domain_device.rb', line 104

def tags
  @tags
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



149
150
151
# File 'lib/crimson-falcon/models/domain_device.rb', line 149

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/crimson-falcon/models/domain_device.rb', line 107

def self.attribute_map
  {
    :'_' => :'_',
    :'agent_version' => :'agent_version',
    :'config_id_base' => :'config_id_base',
    :'config_id_build' => :'config_id_build',
    :'config_id_platform' => :'config_id_platform',
    :'deployment_type' => :'deployment_type',
    :'device_id' => :'device_id',
    :'device_policies' => :'device_policies',
    :'external_ip' => :'external_ip',
    :'first_login_timestamp' => :'first_login_timestamp',
    :'first_login_user' => :'first_login_user',
    :'first_seen' => :'first_seen',
    :'hostname' => :'hostname',
    :'last_login_timestamp' => :'last_login_timestamp',
    :'last_login_user' => :'last_login_user',
    :'last_seen' => :'last_seen',
    :'last_seen_ago_seconds' => :'last_seen_ago_seconds',
    :'local_ip' => :'local_ip',
    :'mac_address' => :'mac_address',
    :'machine_domain' => :'machine_domain',
    :'major_version' => :'major_version',
    :'minor_version' => :'minor_version',
    :'modified_timestamp' => :'modified_timestamp',
    :'notes' => :'notes',
    :'os_version' => :'os_version',
    :'ou' => :'ou',
    :'platform_id' => :'platform_id',
    :'platform_name' => :'platform_name',
    :'product_type' => :'product_type',
    :'product_type_desc' => :'product_type_desc',
    :'release_group' => :'release_group',
    :'site_name' => :'site_name',
    :'status' => :'status',
    :'system_manufacturer' => :'system_manufacturer',
    :'system_product_name' => :'system_product_name',
    :'tags' => :'tags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



448
449
450
# File 'lib/crimson-falcon/models/domain_device.rb', line 448

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



196
197
198
199
# File 'lib/crimson-falcon/models/domain_device.rb', line 196

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/crimson-falcon/models/domain_device.rb', line 154

def self.openapi_types
  {
    :'_' => :'Integer',
    :'agent_version' => :'String',
    :'config_id_base' => :'String',
    :'config_id_build' => :'String',
    :'config_id_platform' => :'String',
    :'deployment_type' => :'String',
    :'device_id' => :'String',
    :'device_policies' => :'DomainMappedDevicePolicies',
    :'external_ip' => :'String',
    :'first_login_timestamp' => :'String',
    :'first_login_user' => :'String',
    :'first_seen' => :'String',
    :'hostname' => :'String',
    :'last_login_timestamp' => :'String',
    :'last_login_user' => :'String',
    :'last_seen' => :'String',
    :'last_seen_ago_seconds' => :'Integer',
    :'local_ip' => :'String',
    :'mac_address' => :'String',
    :'machine_domain' => :'String',
    :'major_version' => :'String',
    :'minor_version' => :'String',
    :'modified_timestamp' => :'String',
    :'notes' => :'Array<String>',
    :'os_version' => :'String',
    :'ou' => :'Array<String>',
    :'platform_id' => :'String',
    :'platform_name' => :'String',
    :'product_type' => :'String',
    :'product_type_desc' => :'String',
    :'release_group' => :'String',
    :'site_name' => :'String',
    :'status' => :'String',
    :'system_manufacturer' => :'String',
    :'system_product_name' => :'String',
    :'tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/crimson-falcon/models/domain_device.rb', line 392

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _ == o._ &&
      agent_version == o.agent_version &&
      config_id_base == o.config_id_base &&
      config_id_build == o.config_id_build &&
      config_id_platform == o.config_id_platform &&
      deployment_type == o.deployment_type &&
      device_id == o.device_id &&
      device_policies == o.device_policies &&
      external_ip == o.external_ip &&
       == o. &&
       == o. &&
      first_seen == o.first_seen &&
      hostname == o.hostname &&
       == o. &&
       == o. &&
      last_seen == o.last_seen &&
      last_seen_ago_seconds == o.last_seen_ago_seconds &&
      local_ip == o.local_ip &&
      mac_address == o.mac_address &&
      machine_domain == o.machine_domain &&
      major_version == o.major_version &&
      minor_version == o.minor_version &&
      modified_timestamp == o.modified_timestamp &&
      notes == o.notes &&
      os_version == o.os_version &&
      ou == o.ou &&
      platform_id == o.platform_id &&
      platform_name == o.platform_name &&
      product_type == o.product_type &&
      product_type_desc == o.product_type_desc &&
      release_group == o.release_group &&
      site_name == o.site_name &&
      status == o.status &&
      system_manufacturer == o.system_manufacturer &&
      system_product_name == o.system_product_name &&
      tags == o.tags
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/crimson-falcon/models/domain_device.rb', line 479

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/crimson-falcon/models/domain_device.rb', line 550

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/crimson-falcon/models/domain_device.rb', line 455

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


435
436
437
# File 'lib/crimson-falcon/models/domain_device.rb', line 435

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



441
442
443
# File 'lib/crimson-falcon/models/domain_device.rb', line 441

def hash
  [_, agent_version, config_id_base, config_id_build, config_id_platform, deployment_type, device_id, device_policies, external_ip, , , first_seen, hostname, , , last_seen, last_seen_ago_seconds, local_ip, mac_address, machine_domain, major_version, minor_version, modified_timestamp, notes, os_version, ou, platform_id, platform_name, product_type, product_type_desc, release_group, site_name, status, system_manufacturer, system_product_name, tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/crimson-falcon/models/domain_device.rb', line 369

def list_invalid_properties
  invalid_properties = Array.new
  if @_.nil?
    invalid_properties.push('invalid value for "_", _ cannot be nil.')
  end

  if @device_id.nil?
    invalid_properties.push('invalid value for "device_id", device_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



526
527
528
# File 'lib/crimson-falcon/models/domain_device.rb', line 526

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/crimson-falcon/models/domain_device.rb', line 532

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



520
521
522
# File 'lib/crimson-falcon/models/domain_device.rb', line 520

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



384
385
386
387
388
# File 'lib/crimson-falcon/models/domain_device.rb', line 384

def valid?
  return false if @_.nil?
  return false if @device_id.nil?
  true
end