Class: Falcon::DomainDiscoverAPIApplicationBrowserExtension
- Inherits:
-
Object
- Object
- Falcon::DomainDiscoverAPIApplicationBrowserExtension
- Defined in:
- lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb
Overview
Uniquely identifies a browser extension.
Instance Attribute Summary collapse
-
#architecture ⇒ Object
The architecture of the browser extension.
-
#browser_name ⇒ Object
The name of the browser that’s running the extension.
-
#enabled ⇒ Object
Describes if the extension is enabled on the host on at least one browser profile.
-
#id ⇒ Object
The unique ID of the browser extension.
-
#installations ⇒ Object
The installations of this browser extension for each browser profile.
-
#permission_severity ⇒ Object
The computed serverity of all permissions requested by the browser extension.
-
#permissions ⇒ Object
The browser permissions the extension requires to run.
-
#store_url ⇒ Object
The calculated browser webstore URL for this extension.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationBrowserExtension
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationBrowserExtension
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIApplicationBrowserExtension` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIApplicationBrowserExtension`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'architecture') self.architecture = attributes[:'architecture'] end if attributes.key?(:'browser_name') self.browser_name = attributes[:'browser_name'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'installations') if (value = attributes[:'installations']).is_a?(Array) self.installations = value end end if attributes.key?(:'permission_severity') self. = attributes[:'permission_severity'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'store_url') self.store_url = attributes[:'store_url'] end end |
Instance Attribute Details
#architecture ⇒ Object
The architecture of the browser extension
36 37 38 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 36 def architecture @architecture end |
#browser_name ⇒ Object
The name of the browser that’s running the extension
39 40 41 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 39 def browser_name @browser_name end |
#enabled ⇒ Object
Describes if the extension is enabled on the host on at least one browser profile
42 43 44 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 42 def enabled @enabled end |
#id ⇒ Object
The unique ID of the browser extension.
45 46 47 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 45 def id @id end |
#installations ⇒ Object
The installations of this browser extension for each browser profile
48 49 50 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 48 def installations @installations end |
#permission_severity ⇒ Object
The computed serverity of all permissions requested by the browser extension
51 52 53 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 51 def @permission_severity end |
#permissions ⇒ Object
The browser permissions the extension requires to run
54 55 56 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 54 def @permissions end |
#store_url ⇒ Object
The calculated browser webstore URL for this extension
57 58 59 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 57 def store_url @store_url end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 60 def self.attribute_map { :'architecture' => :'architecture', :'browser_name' => :'browser_name', :'enabled' => :'enabled', :'id' => :'id', :'installations' => :'installations', :'permission_severity' => :'permission_severity', :'permissions' => :'permissions', :'store_url' => :'store_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 79 def self.openapi_types { :'architecture' => :'String', :'browser_name' => :'String', :'enabled' => :'Boolean', :'id' => :'String', :'installations' => :'Array<DomainDiscoverAPIApplicationBrowserExtensionInstallation>', :'permission_severity' => :'String', :'permissions' => :'Array<String>', :'store_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 175 def ==(o) return true if self.equal?(o) self.class == o.class && architecture == o.architecture && browser_name == o.browser_name && enabled == o.enabled && id == o.id && installations == o.installations && == o. && == o. && store_url == o.store_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 234 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 196 def hash [architecture, browser_name, enabled, id, installations, , , store_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 152 def list_invalid_properties invalid_properties = Array.new if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension.rb', line 167 def valid? return false if @enabled.nil? return false if @id.nil? true end |