Class: Falcon::DomainDiscoverAPIApplicationBrowserExtensionInstallation

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationBrowserExtensionInstallation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIApplicationBrowserExtensionInstallation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIApplicationBrowserExtensionInstallation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'browser_profile_id')
    self.browser_profile_id = attributes[:'browser_profile_id']
  end

  if attributes.key?(:'browser_profile_name')
    self.browser_profile_name = attributes[:'browser_profile_name']
  end

  if attributes.key?(:'browser_version')
    self.browser_version = attributes[:'browser_version']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'user_sid')
    self.user_sid = attributes[:'user_sid']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#browser_profile_idObject

The browser profile ID of this installation



35
36
37
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 35

def browser_profile_id
  @browser_profile_id
end

#browser_profile_nameObject

The browser profile name of this installation



38
39
40
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 38

def browser_profile_name
  @browser_profile_name
end

#browser_versionObject

The version of the browser running this extension



41
42
43
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 41

def browser_version
  @browser_version
end

#enabledObject

Describes if the extension is enabled on this browser profile installation



44
45
46
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 44

def enabled
  @enabled
end

#methodObject

The method that was used to install the browser extension



47
48
49
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 47

def method
  @method
end

#pathObject

The file path location of the browser extension



50
51
52
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 50

def path
  @path
end

#roleObject

The role of the account that installed the extension



53
54
55
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 53

def role
  @role
end

#user_sidObject

The host user SID for which the extension was installed



56
57
58
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 56

def user_sid
  @user_sid
end

#usernameObject

The host username for which the extension was installed



59
60
61
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 59

def username
  @username
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 62

def self.attribute_map
  {
    :'browser_profile_id' => :'browser_profile_id',
    :'browser_profile_name' => :'browser_profile_name',
    :'browser_version' => :'browser_version',
    :'enabled' => :'enabled',
    :'method' => :'method',
    :'path' => :'path',
    :'role' => :'role',
    :'user_sid' => :'user_sid',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 203

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 82

def self.openapi_types
  {
    :'browser_profile_id' => :'String',
    :'browser_profile_name' => :'String',
    :'browser_version' => :'String',
    :'enabled' => :'Boolean',
    :'method' => :'String',
    :'path' => :'String',
    :'role' => :'String',
    :'user_sid' => :'String',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      browser_profile_id == o.browser_profile_id &&
      browser_profile_name == o.browser_profile_name &&
      browser_version == o.browser_version &&
      enabled == o.enabled &&
      method == o.method &&
      path == o.path &&
      role == o.role &&
      user_sid == o.user_sid &&
      username == o.username
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 234

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 305

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 210

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 196

def hash
  [browser_profile_id, browser_profile_name, browser_version, enabled, method, path, role, user_sid, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 281

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



275
276
277
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 275

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
# File 'lib/crimson-falcon/models/domain_discover_api_application_browser_extension_installation.rb', line 167

def valid?
  return false if @enabled.nil?
  true
end