Class: Falcon::DomainDiscoverAPIApplicationHost
- Inherits:
-
Object
- Object
- Falcon::DomainDiscoverAPIApplicationHost
- Defined in:
- lib/crimson-falcon/models/domain_discover_api_application_host.rb
Overview
Represents information about an application’s host’.
Instance Attribute Summary collapse
-
#agent_version ⇒ Object
The version of the Falcon sensor that’s installed on the asset.
-
#aid ⇒ Object
The agent ID of the Falcon sensor installed on the asset.
-
#country ⇒ Object
The name of the country where the asset is located.
-
#current_mac_address ⇒ Object
The last seen MAC address of the asset.
-
#current_network_prefix ⇒ Object
The last seen network prefix of the asset.
-
#external_ip ⇒ Object
The external IPv4 address of the asset.
-
#groups ⇒ Object
The host management groups the asset is part of.
-
#hostname ⇒ Object
The asset’s hostname.
-
#id ⇒ Object
The unique ID of the asset.
-
#internet_exposure ⇒ Object
Whether the asset is exposed to the internet (Yes or Unknown).
-
#kernel_version ⇒ Object
For Linux and Mac hosts: the major version, minor version, and patch version of the kernel for the asset.
-
#machine_domain ⇒ Object
The domain name the asset is currently joined to.
-
#os_version ⇒ Object
The OS version of the asset.
-
#ou ⇒ Object
The organizational unit of the asset.
-
#ous ⇒ Object
The organizational units of the asset.
-
#platform_name ⇒ Object
The platform name of the asset (Windows, Mac, Linux).
-
#product_type_desc ⇒ Object
The product type of the asset (Workstation, Domain Controller, Server).
-
#site_name ⇒ Object
The site name of the domain the asset is joined to (applies only to Windows hosts).
-
#system_manufacturer ⇒ Object
The asset’s system manufacturer.
-
#tags ⇒ Object
The sensor and cloud tags of the asset.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationHost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationHost
Initializes the object
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 160 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIApplicationHost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIApplicationHost`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agent_version') self.agent_version = attributes[:'agent_version'] end if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'current_mac_address') self.current_mac_address = attributes[:'current_mac_address'] end if attributes.key?(:'current_network_prefix') self.current_network_prefix = attributes[:'current_network_prefix'] end if attributes.key?(:'external_ip') self.external_ip = attributes[:'external_ip'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'internet_exposure') self.internet_exposure = attributes[:'internet_exposure'] end if attributes.key?(:'kernel_version') self.kernel_version = attributes[:'kernel_version'] end if attributes.key?(:'machine_domain') self.machine_domain = attributes[:'machine_domain'] end if attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] end if attributes.key?(:'ou') self.ou = attributes[:'ou'] end if attributes.key?(:'ous') if (value = attributes[:'ous']).is_a?(Array) self.ous = value end end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'product_type_desc') self.product_type_desc = attributes[:'product_type_desc'] end if attributes.key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.key?(:'system_manufacturer') self.system_manufacturer = attributes[:'system_manufacturer'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#agent_version ⇒ Object
The version of the Falcon sensor that’s installed on the asset.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 36 def agent_version @agent_version end |
#aid ⇒ Object
The agent ID of the Falcon sensor installed on the asset.
39 40 41 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 39 def aid @aid end |
#country ⇒ Object
The name of the country where the asset is located.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 42 def country @country end |
#current_mac_address ⇒ Object
The last seen MAC address of the asset.
45 46 47 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 45 def current_mac_address @current_mac_address end |
#current_network_prefix ⇒ Object
The last seen network prefix of the asset.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 48 def current_network_prefix @current_network_prefix end |
#external_ip ⇒ Object
The external IPv4 address of the asset.
51 52 53 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 51 def external_ip @external_ip end |
#groups ⇒ Object
The host management groups the asset is part of.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 54 def groups @groups end |
#hostname ⇒ Object
The asset’s hostname.
57 58 59 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 57 def hostname @hostname end |
#id ⇒ Object
The unique ID of the asset.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 60 def id @id end |
#internet_exposure ⇒ Object
Whether the asset is exposed to the internet (Yes or Unknown).
63 64 65 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 63 def internet_exposure @internet_exposure end |
#kernel_version ⇒ Object
For Linux and Mac hosts: the major version, minor version, and patch version of the kernel for the asset. For Windows hosts: the build number of the asset.
66 67 68 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 66 def kernel_version @kernel_version end |
#machine_domain ⇒ Object
The domain name the asset is currently joined to.
69 70 71 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 69 def machine_domain @machine_domain end |
#os_version ⇒ Object
The OS version of the asset.
72 73 74 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 72 def os_version @os_version end |
#ou ⇒ Object
The organizational unit of the asset.
75 76 77 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 75 def ou @ou end |
#ous ⇒ Object
The organizational units of the asset.
78 79 80 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 78 def ous @ous end |
#platform_name ⇒ Object
The platform name of the asset (Windows, Mac, Linux).
81 82 83 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 81 def platform_name @platform_name end |
#product_type_desc ⇒ Object
The product type of the asset (Workstation, Domain Controller, Server).
84 85 86 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 84 def product_type_desc @product_type_desc end |
#site_name ⇒ Object
The site name of the domain the asset is joined to (applies only to Windows hosts).
87 88 89 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 87 def site_name @site_name end |
#system_manufacturer ⇒ Object
The asset’s system manufacturer.
90 91 92 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 90 def system_manufacturer @system_manufacturer end |
#tags ⇒ Object
The sensor and cloud tags of the asset.
93 94 95 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 93 def @tags end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
122 123 124 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 122 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 96 def self.attribute_map { :'agent_version' => :'agent_version', :'aid' => :'aid', :'country' => :'country', :'current_mac_address' => :'current_mac_address', :'current_network_prefix' => :'current_network_prefix', :'external_ip' => :'external_ip', :'groups' => :'groups', :'hostname' => :'hostname', :'id' => :'id', :'internet_exposure' => :'internet_exposure', :'kernel_version' => :'kernel_version', :'machine_domain' => :'machine_domain', :'os_version' => :'os_version', :'ou' => :'ou', :'ous' => :'ous', :'platform_name' => :'platform_name', :'product_type_desc' => :'product_type_desc', :'site_name' => :'site_name', :'system_manufacturer' => :'system_manufacturer', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 320 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
153 154 155 156 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 153 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 127 def self.openapi_types { :'agent_version' => :'String', :'aid' => :'String', :'country' => :'String', :'current_mac_address' => :'String', :'current_network_prefix' => :'String', :'external_ip' => :'String', :'groups' => :'Array<String>', :'hostname' => :'String', :'id' => :'String', :'internet_exposure' => :'String', :'kernel_version' => :'String', :'machine_domain' => :'String', :'os_version' => :'String', :'ou' => :'String', :'ous' => :'Array<String>', :'platform_name' => :'String', :'product_type_desc' => :'String', :'site_name' => :'String', :'system_manufacturer' => :'String', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && agent_version == o.agent_version && aid == o.aid && country == o.country && current_mac_address == o.current_mac_address && current_network_prefix == o.current_network_prefix && external_ip == o.external_ip && groups == o.groups && hostname == o.hostname && id == o.id && internet_exposure == o.internet_exposure && kernel_version == o.kernel_version && machine_domain == o.machine_domain && os_version == o.os_version && ou == o.ou && ous == o.ous && platform_name == o.platform_name && product_type_desc == o.product_type_desc && site_name == o.site_name && system_manufacturer == o.system_manufacturer && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 351 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 313 def hash [agent_version, aid, country, current_mac_address, current_network_prefix, external_ip, groups, hostname, id, internet_exposure, kernel_version, machine_domain, os_version, ou, ous, platform_name, product_type_desc, site_name, system_manufacturer, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
262 263 264 265 266 267 268 269 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 262 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
398 399 400 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 398 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 392 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
273 274 275 276 |
# File 'lib/crimson-falcon/models/domain_discover_api_application_host.rb', line 273 def valid? return false if @id.nil? true end |