Class: Falcon::DomainDiscoverAPIApplicationIDEExtension

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplicationIDEExtension

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIApplicationIDEExtension` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIApplicationIDEExtension`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cost_type')
    self.cost_type = attributes[:'cost_type']
  end

  if attributes.key?(:'ide')
    self.ide = attributes[:'ide']
  end

  if attributes.key?(:'license')
    self.license = attributes[:'license']
  end

  if attributes.key?(:'registry_latest_version_available')
    self.registry_latest_version_available = attributes[:'registry_latest_version_available']
  end

  if attributes.key?(:'release_date')
    self.release_date = attributes[:'release_date']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'vendor_display_name')
    self.vendor_display_name = attributes[:'vendor_display_name']
  end

  if attributes.key?(:'vendor_id')
    self.vendor_id = attributes[:'vendor_id']
  end
end

Instance Attribute Details

#cost_typeObject

Whether the extension is free or paid one-time, or subscription-based



35
36
37
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 35

def cost_type
  @cost_type
end

#ideObject

The IDE the extension is for (VSCode, JetBrains, etc)



38
39
40
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 38

def ide
  @ide
end

#licenseObject

The license type of the extension



41
42
43
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 41

def license
  @license
end

#registry_latest_version_availableObject

The latest available stable version of the extension



44
45
46
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 44

def registry_latest_version_available
  @registry_latest_version_available
end

#release_dateObject

The date the extension was released



47
48
49
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 47

def release_date
  @release_date
end

#tagsObject

A list of tags associated with the extension



50
51
52
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 50

def tags
  @tags
end

#usernameObject

The host username for which the extension was installed



53
54
55
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 53

def username
  @username
end

#vendor_display_nameObject

The display name of the extension vendor



56
57
58
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 56

def vendor_display_name
  @vendor_display_name
end

#vendor_idObject

The ID of the extension vendor



59
60
61
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 59

def vendor_id
  @vendor_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 62

def self.attribute_map
  {
    :'cost_type' => :'cost_type',
    :'ide' => :'ide',
    :'license' => :'license',
    :'registry_latest_version_available' => :'registry_latest_version_available',
    :'release_date' => :'release_date',
    :'tags' => :'tags',
    :'username' => :'username',
    :'vendor_display_name' => :'vendor_display_name',
    :'vendor_id' => :'vendor_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 200

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 82

def self.openapi_types
  {
    :'cost_type' => :'String',
    :'ide' => :'String',
    :'license' => :'String',
    :'registry_latest_version_available' => :'String',
    :'release_date' => :'String',
    :'tags' => :'Array<String>',
    :'username' => :'String',
    :'vendor_display_name' => :'String',
    :'vendor_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cost_type == o.cost_type &&
      ide == o.ide &&
      license == o.license &&
      registry_latest_version_available == o.registry_latest_version_available &&
      release_date == o.release_date &&
      tags == o.tags &&
      username == o.username &&
      vendor_display_name == o.vendor_display_name &&
      vendor_id == o.vendor_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 231

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 302

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 207

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 193

def hash
  [cost_type, ide, license, registry_latest_version_available, release_date, tags, username, vendor_display_name, vendor_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 278

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



272
273
274
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 272

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
# File 'lib/crimson-falcon/models/domain_discover_api_application_ide_extension.rb', line 165

def valid?
  true
end