Class: Falcon::DomainDiscoverAPIOsSecurity

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_discover_apios_security.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainDiscoverAPIOsSecurity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIOsSecurity` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIOsSecurity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'credential_guard_status')
    self.credential_guard_status = attributes[:'credential_guard_status']
  end

  if attributes.key?(:'device_guard_status')
    self.device_guard_status = attributes[:'device_guard_status']
  end

  if attributes.key?(:'iommu_protection_status')
    self.iommu_protection_status = attributes[:'iommu_protection_status']
  end

  if attributes.key?(:'kernel_dma_protection_status')
    self.kernel_dma_protection_status = attributes[:'kernel_dma_protection_status']
  end

  if attributes.key?(:'secure_boot_enabled_status')
    self.secure_boot_enabled_status = attributes[:'secure_boot_enabled_status']
  end

  if attributes.key?(:'secure_boot_requested_status')
    self.secure_boot_requested_status = attributes[:'secure_boot_requested_status']
  end

  if attributes.key?(:'secure_memory_overwrite_requested_status')
    self.secure_memory_overwrite_requested_status = attributes[:'secure_memory_overwrite_requested_status']
  end

  if attributes.key?(:'system_guard_status')
    self.system_guard_status = attributes[:'system_guard_status']
  end

  if attributes.key?(:'uefi_memory_protection_status')
    self.uefi_memory_protection_status = attributes[:'uefi_memory_protection_status']
  end

  if attributes.key?(:'virtualization_based_security_status')
    self.virtualization_based_security_status = attributes[:'virtualization_based_security_status']
  end
end

Instance Attribute Details

#credential_guard_statusObject

The credential guard status of the host



35
36
37
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 35

def credential_guard_status
  @credential_guard_status
end

#device_guard_statusObject

The device guard status of the host



38
39
40
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 38

def device_guard_status
  @device_guard_status
end

#iommu_protection_statusObject

The iommu protection status of the host



41
42
43
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 41

def iommu_protection_status
  @iommu_protection_status
end

#kernel_dma_protection_statusObject

The kernel dma protection status of the host



44
45
46
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 44

def kernel_dma_protection_status
  @kernel_dma_protection_status
end

#secure_boot_enabled_statusObject

The secure boot enabled status of the host



47
48
49
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 47

def secure_boot_enabled_status
  @secure_boot_enabled_status
end

#secure_boot_requested_statusObject

The secure boot requested status of the host



50
51
52
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 50

def secure_boot_requested_status
  @secure_boot_requested_status
end

#secure_memory_overwrite_requested_statusObject

The secure memory overwrite requested status of the host



53
54
55
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 53

def secure_memory_overwrite_requested_status
  @secure_memory_overwrite_requested_status
end

#system_guard_statusObject

The system guard status of the host



56
57
58
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 56

def system_guard_status
  @system_guard_status
end

#uefi_memory_protection_statusObject

The uefi memory protection status of the host



59
60
61
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 59

def uefi_memory_protection_status
  @uefi_memory_protection_status
end

#virtualization_based_security_statusObject

The virtualization based security status of the host



62
63
64
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 62

def virtualization_based_security_status
  @virtualization_based_security_status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 65

def self.attribute_map
  {
    :'credential_guard_status' => :'credential_guard_status',
    :'device_guard_status' => :'device_guard_status',
    :'iommu_protection_status' => :'iommu_protection_status',
    :'kernel_dma_protection_status' => :'kernel_dma_protection_status',
    :'secure_boot_enabled_status' => :'secure_boot_enabled_status',
    :'secure_boot_requested_status' => :'secure_boot_requested_status',
    :'secure_memory_overwrite_requested_status' => :'secure_memory_overwrite_requested_status',
    :'system_guard_status' => :'system_guard_status',
    :'uefi_memory_protection_status' => :'uefi_memory_protection_status',
    :'virtualization_based_security_status' => :'virtualization_based_security_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 208

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 86

def self.openapi_types
  {
    :'credential_guard_status' => :'Boolean',
    :'device_guard_status' => :'Boolean',
    :'iommu_protection_status' => :'String',
    :'kernel_dma_protection_status' => :'Boolean',
    :'secure_boot_enabled_status' => :'Boolean',
    :'secure_boot_requested_status' => :'Boolean',
    :'secure_memory_overwrite_requested_status' => :'String',
    :'system_guard_status' => :'String',
    :'uefi_memory_protection_status' => :'String',
    :'virtualization_based_security_status' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 178

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      credential_guard_status == o.credential_guard_status &&
      device_guard_status == o.device_guard_status &&
      iommu_protection_status == o.iommu_protection_status &&
      kernel_dma_protection_status == o.kernel_dma_protection_status &&
      secure_boot_enabled_status == o.secure_boot_enabled_status &&
      secure_boot_requested_status == o.secure_boot_requested_status &&
      secure_memory_overwrite_requested_status == o.secure_memory_overwrite_requested_status &&
      system_guard_status == o.system_guard_status &&
      uefi_memory_protection_status == o.uefi_memory_protection_status &&
      virtualization_based_security_status == o.virtualization_based_security_status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 239

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 310

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 201

def hash
  [credential_guard_status, device_guard_status, iommu_protection_status, kernel_dma_protection_status, secure_boot_enabled_status, secure_boot_requested_status, secure_memory_overwrite_requested_status, system_guard_status, uefi_memory_protection_status, virtualization_based_security_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 286

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



280
281
282
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 280

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
# File 'lib/crimson-falcon/models/domain_discover_apios_security.rb', line 172

def valid?
  true
end