Class: Falcon::DomainExternalAssetCloudVM

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainExternalAssetCloudVM

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainExternalAssetCloudVM` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainExternalAssetCloudVM`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'instance_id')
    self.instance_id = attributes[:'instance_id']
  end

  if attributes.key?(:'lifecycle')
    self.lifecycle = attributes[:'lifecycle']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'private_ip')
    self.private_ip = attributes[:'private_ip']
  end

  if attributes.key?(:'public_ip')
    self.public_ip = attributes[:'public_ip']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'security_groups')
    if (value = attributes[:'security_groups']).is_a?(Array)
      self.security_groups = value
    end
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#descriptionObject

The VM description



35
36
37
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 35

def description
  @description
end

#instance_idObject

The ID of the cloud VM



38
39
40
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 38

def instance_id
  @instance_id
end

#lifecycleObject

The lifecycle phase



41
42
43
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 41

def lifecycle
  @lifecycle
end

#mac_addressObject

MAC address of the VM



44
45
46
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 44

def mac_address
  @mac_address
end

#owner_idObject

VM owner ID



47
48
49
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 47

def owner_id
  @owner_id
end

#platformObject

VM platform information



50
51
52
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 50

def platform
  @platform
end

#private_ipObject

VM private IP address



53
54
55
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 53

def private_ip
  @private_ip
end

#public_ipObject

VM public IP address



56
57
58
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 56

def public_ip
  @public_ip
end

#regionObject

The cloud region



59
60
61
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 59

def region
  @region
end

#security_groupsObject

Security groups



62
63
64
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 62

def security_groups
  @security_groups
end

#sourceObject

The VM source image



65
66
67
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 65

def source
  @source
end

#statusObject

Connectivity status of the cloud VM



68
69
70
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 68

def status
  @status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 71

def self.attribute_map
  {
    :'description' => :'description',
    :'instance_id' => :'instance_id',
    :'lifecycle' => :'lifecycle',
    :'mac_address' => :'mac_address',
    :'owner_id' => :'owner_id',
    :'platform' => :'platform',
    :'private_ip' => :'private_ip',
    :'public_ip' => :'public_ip',
    :'region' => :'region',
    :'security_groups' => :'security_groups',
    :'source' => :'source',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 230

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 94

def self.openapi_types
  {
    :'description' => :'String',
    :'instance_id' => :'String',
    :'lifecycle' => :'String',
    :'mac_address' => :'String',
    :'owner_id' => :'String',
    :'platform' => :'String',
    :'private_ip' => :'String',
    :'public_ip' => :'String',
    :'region' => :'String',
    :'security_groups' => :'Array<String>',
    :'source' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      instance_id == o.instance_id &&
      lifecycle == o.lifecycle &&
      mac_address == o.mac_address &&
      owner_id == o.owner_id &&
      platform == o.platform &&
      private_ip == o.private_ip &&
      public_ip == o.public_ip &&
      region == o.region &&
      security_groups == o.security_groups &&
      source == o.source &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 261

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 332

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 237

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 223

def hash
  [description, instance_id, lifecycle, mac_address, owner_id, platform, private_ip, public_ip, region, security_groups, source, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 185

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 308

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



302
303
304
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 302

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
# File 'lib/crimson-falcon/models/domain_external_asset_cloud_vm.rb', line 192

def valid?
  true
end