Class: Falcon::DomainExternalAssetService

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_external_asset_service.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainExternalAssetService

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainExternalAssetService` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainExternalAssetService`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applications')
    if (value = attributes[:'applications']).is_a?(Array)
      self.applications = value
    end
  end

  if attributes.key?(:'blob_links')
    self.blob_links = attributes[:'blob_links']
  end

  if attributes.key?(:'cloud_provider')
    self.cloud_provider = attributes[:'cloud_provider']
  end

  if attributes.key?(:'cpes')
    if (value = attributes[:'cpes']).is_a?(Array)
      self.cpes = value
    end
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  end

  if attributes.key?(:'hosting_provider')
    self.hosting_provider = attributes[:'hosting_provider']
  end

  if attributes.key?(:'http_attributes')
    self.http_attributes = attributes[:'http_attributes']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'os')
    self.os = attributes[:'os']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'subsidiaries')
    if (value = attributes[:'subsidiaries']).is_a?(Array)
      self.subsidiaries = value
    end
  end

  if attributes.key?(:'tls')
    self.tls = attributes[:'tls']
  end

  if attributes.key?(:'transport')
    self.transport = attributes[:'transport']
  end
end

Instance Attribute Details

#applicationsObject

Details about the applications associated to the service



35
36
37
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 35

def applications
  @applications
end

Returns the value of attribute blob_links.



37
38
39
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 37

def blob_links
  @blob_links
end

#cloud_providerObject

The cloud provider name



40
41
42
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 40

def cloud_provider
  @cloud_provider
end

#cpesObject

A list of Common Platform Enumeration identifiers for this service. The schema format is: cpe:<cpe_version>:<part>:<vendor>:<product>:<version>:<update>:<edition>:<language>:<sw_edition>:<target_sw>:<target_hw>:<other>



43
44
45
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 43

def cpes
  @cpes
end

#first_seenObject

The first time this service was observed



46
47
48
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 46

def first_seen
  @first_seen
end

#hosting_providerObject

The hosting provider name



49
50
51
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 49

def hosting_provider
  @hosting_provider
end

#http_attributesObject

Returns the value of attribute http_attributes.



51
52
53
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 51

def http_attributes
  @http_attributes
end

#idObject

The unique external asset identifier



54
55
56
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 54

def id
  @id
end

#last_seenObject

The date on which this was last scanned



57
58
59
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 57

def last_seen
  @last_seen
end

#osObject

The operating system the service is running on



60
61
62
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 60

def os
  @os
end

#platform_nameObject

The name of the platform on which the service is running (Windows, Mac, Linux).



63
64
65
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 63

def platform_name
  @platform_name
end

#portObject

The port on which the service is accessible



66
67
68
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 66

def port
  @port
end

#protocolObject

The protocol used to access this service



69
70
71
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 69

def protocol
  @protocol
end

#statusObject

The availability status for this service



72
73
74
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 72

def status
  @status
end

#status_codeObject

The status code returned by the service



75
76
77
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 75

def status_code
  @status_code
end

#subsidiariesObject

List of subsidiaries that the asset belongs to



78
79
80
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 78

def subsidiaries
  @subsidiaries
end

#tlsObject

Returns the value of attribute tls.



80
81
82
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 80

def tls
  @tls
end

#transportObject

The network transport used to access this service



83
84
85
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 83

def transport
  @transport
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 86

def self.attribute_map
  {
    :'applications' => :'applications',
    :'blob_links' => :'blob_links',
    :'cloud_provider' => :'cloud_provider',
    :'cpes' => :'cpes',
    :'first_seen' => :'first_seen',
    :'hosting_provider' => :'hosting_provider',
    :'http_attributes' => :'http_attributes',
    :'id' => :'id',
    :'last_seen' => :'last_seen',
    :'os' => :'os',
    :'platform_name' => :'platform_name',
    :'port' => :'port',
    :'protocol' => :'protocol',
    :'status' => :'status',
    :'status_code' => :'status_code',
    :'subsidiaries' => :'subsidiaries',
    :'tls' => :'tls',
    :'transport' => :'transport'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 326

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



139
140
141
142
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 139

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 115

def self.openapi_types
  {
    :'applications' => :'Array<DomainExternalAssetApplication>',
    :'blob_links' => :'DomainExternalAssetServiceBlobsLinks',
    :'cloud_provider' => :'String',
    :'cpes' => :'Array<String>',
    :'first_seen' => :'Time',
    :'hosting_provider' => :'String',
    :'http_attributes' => :'DomainExternalAssetHTTPAttributes',
    :'id' => :'String',
    :'last_seen' => :'Time',
    :'os' => :'String',
    :'platform_name' => :'String',
    :'port' => :'Integer',
    :'protocol' => :'String',
    :'status' => :'String',
    :'status_code' => :'Integer',
    :'subsidiaries' => :'Array<DomainExternalAssetSubsidiary>',
    :'tls' => :'DomainExternalAssetSSLRecord',
    :'transport' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 288

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applications == o.applications &&
      blob_links == o.blob_links &&
      cloud_provider == o.cloud_provider &&
      cpes == o.cpes &&
      first_seen == o.first_seen &&
      hosting_provider == o.hosting_provider &&
      http_attributes == o.http_attributes &&
      id == o.id &&
      last_seen == o.last_seen &&
      os == o.os &&
      platform_name == o.platform_name &&
      port == o.port &&
      protocol == o.protocol &&
      status == o.status &&
      status_code == o.status_code &&
      subsidiaries == o.subsidiaries &&
      tls == o.tls &&
      transport == o.transport
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 357

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 428

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 333

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 313

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



319
320
321
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 319

def hash
  [applications, blob_links, cloud_provider, cpes, first_seen, hosting_provider, http_attributes, id, last_seen, os, platform_name, port, protocol, status, status_code, subsidiaries, tls, transport].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 240

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_seen.nil?
    invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.')
  end

  if @port.nil?
    invalid_properties.push('invalid value for "port", port cannot be nil.')
  end

  if @protocol.nil?
    invalid_properties.push('invalid value for "protocol", protocol cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @status_code.nil?
    invalid_properties.push('invalid value for "status_code", status_code cannot be nil.')
  end

  if @transport.nil?
    invalid_properties.push('invalid value for "transport", transport cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



404
405
406
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 404

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 410

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



398
399
400
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 398

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



275
276
277
278
279
280
281
282
283
284
# File 'lib/crimson-falcon/models/domain_external_asset_service.rb', line 275

def valid?
  return false if @id.nil?
  return false if @last_seen.nil?
  return false if @port.nil?
  return false if @protocol.nil?
  return false if @status.nil?
  return false if @status_code.nil?
  return false if @transport.nil?
  true
end