Class: Falcon::DomainFemExternalIP

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_fem_external_ip.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainFemExternalIP

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainFemExternalIP` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainFemExternalIP`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aid')
    self.aid = attributes[:'aid']
  end

  if attributes.key?(:'asn')
    self.asn = attributes[:'asn']
  end

  if attributes.key?(:'cloud_provider')
    self.cloud_provider = attributes[:'cloud_provider']
  end

  if attributes.key?(:'cloud_vm')
    self.cloud_vm = attributes[:'cloud_vm']
  end

  if attributes.key?(:'fqdns')
    if (value = attributes[:'fqdns']).is_a?(Array)
      self.fqdns = value
    end
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'isp')
    self.isp = attributes[:'isp']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'ptr')
    self.ptr = attributes[:'ptr']
  end

  if attributes.key?(:'services')
    if (value = attributes[:'services']).is_a?(Array)
      self.services = value
    end
  end
end

Instance Attribute Details

#aidObject

AID if available



35
36
37
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 35

def aid
  @aid
end

#asnObject

ASN



38
39
40
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 38

def asn
  @asn
end

#cloud_providerObject

Cloud Provider



41
42
43
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 41

def cloud_provider
  @cloud_provider
end

#cloud_vmObject

Returns the value of attribute cloud_vm.



43
44
45
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 43

def cloud_vm
  @cloud_vm
end

#fqdnsObject

The FQDN List of the related domains



46
47
48
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 46

def fqdns
  @fqdns
end

#ip_addressObject

The IP address



49
50
51
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 49

def ip_address
  @ip_address
end

#ispObject

The ISP



52
53
54
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 52

def isp
  @isp
end

#locationObject

Returns the value of attribute location.



54
55
56
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 54

def location
  @location
end

#ptrObject

The PTR record



57
58
59
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 57

def ptr
  @ptr
end

#servicesObject

A list of exposed services on the IP



60
61
62
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 60

def services
  @services
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 63

def self.attribute_map
  {
    :'aid' => :'aid',
    :'asn' => :'asn',
    :'cloud_provider' => :'cloud_provider',
    :'cloud_vm' => :'cloud_vm',
    :'fqdns' => :'fqdns',
    :'ip_address' => :'ip_address',
    :'isp' => :'isp',
    :'location' => :'location',
    :'ptr' => :'ptr',
    :'services' => :'services'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 210

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 84

def self.openapi_types
  {
    :'aid' => :'String',
    :'asn' => :'Integer',
    :'cloud_provider' => :'String',
    :'cloud_vm' => :'DomainExternalAssetCloudVM',
    :'fqdns' => :'Array<String>',
    :'ip_address' => :'String',
    :'isp' => :'String',
    :'location' => :'DomainExternalAssetGeographicalLocation',
    :'ptr' => :'String',
    :'services' => :'Array<DomainExternalAssetService>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aid == o.aid &&
      asn == o.asn &&
      cloud_provider == o.cloud_provider &&
      cloud_vm == o.cloud_vm &&
      fqdns == o.fqdns &&
      ip_address == o.ip_address &&
      isp == o.isp &&
      location == o.location &&
      ptr == o.ptr &&
      services == o.services
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 241

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 312

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 217

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 203

def hash
  [aid, asn, cloud_provider, cloud_vm, fqdns, ip_address, isp, location, ptr, services].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 167

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 288

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



282
283
284
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 282

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
# File 'lib/crimson-falcon/models/domain_fem_external_ip.rb', line 174

def valid?
  true
end