Class: Falcon::DomainGCPAccountV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_gcp_account_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainGCPAccountV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 174

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainGCPAccountV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainGCPAccountV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_registration_enabled')
    self.cloud_registration_enabled = attributes[:'cloud_registration_enabled']
  end

  if attributes.key?(:'cloud_scopes')
    if (value = attributes[:'cloud_scopes']).is_a?(Array)
      self.cloud_scopes = value
    end
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'cspm_enabled')
    self.cspm_enabled = attributes[:'cspm_enabled']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'folder_id')
    self.folder_id = attributes[:'folder_id']
  end

  if attributes.key?(:'folder_name')
    self.folder_name = attributes[:'folder_name']
  end

  if attributes.key?(:'gcp_permissions_status')
    if (value = attributes[:'gcp_permissions_status']).is_a?(Array)
      self.gcp_permissions_status = value
    end
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'organization_name')
    self.organization_name = attributes[:'organization_name']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'parent_type')
    self.parent_type = attributes[:'parent_type']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'service_account_client_email')
    self. = attributes[:'service_account_client_email']
  end

  if attributes.key?(:'service_account_client_id')
    self. = attributes[:'service_account_client_id']
  end

  if attributes.key?(:'service_account_conditions')
    if (value = attributes[:'service_account_conditions']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'service_account_id')
    self. = attributes[:'service_account_id']
  end

  if attributes.key?(:'service_account_private_key_id')
    self. = attributes[:'service_account_private_key_id']
  end

  if attributes.key?(:'service_account_project_id')
    self. = attributes[:'service_account_project_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



42
43
44
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 42

def cid
  @cid
end

#cloud_registration_enabledObject

Returns the value of attribute cloud_registration_enabled.



44
45
46
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 44

def cloud_registration_enabled
  @cloud_registration_enabled
end

#cloud_scopesObject

Returns the value of attribute cloud_scopes.



46
47
48
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 46

def cloud_scopes
  @cloud_scopes
end

#conditionsObject

Returns the value of attribute conditions.



48
49
50
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 48

def conditions
  @conditions
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 34

def created_at
  @created_at
end

#cspm_enabledObject

Returns the value of attribute cspm_enabled.



50
51
52
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 50

def cspm_enabled
  @cspm_enabled
end

#deleted_atObject

Returns the value of attribute deleted_at.



36
37
38
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 36

def deleted_at
  @deleted_at
end

#display_nameObject

GCP Display Name



53
54
55
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 53

def display_name
  @display_name
end

#environmentObject

Returns the value of attribute environment.



55
56
57
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 55

def environment
  @environment
end

#folder_idObject

GCP folder ID



58
59
60
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 58

def folder_id
  @folder_id
end

#folder_nameObject

GCP folder Name



61
62
63
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 61

def folder_name
  @folder_name
end

#gcp_permissions_statusObject

Permissions status returned via API.



64
65
66
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 64

def gcp_permissions_status
  @gcp_permissions_status
end

#idObject

Returns the value of attribute id.



38
39
40
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 38

def id
  @id
end

#organization_idObject

GCP organization ID



67
68
69
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 67

def organization_id
  @organization_id
end

#organization_nameObject

GCP organization name



70
71
72
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 70

def organization_name
  @organization_name
end

#parent_idObject

GCP Account ID for organization/folder/projects.



73
74
75
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 73

def parent_id
  @parent_id
end

#parent_typeObject

GCP Parent Type.



76
77
78
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 76

def parent_type
  @parent_type
end

#project_idObject

GCP Project ID



79
80
81
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 79

def project_id
  @project_id
end

#service_account_client_emailObject

Returns the value of attribute service_account_client_email.



81
82
83
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 81

def 
  @service_account_client_email
end

#service_account_client_idObject

Returns the value of attribute service_account_client_id.



83
84
85
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 83

def 
  @service_account_client_id
end

#service_account_conditionsObject

Returns the value of attribute service_account_conditions.



85
86
87
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 85

def 
  @service_account_conditions
end

#service_account_idObject

GCP service account ID



88
89
90
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 88

def 
  @service_account_id
end

#service_account_private_key_idObject

Returns the value of attribute service_account_private_key_id.



90
91
92
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 90

def 
  @service_account_private_key_id
end

#service_account_project_idObject

Returns the value of attribute service_account_project_id.



92
93
94
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 92

def 
  @service_account_project_id
end

#statusObject

Account registration status.



95
96
97
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 95

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



130
131
132
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 130

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 98

def self.attribute_map
  {
    :'created_at' => :'CreatedAt',
    :'deleted_at' => :'DeletedAt',
    :'id' => :'ID',
    :'updated_at' => :'UpdatedAt',
    :'cid' => :'cid',
    :'cloud_registration_enabled' => :'cloud_registration_enabled',
    :'cloud_scopes' => :'cloud_scopes',
    :'conditions' => :'conditions',
    :'cspm_enabled' => :'cspm_enabled',
    :'display_name' => :'display_name',
    :'environment' => :'environment',
    :'folder_id' => :'folder_id',
    :'folder_name' => :'folder_name',
    :'gcp_permissions_status' => :'gcp_permissions_status',
    :'organization_id' => :'organization_id',
    :'organization_name' => :'organization_name',
    :'parent_id' => :'parent_id',
    :'parent_type' => :'parent_type',
    :'project_id' => :'project_id',
    :'service_account_client_email' => :'service_account_client_email',
    :'service_account_client_id' => :'service_account_client_id',
    :'service_account_conditions' => :'service_account_conditions',
    :'service_account_id' => :'service_account_id',
    :'service_account_private_key_id' => :'service_account_private_key_id',
    :'service_account_project_id' => :'service_account_project_id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



411
412
413
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 411

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



167
168
169
170
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 167

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 135

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'id' => :'Integer',
    :'updated_at' => :'Time',
    :'cid' => :'String',
    :'cloud_registration_enabled' => :'Boolean',
    :'cloud_scopes' => :'Array<DomainCloudScope>',
    :'conditions' => :'Array<StatemgmtCondition>',
    :'cspm_enabled' => :'Boolean',
    :'display_name' => :'String',
    :'environment' => :'String',
    :'folder_id' => :'String',
    :'folder_name' => :'String',
    :'gcp_permissions_status' => :'Array<DomainPermission>',
    :'organization_id' => :'String',
    :'organization_name' => :'String',
    :'parent_id' => :'String',
    :'parent_type' => :'String',
    :'project_id' => :'String',
    :'service_account_client_email' => :'String',
    :'service_account_client_id' => :'String',
    :'service_account_conditions' => :'Array<StatemgmtCondition>',
    :'service_account_id' => :'Integer',
    :'service_account_private_key_id' => :'String',
    :'service_account_project_id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 365

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      id == o.id &&
      updated_at == o.updated_at &&
      cid == o.cid &&
      cloud_registration_enabled == o.cloud_registration_enabled &&
      cloud_scopes == o.cloud_scopes &&
      conditions == o.conditions &&
      cspm_enabled == o.cspm_enabled &&
      display_name == o.display_name &&
      environment == o.environment &&
      folder_id == o.folder_id &&
      folder_name == o.folder_name &&
      gcp_permissions_status == o.gcp_permissions_status &&
      organization_id == o.organization_id &&
      organization_name == o.organization_name &&
      parent_id == o.parent_id &&
      parent_type == o.parent_type &&
      project_id == o.project_id &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 442

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 513

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 418

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


398
399
400
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 398

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



404
405
406
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 404

def hash
  [created_at, deleted_at, id, updated_at, cid, cloud_registration_enabled, cloud_scopes, conditions, cspm_enabled, display_name, environment, folder_id, folder_name, gcp_permissions_status, organization_id, organization_name, parent_id, parent_type, project_id, , , , , , , status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 302

def list_invalid_properties
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @deleted_at.nil?
    invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @cloud_registration_enabled.nil?
    invalid_properties.push('invalid value for "cloud_registration_enabled", cloud_registration_enabled cannot be nil.')
  end

  if @cspm_enabled.nil?
    invalid_properties.push('invalid value for "cspm_enabled", cspm_enabled cannot be nil.')
  end

  if @gcp_permissions_status.nil?
    invalid_properties.push('invalid value for "gcp_permissions_status", gcp_permissions_status cannot be nil.')
  end

  if @parent_id.nil?
    invalid_properties.push('invalid value for "parent_id", parent_id cannot be nil.')
  end

  if @service_account_project_id.nil?
    invalid_properties.push('invalid value for "service_account_project_id", service_account_project_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



489
490
491
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 489

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 495

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



483
484
485
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 483

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/crimson-falcon/models/domain_gcp_account_v1.rb', line 349

def valid?
  return false if @created_at.nil?
  return false if @deleted_at.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  return false if @cid.nil?
  return false if @cloud_registration_enabled.nil?
  return false if @cspm_enabled.nil?
  return false if @gcp_permissions_status.nil?
  return false if @parent_id.nil?
  return false if @service_account_project_id.nil?
  true
end