Class: Falcon::DomainGPA
- Inherits:
-
Object
- Object
- Falcon::DomainGPA
- Defined in:
- lib/crimson-falcon/models/domain_gpa.rb
Instance Attribute Summary collapse
-
#algorithm_header_name ⇒ Object
algorithm header name.
-
#encoding ⇒ Object
encoding of the signature, defaults to base64.
-
#field_delimiter ⇒ Object
delimiter used between fields.
-
#fields ⇒ Object
fields of the signature.
-
#hash_function ⇒ Object
hash function to use; defaults to sha256.
-
#header_format ⇒ Object
header value for signature using ${} wrapped variables.
-
#header_name ⇒ Object
name of the header the base64 encoded signature is matched; example: X-CS-Primary-SecretKey; default: Authorization.
-
#key ⇒ Object
private key used to hash.
-
#timestamp_format ⇒ Object
the timestamp format; defaults to RFC3339.
-
#timestamp_header_name ⇒ Object
Returns the value of attribute timestamp_header_name.
-
#type ⇒ Object
Preset type of hmac config.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainGPA
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainGPA
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainGPA` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainGPA`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'algorithm_header_name') self.algorithm_header_name = attributes[:'algorithm_header_name'] end if attributes.key?(:'encoding') self.encoding = attributes[:'encoding'] end if attributes.key?(:'field_delimiter') self.field_delimiter = attributes[:'field_delimiter'] end if attributes.key?(:'fields') if (value = attributes[:'fields']).is_a?(Array) self.fields = value end end if attributes.key?(:'hash_function') self.hash_function = attributes[:'hash_function'] end if attributes.key?(:'header_format') self.header_format = attributes[:'header_format'] end if attributes.key?(:'header_name') self.header_name = attributes[:'header_name'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'timestamp_format') self. = attributes[:'timestamp_format'] end if attributes.key?(:'timestamp_header_name') self. = attributes[:'timestamp_header_name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#algorithm_header_name ⇒ Object
algorithm header name
35 36 37 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 35 def algorithm_header_name @algorithm_header_name end |
#encoding ⇒ Object
encoding of the signature, defaults to base64
38 39 40 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 38 def encoding @encoding end |
#field_delimiter ⇒ Object
delimiter used between fields
41 42 43 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 41 def field_delimiter @field_delimiter end |
#fields ⇒ Object
fields of the signature
44 45 46 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 44 def fields @fields end |
#hash_function ⇒ Object
hash function to use; defaults to sha256
47 48 49 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 47 def hash_function @hash_function end |
#header_format ⇒ Object
header value for signature using ${} wrapped variables
50 51 52 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 50 def header_format @header_format end |
#header_name ⇒ Object
name of the header the base64 encoded signature is matched; example: X-CS-Primary-SecretKey; default: Authorization
53 54 55 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 53 def header_name @header_name end |
#key ⇒ Object
private key used to hash
56 57 58 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 56 def key @key end |
#timestamp_format ⇒ Object
the timestamp format; defaults to RFC3339
59 60 61 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 59 def @timestamp_format end |
#timestamp_header_name ⇒ Object
Returns the value of attribute timestamp_header_name.
61 62 63 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 61 def @timestamp_header_name end |
#type ⇒ Object
Preset type of hmac config. This takes precedence over other config fields, so if this field is set, then it uses the native implementation to generate the hmac signature
64 65 66 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 64 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 84 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 67 def self.attribute_map { :'algorithm_header_name' => :'algorithm_header_name', :'encoding' => :'encoding', :'field_delimiter' => :'field_delimiter', :'fields' => :'fields', :'hash_function' => :'hash_function', :'header_format' => :'header_format', :'header_name' => :'header_name', :'key' => :'key', :'timestamp_format' => :'timestamp_format', :'timestamp_header_name' => :'timestamp_header_name', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 224 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 89 def self.openapi_types { :'algorithm_header_name' => :'String', :'encoding' => :'String', :'field_delimiter' => :'String', :'fields' => :'Array<String>', :'hash_function' => :'String', :'header_format' => :'String', :'header_name' => :'String', :'key' => :'String', :'timestamp_format' => :'String', :'timestamp_header_name' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && algorithm_header_name == o.algorithm_header_name && encoding == o.encoding && field_delimiter == o.field_delimiter && fields == o.fields && hash_function == o.hash_function && header_format == o.header_format && header_name == o.header_name && key == o.key && == o. && == o. && type == o.type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 255 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 326 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 217 def hash [algorithm_header_name, encoding, field_delimiter, fields, hash_function, header_format, header_name, key, , , type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 175 def list_invalid_properties invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
302 303 304 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 302 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 296 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 |
# File 'lib/crimson-falcon/models/domain_gpa.rb', line 186 def valid? return false if @key.nil? true end |