Class: Falcon::DomainGlobalConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_global_config.rb

Overview

Represents information about global configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainGlobalConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainGlobalConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainGlobalConfig`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_confirm_ownership')
    self.auto_confirm_ownership = attributes[:'auto_confirm_ownership']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'managed_host_group')
    self.managed_host_group = attributes[:'managed_host_group']
  end

  if attributes.key?(:'max_concurrent_tasks')
    self.max_concurrent_tasks = attributes[:'max_concurrent_tasks']
  end

  if attributes.key?(:'network_scanning_enabled')
    self.network_scanning_enabled = attributes[:'network_scanning_enabled']
  end

  if attributes.key?(:'scan_exclusion')
    self.scan_exclusion = attributes[:'scan_exclusion']
  end

  if attributes.key?(:'scanners')
    if (value = attributes[:'scanners']).is_a?(Array)
      self.scanners = value
    end
  end

  if attributes.key?(:'scanners_exclusion')
    if (value = attributes[:'scanners_exclusion']).is_a?(Array)
      self.scanners_exclusion = value
    end
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'updated_timestamp')
    self.updated_timestamp = attributes[:'updated_timestamp']
  end
end

Instance Attribute Details

#auto_confirm_ownershipObject

Returns the value of attribute auto_confirm_ownership.



35
36
37
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 35

def auto_confirm_ownership
  @auto_confirm_ownership
end

#cidObject

The customer ID of the configuration



38
39
40
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 38

def cid
  @cid
end

#created_byObject

The user that created the rule



41
42
43
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 41

def created_by
  @created_by
end

#created_timestampObject

The time at which the rule was created



44
45
46
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 44

def created_timestamp
  @created_timestamp
end

#managed_host_groupObject

Returns the value of attribute managed_host_group.



46
47
48
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 46

def managed_host_group
  @managed_host_group
end

#max_concurrent_tasksObject

Maximum scan tasks to run in parallel



49
50
51
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 49

def max_concurrent_tasks
  @max_concurrent_tasks
end

#network_scanning_enabledObject

Attempts to stop ongoing network scans and disables further scans from being executed



52
53
54
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 52

def network_scanning_enabled
  @network_scanning_enabled
end

#scan_exclusionObject

Returns the value of attribute scan_exclusion.



54
55
56
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 54

def scan_exclusion
  @scan_exclusion
end

#scannersObject

Describes the pool of assets that will act as eligible scanners



57
58
59
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 57

def scanners
  @scanners
end

#scanners_exclusionObject

Describes the list of assets that will always be excluded from being selected as scanners



60
61
62
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 60

def scanners_exclusion
  @scanners_exclusion
end

#updated_byObject

The user that updated the rule



63
64
65
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 63

def updated_by
  @updated_by
end

#updated_timestampObject

The time at which the rule was updated



66
67
68
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 66

def updated_timestamp
  @updated_timestamp
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 69

def self.attribute_map
  {
    :'auto_confirm_ownership' => :'auto_confirm_ownership',
    :'cid' => :'cid',
    :'created_by' => :'created_by',
    :'created_timestamp' => :'created_timestamp',
    :'managed_host_group' => :'managed_host_group',
    :'max_concurrent_tasks' => :'max_concurrent_tasks',
    :'network_scanning_enabled' => :'network_scanning_enabled',
    :'scan_exclusion' => :'scan_exclusion',
    :'scanners' => :'scanners',
    :'scanners_exclusion' => :'scanners_exclusion',
    :'updated_by' => :'updated_by',
    :'updated_timestamp' => :'updated_timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 255

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 92

def self.openapi_types
  {
    :'auto_confirm_ownership' => :'DomainAutoConfirmOwnership',
    :'cid' => :'String',
    :'created_by' => :'String',
    :'created_timestamp' => :'String',
    :'managed_host_group' => :'DomainManagedHostGroup',
    :'max_concurrent_tasks' => :'Integer',
    :'network_scanning_enabled' => :'Boolean',
    :'scan_exclusion' => :'DomainScanExclusionV1',
    :'scanners' => :'Array<DomainGlobalConfigScanner>',
    :'scanners_exclusion' => :'Array<DomainGlobalConfigScanner>',
    :'updated_by' => :'String',
    :'updated_timestamp' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_confirm_ownership == o.auto_confirm_ownership &&
      cid == o.cid &&
      created_by == o.created_by &&
      created_timestamp == o.created_timestamp &&
      managed_host_group == o.managed_host_group &&
      max_concurrent_tasks == o.max_concurrent_tasks &&
      network_scanning_enabled == o.network_scanning_enabled &&
      scan_exclusion == o.scan_exclusion &&
      scanners == o.scanners &&
      scanners_exclusion == o.scanners_exclusion &&
      updated_by == o.updated_by &&
      updated_timestamp == o.updated_timestamp
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 286

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 357

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 262

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 248

def hash
  [auto_confirm_ownership, cid, created_by, created_timestamp, managed_host_group, max_concurrent_tasks, network_scanning_enabled, scan_exclusion, scanners, scanners_exclusion, updated_by, updated_timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 185

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @max_concurrent_tasks.nil?
    invalid_properties.push('invalid value for "max_concurrent_tasks", max_concurrent_tasks cannot be nil.')
  end

  if @scan_exclusion.nil?
    invalid_properties.push('invalid value for "scan_exclusion", scan_exclusion cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 333

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



327
328
329
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 327

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
# File 'lib/crimson-falcon/models/domain_global_config.rb', line 212

def valid?
  return false if @cid.nil?
  return false if @created_by.nil?
  return false if @created_timestamp.nil?
  return false if @max_concurrent_tasks.nil?
  return false if @scan_exclusion.nil?
  true
end