Class: Falcon::DomainKnowledgeBaseFile

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_knowledge_base_file.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainKnowledgeBaseFile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainKnowledgeBaseFile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainKnowledgeBaseFile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_deleted')
    self.is_deleted = attributes[:'is_deleted']
  end

  if attributes.key?(:'knowledge_base_id')
    self.knowledge_base_id = attributes[:'knowledge_base_id']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end
end

Instance Attribute Details

#content_typeObject

Returns the value of attribute content_type.



34
35
36
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 34

def content_type
  @content_type
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 36

def created_at
  @created_at
end

#created_byObject

Returns the value of attribute created_by.



38
39
40
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 38

def created_by
  @created_by
end

#idObject

Returns the value of attribute id.



40
41
42
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 40

def id
  @id
end

#is_deletedObject

Returns the value of attribute is_deleted.



42
43
44
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 42

def is_deleted
  @is_deleted
end

#knowledge_base_idObject

Returns the value of attribute knowledge_base_id.



44
45
46
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 44

def knowledge_base_id
  @knowledge_base_id
end

#metadataObject

Returns the value of attribute metadata.



46
47
48
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 46

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



48
49
50
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 48

def name
  @name
end

#sizeObject

Returns the value of attribute size.



50
51
52
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 50

def size
  @size
end

#statusObject

Returns the value of attribute status.



52
53
54
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 52

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



54
55
56
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 54

def updated_at
  @updated_at
end

#updated_byObject

Returns the value of attribute updated_by.



56
57
58
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 56

def updated_by
  @updated_by
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 59

def self.attribute_map
  {
    :'content_type' => :'content_type',
    :'created_at' => :'created_at',
    :'created_by' => :'created_by',
    :'id' => :'id',
    :'is_deleted' => :'is_deleted',
    :'knowledge_base_id' => :'knowledge_base_id',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'size' => :'size',
    :'status' => :'status',
    :'updated_at' => :'updated_at',
    :'updated_by' => :'updated_by'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 278

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 82

def self.openapi_types
  {
    :'content_type' => :'String',
    :'created_at' => :'Time',
    :'created_by' => :'DomainUser',
    :'id' => :'String',
    :'is_deleted' => :'Boolean',
    :'knowledge_base_id' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'name' => :'String',
    :'size' => :'Integer',
    :'status' => :'String',
    :'updated_at' => :'Time',
    :'updated_by' => :'DomainUser'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      content_type == o.content_type &&
      created_at == o.created_at &&
      created_by == o.created_by &&
      id == o.id &&
      is_deleted == o.is_deleted &&
      knowledge_base_id == o.knowledge_base_id &&
       == o. &&
      name == o.name &&
      size == o.size &&
      status == o.status &&
      updated_at == o.updated_at &&
      updated_by == o.updated_by
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 309

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 271

def hash
  [content_type, created_at, created_by, id, is_deleted, knowledge_base_id, , name, size, status, updated_at, updated_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 173

def list_invalid_properties
  invalid_properties = Array.new
  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @is_deleted.nil?
    invalid_properties.push('invalid value for "is_deleted", is_deleted cannot be nil.')
  end

  if @knowledge_base_id.nil?
    invalid_properties.push('invalid value for "knowledge_base_id", knowledge_base_id cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @updated_by.nil?
    invalid_properties.push('invalid value for "updated_by", updated_by cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/crimson-falcon/models/domain_knowledge_base_file.rb', line 228

def valid?
  return false if @content_type.nil?
  return false if @created_at.nil?
  return false if @created_by.nil?
  return false if @id.nil?
  return false if @is_deleted.nil?
  return false if @knowledge_base_id.nil?
  return false if @metadata.nil?
  return false if @name.nil?
  return false if @size.nil?
  return false if @status.nil?
  return false if @updated_at.nil?
  return false if @updated_by.nil?
  true
end