Class: Falcon::DomainLookupFile

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_lookup_file.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainLookupFile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainLookupFile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainLookupFile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_id')
    self.app_id = attributes[:'app_id']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'contents_hash')
    self.contents_hash = attributes[:'contents_hash']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_modified_by')
    self.last_modified_by = attributes[:'last_modified_by']
  end

  if attributes.key?(:'last_modified_timestamp')
    self.last_modified_timestamp = attributes[:'last_modified_timestamp']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'repo')
    self.repo = attributes[:'repo']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'version_numeric')
    self.version_numeric = attributes[:'version_numeric']
  end
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



34
35
36
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 34

def app_id
  @app_id
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 36

def cid
  @cid
end

#contents_hashObject

Returns the value of attribute contents_hash.



38
39
40
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 38

def contents_hash
  @contents_hash
end

#created_byObject

Returns the value of attribute created_by.



40
41
42
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 40

def created_by
  @created_by
end

#created_timestampObject

Returns the value of attribute created_timestamp.



42
43
44
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 42

def created_timestamp
  @created_timestamp
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 44

def description
  @description
end

#filenameObject

Returns the value of attribute filename.



46
47
48
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 46

def filename
  @filename
end

#formatObject

Returns the value of attribute format.



48
49
50
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 48

def format
  @format
end

#idObject

Returns the value of attribute id.



50
51
52
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 50

def id
  @id
end

#last_modified_byObject

Returns the value of attribute last_modified_by.



52
53
54
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 52

def last_modified_by
  @last_modified_by
end

#last_modified_timestampObject

Returns the value of attribute last_modified_timestamp.



54
55
56
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 54

def last_modified_timestamp
  @last_modified_timestamp
end

#nameObject

Returns the value of attribute name.



56
57
58
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 56

def name
  @name
end

#repoObject

Returns the value of attribute repo.



58
59
60
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 58

def repo
  @repo
end

#sizeObject

Returns the value of attribute size.



60
61
62
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 60

def size
  @size
end

#statusObject

Returns the value of attribute status.



62
63
64
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 62

def status
  @status
end

#versionObject

Returns the value of attribute version.



64
65
66
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 64

def version
  @version
end

#version_numericObject

Returns the value of attribute version_numeric.



66
67
68
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 66

def version_numeric
  @version_numeric
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 69

def self.attribute_map
  {
    :'app_id' => :'app_id',
    :'cid' => :'cid',
    :'contents_hash' => :'contents_hash',
    :'created_by' => :'created_by',
    :'created_timestamp' => :'created_timestamp',
    :'description' => :'description',
    :'filename' => :'filename',
    :'format' => :'format',
    :'id' => :'id',
    :'last_modified_by' => :'last_modified_by',
    :'last_modified_timestamp' => :'last_modified_timestamp',
    :'name' => :'name',
    :'repo' => :'repo',
    :'size' => :'size',
    :'status' => :'status',
    :'version' => :'version',
    :'version_numeric' => :'version_numeric'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 336

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 97

def self.openapi_types
  {
    :'app_id' => :'String',
    :'cid' => :'String',
    :'contents_hash' => :'String',
    :'created_by' => :'DomainUser',
    :'created_timestamp' => :'Time',
    :'description' => :'String',
    :'filename' => :'String',
    :'format' => :'String',
    :'id' => :'String',
    :'last_modified_by' => :'DomainUser',
    :'last_modified_timestamp' => :'Time',
    :'name' => :'String',
    :'repo' => :'String',
    :'size' => :'Integer',
    :'status' => :'String',
    :'version' => :'String',
    :'version_numeric' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_id == o.app_id &&
      cid == o.cid &&
      contents_hash == o.contents_hash &&
      created_by == o.created_by &&
      created_timestamp == o.created_timestamp &&
      description == o.description &&
      filename == o.filename &&
      format == o.format &&
      id == o.id &&
      last_modified_by == o.last_modified_by &&
      last_modified_timestamp == o.last_modified_timestamp &&
      name == o.name &&
      repo == o.repo &&
      size == o.size &&
      status == o.status &&
      version == o.version &&
      version_numeric == o.version_numeric
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 367

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 438

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 343

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 329

def hash
  [app_id, cid, contents_hash, created_by, created_timestamp, description, filename, format, id, last_modified_by, last_modified_timestamp, name, repo, size, status, version, version_numeric].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 211

def list_invalid_properties
  invalid_properties = Array.new
  if @contents_hash.nil?
    invalid_properties.push('invalid value for "contents_hash", contents_hash cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @filename.nil?
    invalid_properties.push('invalid value for "filename", filename cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_modified_by.nil?
    invalid_properties.push('invalid value for "last_modified_by", last_modified_by cannot be nil.')
  end

  if @last_modified_timestamp.nil?
    invalid_properties.push('invalid value for "last_modified_timestamp", last_modified_timestamp cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @repo.nil?
    invalid_properties.push('invalid value for "repo", repo cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @version_numeric.nil?
    invalid_properties.push('invalid value for "version_numeric", version_numeric cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



414
415
416
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 414

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 420

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



408
409
410
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 408

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/crimson-falcon/models/domain_lookup_file.rb', line 278

def valid?
  return false if @contents_hash.nil?
  return false if @created_by.nil?
  return false if @created_timestamp.nil?
  return false if @description.nil?
  return false if @filename.nil?
  return false if @format.nil?
  return false if @id.nil?
  return false if @last_modified_by.nil?
  return false if @last_modified_timestamp.nil?
  return false if @name.nil?
  return false if @repo.nil?
  return false if @size.nil?
  return false if @status.nil?
  return false if @version.nil?
  return false if @version_numeric.nil?
  true
end