Class: Falcon::DomainMaliciousFile

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_malicious_file.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainMaliciousFile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainMaliciousFile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainMaliciousFile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'filepath')
    self.filepath = attributes[:'filepath']
  end

  if attributes.key?(:'hash')
    self.hash = attributes[:'hash']
  end

  if attributes.key?(:'host_id')
    self.host_id = attributes[:'host_id']
  end

  if attributes.key?(:'host_scan_id')
    self.host_scan_id = attributes[:'host_scan_id']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'pattern_id')
    self.pattern_id = attributes[:'pattern_id']
  end

  if attributes.key?(:'quarantined')
    self.quarantined = attributes[:'quarantined']
  end

  if attributes.key?(:'scan_id')
    self.scan_id = attributes[:'scan_id']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



34
35
36
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 34

def cid
  @cid
end

#filenameObject

Returns the value of attribute filename.



36
37
38
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 36

def filename
  @filename
end

#filepathObject

Returns the value of attribute filepath.



38
39
40
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 38

def filepath
  @filepath
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 214

def hash
  @hash
end

#host_idObject

Returns the value of attribute host_id.



42
43
44
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 42

def host_id
  @host_id
end

#host_scan_idObject

Returns the value of attribute host_scan_id.



44
45
46
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 44

def host_scan_id
  @host_scan_id
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 46

def id
  @id
end

#last_updatedObject

Returns the value of attribute last_updated.



48
49
50
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 48

def last_updated
  @last_updated
end

#pattern_idObject

Returns the value of attribute pattern_id.



50
51
52
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 50

def pattern_id
  @pattern_id
end

#quarantinedObject

Returns the value of attribute quarantined.



52
53
54
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 52

def quarantined
  @quarantined
end

#scan_idObject

Returns the value of attribute scan_id.



54
55
56
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 54

def scan_id
  @scan_id
end

#severityObject

Returns the value of attribute severity.



56
57
58
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 56

def severity
  @severity
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 59

def self.attribute_map
  {
    :'cid' => :'cid',
    :'filename' => :'filename',
    :'filepath' => :'filepath',
    :'hash' => :'hash',
    :'host_id' => :'host_id',
    :'host_scan_id' => :'host_scan_id',
    :'id' => :'id',
    :'last_updated' => :'last_updated',
    :'pattern_id' => :'pattern_id',
    :'quarantined' => :'quarantined',
    :'scan_id' => :'scan_id',
    :'severity' => :'severity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 221

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 82

def self.openapi_types
  {
    :'cid' => :'String',
    :'filename' => :'String',
    :'filepath' => :'String',
    :'hash' => :'String',
    :'host_id' => :'String',
    :'host_scan_id' => :'String',
    :'id' => :'String',
    :'last_updated' => :'Time',
    :'pattern_id' => :'Integer',
    :'quarantined' => :'Boolean',
    :'scan_id' => :'String',
    :'severity' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      filename == o.filename &&
      filepath == o.filepath &&
      hash == o.hash &&
      host_id == o.host_id &&
      host_scan_id == o.host_scan_id &&
      id == o.id &&
      last_updated == o.last_updated &&
      pattern_id == o.pattern_id &&
      quarantined == o.quarantined &&
      scan_id == o.scan_id &&
      severity == o.severity
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 252

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 323

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 228

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 208

def eql?(o)
  self == o
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 299

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



293
294
295
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 293

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
# File 'lib/crimson-falcon/models/domain_malicious_file.rb', line 182

def valid?
  return false if @id.nil?
  true
end