Class: Falcon::DomainMultiStatusSensorResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_multi_status_sensor_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainMultiStatusSensorResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainMultiStatusSensorResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainMultiStatusSensorResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aid')
    self.aid = attributes[:'aid']
  end

  if attributes.key?(:'base_command')
    self.base_command = attributes[:'base_command']
  end

  if attributes.key?(:'complete')
    self.complete = attributes[:'complete']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end

  if attributes.key?(:'offline_queued')
    self.offline_queued = attributes[:'offline_queued']
  end

  if attributes.key?(:'query_time')
    self.query_time = attributes[:'query_time']
  end

  if attributes.key?(:'sequence_id')
    self.sequence_id = attributes[:'sequence_id']
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  end

  if attributes.key?(:'stderr')
    self.stderr = attributes[:'stderr']
  end

  if attributes.key?(:'stdout')
    self.stdout = attributes[:'stdout']
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  end
end

Instance Attribute Details

#aidObject

Returns the value of attribute aid.



34
35
36
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 34

def aid
  @aid
end

#base_commandObject

Returns the value of attribute base_command.



36
37
38
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 36

def base_command
  @base_command
end

#completeObject

Returns the value of attribute complete.



38
39
40
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 38

def complete
  @complete
end

#errorsObject

Returns the value of attribute errors.



40
41
42
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 40

def errors
  @errors
end

#offline_queuedObject

Returns the value of attribute offline_queued.



42
43
44
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 42

def offline_queued
  @offline_queued
end

#query_timeObject

Returns the value of attribute query_time.



44
45
46
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 44

def query_time
  @query_time
end

#sequence_idObject

Returns the value of attribute sequence_id.



46
47
48
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 46

def sequence_id
  @sequence_id
end

#session_idObject

Returns the value of attribute session_id.



48
49
50
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 48

def session_id
  @session_id
end

#stderrObject

Returns the value of attribute stderr.



50
51
52
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 50

def stderr
  @stderr
end

#stdoutObject

Returns the value of attribute stdout.



52
53
54
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 52

def stdout
  @stdout
end

#task_idObject

Returns the value of attribute task_id.



54
55
56
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 54

def task_id
  @task_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 57

def self.attribute_map
  {
    :'aid' => :'aid',
    :'base_command' => :'base_command',
    :'complete' => :'complete',
    :'errors' => :'errors',
    :'offline_queued' => :'offline_queued',
    :'query_time' => :'query_time',
    :'sequence_id' => :'sequence_id',
    :'session_id' => :'session_id',
    :'stderr' => :'stderr',
    :'stdout' => :'stdout',
    :'task_id' => :'task_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 249

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 79

def self.openapi_types
  {
    :'aid' => :'String',
    :'base_command' => :'String',
    :'complete' => :'Boolean',
    :'errors' => :'Array<MsaAPIError>',
    :'offline_queued' => :'Boolean',
    :'query_time' => :'Float',
    :'sequence_id' => :'Integer',
    :'session_id' => :'String',
    :'stderr' => :'String',
    :'stdout' => :'String',
    :'task_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aid == o.aid &&
      base_command == o.base_command &&
      complete == o.complete &&
      errors == o.errors &&
      offline_queued == o.offline_queued &&
      query_time == o.query_time &&
      sequence_id == o.sequence_id &&
      session_id == o.session_id &&
      stderr == o.stderr &&
      stdout == o.stdout &&
      task_id == o.task_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 280

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 351

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 242

def hash
  [aid, base_command, complete, errors, offline_queued, query_time, sequence_id, session_id, stderr, stdout, task_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @aid.nil?
    invalid_properties.push('invalid value for "aid", aid cannot be nil.')
  end

  if @complete.nil?
    invalid_properties.push('invalid value for "complete", complete cannot be nil.')
  end

  if @errors.nil?
    invalid_properties.push('invalid value for "errors", errors cannot be nil.')
  end

  if @offline_queued.nil?
    invalid_properties.push('invalid value for "offline_queued", offline_queued cannot be nil.')
  end

  if @query_time.nil?
    invalid_properties.push('invalid value for "query_time", query_time cannot be nil.')
  end

  if @session_id.nil?
    invalid_properties.push('invalid value for "session_id", session_id cannot be nil.')
  end

  if @stderr.nil?
    invalid_properties.push('invalid value for "stderr", stderr cannot be nil.')
  end

  if @stdout.nil?
    invalid_properties.push('invalid value for "stdout", stdout cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 327

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



321
322
323
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 321

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
211
212
213
214
# File 'lib/crimson-falcon/models/domain_multi_status_sensor_response.rb', line 204

def valid?
  return false if @aid.nil?
  return false if @complete.nil?
  return false if @errors.nil?
  return false if @offline_queued.nil?
  return false if @query_time.nil?
  return false if @session_id.nil?
  return false if @stderr.nil?
  return false if @stdout.nil?
  true
end