Class: Falcon::DomainPolicyInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_policy_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainPolicyInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 303

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainPolicyInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainPolicyInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'account_scope')
    self. = attributes[:'account_scope']
  end

  if attributes.key?(:'alert_logic')
    self.alert_logic = attributes[:'alert_logic']
  end

  if attributes.key?(:'api_command')
    self.api_command = attributes[:'api_command']
  end

  if attributes.key?(:'asset_type_id')
    self.asset_type_id = attributes[:'asset_type_id']
  end

  if attributes.key?(:'attack_tool')
    self.attack_tool = attributes[:'attack_tool']
  end

  if attributes.key?(:'attack_tool_command')
    self.attack_tool_command = attributes[:'attack_tool_command']
  end

  if attributes.key?(:'attack_types')
    if (value = attributes[:'attack_types']).is_a?(Array)
      self.attack_types = value
    end
  end

  if attributes.key?(:'cis_benchmark_ids')
    if (value = attributes[:'cis_benchmark_ids']).is_a?(Array)
      self.cis_benchmark_ids = value
    end
  end

  if attributes.key?(:'cisa_benchmark_ids')
    if (value = attributes[:'cisa_benchmark_ids']).is_a?(Array)
      self.cisa_benchmark_ids = value
    end
  end

  if attributes.key?(:'cli_command')
    self.cli_command = attributes[:'cli_command']
  end

  if attributes.key?(:'cloud_asset_type')
    self.cloud_asset_type = attributes[:'cloud_asset_type']
  end

  if attributes.key?(:'cloud_document')
    self.cloud_document = attributes[:'cloud_document']
  end

  if attributes.key?(:'cloud_platform')
    self.cloud_platform = attributes[:'cloud_platform']
  end

  if attributes.key?(:'cloud_platform_type')
    self.cloud_platform_type = attributes[:'cloud_platform_type']
  end

  if attributes.key?(:'cloud_service')
    self.cloud_service = attributes[:'cloud_service']
  end

  if attributes.key?(:'cloud_service_friendly')
    self.cloud_service_friendly = attributes[:'cloud_service_friendly']
  end

  if attributes.key?(:'cloud_service_id')
    self.cloud_service_id = attributes[:'cloud_service_id']
  end

  if attributes.key?(:'cloud_service_name')
    self.cloud_service_name = attributes[:'cloud_service_name']
  end

  if attributes.key?(:'cloud_service_subtype')
    self.cloud_service_subtype = attributes[:'cloud_service_subtype']
  end

  if attributes.key?(:'cloud_service_type')
    self.cloud_service_type = attributes[:'cloud_service_type']
  end

  if attributes.key?(:'compliance')
    self.compliance = attributes[:'compliance']
  end

  if attributes.key?(:'confidence')
    self.confidence = attributes[:'confidence']
  end

  if attributes.key?(:'controls')
    if (value = attributes[:'controls']).is_a?(Array)
      self.controls = value
    end
  end

  if attributes.key?(:'default_severity')
    self.default_severity = attributes[:'default_severity']
  end

  if attributes.key?(:'deprecated')
    self.deprecated = attributes[:'deprecated']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'fql_policy')
    self.fql_policy = attributes[:'fql_policy']
  end

  if attributes.key?(:'hipaa_benchmark_ids')
    if (value = attributes[:'hipaa_benchmark_ids']).is_a?(Array)
      self.hipaa_benchmark_ids = value
    end
  end

  if attributes.key?(:'hitrust_benchmark_ids')
    if (value = attributes[:'hitrust_benchmark_ids']).is_a?(Array)
      self.hitrust_benchmark_ids = value
    end
  end

  if attributes.key?(:'internal_only')
    self.internal_only = attributes[:'internal_only']
  end

  if attributes.key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.key?(:'is_global')
    self.is_global = attributes[:'is_global']
  end

  if attributes.key?(:'is_remediable')
    self.is_remediable = attributes[:'is_remediable']
  end

  if attributes.key?(:'iso_benchmark_ids')
    if (value = attributes[:'iso_benchmark_ids']).is_a?(Array)
      self.iso_benchmark_ids = value
    end
  end

  if attributes.key?(:'mitre_attack_cloud_matrix')
    self.mitre_attack_cloud_matrix = attributes[:'mitre_attack_cloud_matrix']
  end

  if attributes.key?(:'mitre_attack_cloud_subtype')
    self.mitre_attack_cloud_subtype = attributes[:'mitre_attack_cloud_subtype']
  end

  if attributes.key?(:'nist_benchmark_ids')
    if (value = attributes[:'nist_benchmark_ids']).is_a?(Array)
      self.nist_benchmark_ids = value
    end
  end

  if attributes.key?(:'pci_benchmark_ids')
    if (value = attributes[:'pci_benchmark_ids']).is_a?(Array)
      self.pci_benchmark_ids = value
    end
  end

  if attributes.key?(:'policy_confidence_score')
    self.policy_confidence_score = attributes[:'policy_confidence_score']
  end

  if attributes.key?(:'policy_fail_query')
    self.policy_fail_query = attributes[:'policy_fail_query']
  end

  if attributes.key?(:'policy_pass_query')
    self.policy_pass_query = attributes[:'policy_pass_query']
  end

  if attributes.key?(:'policy_remediation')
    self.policy_remediation = attributes[:'policy_remediation']
  end

  if attributes.key?(:'policy_severity')
    self.policy_severity = attributes[:'policy_severity']
  end

  if attributes.key?(:'policy_severity_score')
    self.policy_severity_score = attributes[:'policy_severity_score']
  end

  if attributes.key?(:'policy_statement')
    self.policy_statement = attributes[:'policy_statement']
  end

  if attributes.key?(:'policy_type')
    self.policy_type = attributes[:'policy_type']
  end

  if attributes.key?(:'remediation_summary')
    self.remediation_summary = attributes[:'remediation_summary']
  end

  if attributes.key?(:'resource_type_friendly_name')
    self.resource_type_friendly_name = attributes[:'resource_type_friendly_name']
  end

  if attributes.key?(:'resource_type_id')
    self.resource_type_id = attributes[:'resource_type_id']
  end

  if attributes.key?(:'soc2_benchmark_ids')
    if (value = attributes[:'soc2_benchmark_ids']).is_a?(Array)
      self.soc2_benchmark_ids = value
    end
  end

  if attributes.key?(:'tactic')
    self.tactic = attributes[:'tactic']
  end

  if attributes.key?(:'tactic_id')
    self.tactic_id = attributes[:'tactic_id']
  end

  if attributes.key?(:'tactic_url')
    self.tactic_url = attributes[:'tactic_url']
  end

  if attributes.key?(:'technique')
    self.technique = attributes[:'technique']
  end

  if attributes.key?(:'technique_id')
    self.technique_id = attributes[:'technique_id']
  end

  if attributes.key?(:'technique_url')
    self.technique_url = attributes[:'technique_url']
  end
end

Instance Attribute Details

#account_scopeObject

Returns the value of attribute account_scope.



42
43
44
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 42

def 
  @account_scope
end

#alert_logicObject

Returns the value of attribute alert_logic.



44
45
46
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 44

def alert_logic
  @alert_logic
end

#api_commandObject

Returns the value of attribute api_command.



46
47
48
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 46

def api_command
  @api_command
end

#asset_type_idObject

Returns the value of attribute asset_type_id.



48
49
50
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 48

def asset_type_id
  @asset_type_id
end

#attack_toolObject

Returns the value of attribute attack_tool.



50
51
52
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 50

def attack_tool
  @attack_tool
end

#attack_tool_commandObject

Returns the value of attribute attack_tool_command.



52
53
54
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 52

def attack_tool_command
  @attack_tool_command
end

#attack_typesObject

Returns the value of attribute attack_types.



54
55
56
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 54

def attack_types
  @attack_types
end

#cis_benchmark_idsObject

Returns the value of attribute cis_benchmark_ids.



56
57
58
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 56

def cis_benchmark_ids
  @cis_benchmark_ids
end

#cisa_benchmark_idsObject

Returns the value of attribute cisa_benchmark_ids.



58
59
60
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 58

def cisa_benchmark_ids
  @cisa_benchmark_ids
end

#cli_commandObject

Returns the value of attribute cli_command.



60
61
62
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 60

def cli_command
  @cli_command
end

#cloud_asset_typeObject

Returns the value of attribute cloud_asset_type.



62
63
64
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 62

def cloud_asset_type
  @cloud_asset_type
end

#cloud_documentObject

Returns the value of attribute cloud_document.



64
65
66
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 64

def cloud_document
  @cloud_document
end

#cloud_platformObject

Returns the value of attribute cloud_platform.



66
67
68
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 66

def cloud_platform
  @cloud_platform
end

#cloud_platform_typeObject

Returns the value of attribute cloud_platform_type.



68
69
70
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 68

def cloud_platform_type
  @cloud_platform_type
end

#cloud_serviceObject

Returns the value of attribute cloud_service.



70
71
72
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 70

def cloud_service
  @cloud_service
end

#cloud_service_friendlyObject

Returns the value of attribute cloud_service_friendly.



72
73
74
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 72

def cloud_service_friendly
  @cloud_service_friendly
end

#cloud_service_idObject

Returns the value of attribute cloud_service_id.



74
75
76
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 74

def cloud_service_id
  @cloud_service_id
end

#cloud_service_nameObject

Returns the value of attribute cloud_service_name.



76
77
78
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 76

def cloud_service_name
  @cloud_service_name
end

#cloud_service_subtypeObject

Returns the value of attribute cloud_service_subtype.



78
79
80
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 78

def cloud_service_subtype
  @cloud_service_subtype
end

#cloud_service_typeObject

Returns the value of attribute cloud_service_type.



80
81
82
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 80

def cloud_service_type
  @cloud_service_type
end

#complianceObject

Returns the value of attribute compliance.



82
83
84
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 82

def compliance
  @compliance
end

#confidenceObject

Returns the value of attribute confidence.



84
85
86
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 84

def confidence
  @confidence
end

#controlsObject

Returns the value of attribute controls.



86
87
88
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 86

def controls
  @controls
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 34

def created_at
  @created_at
end

#default_severityObject

Returns the value of attribute default_severity.



88
89
90
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 88

def default_severity
  @default_severity
end

#deleted_atObject

Returns the value of attribute deleted_at.



36
37
38
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 36

def deleted_at
  @deleted_at
end

#deprecatedObject

Returns the value of attribute deprecated.



90
91
92
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 90

def deprecated
  @deprecated
end

#descriptionObject

Returns the value of attribute description.



92
93
94
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 92

def description
  @description
end

#event_typeObject

Returns the value of attribute event_type.



94
95
96
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 94

def event_type
  @event_type
end

#fql_policyObject

Returns the value of attribute fql_policy.



96
97
98
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 96

def fql_policy
  @fql_policy
end

#hipaa_benchmark_idsObject

Returns the value of attribute hipaa_benchmark_ids.



98
99
100
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 98

def hipaa_benchmark_ids
  @hipaa_benchmark_ids
end

#hitrust_benchmark_idsObject

Returns the value of attribute hitrust_benchmark_ids.



100
101
102
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 100

def hitrust_benchmark_ids
  @hitrust_benchmark_ids
end

#idObject

Returns the value of attribute id.



38
39
40
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 38

def id
  @id
end

#internal_onlyObject

Returns the value of attribute internal_only.



102
103
104
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 102

def internal_only
  @internal_only
end

#is_enabledObject

Returns the value of attribute is_enabled.



104
105
106
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 104

def is_enabled
  @is_enabled
end

#is_globalObject

Returns the value of attribute is_global.



106
107
108
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 106

def is_global
  @is_global
end

#is_remediableObject

Returns the value of attribute is_remediable.



108
109
110
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 108

def is_remediable
  @is_remediable
end

#iso_benchmark_idsObject

Returns the value of attribute iso_benchmark_ids.



110
111
112
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 110

def iso_benchmark_ids
  @iso_benchmark_ids
end

#mitre_attack_cloud_matrixObject

Returns the value of attribute mitre_attack_cloud_matrix.



112
113
114
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 112

def mitre_attack_cloud_matrix
  @mitre_attack_cloud_matrix
end

#mitre_attack_cloud_subtypeObject

Returns the value of attribute mitre_attack_cloud_subtype.



114
115
116
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 114

def mitre_attack_cloud_subtype
  @mitre_attack_cloud_subtype
end

#nist_benchmark_idsObject

Returns the value of attribute nist_benchmark_ids.



116
117
118
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 116

def nist_benchmark_ids
  @nist_benchmark_ids
end

#pci_benchmark_idsObject

Returns the value of attribute pci_benchmark_ids.



118
119
120
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 118

def pci_benchmark_ids
  @pci_benchmark_ids
end

#policy_confidence_scoreObject

Returns the value of attribute policy_confidence_score.



120
121
122
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 120

def policy_confidence_score
  @policy_confidence_score
end

#policy_fail_queryObject

Returns the value of attribute policy_fail_query.



122
123
124
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 122

def policy_fail_query
  @policy_fail_query
end

#policy_pass_queryObject

Returns the value of attribute policy_pass_query.



124
125
126
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 124

def policy_pass_query
  @policy_pass_query
end

#policy_remediationObject

Returns the value of attribute policy_remediation.



126
127
128
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 126

def policy_remediation
  @policy_remediation
end

#policy_severityObject

Returns the value of attribute policy_severity.



128
129
130
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 128

def policy_severity
  @policy_severity
end

#policy_severity_scoreObject

Returns the value of attribute policy_severity_score.



130
131
132
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 130

def policy_severity_score
  @policy_severity_score
end

#policy_statementObject

Returns the value of attribute policy_statement.



132
133
134
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 132

def policy_statement
  @policy_statement
end

#policy_typeObject

Returns the value of attribute policy_type.



134
135
136
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 134

def policy_type
  @policy_type
end

#remediation_summaryObject

Returns the value of attribute remediation_summary.



136
137
138
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 136

def remediation_summary
  @remediation_summary
end

#resource_type_friendly_nameObject

Returns the value of attribute resource_type_friendly_name.



138
139
140
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 138

def resource_type_friendly_name
  @resource_type_friendly_name
end

#resource_type_idObject

Returns the value of attribute resource_type_id.



140
141
142
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 140

def resource_type_id
  @resource_type_id
end

#soc2_benchmark_idsObject

Returns the value of attribute soc2_benchmark_ids.



142
143
144
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 142

def soc2_benchmark_ids
  @soc2_benchmark_ids
end

#tacticObject

Returns the value of attribute tactic.



144
145
146
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 144

def tactic
  @tactic
end

#tactic_idObject

Returns the value of attribute tactic_id.



146
147
148
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 146

def tactic_id
  @tactic_id
end

#tactic_urlObject

Returns the value of attribute tactic_url.



148
149
150
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 148

def tactic_url
  @tactic_url
end

#techniqueObject

Returns the value of attribute technique.



150
151
152
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 150

def technique
  @technique
end

#technique_idObject

Returns the value of attribute technique_id.



152
153
154
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 152

def technique_id
  @technique_id
end

#technique_urlObject

Returns the value of attribute technique_url.



154
155
156
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 154

def technique_url
  @technique_url
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



224
225
226
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 224

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 157

def self.attribute_map
  {
    :'created_at' => :'CreatedAt',
    :'deleted_at' => :'DeletedAt',
    :'id' => :'ID',
    :'updated_at' => :'UpdatedAt',
    :'account_scope' => :'account_scope',
    :'alert_logic' => :'alert_logic',
    :'api_command' => :'api_command',
    :'asset_type_id' => :'asset_type_id',
    :'attack_tool' => :'attack_tool',
    :'attack_tool_command' => :'attack_tool_command',
    :'attack_types' => :'attack_types',
    :'cis_benchmark_ids' => :'cis_benchmark_ids',
    :'cisa_benchmark_ids' => :'cisa_benchmark_ids',
    :'cli_command' => :'cli_command',
    :'cloud_asset_type' => :'cloud_asset_type',
    :'cloud_document' => :'cloud_document',
    :'cloud_platform' => :'cloud_platform',
    :'cloud_platform_type' => :'cloud_platform_type',
    :'cloud_service' => :'cloud_service',
    :'cloud_service_friendly' => :'cloud_service_friendly',
    :'cloud_service_id' => :'cloud_service_id',
    :'cloud_service_name' => :'cloud_service_name',
    :'cloud_service_subtype' => :'cloud_service_subtype',
    :'cloud_service_type' => :'cloud_service_type',
    :'compliance' => :'compliance',
    :'confidence' => :'confidence',
    :'controls' => :'controls',
    :'default_severity' => :'default_severity',
    :'deprecated' => :'deprecated',
    :'description' => :'description',
    :'event_type' => :'event_type',
    :'fql_policy' => :'fql_policy',
    :'hipaa_benchmark_ids' => :'hipaa_benchmark_ids',
    :'hitrust_benchmark_ids' => :'hitrust_benchmark_ids',
    :'internal_only' => :'internal_only',
    :'is_enabled' => :'is_enabled',
    :'is_global' => :'is_global',
    :'is_remediable' => :'is_remediable',
    :'iso_benchmark_ids' => :'iso_benchmark_ids',
    :'mitre_attack_cloud_matrix' => :'mitre_attack_cloud_matrix',
    :'mitre_attack_cloud_subtype' => :'mitre_attack_cloud_subtype',
    :'nist_benchmark_ids' => :'nist_benchmark_ids',
    :'pci_benchmark_ids' => :'pci_benchmark_ids',
    :'policy_confidence_score' => :'policy_confidence_score',
    :'policy_fail_query' => :'policy_fail_query',
    :'policy_pass_query' => :'policy_pass_query',
    :'policy_remediation' => :'policy_remediation',
    :'policy_severity' => :'policy_severity',
    :'policy_severity_score' => :'policy_severity_score',
    :'policy_statement' => :'policy_statement',
    :'policy_type' => :'policy_type',
    :'remediation_summary' => :'remediation_summary',
    :'resource_type_friendly_name' => :'resource_type_friendly_name',
    :'resource_type_id' => :'resource_type_id',
    :'soc2_benchmark_ids' => :'soc2_benchmark_ids',
    :'tactic' => :'tactic',
    :'tactic_id' => :'tactic_id',
    :'tactic_url' => :'tactic_url',
    :'technique' => :'technique',
    :'technique_id' => :'technique_id',
    :'technique_url' => :'technique_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



712
713
714
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 712

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



296
297
298
299
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 296

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 229

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'id' => :'Integer',
    :'updated_at' => :'Time',
    :'account_scope' => :'String',
    :'alert_logic' => :'String',
    :'api_command' => :'String',
    :'asset_type_id' => :'Integer',
    :'attack_tool' => :'String',
    :'attack_tool_command' => :'String',
    :'attack_types' => :'Array<String>',
    :'cis_benchmark_ids' => :'Array<Integer>',
    :'cisa_benchmark_ids' => :'Array<Integer>',
    :'cli_command' => :'String',
    :'cloud_asset_type' => :'String',
    :'cloud_document' => :'String',
    :'cloud_platform' => :'Integer',
    :'cloud_platform_type' => :'String',
    :'cloud_service' => :'Integer',
    :'cloud_service_friendly' => :'String',
    :'cloud_service_id' => :'Integer',
    :'cloud_service_name' => :'String',
    :'cloud_service_subtype' => :'String',
    :'cloud_service_type' => :'String',
    :'compliance' => :'DomainCompliance',
    :'confidence' => :'String',
    :'controls' => :'Array<DomainControl>',
    :'default_severity' => :'String',
    :'deprecated' => :'Boolean',
    :'description' => :'String',
    :'event_type' => :'String',
    :'fql_policy' => :'String',
    :'hipaa_benchmark_ids' => :'Array<Integer>',
    :'hitrust_benchmark_ids' => :'Array<Integer>',
    :'internal_only' => :'Boolean',
    :'is_enabled' => :'Boolean',
    :'is_global' => :'Boolean',
    :'is_remediable' => :'Boolean',
    :'iso_benchmark_ids' => :'Array<Integer>',
    :'mitre_attack_cloud_matrix' => :'String',
    :'mitre_attack_cloud_subtype' => :'String',
    :'nist_benchmark_ids' => :'Array<Integer>',
    :'pci_benchmark_ids' => :'Array<Integer>',
    :'policy_confidence_score' => :'Integer',
    :'policy_fail_query' => :'String',
    :'policy_pass_query' => :'String',
    :'policy_remediation' => :'String',
    :'policy_severity' => :'Integer',
    :'policy_severity_score' => :'Integer',
    :'policy_statement' => :'String',
    :'policy_type' => :'String',
    :'remediation_summary' => :'String',
    :'resource_type_friendly_name' => :'String',
    :'resource_type_id' => :'String',
    :'soc2_benchmark_ids' => :'Array<Integer>',
    :'tactic' => :'String',
    :'tactic_id' => :'String',
    :'tactic_url' => :'String',
    :'technique' => :'String',
    :'technique_id' => :'String',
    :'technique_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 631

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      id == o.id &&
      updated_at == o.updated_at &&
       == o. &&
      alert_logic == o.alert_logic &&
      api_command == o.api_command &&
      asset_type_id == o.asset_type_id &&
      attack_tool == o.attack_tool &&
      attack_tool_command == o.attack_tool_command &&
      attack_types == o.attack_types &&
      cis_benchmark_ids == o.cis_benchmark_ids &&
      cisa_benchmark_ids == o.cisa_benchmark_ids &&
      cli_command == o.cli_command &&
      cloud_asset_type == o.cloud_asset_type &&
      cloud_document == o.cloud_document &&
      cloud_platform == o.cloud_platform &&
      cloud_platform_type == o.cloud_platform_type &&
      cloud_service == o.cloud_service &&
      cloud_service_friendly == o.cloud_service_friendly &&
      cloud_service_id == o.cloud_service_id &&
      cloud_service_name == o.cloud_service_name &&
      cloud_service_subtype == o.cloud_service_subtype &&
      cloud_service_type == o.cloud_service_type &&
      compliance == o.compliance &&
      confidence == o.confidence &&
      controls == o.controls &&
      default_severity == o.default_severity &&
      deprecated == o.deprecated &&
      description == o.description &&
      event_type == o.event_type &&
      fql_policy == o.fql_policy &&
      hipaa_benchmark_ids == o.hipaa_benchmark_ids &&
      hitrust_benchmark_ids == o.hitrust_benchmark_ids &&
      internal_only == o.internal_only &&
      is_enabled == o.is_enabled &&
      is_global == o.is_global &&
      is_remediable == o.is_remediable &&
      iso_benchmark_ids == o.iso_benchmark_ids &&
      mitre_attack_cloud_matrix == o.mitre_attack_cloud_matrix &&
      mitre_attack_cloud_subtype == o.mitre_attack_cloud_subtype &&
      nist_benchmark_ids == o.nist_benchmark_ids &&
      pci_benchmark_ids == o.pci_benchmark_ids &&
      policy_confidence_score == o.policy_confidence_score &&
      policy_fail_query == o.policy_fail_query &&
      policy_pass_query == o.policy_pass_query &&
      policy_remediation == o.policy_remediation &&
      policy_severity == o.policy_severity &&
      policy_severity_score == o.policy_severity_score &&
      policy_statement == o.policy_statement &&
      policy_type == o.policy_type &&
      remediation_summary == o.remediation_summary &&
      resource_type_friendly_name == o.resource_type_friendly_name &&
      resource_type_id == o.resource_type_id &&
      soc2_benchmark_ids == o.soc2_benchmark_ids &&
      tactic == o.tactic &&
      tactic_id == o.tactic_id &&
      tactic_url == o.tactic_url &&
      technique == o.technique &&
      technique_id == o.technique_id &&
      technique_url == o.technique_url
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 743

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



814
815
816
817
818
819
820
821
822
823
824
825
826
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 814

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 719

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


699
700
701
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 699

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



705
706
707
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 705

def hash
  [created_at, deleted_at, id, updated_at, , alert_logic, api_command, asset_type_id, attack_tool, attack_tool_command, attack_types, cis_benchmark_ids, cisa_benchmark_ids, cli_command, cloud_asset_type, cloud_document, cloud_platform, cloud_platform_type, cloud_service, cloud_service_friendly, cloud_service_id, cloud_service_name, cloud_service_subtype, cloud_service_type, compliance, confidence, controls, default_severity, deprecated, description, event_type, fql_policy, hipaa_benchmark_ids, hitrust_benchmark_ids, internal_only, is_enabled, is_global, is_remediable, iso_benchmark_ids, mitre_attack_cloud_matrix, mitre_attack_cloud_subtype, nist_benchmark_ids, pci_benchmark_ids, policy_confidence_score, policy_fail_query, policy_pass_query, policy_remediation, policy_severity, policy_severity_score, policy_statement, policy_type, remediation_summary, resource_type_friendly_name, resource_type_id, soc2_benchmark_ids, tactic, tactic_id, tactic_url, technique, technique_id, technique_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 583

def list_invalid_properties
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @deleted_at.nil?
    invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @account_scope.nil?
    invalid_properties.push('invalid value for "account_scope", account_scope cannot be nil.')
  end

  if @is_enabled.nil?
    invalid_properties.push('invalid value for "is_enabled", is_enabled cannot be nil.')
  end

  if @is_remediable.nil?
    invalid_properties.push('invalid value for "is_remediable", is_remediable cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



790
791
792
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 790

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



796
797
798
799
800
801
802
803
804
805
806
807
808
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 796

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



784
785
786
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 784

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



618
619
620
621
622
623
624
625
626
627
# File 'lib/crimson-falcon/models/domain_policy_info.rb', line 618

def valid?
  return false if @created_at.nil?
  return false if @deleted_at.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  return false if @account_scope.nil?
  return false if @is_enabled.nil?
  return false if @is_remediable.nil?
  true
end