Class: Falcon::DomainReportExecutionSummaryV1
- Inherits:
-
Object
- Object
- Falcon::DomainReportExecutionSummaryV1
- Defined in:
- lib/crimson-falcon/models/domain_report_execution_summary_v1.rb
Instance Attribute Summary collapse
-
#execution_metadata ⇒ Object
Returns the value of attribute execution_metadata.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_updated_on ⇒ Object
Returns the value of attribute last_updated_on.
-
#report_file_reference ⇒ Object
Returns the value of attribute report_file_reference.
-
#report_params ⇒ Object
Returns the value of attribute report_params.
-
#result_metadata ⇒ Object
Returns the value of attribute result_metadata.
-
#status ⇒ Object
Returns the value of attribute status.
-
#status_display ⇒ Object
Returns the value of attribute status_display.
-
#status_msg ⇒ Object
Returns the value of attribute status_msg.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainReportExecutionSummaryV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainReportExecutionSummaryV1
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainReportExecutionSummaryV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainReportExecutionSummaryV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'execution_metadata') self. = attributes[:'execution_metadata'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'last_updated_on') self.last_updated_on = attributes[:'last_updated_on'] end if attributes.key?(:'report_file_reference') self.report_file_reference = attributes[:'report_file_reference'] end if attributes.key?(:'report_params') self.report_params = attributes[:'report_params'] end if attributes.key?(:'result_metadata') self. = attributes[:'result_metadata'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'status_display') self.status_display = attributes[:'status_display'] end if attributes.key?(:'status_msg') self.status_msg = attributes[:'status_msg'] end end |
Instance Attribute Details
#execution_metadata ⇒ Object
Returns the value of attribute execution_metadata.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 34 def @execution_metadata end |
#id ⇒ Object
Returns the value of attribute id.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 36 def id @id end |
#last_updated_on ⇒ Object
Returns the value of attribute last_updated_on.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 38 def last_updated_on @last_updated_on end |
#report_file_reference ⇒ Object
Returns the value of attribute report_file_reference.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 40 def report_file_reference @report_file_reference end |
#report_params ⇒ Object
Returns the value of attribute report_params.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 42 def report_params @report_params end |
#result_metadata ⇒ Object
Returns the value of attribute result_metadata.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 44 def @result_metadata end |
#status ⇒ Object
Returns the value of attribute status.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 46 def status @status end |
#status_display ⇒ Object
Returns the value of attribute status_display.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 48 def status_display @status_display end |
#status_msg ⇒ Object
Returns the value of attribute status_msg.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 50 def status_msg @status_msg end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 53 def self.attribute_map { :'execution_metadata' => :'execution_metadata', :'id' => :'id', :'last_updated_on' => :'last_updated_on', :'report_file_reference' => :'report_file_reference', :'report_params' => :'report_params', :'result_metadata' => :'result_metadata', :'status' => :'status', :'status_display' => :'status_display', :'status_msg' => :'status_msg' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 224 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 73 def self.openapi_types { :'execution_metadata' => :'DomainExecutionMetadataSummary', :'id' => :'String', :'last_updated_on' => :'Time', :'report_file_reference' => :'String', :'report_params' => :'DomainReportParams', :'result_metadata' => :'DomainResultMetadata', :'status' => :'String', :'status_display' => :'String', :'status_msg' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && id == o.id && last_updated_on == o.last_updated_on && report_file_reference == o.report_file_reference && report_params == o.report_params && == o. && status == o.status && status_display == o.status_display && status_msg == o.status_msg end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 255 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 326 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 217 def hash [, id, last_updated_on, report_file_reference, report_params, , status, status_display, status_msg].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 147 def list_invalid_properties invalid_properties = Array.new if @execution_metadata.nil? invalid_properties.push('invalid value for "execution_metadata", execution_metadata cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @last_updated_on.nil? invalid_properties.push('invalid value for "last_updated_on", last_updated_on cannot be nil.') end if @report_params.nil? invalid_properties.push('invalid value for "report_params", report_params cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @status_display.nil? invalid_properties.push('invalid value for "status_display", status_display cannot be nil.') end if @status_msg.nil? invalid_properties.push('invalid value for "status_msg", status_msg cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
302 303 304 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 302 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 296 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 185 186 187 188 189 190 191 |
# File 'lib/crimson-falcon/models/domain_report_execution_summary_v1.rb', line 182 def valid? return false if @execution_metadata.nil? return false if @id.nil? return false if @last_updated_on.nil? return false if @report_params.nil? return false if @status.nil? return false if @status_display.nil? return false if @status_msg.nil? true end |