Class: Falcon::DomainReportMetadata

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_report_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainReportMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainReportMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainReportMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_by_user_id')
    self.created_by_user_id = attributes[:'created_by_user_id']
  end

  if attributes.key?(:'created_by_uuid')
    self.created_by_uuid = attributes[:'created_by_uuid']
  end

  if attributes.key?(:'discover_params')
    self.discover_params = attributes[:'discover_params']
  end

  if attributes.key?(:'kestrel_data_export_params')
    self.kestrel_data_export_params = attributes[:'kestrel_data_export_params']
  end

  if attributes.key?(:'kestrel_params')
    self.kestrel_params = attributes[:'kestrel_params']
  end

  if attributes.key?(:'last_scheduled_execution')
    self.last_scheduled_execution = attributes[:'last_scheduled_execution']
  end

  if attributes.key?(:'last_unscheduled_execution')
    self.last_unscheduled_execution = attributes[:'last_unscheduled_execution']
  end

  if attributes.key?(:'subtype')
    self.subtype = attributes[:'subtype']
  end

  if attributes.key?(:'xdr_params')
    self.xdr_params = attributes[:'xdr_params']
  end
end

Instance Attribute Details

#created_by_user_idObject

Returns the value of attribute created_by_user_id.



34
35
36
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 34

def created_by_user_id
  @created_by_user_id
end

#created_by_uuidObject

Returns the value of attribute created_by_uuid.



36
37
38
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 36

def created_by_uuid
  @created_by_uuid
end

#discover_paramsObject

Returns the value of attribute discover_params.



38
39
40
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 38

def discover_params
  @discover_params
end

#kestrel_data_export_paramsObject

Returns the value of attribute kestrel_data_export_params.



40
41
42
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 40

def kestrel_data_export_params
  @kestrel_data_export_params
end

#kestrel_paramsObject

Returns the value of attribute kestrel_params.



42
43
44
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 42

def kestrel_params
  @kestrel_params
end

#last_scheduled_executionObject

Returns the value of attribute last_scheduled_execution.



44
45
46
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 44

def last_scheduled_execution
  @last_scheduled_execution
end

#last_unscheduled_executionObject

Returns the value of attribute last_unscheduled_execution.



46
47
48
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 46

def last_unscheduled_execution
  @last_unscheduled_execution
end

#subtypeObject

Returns the value of attribute subtype.



48
49
50
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 48

def subtype
  @subtype
end

#xdr_paramsObject

Returns the value of attribute xdr_params.



50
51
52
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 50

def xdr_params
  @xdr_params
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 53

def self.attribute_map
  {
    :'created_by_user_id' => :'created_by_user_id',
    :'created_by_uuid' => :'created_by_uuid',
    :'discover_params' => :'discover_params',
    :'kestrel_data_export_params' => :'kestrel_data_export_params',
    :'kestrel_params' => :'kestrel_params',
    :'last_scheduled_execution' => :'last_scheduled_execution',
    :'last_unscheduled_execution' => :'last_unscheduled_execution',
    :'subtype' => :'subtype',
    :'xdr_params' => :'xdr_params'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 209

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 73

def self.openapi_types
  {
    :'created_by_user_id' => :'String',
    :'created_by_uuid' => :'String',
    :'discover_params' => :'DomainDiscoverParams',
    :'kestrel_data_export_params' => :'DomainKestrelDataExportParams',
    :'kestrel_params' => :'DomainKestrelParams',
    :'last_scheduled_execution' => :'DomainLastScheduledExecution',
    :'last_unscheduled_execution' => :'DomainLastUnscheduledExecution',
    :'subtype' => :'String',
    :'xdr_params' => :'DomainXDRParams'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_by_user_id == o.created_by_user_id &&
      created_by_uuid == o.created_by_uuid &&
      discover_params == o.discover_params &&
      kestrel_data_export_params == o.kestrel_data_export_params &&
      kestrel_params == o.kestrel_params &&
      last_scheduled_execution == o.last_scheduled_execution &&
      last_unscheduled_execution == o.last_unscheduled_execution &&
      subtype == o.subtype &&
      xdr_params == o.xdr_params
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 240

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 311

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 216

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 202

def hash
  [created_by_user_id, created_by_uuid, discover_params, kestrel_data_export_params, kestrel_params, last_scheduled_execution, last_unscheduled_execution, subtype, xdr_params].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 147

def list_invalid_properties
  invalid_properties = Array.new
  if @created_by_user_id.nil?
    invalid_properties.push('invalid value for "created_by_user_id", created_by_user_id cannot be nil.')
  end

  if @created_by_uuid.nil?
    invalid_properties.push('invalid value for "created_by_uuid", created_by_uuid cannot be nil.')
  end

  if @last_unscheduled_execution.nil?
    invalid_properties.push('invalid value for "last_unscheduled_execution", last_unscheduled_execution cannot be nil.')
  end

  if @subtype.nil?
    invalid_properties.push('invalid value for "subtype", subtype cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 287

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 281

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
# File 'lib/crimson-falcon/models/domain_report_metadata.rb', line 170

def valid?
  return false if @created_by_user_id.nil?
  return false if @created_by_uuid.nil?
  return false if @last_unscheduled_execution.nil?
  return false if @subtype.nil?
  true
end