Class: Falcon::DomainScanScheduling

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_scan_scheduling.rb

Overview

Represents scan scheduling configuration

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainScanScheduling

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainScanScheduling` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainScanScheduling`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'days_of_month')
    if (value = attributes[:'days_of_month']).is_a?(Array)
      self.days_of_month = value
    end
  end

  if attributes.key?(:'days_of_week')
    if (value = attributes[:'days_of_week']).is_a?(Array)
      self.days_of_week = value
    end
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'frequency')
    self.frequency = attributes[:'frequency']
  end

  if attributes.key?(:'occurrence')
    self.occurrence = attributes[:'occurrence']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'timeout_seconds')
    self.timeout_seconds = attributes[:'timeout_seconds']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end
end

Instance Attribute Details

#days_of_monthObject

The days of the month that scan created will run on. Valid range: 1-31



36
37
38
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 36

def days_of_month
  @days_of_month
end

#days_of_weekObject

The days of the week that scan created will run on



39
40
41
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 39

def days_of_week
  @days_of_week
end

#end_dateObject

The date at which scans created will end running



42
43
44
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 42

def end_date
  @end_date
end

#frequencyObject

The frequency of the scan scheduling configuration



45
46
47
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 45

def frequency
  @frequency
end

#occurrenceObject

The occurrence of the scan scheduling configuration



48
49
50
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 48

def occurrence
  @occurrence
end

#start_dateObject

The date at which scans created will start running



51
52
53
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 51

def start_date
  @start_date
end

#start_timeObject

The time at which scans created will start running



54
55
56
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 54

def start_time
  @start_time
end

#timeout_secondsObject

The timeout seconds of the scan scheduling configuration



57
58
59
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 57

def timeout_seconds
  @timeout_seconds
end

#timezoneObject

The timezone used to identify the scan scheduling configuration



60
61
62
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 60

def timezone
  @timezone
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 100

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 85

def self.attribute_map
  {
    :'days_of_month' => :'days_of_month',
    :'days_of_week' => :'days_of_week',
    :'end_date' => :'end_date',
    :'frequency' => :'frequency',
    :'occurrence' => :'occurrence',
    :'start_date' => :'start_date',
    :'start_time' => :'start_time',
    :'timeout_seconds' => :'timeout_seconds',
    :'timezone' => :'timezone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 264

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 105

def self.openapi_types
  {
    :'days_of_month' => :'Array<Integer>',
    :'days_of_week' => :'Array<Integer>',
    :'end_date' => :'String',
    :'frequency' => :'String',
    :'occurrence' => :'String',
    :'start_date' => :'String',
    :'start_time' => :'String',
    :'timeout_seconds' => :'Integer',
    :'timezone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      days_of_month == o.days_of_month &&
      days_of_week == o.days_of_week &&
      end_date == o.end_date &&
      frequency == o.frequency &&
      occurrence == o.occurrence &&
      start_date == o.start_date &&
      start_time == o.start_time &&
      timeout_seconds == o.timeout_seconds &&
      timezone == o.timezone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 295

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 366

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 271

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 251

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



257
258
259
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 257

def hash
  [days_of_month, days_of_week, end_date, frequency, occurrence, start_date, start_time, timeout_seconds, timezone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  if @frequency.nil?
    invalid_properties.push('invalid value for "frequency", frequency cannot be nil.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @start_time.nil?
    invalid_properties.push('invalid value for "start_time", start_time cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
# File 'lib/crimson-falcon/models/domain_scan_scheduling.rb', line 202

def valid?
  return false if @frequency.nil?
  frequency_validator = EnumAttributeValidator.new('String', ["once,daily,weekly,monthly"])
  return false unless frequency_validator.valid?(@frequency)
  occurrence_validator = EnumAttributeValidator.new('String', ["Day(s),First,Second,Third,Fourth,Last"])
  return false unless occurrence_validator.valid?(@occurrence)
  return false if @start_date.nil?
  return false if @start_time.nil?
  true
end