Class: Falcon::DomainScanner
- Inherits:
-
Object
- Object
- Falcon::DomainScanner
- Defined in:
- lib/crimson-falcon/models/domain_scanner.rb
Overview
Represents a scanner entity
Instance Attribute Summary collapse
-
#agent_version ⇒ Object
The agent version of the scanner.
-
#aid ⇒ Object
The AID of the scanner.
-
#available_disk_space ⇒ Object
The available disk space of the scanner.
-
#available_disk_space_pct ⇒ Object
The available disk space percentage of the scanner.
-
#average_memory_usage ⇒ Object
The average memory usage of the scanner.
-
#average_memory_usage_pct ⇒ Object
The average memory usage percentage of the scanner.
-
#average_processor_usage ⇒ Object
The average processor usage of the scanner.
-
#hostname ⇒ Object
The hostname of the scanner.
-
#id ⇒ Object
The ID of the scanner.
-
#last_seen_network_id ⇒ Object
The last network ID of the scanner.
-
#last_seen_timestamp ⇒ Object
The last seen timestamp of the scanner.
-
#last_seen_zone_id ⇒ Object
The last zone ID of the scanner.
-
#local_ip ⇒ Object
The local IP address of the scanner.
-
#max_memory_usage ⇒ Object
The max memory usage of the scanner.
-
#max_memory_usage_pct ⇒ Object
The max memory usage percentage of the scanner.
-
#max_processor_usage ⇒ Object
The max processor usage of the scanner.
-
#network_ids ⇒ Object
The network IDs of the scanner.
-
#os_version ⇒ Object
The OS version of the scanner.
-
#platform_name ⇒ Object
The platform name of the scanner.
-
#product_type_desc ⇒ Object
The product type of the scanner.
-
#used_disk_space ⇒ Object
The used disk space of the scanner.
-
#used_disk_space_pct ⇒ Object
The used disk space percentage of the scanner.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainScanner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainScanner
Initializes the object
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 170 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainScanner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainScanner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agent_version') self.agent_version = attributes[:'agent_version'] end if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'available_disk_space') self.available_disk_space = attributes[:'available_disk_space'] end if attributes.key?(:'available_disk_space_pct') self.available_disk_space_pct = attributes[:'available_disk_space_pct'] end if attributes.key?(:'average_memory_usage') self.average_memory_usage = attributes[:'average_memory_usage'] end if attributes.key?(:'average_memory_usage_pct') self.average_memory_usage_pct = attributes[:'average_memory_usage_pct'] end if attributes.key?(:'average_processor_usage') self.average_processor_usage = attributes[:'average_processor_usage'] end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'last_seen_network_id') self.last_seen_network_id = attributes[:'last_seen_network_id'] end if attributes.key?(:'last_seen_timestamp') self. = attributes[:'last_seen_timestamp'] end if attributes.key?(:'last_seen_zone_id') self.last_seen_zone_id = attributes[:'last_seen_zone_id'] end if attributes.key?(:'local_ip') self.local_ip = attributes[:'local_ip'] end if attributes.key?(:'max_memory_usage') self.max_memory_usage = attributes[:'max_memory_usage'] end if attributes.key?(:'max_memory_usage_pct') self.max_memory_usage_pct = attributes[:'max_memory_usage_pct'] end if attributes.key?(:'max_processor_usage') self.max_processor_usage = attributes[:'max_processor_usage'] end if attributes.key?(:'network_ids') if (value = attributes[:'network_ids']).is_a?(Array) self.network_ids = value end end if attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'product_type_desc') self.product_type_desc = attributes[:'product_type_desc'] end if attributes.key?(:'used_disk_space') self.used_disk_space = attributes[:'used_disk_space'] end if attributes.key?(:'used_disk_space_pct') self.used_disk_space_pct = attributes[:'used_disk_space_pct'] end end |
Instance Attribute Details
#agent_version ⇒ Object
The agent version of the scanner
36 37 38 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 36 def agent_version @agent_version end |
#aid ⇒ Object
The AID of the scanner
39 40 41 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 39 def aid @aid end |
#available_disk_space ⇒ Object
The available disk space of the scanner
42 43 44 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 42 def available_disk_space @available_disk_space end |
#available_disk_space_pct ⇒ Object
The available disk space percentage of the scanner
45 46 47 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 45 def available_disk_space_pct @available_disk_space_pct end |
#average_memory_usage ⇒ Object
The average memory usage of the scanner
48 49 50 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 48 def average_memory_usage @average_memory_usage end |
#average_memory_usage_pct ⇒ Object
The average memory usage percentage of the scanner
51 52 53 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 51 def average_memory_usage_pct @average_memory_usage_pct end |
#average_processor_usage ⇒ Object
The average processor usage of the scanner
54 55 56 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 54 def average_processor_usage @average_processor_usage end |
#hostname ⇒ Object
The hostname of the scanner
57 58 59 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 57 def hostname @hostname end |
#id ⇒ Object
The ID of the scanner
60 61 62 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 60 def id @id end |
#last_seen_network_id ⇒ Object
The last network ID of the scanner
63 64 65 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 63 def last_seen_network_id @last_seen_network_id end |
#last_seen_timestamp ⇒ Object
The last seen timestamp of the scanner
66 67 68 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 66 def @last_seen_timestamp end |
#last_seen_zone_id ⇒ Object
The last zone ID of the scanner
69 70 71 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 69 def last_seen_zone_id @last_seen_zone_id end |
#local_ip ⇒ Object
The local IP address of the scanner
72 73 74 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 72 def local_ip @local_ip end |
#max_memory_usage ⇒ Object
The max memory usage of the scanner
75 76 77 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 75 def max_memory_usage @max_memory_usage end |
#max_memory_usage_pct ⇒ Object
The max memory usage percentage of the scanner
78 79 80 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 78 def max_memory_usage_pct @max_memory_usage_pct end |
#max_processor_usage ⇒ Object
The max processor usage of the scanner
81 82 83 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 81 def max_processor_usage @max_processor_usage end |
#network_ids ⇒ Object
The network IDs of the scanner
84 85 86 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 84 def network_ids @network_ids end |
#os_version ⇒ Object
The OS version of the scanner
87 88 89 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 87 def os_version @os_version end |
#platform_name ⇒ Object
The platform name of the scanner
90 91 92 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 90 def platform_name @platform_name end |
#product_type_desc ⇒ Object
The product type of the scanner
93 94 95 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 93 def product_type_desc @product_type_desc end |
#used_disk_space ⇒ Object
The used disk space of the scanner
96 97 98 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 96 def used_disk_space @used_disk_space end |
#used_disk_space_pct ⇒ Object
The used disk space percentage of the scanner
99 100 101 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 99 def used_disk_space_pct @used_disk_space_pct end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
130 131 132 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 130 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 102 def self.attribute_map { :'agent_version' => :'agent_version', :'aid' => :'aid', :'available_disk_space' => :'available_disk_space', :'available_disk_space_pct' => :'available_disk_space_pct', :'average_memory_usage' => :'average_memory_usage', :'average_memory_usage_pct' => :'average_memory_usage_pct', :'average_processor_usage' => :'average_processor_usage', :'hostname' => :'hostname', :'id' => :'id', :'last_seen_network_id' => :'last_seen_network_id', :'last_seen_timestamp' => :'last_seen_timestamp', :'last_seen_zone_id' => :'last_seen_zone_id', :'local_ip' => :'local_ip', :'max_memory_usage' => :'max_memory_usage', :'max_memory_usage_pct' => :'max_memory_usage_pct', :'max_processor_usage' => :'max_processor_usage', :'network_ids' => :'network_ids', :'os_version' => :'os_version', :'platform_name' => :'platform_name', :'product_type_desc' => :'product_type_desc', :'used_disk_space' => :'used_disk_space', :'used_disk_space_pct' => :'used_disk_space_pct' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
371 372 373 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 371 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
163 164 165 166 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 163 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 135 def self.openapi_types { :'agent_version' => :'String', :'aid' => :'String', :'available_disk_space' => :'Integer', :'available_disk_space_pct' => :'Integer', :'average_memory_usage' => :'Integer', :'average_memory_usage_pct' => :'Integer', :'average_processor_usage' => :'Integer', :'hostname' => :'String', :'id' => :'String', :'last_seen_network_id' => :'String', :'last_seen_timestamp' => :'String', :'last_seen_zone_id' => :'String', :'local_ip' => :'String', :'max_memory_usage' => :'Integer', :'max_memory_usage_pct' => :'Integer', :'max_processor_usage' => :'Integer', :'network_ids' => :'Array<String>', :'os_version' => :'String', :'platform_name' => :'String', :'product_type_desc' => :'String', :'used_disk_space' => :'Integer', :'used_disk_space_pct' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 329 def ==(o) return true if self.equal?(o) self.class == o.class && agent_version == o.agent_version && aid == o.aid && available_disk_space == o.available_disk_space && available_disk_space_pct == o.available_disk_space_pct && average_memory_usage == o.average_memory_usage && average_memory_usage_pct == o.average_memory_usage_pct && average_processor_usage == o.average_processor_usage && hostname == o.hostname && id == o.id && last_seen_network_id == o.last_seen_network_id && == o. && last_seen_zone_id == o.last_seen_zone_id && local_ip == o.local_ip && max_memory_usage == o.max_memory_usage && max_memory_usage_pct == o.max_memory_usage_pct && max_processor_usage == o.max_processor_usage && network_ids == o.network_ids && os_version == o.os_version && platform_name == o.platform_name && product_type_desc == o.product_type_desc && used_disk_space == o.used_disk_space && used_disk_space_pct == o.used_disk_space_pct end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 402 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 473 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 378 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
358 359 360 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 358 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 364 def hash [agent_version, aid, available_disk_space, available_disk_space_pct, average_memory_usage, average_memory_usage_pct, average_processor_usage, hostname, id, last_seen_network_id, , last_seen_zone_id, local_ip, max_memory_usage, max_memory_usage_pct, max_processor_usage, network_ids, os_version, platform_name, product_type_desc, used_disk_space, used_disk_space_pct].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 276 def list_invalid_properties invalid_properties = Array.new if @agent_version.nil? invalid_properties.push('invalid value for "agent_version", agent_version cannot be nil.') end if @aid.nil? invalid_properties.push('invalid value for "aid", aid cannot be nil.') end if @hostname.nil? invalid_properties.push('invalid value for "hostname", hostname cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @local_ip.nil? invalid_properties.push('invalid value for "local_ip", local_ip cannot be nil.') end if @network_ids.nil? invalid_properties.push('invalid value for "network_ids", network_ids cannot be nil.') end if @os_version.nil? invalid_properties.push('invalid value for "os_version", os_version cannot be nil.') end if @platform_name.nil? invalid_properties.push('invalid value for "platform_name", platform_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
449 450 451 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 449 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 455 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
443 444 445 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 443 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/crimson-falcon/models/domain_scanner.rb', line 315 def valid? return false if @agent_version.nil? return false if @aid.nil? return false if @hostname.nil? return false if @id.nil? return false if @local_ip.nil? return false if @network_ids.nil? return false if @os_version.nil? return false if @platform_name.nil? true end |