Class: Falcon::DomainScheduledReportV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_scheduled_report_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainScheduledReportV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 171

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainScheduledReportV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainScheduledReportV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'api_client_id')
    self.api_client_id = attributes[:'api_client_id']
  end

  if attributes.key?(:'can_write')
    self.can_write = attributes[:'can_write']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'expiration_on')
    self.expiration_on = attributes[:'expiration_on']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_execution')
    self.last_execution = attributes[:'last_execution']
  end

  if attributes.key?(:'last_updated_on')
    self.last_updated_on = attributes[:'last_updated_on']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'next_execution_on')
    self.next_execution_on = attributes[:'next_execution_on']
  end

  if attributes.key?(:'notifications')
    if (value = attributes[:'notifications']).is_a?(Array)
      self.notifications = value
    end
  end

  if attributes.key?(:'owned_by_cs')
    self.owned_by_cs = attributes[:'owned_by_cs']
  end

  if attributes.key?(:'report_metadata')
    self. = attributes[:'report_metadata']
  end

  if attributes.key?(:'report_params')
    self.report_params = attributes[:'report_params']
  end

  if attributes.key?(:'schedule')
    self.schedule = attributes[:'schedule']
  end

  if attributes.key?(:'schedule_type')
    self.schedule_type = attributes[:'schedule_type']
  end

  if attributes.key?(:'secret_references')
    self.secret_references = attributes[:'secret_references']
  end

  if attributes.key?(:'shared_with')
    if (value = attributes[:'shared_with']).is_a?(Array)
      self.shared_with = value
    end
  end

  if attributes.key?(:'start_on')
    self.start_on = attributes[:'start_on']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'stop_on')
    self.stop_on = attributes[:'stop_on']
  end

  if attributes.key?(:'stopped_by_cs')
    self.stopped_by_cs = attributes[:'stopped_by_cs']
  end

  if attributes.key?(:'tracking')
    self.tracking = attributes[:'tracking']
  end

  if attributes.key?(:'trigger_reference')
    self.trigger_reference = attributes[:'trigger_reference']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_uuid')
    self.user_uuid = attributes[:'user_uuid']
  end
end

Instance Attribute Details

#api_client_idObject

Returns the value of attribute api_client_id.



34
35
36
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 34

def api_client_id
  @api_client_id
end

#can_writeObject

Returns the value of attribute can_write.



36
37
38
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 36

def can_write
  @can_write
end

#created_onObject

Returns the value of attribute created_on.



38
39
40
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 38

def created_on
  @created_on
end

#customer_idObject

Returns the value of attribute customer_id.



40
41
42
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 40

def customer_id
  @customer_id
end

#descriptionObject

Returns the value of attribute description.



42
43
44
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 42

def description
  @description
end

#expiration_onObject

Returns the value of attribute expiration_on.



44
45
46
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 44

def expiration_on
  @expiration_on
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 46

def id
  @id
end

#last_executionObject

Returns the value of attribute last_execution.



48
49
50
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 48

def last_execution
  @last_execution
end

#last_updated_onObject

Returns the value of attribute last_updated_on.



50
51
52
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 50

def last_updated_on
  @last_updated_on
end

#nameObject

Returns the value of attribute name.



52
53
54
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 52

def name
  @name
end

#next_execution_onObject

Returns the value of attribute next_execution_on.



54
55
56
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 54

def next_execution_on
  @next_execution_on
end

#notificationsObject

Returns the value of attribute notifications.



56
57
58
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 56

def notifications
  @notifications
end

#owned_by_csObject

Returns the value of attribute owned_by_cs.



58
59
60
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 58

def owned_by_cs
  @owned_by_cs
end

#report_metadataObject

Returns the value of attribute report_metadata.



60
61
62
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 60

def 
  @report_metadata
end

#report_paramsObject

Returns the value of attribute report_params.



62
63
64
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 62

def report_params
  @report_params
end

#scheduleObject

Returns the value of attribute schedule.



64
65
66
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 64

def schedule
  @schedule
end

#schedule_typeObject

Returns the value of attribute schedule_type.



66
67
68
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 66

def schedule_type
  @schedule_type
end

#secret_referencesObject

Returns the value of attribute secret_references.



68
69
70
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 68

def secret_references
  @secret_references
end

#shared_withObject

Returns the value of attribute shared_with.



70
71
72
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 70

def shared_with
  @shared_with
end

#start_onObject

Returns the value of attribute start_on.



72
73
74
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 72

def start_on
  @start_on
end

#statusObject

Returns the value of attribute status.



74
75
76
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 74

def status
  @status
end

#stop_onObject

Returns the value of attribute stop_on.



76
77
78
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 76

def stop_on
  @stop_on
end

#stopped_by_csObject

Returns the value of attribute stopped_by_cs.



78
79
80
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 78

def stopped_by_cs
  @stopped_by_cs
end

#trackingObject

Returns the value of attribute tracking.



80
81
82
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 80

def tracking
  @tracking
end

#trigger_referenceObject

Returns the value of attribute trigger_reference.



82
83
84
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 82

def trigger_reference
  @trigger_reference
end

#typeObject

Returns the value of attribute type.



84
85
86
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 84

def type
  @type
end

#user_idObject

Returns the value of attribute user_id.



86
87
88
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 86

def user_id
  @user_id
end

#user_uuidObject

Returns the value of attribute user_uuid.



88
89
90
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 88

def user_uuid
  @user_uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 125

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 91

def self.attribute_map
  {
    :'api_client_id' => :'api_client_id',
    :'can_write' => :'can_write',
    :'created_on' => :'created_on',
    :'customer_id' => :'customer_id',
    :'description' => :'description',
    :'expiration_on' => :'expiration_on',
    :'id' => :'id',
    :'last_execution' => :'last_execution',
    :'last_updated_on' => :'last_updated_on',
    :'name' => :'name',
    :'next_execution_on' => :'next_execution_on',
    :'notifications' => :'notifications',
    :'owned_by_cs' => :'owned_by_cs',
    :'report_metadata' => :'report_metadata',
    :'report_params' => :'report_params',
    :'schedule' => :'schedule',
    :'schedule_type' => :'schedule_type',
    :'secret_references' => :'secret_references',
    :'shared_with' => :'shared_with',
    :'start_on' => :'start_on',
    :'status' => :'status',
    :'stop_on' => :'stop_on',
    :'stopped_by_cs' => :'stopped_by_cs',
    :'tracking' => :'tracking',
    :'trigger_reference' => :'trigger_reference',
    :'type' => :'type',
    :'user_id' => :'user_id',
    :'user_uuid' => :'user_uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



444
445
446
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 444

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



164
165
166
167
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 164

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 130

def self.openapi_types
  {
    :'api_client_id' => :'String',
    :'can_write' => :'Boolean',
    :'created_on' => :'Time',
    :'customer_id' => :'String',
    :'description' => :'String',
    :'expiration_on' => :'Time',
    :'id' => :'String',
    :'last_execution' => :'DomainReportExecutionSummaryV1',
    :'last_updated_on' => :'Time',
    :'name' => :'String',
    :'next_execution_on' => :'Time',
    :'notifications' => :'Array<DomainNotifications>',
    :'owned_by_cs' => :'Boolean',
    :'report_metadata' => :'DomainReportMetadata',
    :'report_params' => :'DomainReportParams',
    :'schedule' => :'DomainSchedule',
    :'schedule_type' => :'String',
    :'secret_references' => :'DomainSecretReferencesV1',
    :'shared_with' => :'Array<String>',
    :'start_on' => :'Time',
    :'status' => :'String',
    :'stop_on' => :'Time',
    :'stopped_by_cs' => :'Boolean',
    :'tracking' => :'String',
    :'trigger_reference' => :'String',
    :'type' => :'String',
    :'user_id' => :'String',
    :'user_uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 396

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      api_client_id == o.api_client_id &&
      can_write == o.can_write &&
      created_on == o.created_on &&
      customer_id == o.customer_id &&
      description == o.description &&
      expiration_on == o.expiration_on &&
      id == o.id &&
      last_execution == o.last_execution &&
      last_updated_on == o.last_updated_on &&
      name == o.name &&
      next_execution_on == o.next_execution_on &&
      notifications == o.notifications &&
      owned_by_cs == o.owned_by_cs &&
       == o. &&
      report_params == o.report_params &&
      schedule == o.schedule &&
      schedule_type == o.schedule_type &&
      secret_references == o.secret_references &&
      shared_with == o.shared_with &&
      start_on == o.start_on &&
      status == o.status &&
      stop_on == o.stop_on &&
      stopped_by_cs == o.stopped_by_cs &&
      tracking == o.tracking &&
      trigger_reference == o.trigger_reference &&
      type == o.type &&
      user_id == o.user_id &&
      user_uuid == o.user_uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 475

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



546
547
548
549
550
551
552
553
554
555
556
557
558
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 546

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 451

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


431
432
433
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 431

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



437
438
439
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 437

def hash
  [api_client_id, can_write, created_on, customer_id, description, expiration_on, id, last_execution, last_updated_on, name, next_execution_on, notifications, owned_by_cs, , report_params, schedule, schedule_type, secret_references, shared_with, start_on, status, stop_on, stopped_by_cs, tracking, trigger_reference, type, user_id, user_uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 303

def list_invalid_properties
  invalid_properties = Array.new
  if @api_client_id.nil?
    invalid_properties.push('invalid value for "api_client_id", api_client_id cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_updated_on.nil?
    invalid_properties.push('invalid value for "last_updated_on", last_updated_on cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @notifications.nil?
    invalid_properties.push('invalid value for "notifications", notifications cannot be nil.')
  end

  if @report_params.nil?
    invalid_properties.push('invalid value for "report_params", report_params cannot be nil.')
  end

  if @schedule.nil?
    invalid_properties.push('invalid value for "schedule", schedule cannot be nil.')
  end

  if @schedule_type.nil?
    invalid_properties.push('invalid value for "schedule_type", schedule_type cannot be nil.')
  end

  if @shared_with.nil?
    invalid_properties.push('invalid value for "shared_with", shared_with cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @user_uuid.nil?
    invalid_properties.push('invalid value for "user_uuid", user_uuid cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



522
523
524
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 522

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 528

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



516
517
518
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 516

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/domain_scheduled_report_v1.rb', line 374

def valid?
  return false if @api_client_id.nil?
  return false if @created_on.nil?
  return false if @customer_id.nil?
  return false if @description.nil?
  return false if @id.nil?
  return false if @last_updated_on.nil?
  return false if @name.nil?
  return false if @notifications.nil?
  return false if @report_params.nil?
  return false if @schedule.nil?
  return false if @schedule_type.nil?
  return false if @shared_with.nil?
  return false if @status.nil?
  return false if @type.nil?
  return false if @user_id.nil?
  return false if @user_uuid.nil?
  true
end