Class: Falcon::DomainSession

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_session.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/crimson-falcon/models/domain_session.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainSession` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainSession`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_request_ids')
    if (value = attributes[:'cloud_request_ids']).is_a?(Array)
      self.cloud_request_ids = value
    end
  end

  if attributes.key?(:'commands')
    if (value = attributes[:'commands']).is_a?(Hash)
      self.commands = value
    end
  end

  if attributes.key?(:'commands_queued')
    self.commands_queued = attributes[:'commands_queued']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'device_details')
    self.device_details = attributes[:'device_details']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'execution_id')
    self.execution_id = attributes[:'execution_id']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'logs')
    if (value = attributes[:'logs']).is_a?(Array)
      self.logs = value
    end
  end

  if attributes.key?(:'offline_queued')
    self.offline_queued = attributes[:'offline_queued']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'platform_id')
    self.platform_id = attributes[:'platform_id']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'pwd')
    self.pwd = attributes[:'pwd']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_uuid')
    self.user_uuid = attributes[:'user_uuid']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



34
35
36
# File 'lib/crimson-falcon/models/domain_session.rb', line 34

def cid
  @cid
end

#cloud_request_idsObject

Returns the value of attribute cloud_request_ids.



36
37
38
# File 'lib/crimson-falcon/models/domain_session.rb', line 36

def cloud_request_ids
  @cloud_request_ids
end

#commandsObject

Returns the value of attribute commands.



38
39
40
# File 'lib/crimson-falcon/models/domain_session.rb', line 38

def commands
  @commands
end

#commands_queuedObject

Returns the value of attribute commands_queued.



40
41
42
# File 'lib/crimson-falcon/models/domain_session.rb', line 40

def commands_queued
  @commands_queued
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/crimson-falcon/models/domain_session.rb', line 42

def created_at
  @created_at
end

#deleted_atObject

Returns the value of attribute deleted_at.



44
45
46
# File 'lib/crimson-falcon/models/domain_session.rb', line 44

def deleted_at
  @deleted_at
end

#device_detailsObject

Returns the value of attribute device_details.



46
47
48
# File 'lib/crimson-falcon/models/domain_session.rb', line 46

def device_details
  @device_details
end

#device_idObject

Returns the value of attribute device_id.



48
49
50
# File 'lib/crimson-falcon/models/domain_session.rb', line 48

def device_id
  @device_id
end

#durationObject

Returns the value of attribute duration.



50
51
52
# File 'lib/crimson-falcon/models/domain_session.rb', line 50

def duration
  @duration
end

#execution_idObject

Returns the value of attribute execution_id.



52
53
54
# File 'lib/crimson-falcon/models/domain_session.rb', line 52

def execution_id
  @execution_id
end

#hostnameObject

Returns the value of attribute hostname.



54
55
56
# File 'lib/crimson-falcon/models/domain_session.rb', line 54

def hostname
  @hostname
end

#idObject

Returns the value of attribute id.



56
57
58
# File 'lib/crimson-falcon/models/domain_session.rb', line 56

def id
  @id
end

#logsObject

Returns the value of attribute logs.



58
59
60
# File 'lib/crimson-falcon/models/domain_session.rb', line 58

def logs
  @logs
end

#offline_queuedObject

Returns the value of attribute offline_queued.



60
61
62
# File 'lib/crimson-falcon/models/domain_session.rb', line 60

def offline_queued
  @offline_queued
end

#originObject

Returns the value of attribute origin.



62
63
64
# File 'lib/crimson-falcon/models/domain_session.rb', line 62

def origin
  @origin
end

#platform_idObject

Returns the value of attribute platform_id.



64
65
66
# File 'lib/crimson-falcon/models/domain_session.rb', line 64

def platform_id
  @platform_id
end

#platform_nameObject

Returns the value of attribute platform_name.



66
67
68
# File 'lib/crimson-falcon/models/domain_session.rb', line 66

def platform_name
  @platform_name
end

#pwdObject

Returns the value of attribute pwd.



68
69
70
# File 'lib/crimson-falcon/models/domain_session.rb', line 68

def pwd
  @pwd
end

#updated_atObject

Returns the value of attribute updated_at.



70
71
72
# File 'lib/crimson-falcon/models/domain_session.rb', line 70

def updated_at
  @updated_at
end

#user_idObject

Returns the value of attribute user_id.



72
73
74
# File 'lib/crimson-falcon/models/domain_session.rb', line 72

def user_id
  @user_id
end

#user_uuidObject

Returns the value of attribute user_uuid.



74
75
76
# File 'lib/crimson-falcon/models/domain_session.rb', line 74

def user_uuid
  @user_uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/crimson-falcon/models/domain_session.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/domain_session.rb', line 77

def self.attribute_map
  {
    :'cid' => :'cid',
    :'cloud_request_ids' => :'cloud_request_ids',
    :'commands' => :'commands',
    :'commands_queued' => :'commands_queued',
    :'created_at' => :'created_at',
    :'deleted_at' => :'deleted_at',
    :'device_details' => :'device_details',
    :'device_id' => :'device_id',
    :'duration' => :'duration',
    :'execution_id' => :'execution_id',
    :'hostname' => :'hostname',
    :'id' => :'id',
    :'logs' => :'logs',
    :'offline_queued' => :'offline_queued',
    :'origin' => :'origin',
    :'platform_id' => :'platform_id',
    :'platform_name' => :'platform_name',
    :'pwd' => :'pwd',
    :'updated_at' => :'updated_at',
    :'user_id' => :'user_id',
    :'user_uuid' => :'user_uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



378
379
380
# File 'lib/crimson-falcon/models/domain_session.rb', line 378

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/crimson-falcon/models/domain_session.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/crimson-falcon/models/domain_session.rb', line 109

def self.openapi_types
  {
    :'cid' => :'String',
    :'cloud_request_ids' => :'Array<String>',
    :'commands' => :'Hash<String, Object>',
    :'commands_queued' => :'Boolean',
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'device_details' => :'DomainDevice',
    :'device_id' => :'String',
    :'duration' => :'Float',
    :'execution_id' => :'String',
    :'hostname' => :'String',
    :'id' => :'String',
    :'logs' => :'Array<ModelSessionLog>',
    :'offline_queued' => :'Boolean',
    :'origin' => :'String',
    :'platform_id' => :'Integer',
    :'platform_name' => :'String',
    :'pwd' => :'String',
    :'updated_at' => :'Time',
    :'user_id' => :'String',
    :'user_uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/crimson-falcon/models/domain_session.rb', line 337

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      cloud_request_ids == o.cloud_request_ids &&
      commands == o.commands &&
      commands_queued == o.commands_queued &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      device_details == o.device_details &&
      device_id == o.device_id &&
      duration == o.duration &&
      execution_id == o.execution_id &&
      hostname == o.hostname &&
      id == o.id &&
      logs == o.logs &&
      offline_queued == o.offline_queued &&
      origin == o.origin &&
      platform_id == o.platform_id &&
      platform_name == o.platform_name &&
      pwd == o.pwd &&
      updated_at == o.updated_at &&
      user_id == o.user_id &&
      user_uuid == o.user_uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/crimson-falcon/models/domain_session.rb', line 409

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/crimson-falcon/models/domain_session.rb', line 480

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/crimson-falcon/models/domain_session.rb', line 385

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


365
366
367
# File 'lib/crimson-falcon/models/domain_session.rb', line 365

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



371
372
373
# File 'lib/crimson-falcon/models/domain_session.rb', line 371

def hash
  [cid, cloud_request_ids, commands, commands_queued, created_at, deleted_at, device_details, device_id, duration, execution_id, hostname, id, logs, offline_queued, origin, platform_id, platform_name, pwd, updated_at, user_id, user_uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/crimson-falcon/models/domain_session.rb', line 249

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @cloud_request_ids.nil?
    invalid_properties.push('invalid value for "cloud_request_ids", cloud_request_ids cannot be nil.')
  end

  if @commands_queued.nil?
    invalid_properties.push('invalid value for "commands_queued", commands_queued cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @deleted_at.nil?
    invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.')
  end

  if @device_id.nil?
    invalid_properties.push('invalid value for "device_id", device_id cannot be nil.')
  end

  if @duration.nil?
    invalid_properties.push('invalid value for "duration", duration cannot be nil.')
  end

  if @hostname.nil?
    invalid_properties.push('invalid value for "hostname", hostname cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @logs.nil?
    invalid_properties.push('invalid value for "logs", logs cannot be nil.')
  end

  if @offline_queued.nil?
    invalid_properties.push('invalid value for "offline_queued", offline_queued cannot be nil.')
  end

  if @origin.nil?
    invalid_properties.push('invalid value for "origin", origin cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @user_uuid.nil?
    invalid_properties.push('invalid value for "user_uuid", user_uuid cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



456
457
458
# File 'lib/crimson-falcon/models/domain_session.rb', line 456

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/crimson-falcon/models/domain_session.rb', line 462

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



450
451
452
# File 'lib/crimson-falcon/models/domain_session.rb', line 450

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/crimson-falcon/models/domain_session.rb', line 316

def valid?
  return false if @cid.nil?
  return false if @cloud_request_ids.nil?
  return false if @commands_queued.nil?
  return false if @created_at.nil?
  return false if @deleted_at.nil?
  return false if @device_id.nil?
  return false if @duration.nil?
  return false if @hostname.nil?
  return false if @id.nil?
  return false if @logs.nil?
  return false if @offline_queued.nil?
  return false if @origin.nil?
  return false if @updated_at.nil?
  return false if @user_id.nil?
  return false if @user_uuid.nil?
  true
end