Class: Falcon::DomainSsIoaExclusionCreateReqV2

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainSsIoaExclusionCreateReqV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainSsIoaExclusionCreateReqV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainSsIoaExclusionCreateReqV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cl_regex')
    self.cl_regex = attributes[:'cl_regex']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'detection_json')
    self.detection_json = attributes[:'detection_json']
  end

  if attributes.key?(:'grandparent_cl_regex')
    self.grandparent_cl_regex = attributes[:'grandparent_cl_regex']
  end

  if attributes.key?(:'grandparent_ifn_regex')
    self.grandparent_ifn_regex = attributes[:'grandparent_ifn_regex']
  end

  if attributes.key?(:'host_groups')
    if (value = attributes[:'host_groups']).is_a?(Array)
      self.host_groups = value
    end
  end

  if attributes.key?(:'ifn_regex')
    self.ifn_regex = attributes[:'ifn_regex']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'parent_cl_regex')
    self.parent_cl_regex = attributes[:'parent_cl_regex']
  end

  if attributes.key?(:'parent_ifn_regex')
    self.parent_ifn_regex = attributes[:'parent_ifn_regex']
  end

  if attributes.key?(:'pattern_id')
    self.pattern_id = attributes[:'pattern_id']
  end

  if attributes.key?(:'pattern_name')
    self.pattern_name = attributes[:'pattern_name']
  end
end

Instance Attribute Details

#cl_regexObject

Returns the value of attribute cl_regex.



34
35
36
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 34

def cl_regex
  @cl_regex
end

#commentObject

Returns the value of attribute comment.



36
37
38
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 36

def comment
  @comment
end

#descriptionObject

Returns the value of attribute description.



38
39
40
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 38

def description
  @description
end

#detection_jsonObject

Returns the value of attribute detection_json.



40
41
42
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 40

def detection_json
  @detection_json
end

#grandparent_cl_regexObject

Returns the value of attribute grandparent_cl_regex.



42
43
44
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 42

def grandparent_cl_regex
  @grandparent_cl_regex
end

#grandparent_ifn_regexObject

Returns the value of attribute grandparent_ifn_regex.



44
45
46
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 44

def grandparent_ifn_regex
  @grandparent_ifn_regex
end

#host_groupsObject

Returns the value of attribute host_groups.



46
47
48
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 46

def host_groups
  @host_groups
end

#ifn_regexObject

Returns the value of attribute ifn_regex.



48
49
50
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 48

def ifn_regex
  @ifn_regex
end

#nameObject

Returns the value of attribute name.



50
51
52
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 50

def name
  @name
end

#parent_cl_regexObject

Returns the value of attribute parent_cl_regex.



52
53
54
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 52

def parent_cl_regex
  @parent_cl_regex
end

#parent_ifn_regexObject

Returns the value of attribute parent_ifn_regex.



54
55
56
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 54

def parent_ifn_regex
  @parent_ifn_regex
end

#pattern_idObject

Returns the value of attribute pattern_id.



56
57
58
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 56

def pattern_id
  @pattern_id
end

#pattern_nameObject

Returns the value of attribute pattern_name.



58
59
60
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 58

def pattern_name
  @pattern_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 61

def self.attribute_map
  {
    :'cl_regex' => :'cl_regex',
    :'comment' => :'comment',
    :'description' => :'description',
    :'detection_json' => :'detection_json',
    :'grandparent_cl_regex' => :'grandparent_cl_regex',
    :'grandparent_ifn_regex' => :'grandparent_ifn_regex',
    :'host_groups' => :'host_groups',
    :'ifn_regex' => :'ifn_regex',
    :'name' => :'name',
    :'parent_cl_regex' => :'parent_cl_regex',
    :'parent_ifn_regex' => :'parent_ifn_regex',
    :'pattern_id' => :'pattern_id',
    :'pattern_name' => :'pattern_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 247

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 85

def self.openapi_types
  {
    :'cl_regex' => :'String',
    :'comment' => :'String',
    :'description' => :'String',
    :'detection_json' => :'String',
    :'grandparent_cl_regex' => :'String',
    :'grandparent_ifn_regex' => :'String',
    :'host_groups' => :'Array<String>',
    :'ifn_regex' => :'String',
    :'name' => :'String',
    :'parent_cl_regex' => :'String',
    :'parent_ifn_regex' => :'String',
    :'pattern_id' => :'String',
    :'pattern_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cl_regex == o.cl_regex &&
      comment == o.comment &&
      description == o.description &&
      detection_json == o.detection_json &&
      grandparent_cl_regex == o.grandparent_cl_regex &&
      grandparent_ifn_regex == o.grandparent_ifn_regex &&
      host_groups == o.host_groups &&
      ifn_regex == o.ifn_regex &&
      name == o.name &&
      parent_cl_regex == o.parent_cl_regex &&
      parent_ifn_regex == o.parent_ifn_regex &&
      pattern_id == o.pattern_id &&
      pattern_name == o.pattern_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 278

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 349

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 254

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 240

def hash
  [cl_regex, comment, description, detection_json, grandparent_cl_regex, grandparent_ifn_regex, host_groups, ifn_regex, name, parent_cl_regex, parent_ifn_regex, pattern_id, pattern_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @cl_regex.nil?
    invalid_properties.push('invalid value for "cl_regex", cl_regex cannot be nil.')
  end

  if @ifn_regex.nil?
    invalid_properties.push('invalid value for "ifn_regex", ifn_regex cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @pattern_id.nil?
    invalid_properties.push('invalid value for "pattern_id", pattern_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 325

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 319

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusion_create_req_v2.rb', line 204

def valid?
  return false if @cl_regex.nil?
  return false if @ifn_regex.nil?
  return false if @name.nil?
  return false if @pattern_id.nil?
  true
end