Class: Falcon::DomainSsIoaExclusionsV2
- Inherits:
-
Object
- Object
- Falcon::DomainSsIoaExclusionsV2
- Defined in:
- lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb
Instance Attribute Summary collapse
-
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
-
#cl_regex ⇒ Object
Returns the value of attribute cl_regex.
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#description ⇒ Object
Returns the value of attribute description.
-
#detection_json ⇒ Object
Returns the value of attribute detection_json.
-
#grandparent_cl_regex ⇒ Object
Returns the value of attribute grandparent_cl_regex.
-
#grandparent_ifn_regex ⇒ Object
Returns the value of attribute grandparent_ifn_regex.
-
#host_groups ⇒ Object
Returns the value of attribute host_groups.
-
#id ⇒ Object
Returns the value of attribute id.
-
#ifn_regex ⇒ Object
Returns the value of attribute ifn_regex.
-
#last_modified ⇒ Object
Returns the value of attribute last_modified.
-
#modified_by ⇒ Object
Returns the value of attribute modified_by.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent_cl_regex ⇒ Object
Returns the value of attribute parent_cl_regex.
-
#parent_ifn_regex ⇒ Object
Returns the value of attribute parent_ifn_regex.
-
#pattern_id ⇒ Object
Returns the value of attribute pattern_id.
-
#pattern_name ⇒ Object
Returns the value of attribute pattern_name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainSsIoaExclusionsV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainSsIoaExclusionsV2
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 135 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainSsIoaExclusionsV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainSsIoaExclusionsV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'applied_globally') self.applied_globally = attributes[:'applied_globally'] end if attributes.key?(:'cl_regex') self.cl_regex = attributes[:'cl_regex'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'detection_json') self.detection_json = attributes[:'detection_json'] end if attributes.key?(:'grandparent_cl_regex') self.grandparent_cl_regex = attributes[:'grandparent_cl_regex'] end if attributes.key?(:'grandparent_ifn_regex') self.grandparent_ifn_regex = attributes[:'grandparent_ifn_regex'] end if attributes.key?(:'host_groups') if (value = attributes[:'host_groups']).is_a?(Array) self.host_groups = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ifn_regex') self.ifn_regex = attributes[:'ifn_regex'] end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'parent_cl_regex') self.parent_cl_regex = attributes[:'parent_cl_regex'] end if attributes.key?(:'parent_ifn_regex') self.parent_ifn_regex = attributes[:'parent_ifn_regex'] end if attributes.key?(:'pattern_id') self.pattern_id = attributes[:'pattern_id'] end if attributes.key?(:'pattern_name') self.pattern_name = attributes[:'pattern_name'] end end |
Instance Attribute Details
#applied_globally ⇒ Object
Returns the value of attribute applied_globally.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 34 def applied_globally @applied_globally end |
#cl_regex ⇒ Object
Returns the value of attribute cl_regex.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 36 def cl_regex @cl_regex end |
#comment ⇒ Object
Returns the value of attribute comment.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 38 def comment @comment end |
#created_by ⇒ Object
Returns the value of attribute created_by.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 40 def created_by @created_by end |
#created_on ⇒ Object
Returns the value of attribute created_on.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 42 def created_on @created_on end |
#description ⇒ Object
Returns the value of attribute description.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 44 def description @description end |
#detection_json ⇒ Object
Returns the value of attribute detection_json.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 46 def detection_json @detection_json end |
#grandparent_cl_regex ⇒ Object
Returns the value of attribute grandparent_cl_regex.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 48 def grandparent_cl_regex @grandparent_cl_regex end |
#grandparent_ifn_regex ⇒ Object
Returns the value of attribute grandparent_ifn_regex.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 50 def grandparent_ifn_regex @grandparent_ifn_regex end |
#host_groups ⇒ Object
Returns the value of attribute host_groups.
52 53 54 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 52 def host_groups @host_groups end |
#id ⇒ Object
Returns the value of attribute id.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 54 def id @id end |
#ifn_regex ⇒ Object
Returns the value of attribute ifn_regex.
56 57 58 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 56 def ifn_regex @ifn_regex end |
#last_modified ⇒ Object
Returns the value of attribute last_modified.
58 59 60 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 58 def last_modified @last_modified end |
#modified_by ⇒ Object
Returns the value of attribute modified_by.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 60 def modified_by @modified_by end |
#name ⇒ Object
Returns the value of attribute name.
62 63 64 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 62 def name @name end |
#parent_cl_regex ⇒ Object
Returns the value of attribute parent_cl_regex.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 64 def parent_cl_regex @parent_cl_regex end |
#parent_ifn_regex ⇒ Object
Returns the value of attribute parent_ifn_regex.
66 67 68 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 66 def parent_ifn_regex @parent_ifn_regex end |
#pattern_id ⇒ Object
Returns the value of attribute pattern_id.
68 69 70 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 68 def pattern_id @pattern_id end |
#pattern_name ⇒ Object
Returns the value of attribute pattern_name.
70 71 72 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 70 def pattern_name @pattern_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 73 def self.attribute_map { :'applied_globally' => :'applied_globally', :'cl_regex' => :'cl_regex', :'comment' => :'comment', :'created_by' => :'created_by', :'created_on' => :'created_on', :'description' => :'description', :'detection_json' => :'detection_json', :'grandparent_cl_regex' => :'grandparent_cl_regex', :'grandparent_ifn_regex' => :'grandparent_ifn_regex', :'host_groups' => :'host_groups', :'id' => :'id', :'ifn_regex' => :'ifn_regex', :'last_modified' => :'last_modified', :'modified_by' => :'modified_by', :'name' => :'name', :'parent_cl_regex' => :'parent_cl_regex', :'parent_ifn_regex' => :'parent_ifn_regex', :'pattern_id' => :'pattern_id', :'pattern_name' => :'pattern_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 286 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 128 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 103 def self.openapi_types { :'applied_globally' => :'Boolean', :'cl_regex' => :'String', :'comment' => :'String', :'created_by' => :'String', :'created_on' => :'Time', :'description' => :'String', :'detection_json' => :'String', :'grandparent_cl_regex' => :'String', :'grandparent_ifn_regex' => :'String', :'host_groups' => :'Array<String>', :'id' => :'String', :'ifn_regex' => :'String', :'last_modified' => :'Time', :'modified_by' => :'String', :'name' => :'String', :'parent_cl_regex' => :'String', :'parent_ifn_regex' => :'String', :'pattern_id' => :'String', :'pattern_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 247 def ==(o) return true if self.equal?(o) self.class == o.class && applied_globally == o.applied_globally && cl_regex == o.cl_regex && comment == o.comment && created_by == o.created_by && created_on == o.created_on && description == o.description && detection_json == o.detection_json && grandparent_cl_regex == o.grandparent_cl_regex && grandparent_ifn_regex == o.grandparent_ifn_regex && host_groups == o.host_groups && id == o.id && ifn_regex == o.ifn_regex && last_modified == o.last_modified && modified_by == o.modified_by && name == o.name && parent_cl_regex == o.parent_cl_regex && parent_ifn_regex == o.parent_ifn_regex && pattern_id == o.pattern_id && pattern_name == o.pattern_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 317 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 388 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 293 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 279 def hash [applied_globally, cl_regex, comment, created_by, created_on, description, detection_json, grandparent_cl_regex, grandparent_ifn_regex, host_groups, id, ifn_regex, last_modified, modified_by, name, parent_cl_regex, parent_ifn_regex, pattern_id, pattern_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 229 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
364 365 366 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 364 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 370 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 358 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 |
# File 'lib/crimson-falcon/models/domain_ss_ioa_exclusions_v2.rb', line 240 def valid? return false if @id.nil? true end |