Class: Falcon::DomainTemplate

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_template.rb

Overview

Represents a template entity

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/crimson-falcon/models/domain_template.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainTemplate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_check_level')
    self.active_check_level = attributes[:'active_check_level']
  end

  if attributes.key?(:'additional_tcp_ports')
    if (value = attributes[:'additional_tcp_ports']).is_a?(Array)
      self.additional_tcp_ports = value
    end
  end

  if attributes.key?(:'additional_udp_ports')
    if (value = attributes[:'additional_udp_ports']).is_a?(Array)
      self.additional_udp_ports = value
    end
  end

  if attributes.key?(:'auto_include_new_detections')
    self.auto_include_new_detections = attributes[:'auto_include_new_detections']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'detections')
    if (value = attributes[:'detections']).is_a?(Array)
      self.detections = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'ignore_tcp_resets')
    self.ignore_tcp_resets = attributes[:'ignore_tcp_resets']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ports_scan_level')
    self.ports_scan_level = attributes[:'ports_scan_level']
  end

  if attributes.key?(:'scan_intensity')
    self.scan_intensity = attributes[:'scan_intensity']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'updated_timestamp')
    self.updated_timestamp = attributes[:'updated_timestamp']
  end
end

Instance Attribute Details

#active_check_levelObject

The active check level associated with the template



36
37
38
# File 'lib/crimson-falcon/models/domain_template.rb', line 36

def active_check_level
  @active_check_level
end

#additional_tcp_portsObject

Additional TCP ports associated with the template



39
40
41
# File 'lib/crimson-falcon/models/domain_template.rb', line 39

def additional_tcp_ports
  @additional_tcp_ports
end

#additional_udp_portsObject

Additional UDP ports associated with the template



42
43
44
# File 'lib/crimson-falcon/models/domain_template.rb', line 42

def additional_udp_ports
  @additional_udp_ports
end

#auto_include_new_detectionsObject

Automatically include new detections in the template



45
46
47
# File 'lib/crimson-falcon/models/domain_template.rb', line 45

def auto_include_new_detections
  @auto_include_new_detections
end

#cidObject

The customer who owns the template



48
49
50
# File 'lib/crimson-falcon/models/domain_template.rb', line 48

def cid
  @cid
end

#created_byObject

The user that created the template



51
52
53
# File 'lib/crimson-falcon/models/domain_template.rb', line 51

def created_by
  @created_by
end

#created_timestampObject

The time at which the template was created



54
55
56
# File 'lib/crimson-falcon/models/domain_template.rb', line 54

def created_timestamp
  @created_timestamp
end

#detectionsObject

Detections associated with the template



57
58
59
# File 'lib/crimson-falcon/models/domain_template.rb', line 57

def detections
  @detections
end

#idObject

The unique identifier of the template



60
61
62
# File 'lib/crimson-falcon/models/domain_template.rb', line 60

def id
  @id
end

#ignore_tcp_resetsObject

Ignore TCP resets associated with the template



63
64
65
# File 'lib/crimson-falcon/models/domain_template.rb', line 63

def ignore_tcp_resets
  @ignore_tcp_resets
end

#nameObject

The name which was given to the template



66
67
68
# File 'lib/crimson-falcon/models/domain_template.rb', line 66

def name
  @name
end

#ports_scan_levelObject

The port scan level associated with the template



69
70
71
# File 'lib/crimson-falcon/models/domain_template.rb', line 69

def ports_scan_level
  @ports_scan_level
end

#scan_intensityObject

The scan intensity at which scans will run from this template



72
73
74
# File 'lib/crimson-falcon/models/domain_template.rb', line 72

def scan_intensity
  @scan_intensity
end

#typeObject

The type of the template



75
76
77
# File 'lib/crimson-falcon/models/domain_template.rb', line 75

def type
  @type
end

#updated_byObject

The user that updated the template



78
79
80
# File 'lib/crimson-falcon/models/domain_template.rb', line 78

def updated_by
  @updated_by
end

#updated_timestampObject

The time at which the template was updated



81
82
83
# File 'lib/crimson-falcon/models/domain_template.rb', line 81

def updated_timestamp
  @updated_timestamp
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



128
129
130
# File 'lib/crimson-falcon/models/domain_template.rb', line 128

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/crimson-falcon/models/domain_template.rb', line 106

def self.attribute_map
  {
    :'active_check_level' => :'active_check_level',
    :'additional_tcp_ports' => :'additional_tcp_ports',
    :'additional_udp_ports' => :'additional_udp_ports',
    :'auto_include_new_detections' => :'auto_include_new_detections',
    :'cid' => :'cid',
    :'created_by' => :'created_by',
    :'created_timestamp' => :'created_timestamp',
    :'detections' => :'detections',
    :'id' => :'id',
    :'ignore_tcp_resets' => :'ignore_tcp_resets',
    :'name' => :'name',
    :'ports_scan_level' => :'ports_scan_level',
    :'scan_intensity' => :'scan_intensity',
    :'type' => :'type',
    :'updated_by' => :'updated_by',
    :'updated_timestamp' => :'updated_timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



405
406
407
# File 'lib/crimson-falcon/models/domain_template.rb', line 405

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



155
156
157
158
# File 'lib/crimson-falcon/models/domain_template.rb', line 155

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/crimson-falcon/models/domain_template.rb', line 133

def self.openapi_types
  {
    :'active_check_level' => :'String',
    :'additional_tcp_ports' => :'Array<String>',
    :'additional_udp_ports' => :'Array<String>',
    :'auto_include_new_detections' => :'Boolean',
    :'cid' => :'String',
    :'created_by' => :'String',
    :'created_timestamp' => :'String',
    :'detections' => :'Array<String>',
    :'id' => :'String',
    :'ignore_tcp_resets' => :'Boolean',
    :'name' => :'String',
    :'ports_scan_level' => :'String',
    :'scan_intensity' => :'String',
    :'type' => :'String',
    :'updated_by' => :'String',
    :'updated_timestamp' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/crimson-falcon/models/domain_template.rb', line 369

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_check_level == o.active_check_level &&
      additional_tcp_ports == o.additional_tcp_ports &&
      additional_udp_ports == o.additional_udp_ports &&
      auto_include_new_detections == o.auto_include_new_detections &&
      cid == o.cid &&
      created_by == o.created_by &&
      created_timestamp == o.created_timestamp &&
      detections == o.detections &&
      id == o.id &&
      ignore_tcp_resets == o.ignore_tcp_resets &&
      name == o.name &&
      ports_scan_level == o.ports_scan_level &&
      scan_intensity == o.scan_intensity &&
      type == o.type &&
      updated_by == o.updated_by &&
      updated_timestamp == o.updated_timestamp
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/crimson-falcon/models/domain_template.rb', line 436

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



507
508
509
510
511
512
513
514
515
516
517
518
519
# File 'lib/crimson-falcon/models/domain_template.rb', line 507

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/crimson-falcon/models/domain_template.rb', line 412

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


392
393
394
# File 'lib/crimson-falcon/models/domain_template.rb', line 392

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



398
399
400
# File 'lib/crimson-falcon/models/domain_template.rb', line 398

def hash
  [active_check_level, additional_tcp_ports, additional_udp_ports, auto_include_new_detections, cid, created_by, created_timestamp, detections, id, ignore_tcp_resets, name, ports_scan_level, scan_intensity, type, updated_by, updated_timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/models/domain_template.rb', line 248

def list_invalid_properties
  invalid_properties = Array.new
  if @active_check_level.nil?
    invalid_properties.push('invalid value for "active_check_level", active_check_level cannot be nil.')
  end

  if @auto_include_new_detections.nil?
    invalid_properties.push('invalid value for "auto_include_new_detections", auto_include_new_detections cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @detections.nil?
    invalid_properties.push('invalid value for "detections", detections cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @ignore_tcp_resets.nil?
    invalid_properties.push('invalid value for "ignore_tcp_resets", ignore_tcp_resets cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @ports_scan_level.nil?
    invalid_properties.push('invalid value for "ports_scan_level", ports_scan_level cannot be nil.')
  end

  if @scan_intensity.nil?
    invalid_properties.push('invalid value for "scan_intensity", scan_intensity cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



483
484
485
# File 'lib/crimson-falcon/models/domain_template.rb', line 483

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/crimson-falcon/models/domain_template.rb', line 489

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



477
478
479
# File 'lib/crimson-falcon/models/domain_template.rb', line 477

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/crimson-falcon/models/domain_template.rb', line 303

def valid?
  return false if @active_check_level.nil?
  active_check_level_validator = EnumAttributeValidator.new('String', ["active_check_safe_only,active_check_all"])
  return false unless active_check_level_validator.valid?(@active_check_level)
  return false if @auto_include_new_detections.nil?
  return false if @cid.nil?
  return false if @created_by.nil?
  return false if @created_timestamp.nil?
  return false if @detections.nil?
  return false if @id.nil?
  return false if @ignore_tcp_resets.nil?
  return false if @name.nil?
  return false if @ports_scan_level.nil?
  ports_scan_level_validator = EnumAttributeValidator.new('String', ["default,all_ports,custom"])
  return false unless ports_scan_level_validator.valid?(@ports_scan_level)
  return false if @scan_intensity.nil?
  scan_intensity_validator = EnumAttributeValidator.new('String', ["basic,standard,cautious,maximum"])
  return false unless scan_intensity_validator.valid?(@scan_intensity)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["discovery,assessment"])
  return false unless type_validator.valid?(@type)
  true
end