Class: Falcon::DomainTemplateUpdateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/domain_template_update_request.rb

Overview

Represents a request to update a template Represents a request to update a template

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainTemplateUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainTemplateUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainTemplateUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_check_level')
    self.active_check_level = attributes[:'active_check_level']
  end

  if attributes.key?(:'additional_tcp_ports')
    if (value = attributes[:'additional_tcp_ports']).is_a?(Array)
      self.additional_tcp_ports = value
    end
  end

  if attributes.key?(:'additional_udp_ports')
    if (value = attributes[:'additional_udp_ports']).is_a?(Array)
      self.additional_udp_ports = value
    end
  end

  if attributes.key?(:'auto_include_new_detections')
    self.auto_include_new_detections = attributes[:'auto_include_new_detections']
  end

  if attributes.key?(:'detections')
    if (value = attributes[:'detections']).is_a?(Array)
      self.detections = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'ignore_tcp_resets')
    self.ignore_tcp_resets = attributes[:'ignore_tcp_resets']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ports_scan_level')
    self.ports_scan_level = attributes[:'ports_scan_level']
  end

  if attributes.key?(:'scan_intensity')
    self.scan_intensity = attributes[:'scan_intensity']
  end
end

Instance Attribute Details

#active_check_levelObject

The active check level associated with the template



36
37
38
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 36

def active_check_level
  @active_check_level
end

#additional_tcp_portsObject

Additional TCP ports associated with the template



39
40
41
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 39

def additional_tcp_ports
  @additional_tcp_ports
end

#additional_udp_portsObject

Additional UDP ports associated with the template



42
43
44
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 42

def additional_udp_ports
  @additional_udp_ports
end

#auto_include_new_detectionsObject

Automatically include new detections in the template



45
46
47
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 45

def auto_include_new_detections
  @auto_include_new_detections
end

#detectionsObject

Detections associated with the template



48
49
50
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 48

def detections
  @detections
end

#idObject

The unique identifier of the template



51
52
53
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 51

def id
  @id
end

#ignore_tcp_resetsObject

Ignore TCP resets associated with the template



54
55
56
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 54

def ignore_tcp_resets
  @ignore_tcp_resets
end

#nameObject

The name given to the template



57
58
59
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 57

def name
  @name
end

#ports_scan_levelObject

The port scan level associated with the template



60
61
62
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 60

def ports_scan_level
  @ports_scan_level
end

#scan_intensityObject

The scan intensity at which scans will run from this template



63
64
65
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 63

def scan_intensity
  @scan_intensity
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 88

def self.attribute_map
  {
    :'active_check_level' => :'active_check_level',
    :'additional_tcp_ports' => :'additional_tcp_ports',
    :'additional_udp_ports' => :'additional_udp_ports',
    :'auto_include_new_detections' => :'auto_include_new_detections',
    :'detections' => :'detections',
    :'id' => :'id',
    :'ignore_tcp_resets' => :'ignore_tcp_resets',
    :'name' => :'name',
    :'ports_scan_level' => :'ports_scan_level',
    :'scan_intensity' => :'scan_intensity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 278

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 125

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 109

def self.openapi_types
  {
    :'active_check_level' => :'String',
    :'additional_tcp_ports' => :'Array<String>',
    :'additional_udp_ports' => :'Array<String>',
    :'auto_include_new_detections' => :'Boolean',
    :'detections' => :'Array<String>',
    :'id' => :'String',
    :'ignore_tcp_resets' => :'Boolean',
    :'name' => :'String',
    :'ports_scan_level' => :'String',
    :'scan_intensity' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_check_level == o.active_check_level &&
      additional_tcp_ports == o.additional_tcp_ports &&
      additional_udp_ports == o.additional_udp_ports &&
      auto_include_new_detections == o.auto_include_new_detections &&
      detections == o.detections &&
      id == o.id &&
      ignore_tcp_resets == o.ignore_tcp_resets &&
      name == o.name &&
      ports_scan_level == o.ports_scan_level &&
      scan_intensity == o.scan_intensity
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 309

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 271

def hash
  [active_check_level, additional_tcp_ports, additional_udp_ports, auto_include_new_detections, detections, id, ignore_tcp_resets, name, ports_scan_level, scan_intensity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 194

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
# File 'lib/crimson-falcon/models/domain_template_update_request.rb', line 205

def valid?
  active_check_level_validator = EnumAttributeValidator.new('String', ["active_check_safe_only,active_check_all"])
  return false unless active_check_level_validator.valid?(@active_check_level)
  return false if @id.nil?
  ports_scan_level_validator = EnumAttributeValidator.new('String', ["default,all_ports,custom"])
  return false unless ports_scan_level_validator.valid?(@ports_scan_level)
  scan_intensity_validator = EnumAttributeValidator.new('String', ["basic,standard,cautious,maximum"])
  return false unless scan_intensity_validator.valid?(@scan_intensity)
  true
end