Class: Falcon::DomainUpdateRuleRequestV1
- Inherits:
-
Object
- Object
- Falcon::DomainUpdateRuleRequestV1
- Defined in:
- lib/crimson-falcon/models/domain_update_rule_request_v1.rb
Instance Attribute Summary collapse
-
#breach_monitor_only ⇒ Object
Monitor only for exposed data.
-
#breach_monitoring_enabled ⇒ Object
Whether to monitor for exposed data.
-
#filter ⇒ Object
The FQL filter to be used for searching.
-
#id ⇒ Object
The rule ID to be updated.
-
#match_on_tsq_result_types ⇒ Object
Which result types to monitor for.
-
#name ⇒ Object
The name of a given rule.
-
#permissions ⇒ Object
The permissions for a given rule which specifies the rule’s access by other users.
-
#priority ⇒ Object
The priority for a given rule.
-
#substring_matching_enabled ⇒ Object
Whether to monitor for substring matches.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainUpdateRuleRequestV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainUpdateRuleRequestV1
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainUpdateRuleRequestV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainUpdateRuleRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'breach_monitor_only') self.breach_monitor_only = attributes[:'breach_monitor_only'] end if attributes.key?(:'breach_monitoring_enabled') self.breach_monitoring_enabled = attributes[:'breach_monitoring_enabled'] end if attributes.key?(:'filter') self.filter = attributes[:'filter'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'match_on_tsq_result_types') if (value = attributes[:'match_on_tsq_result_types']).is_a?(Array) self.match_on_tsq_result_types = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'permissions') self. = attributes[:'permissions'] end if attributes.key?(:'priority') self.priority = attributes[:'priority'] end if attributes.key?(:'substring_matching_enabled') self.substring_matching_enabled = attributes[:'substring_matching_enabled'] end end |
Instance Attribute Details
#breach_monitor_only ⇒ Object
Monitor only for exposed data. Must be accompanied by breach_monitoring_enabled:true.
35 36 37 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 35 def breach_monitor_only @breach_monitor_only end |
#breach_monitoring_enabled ⇒ Object
Whether to monitor for exposed data. Available only for ‘Company Domains` and `Email addresses` rule topics.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 38 def breach_monitoring_enabled @breach_monitoring_enabled end |
#filter ⇒ Object
The FQL filter to be used for searching
41 42 43 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 41 def filter @filter end |
#id ⇒ Object
The rule ID to be updated
44 45 46 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 44 def id @id end |
#match_on_tsq_result_types ⇒ Object
Which result types to monitor for. Can be set to only monitor domains or subdomains, as well as both. Only available for the ‘Typosquatting` rule topic.
47 48 49 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 47 def match_on_tsq_result_types @match_on_tsq_result_types end |
#name ⇒ Object
The name of a given rule
50 51 52 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 50 def name @name end |
#permissions ⇒ Object
The permissions for a given rule which specifies the rule’s access by other users. Possible values: [‘public`, `private`]
53 54 55 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 53 def @permissions end |
#priority ⇒ Object
The priority for a given rule. Possible values: [‘none`, `low`, `medium`, `high`, `critical`]
56 57 58 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 56 def priority @priority end |
#substring_matching_enabled ⇒ Object
Whether to monitor for substring matches. Only available for the ‘Typosquatting` topic.
59 60 61 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 59 def substring_matching_enabled @substring_matching_enabled end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 62 def self.attribute_map { :'breach_monitor_only' => :'breach_monitor_only', :'breach_monitoring_enabled' => :'breach_monitoring_enabled', :'filter' => :'filter', :'id' => :'id', :'match_on_tsq_result_types' => :'match_on_tsq_result_types', :'name' => :'name', :'permissions' => :'permissions', :'priority' => :'priority', :'substring_matching_enabled' => :'substring_matching_enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 245 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 82 def self.openapi_types { :'breach_monitor_only' => :'Boolean', :'breach_monitoring_enabled' => :'Boolean', :'filter' => :'String', :'id' => :'String', :'match_on_tsq_result_types' => :'Array<String>', :'name' => :'String', :'permissions' => :'String', :'priority' => :'String', :'substring_matching_enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 216 def ==(o) return true if self.equal?(o) self.class == o.class && breach_monitor_only == o.breach_monitor_only && breach_monitoring_enabled == o.breach_monitoring_enabled && filter == o.filter && id == o.id && match_on_tsq_result_types == o.match_on_tsq_result_types && name == o.name && == o. && priority == o.priority && substring_matching_enabled == o.substring_matching_enabled end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 276 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 252 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 238 def hash [breach_monitor_only, breach_monitoring_enabled, filter, id, match_on_tsq_result_types, name, , priority, substring_matching_enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 158 def list_invalid_properties invalid_properties = Array.new if @breach_monitor_only.nil? invalid_properties.push('invalid value for "breach_monitor_only", breach_monitor_only cannot be nil.') end if @breach_monitoring_enabled.nil? invalid_properties.push('invalid value for "breach_monitoring_enabled", breach_monitoring_enabled cannot be nil.') end if @filter.nil? invalid_properties.push('invalid value for "filter", filter cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @match_on_tsq_result_types.nil? invalid_properties.push('invalid value for "match_on_tsq_result_types", match_on_tsq_result_types cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @permissions.nil? invalid_properties.push('invalid value for "permissions", permissions cannot be nil.') end if @priority.nil? invalid_properties.push('invalid value for "priority", priority cannot be nil.') end if @substring_matching_enabled.nil? invalid_properties.push('invalid value for "substring_matching_enabled", substring_matching_enabled cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/crimson-falcon/models/domain_update_rule_request_v1.rb', line 201 def valid? return false if @breach_monitor_only.nil? return false if @breach_monitoring_enabled.nil? return false if @filter.nil? return false if @id.nil? return false if @match_on_tsq_result_types.nil? return false if @name.nil? return false if @permissions.nil? return false if @priority.nil? return false if @substring_matching_enabled.nil? true end |