Class: Falcon::DtoGCPRegistration

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/dto_gcp_registration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DtoGCPRegistration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DtoGCPRegistration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DtoGCPRegistration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'additional_properties')
    self.additional_properties = attributes[:'additional_properties']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'deployment_method')
    self.deployment_method = attributes[:'deployment_method']
  end

  if attributes.key?(:'excluded_project_patterns')
    if (value = attributes[:'excluded_project_patterns']).is_a?(Array)
      self.excluded_project_patterns = value
    end
  end

  if attributes.key?(:'falcon_client_key_id')
    self.falcon_client_key_id = attributes[:'falcon_client_key_id']
  end

  if attributes.key?(:'falcon_client_key_type')
    self.falcon_client_key_type = attributes[:'falcon_client_key_type']
  end

  if attributes.key?(:'folders')
    if (value = attributes[:'folders']).is_a?(Array)
      self.folders = value
    end
  end

  if attributes.key?(:'infra_manager_properties')
    self.infra_manager_properties = attributes[:'infra_manager_properties']
  end

  if attributes.key?(:'infra_project_id')
    self.infra_project_id = attributes[:'infra_project_id']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  end

  if attributes.key?(:'log_ingestion_properties')
    self.log_ingestion_properties = attributes[:'log_ingestion_properties']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'projects')
    if (value = attributes[:'projects']).is_a?(Array)
      self.projects = value
    end
  end

  if attributes.key?(:'registration_id')
    self.registration_id = attributes[:'registration_id']
  end

  if attributes.key?(:'registration_name')
    self.registration_name = attributes[:'registration_name']
  end

  if attributes.key?(:'registration_scope')
    self.registration_scope = attributes[:'registration_scope']
  end

  if attributes.key?(:'resource_name_prefix')
    self.resource_name_prefix = attributes[:'resource_name_prefix']
  end

  if attributes.key?(:'resource_name_suffix')
    self.resource_name_suffix = attributes[:'resource_name_suffix']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.key?(:'wif_properties')
    self.wif_properties = attributes[:'wif_properties']
  end
end

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



34
35
36
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 34

def additional_properties
  @additional_properties
end

#createdObject

Returns the value of attribute created.



36
37
38
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 36

def created
  @created
end

#deployment_methodObject

Returns the value of attribute deployment_method.



38
39
40
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 38

def deployment_method
  @deployment_method
end

#excluded_project_patternsObject

Returns the value of attribute excluded_project_patterns.



40
41
42
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 40

def excluded_project_patterns
  @excluded_project_patterns
end

#falcon_client_key_idObject

Returns the value of attribute falcon_client_key_id.



42
43
44
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 42

def falcon_client_key_id
  @falcon_client_key_id
end

#falcon_client_key_typeObject

Returns the value of attribute falcon_client_key_type.



44
45
46
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 44

def falcon_client_key_type
  @falcon_client_key_type
end

#foldersObject

Returns the value of attribute folders.



46
47
48
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 46

def folders
  @folders
end

#infra_manager_propertiesObject

Returns the value of attribute infra_manager_properties.



48
49
50
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 48

def infra_manager_properties
  @infra_manager_properties
end

#infra_project_idObject

Returns the value of attribute infra_project_id.



50
51
52
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 50

def infra_project_id
  @infra_project_id
end

#labelsObject

Returns the value of attribute labels.



52
53
54
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 52

def labels
  @labels
end

#log_ingestion_propertiesObject

Returns the value of attribute log_ingestion_properties.



54
55
56
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 54

def log_ingestion_properties
  @log_ingestion_properties
end

#organizationObject

Returns the value of attribute organization.



56
57
58
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 56

def organization
  @organization
end

#productsObject

Returns the value of attribute products.



58
59
60
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 58

def products
  @products
end

#projectsObject

Returns the value of attribute projects.



60
61
62
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 60

def projects
  @projects
end

#registration_idObject

Returns the value of attribute registration_id.



62
63
64
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 62

def registration_id
  @registration_id
end

#registration_nameObject

Returns the value of attribute registration_name.



64
65
66
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 64

def registration_name
  @registration_name
end

#registration_scopeObject

Returns the value of attribute registration_scope.



66
67
68
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 66

def registration_scope
  @registration_scope
end

#resource_name_prefixObject

Returns the value of attribute resource_name_prefix.



68
69
70
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 68

def resource_name_prefix
  @resource_name_prefix
end

#resource_name_suffixObject

Returns the value of attribute resource_name_suffix.



70
71
72
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 70

def resource_name_suffix
  @resource_name_suffix
end

#statusObject

Returns the value of attribute status.



72
73
74
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 72

def status
  @status
end

#tagsObject

Returns the value of attribute tags.



74
75
76
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 74

def tags
  @tags
end

#updatedObject

Returns the value of attribute updated.



76
77
78
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 76

def updated
  @updated
end

#wif_propertiesObject

Returns the value of attribute wif_properties.



78
79
80
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 78

def wif_properties
  @wif_properties
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 81

def self.attribute_map
  {
    :'additional_properties' => :'additional_properties',
    :'created' => :'created',
    :'deployment_method' => :'deployment_method',
    :'excluded_project_patterns' => :'excluded_project_patterns',
    :'falcon_client_key_id' => :'falcon_client_key_id',
    :'falcon_client_key_type' => :'falcon_client_key_type',
    :'folders' => :'folders',
    :'infra_manager_properties' => :'infra_manager_properties',
    :'infra_project_id' => :'infra_project_id',
    :'labels' => :'labels',
    :'log_ingestion_properties' => :'log_ingestion_properties',
    :'organization' => :'organization',
    :'products' => :'products',
    :'projects' => :'projects',
    :'registration_id' => :'registration_id',
    :'registration_name' => :'registration_name',
    :'registration_scope' => :'registration_scope',
    :'resource_name_prefix' => :'resource_name_prefix',
    :'resource_name_suffix' => :'resource_name_suffix',
    :'status' => :'status',
    :'tags' => :'tags',
    :'updated' => :'updated',
    :'wif_properties' => :'wif_properties'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 327

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



144
145
146
147
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 144

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 115

def self.openapi_types
  {
    :'additional_properties' => :'Object',
    :'created' => :'Time',
    :'deployment_method' => :'String',
    :'excluded_project_patterns' => :'Array<String>',
    :'falcon_client_key_id' => :'String',
    :'falcon_client_key_type' => :'String',
    :'folders' => :'Array<DtoFolder>',
    :'infra_manager_properties' => :'DtoInfraManagerProperties',
    :'infra_project_id' => :'String',
    :'labels' => :'Hash<String, String>',
    :'log_ingestion_properties' => :'DtoLogIngestionProperties',
    :'organization' => :'DtoOrganization',
    :'products' => :'Array<DomainProductFeatures>',
    :'projects' => :'Array<DtoProject>',
    :'registration_id' => :'String',
    :'registration_name' => :'String',
    :'registration_scope' => :'String',
    :'resource_name_prefix' => :'String',
    :'resource_name_suffix' => :'String',
    :'status' => :'String',
    :'tags' => :'Hash<String, String>',
    :'updated' => :'Time',
    :'wif_properties' => :'DtoWIFProperties'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      additional_properties == o.additional_properties &&
      created == o.created &&
      deployment_method == o.deployment_method &&
      excluded_project_patterns == o.excluded_project_patterns &&
      falcon_client_key_id == o.falcon_client_key_id &&
      falcon_client_key_type == o.falcon_client_key_type &&
      folders == o.folders &&
      infra_manager_properties == o.infra_manager_properties &&
      infra_project_id == o.infra_project_id &&
      labels == o.labels &&
      log_ingestion_properties == o.log_ingestion_properties &&
      organization == o.organization &&
      products == o.products &&
      projects == o.projects &&
      registration_id == o.registration_id &&
      registration_name == o.registration_name &&
      registration_scope == o.registration_scope &&
      resource_name_prefix == o.resource_name_prefix &&
      resource_name_suffix == o.resource_name_suffix &&
      status == o.status &&
      tags == o.tags &&
      updated == o.updated &&
      wif_properties == o.wif_properties
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 358

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 429

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 334

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 314

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



320
321
322
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 320

def hash
  [additional_properties, created, deployment_method, excluded_project_patterns, falcon_client_key_id, falcon_client_key_type, folders, infra_manager_properties, infra_project_id, labels, log_ingestion_properties, organization, products, projects, registration_id, registration_name, registration_scope, resource_name_prefix, resource_name_suffix, status, tags, updated, wif_properties].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



271
272
273
274
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 271

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



405
406
407
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 405

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 411

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



399
400
401
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 399

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



278
279
280
# File 'lib/crimson-falcon/models/dto_gcp_registration.rb', line 278

def valid?
  true
end