Class: Falcon::DtoUpdateGCPRegistrationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/dto_update_gcp_registration_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DtoUpdateGCPRegistrationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DtoUpdateGCPRegistrationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DtoUpdateGCPRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'additional_properties')
    self.additional_properties = attributes[:'additional_properties']
  end

  if attributes.key?(:'deployment_method')
    self.deployment_method = attributes[:'deployment_method']
  end

  if attributes.key?(:'entity_id')
    if (value = attributes[:'entity_id']).is_a?(Array)
      self.entity_id = value
    end
  end

  if attributes.key?(:'excluded_project_patterns')
    if (value = attributes[:'excluded_project_patterns']).is_a?(Array)
      self.excluded_project_patterns = value
    end
  end

  if attributes.key?(:'falcon_client_key_id')
    self.falcon_client_key_id = attributes[:'falcon_client_key_id']
  end

  if attributes.key?(:'falcon_client_key_type')
    self.falcon_client_key_type = attributes[:'falcon_client_key_type']
  end

  if attributes.key?(:'infra_manager_region')
    self.infra_manager_region = attributes[:'infra_manager_region']
  end

  if attributes.key?(:'infra_project_id')
    self.infra_project_id = attributes[:'infra_project_id']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  end

  if attributes.key?(:'log_ingestion_sink_name')
    self.log_ingestion_sink_name = attributes[:'log_ingestion_sink_name']
  end

  if attributes.key?(:'log_ingestion_subscription_name')
    self.log_ingestion_subscription_name = attributes[:'log_ingestion_subscription_name']
  end

  if attributes.key?(:'log_ingestion_topic_id')
    self.log_ingestion_topic_id = attributes[:'log_ingestion_topic_id']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'registration_name')
    self.registration_name = attributes[:'registration_name']
  end

  if attributes.key?(:'registration_scope')
    self.registration_scope = attributes[:'registration_scope']
  end

  if attributes.key?(:'resource_name_prefix')
    self.resource_name_prefix = attributes[:'resource_name_prefix']
  end

  if attributes.key?(:'resource_name_suffix')
    self.resource_name_suffix = attributes[:'resource_name_suffix']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'wif_pool_name')
    self.wif_pool_name = attributes[:'wif_pool_name']
  end

  if attributes.key?(:'wif_project_id')
    self.wif_project_id = attributes[:'wif_project_id']
  end

  if attributes.key?(:'wif_project_number')
    self.wif_project_number = attributes[:'wif_project_number']
  end

  if attributes.key?(:'wif_provider_name')
    self.wif_provider_name = attributes[:'wif_provider_name']
  end
end

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



34
35
36
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 34

def additional_properties
  @additional_properties
end

#deployment_methodObject

Returns the value of attribute deployment_method.



36
37
38
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 36

def deployment_method
  @deployment_method
end

#entity_idObject

Returns the value of attribute entity_id.



38
39
40
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 38

def entity_id
  @entity_id
end

#excluded_project_patternsObject

Returns the value of attribute excluded_project_patterns.



40
41
42
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 40

def excluded_project_patterns
  @excluded_project_patterns
end

#falcon_client_key_idObject

Returns the value of attribute falcon_client_key_id.



42
43
44
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 42

def falcon_client_key_id
  @falcon_client_key_id
end

#falcon_client_key_typeObject

Returns the value of attribute falcon_client_key_type.



44
45
46
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 44

def falcon_client_key_type
  @falcon_client_key_type
end

#infra_manager_regionObject

Returns the value of attribute infra_manager_region.



46
47
48
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 46

def infra_manager_region
  @infra_manager_region
end

#infra_project_idObject

Returns the value of attribute infra_project_id.



48
49
50
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 48

def infra_project_id
  @infra_project_id
end

#labelsObject

Returns the value of attribute labels.



50
51
52
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 50

def labels
  @labels
end

#log_ingestion_sink_nameObject

Returns the value of attribute log_ingestion_sink_name.



52
53
54
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 52

def log_ingestion_sink_name
  @log_ingestion_sink_name
end

#log_ingestion_subscription_nameObject

Returns the value of attribute log_ingestion_subscription_name.



54
55
56
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 54

def log_ingestion_subscription_name
  @log_ingestion_subscription_name
end

#log_ingestion_topic_idObject

Returns the value of attribute log_ingestion_topic_id.



56
57
58
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 56

def log_ingestion_topic_id
  @log_ingestion_topic_id
end

#productsObject

Returns the value of attribute products.



58
59
60
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 58

def products
  @products
end

#registration_nameObject

Returns the value of attribute registration_name.



60
61
62
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 60

def registration_name
  @registration_name
end

#registration_scopeObject

Returns the value of attribute registration_scope.



62
63
64
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 62

def registration_scope
  @registration_scope
end

#resource_name_prefixObject

Returns the value of attribute resource_name_prefix.



64
65
66
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 64

def resource_name_prefix
  @resource_name_prefix
end

#resource_name_suffixObject

Returns the value of attribute resource_name_suffix.



66
67
68
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 66

def resource_name_suffix
  @resource_name_suffix
end

#tagsObject

Returns the value of attribute tags.



68
69
70
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 68

def tags
  @tags
end

#wif_pool_nameObject

Returns the value of attribute wif_pool_name.



70
71
72
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 70

def wif_pool_name
  @wif_pool_name
end

#wif_project_idObject

Returns the value of attribute wif_project_id.



72
73
74
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 72

def wif_project_id
  @wif_project_id
end

#wif_project_numberObject

Returns the value of attribute wif_project_number.



74
75
76
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 74

def wif_project_number
  @wif_project_number
end

#wif_provider_nameObject

Returns the value of attribute wif_provider_name.



76
77
78
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 76

def wif_provider_name
  @wif_provider_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 107

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 79

def self.attribute_map
  {
    :'additional_properties' => :'additional_properties',
    :'deployment_method' => :'deployment_method',
    :'entity_id' => :'entity_id',
    :'excluded_project_patterns' => :'excluded_project_patterns',
    :'falcon_client_key_id' => :'falcon_client_key_id',
    :'falcon_client_key_type' => :'falcon_client_key_type',
    :'infra_manager_region' => :'infra_manager_region',
    :'infra_project_id' => :'infra_project_id',
    :'labels' => :'labels',
    :'log_ingestion_sink_name' => :'log_ingestion_sink_name',
    :'log_ingestion_subscription_name' => :'log_ingestion_subscription_name',
    :'log_ingestion_topic_id' => :'log_ingestion_topic_id',
    :'products' => :'products',
    :'registration_name' => :'registration_name',
    :'registration_scope' => :'registration_scope',
    :'resource_name_prefix' => :'resource_name_prefix',
    :'resource_name_suffix' => :'resource_name_suffix',
    :'tags' => :'tags',
    :'wif_pool_name' => :'wif_pool_name',
    :'wif_project_id' => :'wif_project_id',
    :'wif_project_number' => :'wif_project_number',
    :'wif_provider_name' => :'wif_provider_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 316

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 112

def self.openapi_types
  {
    :'additional_properties' => :'Object',
    :'deployment_method' => :'String',
    :'entity_id' => :'Array<String>',
    :'excluded_project_patterns' => :'Array<String>',
    :'falcon_client_key_id' => :'String',
    :'falcon_client_key_type' => :'String',
    :'infra_manager_region' => :'String',
    :'infra_project_id' => :'String',
    :'labels' => :'Hash<String, String>',
    :'log_ingestion_sink_name' => :'String',
    :'log_ingestion_subscription_name' => :'String',
    :'log_ingestion_topic_id' => :'String',
    :'products' => :'Array<DomainProductFeatures>',
    :'registration_name' => :'String',
    :'registration_scope' => :'String',
    :'resource_name_prefix' => :'String',
    :'resource_name_suffix' => :'String',
    :'tags' => :'Hash<String, String>',
    :'wif_pool_name' => :'String',
    :'wif_project_id' => :'String',
    :'wif_project_number' => :'String',
    :'wif_provider_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      additional_properties == o.additional_properties &&
      deployment_method == o.deployment_method &&
      entity_id == o.entity_id &&
      excluded_project_patterns == o.excluded_project_patterns &&
      falcon_client_key_id == o.falcon_client_key_id &&
      falcon_client_key_type == o.falcon_client_key_type &&
      infra_manager_region == o.infra_manager_region &&
      infra_project_id == o.infra_project_id &&
      labels == o.labels &&
      log_ingestion_sink_name == o.log_ingestion_sink_name &&
      log_ingestion_subscription_name == o.log_ingestion_subscription_name &&
      log_ingestion_topic_id == o.log_ingestion_topic_id &&
      products == o.products &&
      registration_name == o.registration_name &&
      registration_scope == o.registration_scope &&
      resource_name_prefix == o.resource_name_prefix &&
      resource_name_suffix == o.resource_name_suffix &&
      tags == o.tags &&
      wif_pool_name == o.wif_pool_name &&
      wif_project_id == o.wif_project_id &&
      wif_project_number == o.wif_project_number &&
      wif_provider_name == o.wif_provider_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 347

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 418

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 323

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 309

def hash
  [additional_properties, deployment_method, entity_id, excluded_project_patterns, falcon_client_key_id, falcon_client_key_type, infra_manager_region, infra_project_id, labels, log_ingestion_sink_name, log_ingestion_subscription_name, log_ingestion_topic_id, products, registration_name, registration_scope, resource_name_prefix, resource_name_suffix, tags, wif_pool_name, wif_project_id, wif_project_number, wif_provider_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



261
262
263
264
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 261

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 394

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 400

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



388
389
390
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 388

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



268
269
270
# File 'lib/crimson-falcon/models/dto_update_gcp_registration_request.rb', line 268

def valid?
  true
end