Class: Falcon::EmpowerapiRemoteCommandPutFileV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmpowerapiRemoteCommandPutFileV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::EmpowerapiRemoteCommandPutFileV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::EmpowerapiRemoteCommandPutFileV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'comments_for_audit_log')
    self.comments_for_audit_log = attributes[:'comments_for_audit_log']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_by_uuid')
    self.created_by_uuid = attributes[:'created_by_uuid']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'file_type')
    self.file_type = attributes[:'file_type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'modified_by_uuid')
    self.modified_by_uuid = attributes[:'modified_by_uuid']
  end

  if attributes.key?(:'modified_timestamp')
    self.modified_timestamp = attributes[:'modified_timestamp']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'permission_type')
    self.permission_type = attributes[:'permission_type']
  end

  if attributes.key?(:'platform')
    if (value = attributes[:'platform']).is_a?(Array)
      self.platform = value
    end
  end

  if attributes.key?(:'run_attempt_count')
    self.run_attempt_count = attributes[:'run_attempt_count']
  end

  if attributes.key?(:'run_success_count')
    self.run_success_count = attributes[:'run_success_count']
  end

  if attributes.key?(:'sha256')
    self.sha256 = attributes[:'sha256']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'write_access')
    self.write_access = attributes[:'write_access']
  end
end

Instance Attribute Details

#comments_for_audit_logObject

Returns the value of attribute comments_for_audit_log.



34
35
36
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 34

def comments_for_audit_log
  @comments_for_audit_log
end

#contentObject

Returns the value of attribute content.



36
37
38
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 36

def content
  @content
end

#created_byObject

Returns the value of attribute created_by.



38
39
40
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 38

def created_by
  @created_by
end

#created_by_uuidObject

Returns the value of attribute created_by_uuid.



40
41
42
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 40

def created_by_uuid
  @created_by_uuid
end

#created_timestampObject

Returns the value of attribute created_timestamp.



42
43
44
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 42

def created_timestamp
  @created_timestamp
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 44

def description
  @description
end

#file_typeObject

Returns the value of attribute file_type.



46
47
48
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 46

def file_type
  @file_type
end

#idObject

Returns the value of attribute id.



48
49
50
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 48

def id
  @id
end

#modified_byObject

Returns the value of attribute modified_by.



50
51
52
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 50

def modified_by
  @modified_by
end

#modified_by_uuidObject

Returns the value of attribute modified_by_uuid.



52
53
54
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 52

def modified_by_uuid
  @modified_by_uuid
end

#modified_timestampObject

Returns the value of attribute modified_timestamp.



54
55
56
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 54

def modified_timestamp
  @modified_timestamp
end

#nameObject

Returns the value of attribute name.



56
57
58
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 56

def name
  @name
end

#permission_typeObject

Returns the value of attribute permission_type.



58
59
60
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 58

def permission_type
  @permission_type
end

#platformObject

Returns the value of attribute platform.



60
61
62
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 60

def platform
  @platform
end

#run_attempt_countObject

Returns the value of attribute run_attempt_count.



62
63
64
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 62

def run_attempt_count
  @run_attempt_count
end

#run_success_countObject

Returns the value of attribute run_success_count.



64
65
66
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 64

def run_success_count
  @run_success_count
end

#sha256Object

Returns the value of attribute sha256.



66
67
68
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 66

def sha256
  @sha256
end

#sizeObject

Returns the value of attribute size.



68
69
70
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 68

def size
  @size
end

#write_accessObject

Returns the value of attribute write_access.



70
71
72
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 70

def write_access
  @write_access
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 73

def self.attribute_map
  {
    :'comments_for_audit_log' => :'comments_for_audit_log',
    :'content' => :'content',
    :'created_by' => :'created_by',
    :'created_by_uuid' => :'created_by_uuid',
    :'created_timestamp' => :'created_timestamp',
    :'description' => :'description',
    :'file_type' => :'file_type',
    :'id' => :'id',
    :'modified_by' => :'modified_by',
    :'modified_by_uuid' => :'modified_by_uuid',
    :'modified_timestamp' => :'modified_timestamp',
    :'name' => :'name',
    :'permission_type' => :'permission_type',
    :'platform' => :'platform',
    :'run_attempt_count' => :'run_attempt_count',
    :'run_success_count' => :'run_success_count',
    :'sha256' => :'sha256',
    :'size' => :'size',
    :'write_access' => :'write_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 296

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 103

def self.openapi_types
  {
    :'comments_for_audit_log' => :'String',
    :'content' => :'String',
    :'created_by' => :'String',
    :'created_by_uuid' => :'String',
    :'created_timestamp' => :'Time',
    :'description' => :'String',
    :'file_type' => :'String',
    :'id' => :'String',
    :'modified_by' => :'String',
    :'modified_by_uuid' => :'String',
    :'modified_timestamp' => :'Time',
    :'name' => :'String',
    :'permission_type' => :'String',
    :'platform' => :'Array<String>',
    :'run_attempt_count' => :'Integer',
    :'run_success_count' => :'Integer',
    :'sha256' => :'String',
    :'size' => :'Integer',
    :'write_access' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      comments_for_audit_log == o.comments_for_audit_log &&
      content == o.content &&
      created_by == o.created_by &&
      created_by_uuid == o.created_by_uuid &&
      created_timestamp == o.created_timestamp &&
      description == o.description &&
      file_type == o.file_type &&
      id == o.id &&
      modified_by == o.modified_by &&
      modified_by_uuid == o.modified_by_uuid &&
      modified_timestamp == o.modified_timestamp &&
      name == o.name &&
      permission_type == o.permission_type &&
      platform == o.platform &&
      run_attempt_count == o.run_attempt_count &&
      run_success_count == o.run_success_count &&
      sha256 == o.sha256 &&
      size == o.size &&
      write_access == o.write_access
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 327

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 289

def hash
  [comments_for_audit_log, content, created_by, created_by_uuid, created_timestamp, description, file_type, id, modified_by, modified_by_uuid, modified_timestamp, name, permission_type, platform, run_attempt_count, run_success_count, sha256, size, write_access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 229

def list_invalid_properties
  invalid_properties = Array.new
  if @run_attempt_count.nil?
    invalid_properties.push('invalid value for "run_attempt_count", run_attempt_count cannot be nil.')
  end

  if @run_success_count.nil?
    invalid_properties.push('invalid value for "run_success_count", run_success_count cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 374

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



368
369
370
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 368

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



248
249
250
251
252
253
# File 'lib/crimson-falcon/models/empowerapi_remote_command_put_file_v1.rb', line 248

def valid?
  return false if @run_attempt_count.nil?
  return false if @run_success_count.nil?
  return false if @size.nil?
  true
end