Class: Falcon::EntitiesODSScanRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/entities_ods_scan_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EntitiesODSScanRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 171

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::EntitiesODSScanRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::EntitiesODSScanRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cloud_ml_level_detection')
    self.cloud_ml_level_detection = attributes[:'cloud_ml_level_detection']
  end

  if attributes.key?(:'cloud_ml_level_prevention')
    self.cloud_ml_level_prevention = attributes[:'cloud_ml_level_prevention']
  end

  if attributes.key?(:'cloud_pup_adware_level_detection')
    self.cloud_pup_adware_level_detection = attributes[:'cloud_pup_adware_level_detection']
  end

  if attributes.key?(:'cloud_pup_adware_level_prevention')
    self.cloud_pup_adware_level_prevention = attributes[:'cloud_pup_adware_level_prevention']
  end

  if attributes.key?(:'cpu_priority')
    self.cpu_priority = attributes[:'cpu_priority']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'endpoint_notification')
    self.endpoint_notification = attributes[:'endpoint_notification']
  end

  if attributes.key?(:'file_paths')
    if (value = attributes[:'file_paths']).is_a?(Array)
      self.file_paths = value
    end
  end

  if attributes.key?(:'host_groups')
    if (value = attributes[:'host_groups']).is_a?(Array)
      self.host_groups = value
    end
  end

  if attributes.key?(:'hosts')
    if (value = attributes[:'hosts']).is_a?(Array)
      self.hosts = value
    end
  end

  if attributes.key?(:'initiated_from')
    self.initiated_from = attributes[:'initiated_from']
  end

  if attributes.key?(:'mac_cloud_ml_level_detection')
    self.mac_cloud_ml_level_detection = attributes[:'mac_cloud_ml_level_detection']
  end

  if attributes.key?(:'mac_cloud_ml_level_prevention')
    self.mac_cloud_ml_level_prevention = attributes[:'mac_cloud_ml_level_prevention']
  end

  if attributes.key?(:'mac_cloud_pup_adware_level_detection')
    self.mac_cloud_pup_adware_level_detection = attributes[:'mac_cloud_pup_adware_level_detection']
  end

  if attributes.key?(:'mac_cloud_pup_adware_level_prevention')
    self.mac_cloud_pup_adware_level_prevention = attributes[:'mac_cloud_pup_adware_level_prevention']
  end

  if attributes.key?(:'mac_scan_exclusions')
    if (value = attributes[:'mac_scan_exclusions']).is_a?(Array)
      self.mac_scan_exclusions = value
    end
  end

  if attributes.key?(:'mac_scan_inclusions')
    if (value = attributes[:'mac_scan_inclusions']).is_a?(Array)
      self.mac_scan_inclusions = value
    end
  end

  if attributes.key?(:'mac_sensor_ml_level_detection')
    self.mac_sensor_ml_level_detection = attributes[:'mac_sensor_ml_level_detection']
  end

  if attributes.key?(:'mac_sensor_ml_level_prevention')
    self.mac_sensor_ml_level_prevention = attributes[:'mac_sensor_ml_level_prevention']
  end

  if attributes.key?(:'mac_sensor_pup_adware_level_detection')
    self.mac_sensor_pup_adware_level_detection = attributes[:'mac_sensor_pup_adware_level_detection']
  end

  if attributes.key?(:'mac_sensor_pup_adware_level_prevention')
    self.mac_sensor_pup_adware_level_prevention = attributes[:'mac_sensor_pup_adware_level_prevention']
  end

  if attributes.key?(:'max_duration')
    self.max_duration = attributes[:'max_duration']
  end

  if attributes.key?(:'pause_duration')
    self.pause_duration = attributes[:'pause_duration']
  end

  if attributes.key?(:'quarantine')
    self.quarantine = attributes[:'quarantine']
  end

  if attributes.key?(:'scan_exclusions')
    if (value = attributes[:'scan_exclusions']).is_a?(Array)
      self.scan_exclusions = value
    end
  end

  if attributes.key?(:'scan_inclusions')
    if (value = attributes[:'scan_inclusions']).is_a?(Array)
      self.scan_inclusions = value
    end
  end

  if attributes.key?(:'sensor_ml_level_detection')
    self.sensor_ml_level_detection = attributes[:'sensor_ml_level_detection']
  end

  if attributes.key?(:'sensor_ml_level_prevention')
    self.sensor_ml_level_prevention = attributes[:'sensor_ml_level_prevention']
  end
end

Instance Attribute Details

#cloud_ml_level_detectionObject

Returns the value of attribute cloud_ml_level_detection.



34
35
36
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 34

def cloud_ml_level_detection
  @cloud_ml_level_detection
end

#cloud_ml_level_preventionObject

Returns the value of attribute cloud_ml_level_prevention.



36
37
38
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 36

def cloud_ml_level_prevention
  @cloud_ml_level_prevention
end

#cloud_pup_adware_level_detectionObject

Returns the value of attribute cloud_pup_adware_level_detection.



38
39
40
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 38

def cloud_pup_adware_level_detection
  @cloud_pup_adware_level_detection
end

#cloud_pup_adware_level_preventionObject

Returns the value of attribute cloud_pup_adware_level_prevention.



40
41
42
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 40

def cloud_pup_adware_level_prevention
  @cloud_pup_adware_level_prevention
end

#cpu_priorityObject

Returns the value of attribute cpu_priority.



42
43
44
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 42

def cpu_priority
  @cpu_priority
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 44

def description
  @description
end

#endpoint_notificationObject

Returns the value of attribute endpoint_notification.



46
47
48
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 46

def endpoint_notification
  @endpoint_notification
end

#file_pathsObject

Returns the value of attribute file_paths.



48
49
50
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 48

def file_paths
  @file_paths
end

#host_groupsObject

Returns the value of attribute host_groups.



50
51
52
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 50

def host_groups
  @host_groups
end

#hostsObject

Returns the value of attribute hosts.



52
53
54
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 52

def hosts
  @hosts
end

#initiated_fromObject

Returns the value of attribute initiated_from.



54
55
56
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 54

def initiated_from
  @initiated_from
end

#mac_cloud_ml_level_detectionObject

Returns the value of attribute mac_cloud_ml_level_detection.



56
57
58
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 56

def mac_cloud_ml_level_detection
  @mac_cloud_ml_level_detection
end

#mac_cloud_ml_level_preventionObject

Returns the value of attribute mac_cloud_ml_level_prevention.



58
59
60
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 58

def mac_cloud_ml_level_prevention
  @mac_cloud_ml_level_prevention
end

#mac_cloud_pup_adware_level_detectionObject

Returns the value of attribute mac_cloud_pup_adware_level_detection.



60
61
62
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 60

def mac_cloud_pup_adware_level_detection
  @mac_cloud_pup_adware_level_detection
end

#mac_cloud_pup_adware_level_preventionObject

Returns the value of attribute mac_cloud_pup_adware_level_prevention.



62
63
64
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 62

def mac_cloud_pup_adware_level_prevention
  @mac_cloud_pup_adware_level_prevention
end

#mac_scan_exclusionsObject

Returns the value of attribute mac_scan_exclusions.



64
65
66
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 64

def mac_scan_exclusions
  @mac_scan_exclusions
end

#mac_scan_inclusionsObject

Returns the value of attribute mac_scan_inclusions.



66
67
68
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 66

def mac_scan_inclusions
  @mac_scan_inclusions
end

#mac_sensor_ml_level_detectionObject

Returns the value of attribute mac_sensor_ml_level_detection.



68
69
70
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 68

def mac_sensor_ml_level_detection
  @mac_sensor_ml_level_detection
end

#mac_sensor_ml_level_preventionObject

Returns the value of attribute mac_sensor_ml_level_prevention.



70
71
72
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 70

def mac_sensor_ml_level_prevention
  @mac_sensor_ml_level_prevention
end

#mac_sensor_pup_adware_level_detectionObject

Returns the value of attribute mac_sensor_pup_adware_level_detection.



72
73
74
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 72

def mac_sensor_pup_adware_level_detection
  @mac_sensor_pup_adware_level_detection
end

#mac_sensor_pup_adware_level_preventionObject

Returns the value of attribute mac_sensor_pup_adware_level_prevention.



74
75
76
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 74

def mac_sensor_pup_adware_level_prevention
  @mac_sensor_pup_adware_level_prevention
end

#max_durationObject

Returns the value of attribute max_duration.



76
77
78
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 76

def max_duration
  @max_duration
end

#pause_durationObject

Returns the value of attribute pause_duration.



78
79
80
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 78

def pause_duration
  @pause_duration
end

#quarantineObject

Returns the value of attribute quarantine.



80
81
82
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 80

def quarantine
  @quarantine
end

#scan_exclusionsObject

Returns the value of attribute scan_exclusions.



82
83
84
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 82

def scan_exclusions
  @scan_exclusions
end

#scan_inclusionsObject

Returns the value of attribute scan_inclusions.



84
85
86
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 84

def scan_inclusions
  @scan_inclusions
end

#sensor_ml_level_detectionObject

Returns the value of attribute sensor_ml_level_detection.



86
87
88
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 86

def sensor_ml_level_detection
  @sensor_ml_level_detection
end

#sensor_ml_level_preventionObject

Returns the value of attribute sensor_ml_level_prevention.



88
89
90
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 88

def sensor_ml_level_prevention
  @sensor_ml_level_prevention
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 125

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 91

def self.attribute_map
  {
    :'cloud_ml_level_detection' => :'cloud_ml_level_detection',
    :'cloud_ml_level_prevention' => :'cloud_ml_level_prevention',
    :'cloud_pup_adware_level_detection' => :'cloud_pup_adware_level_detection',
    :'cloud_pup_adware_level_prevention' => :'cloud_pup_adware_level_prevention',
    :'cpu_priority' => :'cpu_priority',
    :'description' => :'description',
    :'endpoint_notification' => :'endpoint_notification',
    :'file_paths' => :'file_paths',
    :'host_groups' => :'host_groups',
    :'hosts' => :'hosts',
    :'initiated_from' => :'initiated_from',
    :'mac_cloud_ml_level_detection' => :'mac_cloud_ml_level_detection',
    :'mac_cloud_ml_level_prevention' => :'mac_cloud_ml_level_prevention',
    :'mac_cloud_pup_adware_level_detection' => :'mac_cloud_pup_adware_level_detection',
    :'mac_cloud_pup_adware_level_prevention' => :'mac_cloud_pup_adware_level_prevention',
    :'mac_scan_exclusions' => :'mac_scan_exclusions',
    :'mac_scan_inclusions' => :'mac_scan_inclusions',
    :'mac_sensor_ml_level_detection' => :'mac_sensor_ml_level_detection',
    :'mac_sensor_ml_level_prevention' => :'mac_sensor_ml_level_prevention',
    :'mac_sensor_pup_adware_level_detection' => :'mac_sensor_pup_adware_level_detection',
    :'mac_sensor_pup_adware_level_prevention' => :'mac_sensor_pup_adware_level_prevention',
    :'max_duration' => :'max_duration',
    :'pause_duration' => :'pause_duration',
    :'quarantine' => :'quarantine',
    :'scan_exclusions' => :'scan_exclusions',
    :'scan_inclusions' => :'scan_inclusions',
    :'sensor_ml_level_detection' => :'sensor_ml_level_detection',
    :'sensor_ml_level_prevention' => :'sensor_ml_level_prevention'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



514
515
516
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 514

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



164
165
166
167
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 164

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 130

def self.openapi_types
  {
    :'cloud_ml_level_detection' => :'Integer',
    :'cloud_ml_level_prevention' => :'Integer',
    :'cloud_pup_adware_level_detection' => :'Integer',
    :'cloud_pup_adware_level_prevention' => :'Integer',
    :'cpu_priority' => :'Integer',
    :'description' => :'String',
    :'endpoint_notification' => :'Boolean',
    :'file_paths' => :'Array<String>',
    :'host_groups' => :'Array<String>',
    :'hosts' => :'Array<String>',
    :'initiated_from' => :'String',
    :'mac_cloud_ml_level_detection' => :'Integer',
    :'mac_cloud_ml_level_prevention' => :'Integer',
    :'mac_cloud_pup_adware_level_detection' => :'Integer',
    :'mac_cloud_pup_adware_level_prevention' => :'Integer',
    :'mac_scan_exclusions' => :'Array<String>',
    :'mac_scan_inclusions' => :'Array<String>',
    :'mac_sensor_ml_level_detection' => :'Integer',
    :'mac_sensor_ml_level_prevention' => :'Integer',
    :'mac_sensor_pup_adware_level_detection' => :'Integer',
    :'mac_sensor_pup_adware_level_prevention' => :'Integer',
    :'max_duration' => :'Integer',
    :'pause_duration' => :'Integer',
    :'quarantine' => :'Boolean',
    :'scan_exclusions' => :'Array<String>',
    :'scan_inclusions' => :'Array<String>',
    :'sensor_ml_level_detection' => :'Integer',
    :'sensor_ml_level_prevention' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 466

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cloud_ml_level_detection == o.cloud_ml_level_detection &&
      cloud_ml_level_prevention == o.cloud_ml_level_prevention &&
      cloud_pup_adware_level_detection == o.cloud_pup_adware_level_detection &&
      cloud_pup_adware_level_prevention == o.cloud_pup_adware_level_prevention &&
      cpu_priority == o.cpu_priority &&
      description == o.description &&
      endpoint_notification == o.endpoint_notification &&
      file_paths == o.file_paths &&
      host_groups == o.host_groups &&
      hosts == o.hosts &&
      initiated_from == o.initiated_from &&
      mac_cloud_ml_level_detection == o.mac_cloud_ml_level_detection &&
      mac_cloud_ml_level_prevention == o.mac_cloud_ml_level_prevention &&
      mac_cloud_pup_adware_level_detection == o.mac_cloud_pup_adware_level_detection &&
      mac_cloud_pup_adware_level_prevention == o.mac_cloud_pup_adware_level_prevention &&
      mac_scan_exclusions == o.mac_scan_exclusions &&
      mac_scan_inclusions == o.mac_scan_inclusions &&
      mac_sensor_ml_level_detection == o.mac_sensor_ml_level_detection &&
      mac_sensor_ml_level_prevention == o.mac_sensor_ml_level_prevention &&
      mac_sensor_pup_adware_level_detection == o.mac_sensor_pup_adware_level_detection &&
      mac_sensor_pup_adware_level_prevention == o.mac_sensor_pup_adware_level_prevention &&
      max_duration == o.max_duration &&
      pause_duration == o.pause_duration &&
      quarantine == o.quarantine &&
      scan_exclusions == o.scan_exclusions &&
      scan_inclusions == o.scan_inclusions &&
      sensor_ml_level_detection == o.sensor_ml_level_detection &&
      sensor_ml_level_prevention == o.sensor_ml_level_prevention
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 545

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 616

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 521

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


501
502
503
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 501

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



507
508
509
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 507

def hash
  [cloud_ml_level_detection, cloud_ml_level_prevention, cloud_pup_adware_level_detection, cloud_pup_adware_level_prevention, cpu_priority, description, endpoint_notification, file_paths, host_groups, hosts, initiated_from, mac_cloud_ml_level_detection, mac_cloud_ml_level_prevention, mac_cloud_pup_adware_level_detection, mac_cloud_pup_adware_level_prevention, mac_scan_exclusions, mac_scan_inclusions, mac_sensor_ml_level_detection, mac_sensor_ml_level_prevention, mac_sensor_pup_adware_level_detection, mac_sensor_pup_adware_level_prevention, max_duration, pause_duration, quarantine, scan_exclusions, scan_inclusions, sensor_ml_level_detection, sensor_ml_level_prevention].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 313

def list_invalid_properties
  invalid_properties = Array.new
  if @cloud_ml_level_detection.nil?
    invalid_properties.push('invalid value for "cloud_ml_level_detection", cloud_ml_level_detection cannot be nil.')
  end

  if @cloud_ml_level_prevention.nil?
    invalid_properties.push('invalid value for "cloud_ml_level_prevention", cloud_ml_level_prevention cannot be nil.')
  end

  if @cloud_pup_adware_level_detection.nil?
    invalid_properties.push('invalid value for "cloud_pup_adware_level_detection", cloud_pup_adware_level_detection cannot be nil.')
  end

  if @cloud_pup_adware_level_prevention.nil?
    invalid_properties.push('invalid value for "cloud_pup_adware_level_prevention", cloud_pup_adware_level_prevention cannot be nil.')
  end

  if @cpu_priority.nil?
    invalid_properties.push('invalid value for "cpu_priority", cpu_priority cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @endpoint_notification.nil?
    invalid_properties.push('invalid value for "endpoint_notification", endpoint_notification cannot be nil.')
  end

  if @file_paths.nil?
    invalid_properties.push('invalid value for "file_paths", file_paths cannot be nil.')
  end

  if @host_groups.nil?
    invalid_properties.push('invalid value for "host_groups", host_groups cannot be nil.')
  end

  if @hosts.nil?
    invalid_properties.push('invalid value for "hosts", hosts cannot be nil.')
  end

  if @initiated_from.nil?
    invalid_properties.push('invalid value for "initiated_from", initiated_from cannot be nil.')
  end

  if @mac_cloud_ml_level_detection.nil?
    invalid_properties.push('invalid value for "mac_cloud_ml_level_detection", mac_cloud_ml_level_detection cannot be nil.')
  end

  if @mac_cloud_ml_level_prevention.nil?
    invalid_properties.push('invalid value for "mac_cloud_ml_level_prevention", mac_cloud_ml_level_prevention cannot be nil.')
  end

  if @mac_cloud_pup_adware_level_detection.nil?
    invalid_properties.push('invalid value for "mac_cloud_pup_adware_level_detection", mac_cloud_pup_adware_level_detection cannot be nil.')
  end

  if @mac_cloud_pup_adware_level_prevention.nil?
    invalid_properties.push('invalid value for "mac_cloud_pup_adware_level_prevention", mac_cloud_pup_adware_level_prevention cannot be nil.')
  end

  if @mac_scan_exclusions.nil?
    invalid_properties.push('invalid value for "mac_scan_exclusions", mac_scan_exclusions cannot be nil.')
  end

  if @mac_scan_inclusions.nil?
    invalid_properties.push('invalid value for "mac_scan_inclusions", mac_scan_inclusions cannot be nil.')
  end

  if @mac_sensor_ml_level_detection.nil?
    invalid_properties.push('invalid value for "mac_sensor_ml_level_detection", mac_sensor_ml_level_detection cannot be nil.')
  end

  if @mac_sensor_ml_level_prevention.nil?
    invalid_properties.push('invalid value for "mac_sensor_ml_level_prevention", mac_sensor_ml_level_prevention cannot be nil.')
  end

  if @mac_sensor_pup_adware_level_detection.nil?
    invalid_properties.push('invalid value for "mac_sensor_pup_adware_level_detection", mac_sensor_pup_adware_level_detection cannot be nil.')
  end

  if @mac_sensor_pup_adware_level_prevention.nil?
    invalid_properties.push('invalid value for "mac_sensor_pup_adware_level_prevention", mac_sensor_pup_adware_level_prevention cannot be nil.')
  end

  if @max_duration.nil?
    invalid_properties.push('invalid value for "max_duration", max_duration cannot be nil.')
  end

  if @pause_duration.nil?
    invalid_properties.push('invalid value for "pause_duration", pause_duration cannot be nil.')
  end

  if @quarantine.nil?
    invalid_properties.push('invalid value for "quarantine", quarantine cannot be nil.')
  end

  if @scan_exclusions.nil?
    invalid_properties.push('invalid value for "scan_exclusions", scan_exclusions cannot be nil.')
  end

  if @scan_inclusions.nil?
    invalid_properties.push('invalid value for "scan_inclusions", scan_inclusions cannot be nil.')
  end

  if @sensor_ml_level_detection.nil?
    invalid_properties.push('invalid value for "sensor_ml_level_detection", sensor_ml_level_detection cannot be nil.')
  end

  if @sensor_ml_level_prevention.nil?
    invalid_properties.push('invalid value for "sensor_ml_level_prevention", sensor_ml_level_prevention cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



592
593
594
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 592

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 598

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



586
587
588
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 586

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/crimson-falcon/models/entities_ods_scan_request.rb', line 432

def valid?
  return false if @cloud_ml_level_detection.nil?
  return false if @cloud_ml_level_prevention.nil?
  return false if @cloud_pup_adware_level_detection.nil?
  return false if @cloud_pup_adware_level_prevention.nil?
  return false if @cpu_priority.nil?
  return false if @description.nil?
  return false if @endpoint_notification.nil?
  return false if @file_paths.nil?
  return false if @host_groups.nil?
  return false if @hosts.nil?
  return false if @initiated_from.nil?
  return false if @mac_cloud_ml_level_detection.nil?
  return false if @mac_cloud_ml_level_prevention.nil?
  return false if @mac_cloud_pup_adware_level_detection.nil?
  return false if @mac_cloud_pup_adware_level_prevention.nil?
  return false if @mac_scan_exclusions.nil?
  return false if @mac_scan_inclusions.nil?
  return false if @mac_sensor_ml_level_detection.nil?
  return false if @mac_sensor_ml_level_prevention.nil?
  return false if @mac_sensor_pup_adware_level_detection.nil?
  return false if @mac_sensor_pup_adware_level_prevention.nil?
  return false if @max_duration.nil?
  return false if @pause_duration.nil?
  return false if @quarantine.nil?
  return false if @scan_exclusions.nil?
  return false if @scan_inclusions.nil?
  return false if @sensor_ml_level_detection.nil?
  return false if @sensor_ml_level_prevention.nil?
  true
end