Class: Falcon::EvaluationsEvaluationResource

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/evaluations_evaluation_resource.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EvaluationsEvaluationResource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::EvaluationsEvaluationResource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::EvaluationsEvaluationResource`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'captured')
    self.captured = attributes[:'captured']
  end

  if attributes.key?(:'cloud_groups')
    if (value = attributes[:'cloud_groups']).is_a?(Array)
      self.cloud_groups = value
    end
  end

  if attributes.key?(:'cloud_labels')
    if (value = attributes[:'cloud_labels']).is_a?(Array)
      self.cloud_labels = value
    end
  end

  if attributes.key?(:'cloud_scopes')
    if (value = attributes[:'cloud_scopes']).is_a?(Array)
      self.cloud_scopes = value
    end
  end

  if attributes.key?(:'creation_time')
    self.creation_time = attributes[:'creation_time']
  end

  if attributes.key?(:'gcrn')
    self.gcrn = attributes[:'gcrn']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'resource_type')
    self.resource_type = attributes[:'resource_type']
  end

  if attributes.key?(:'resource_type_name')
    self.resource_type_name = attributes[:'resource_type_name']
  end

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  end

  if attributes.key?(:'service_category')
    self.service_category = attributes[:'service_category']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#capturedObject

Returns the value of attribute captured.



34
35
36
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 34

def captured
  @captured
end

#cloud_groupsObject

Returns the value of attribute cloud_groups.



36
37
38
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 36

def cloud_groups
  @cloud_groups
end

#cloud_labelsObject

Returns the value of attribute cloud_labels.



38
39
40
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 38

def cloud_labels
  @cloud_labels
end

#cloud_scopesObject

Returns the value of attribute cloud_scopes.



40
41
42
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 40

def cloud_scopes
  @cloud_scopes
end

#creation_timeObject

Returns the value of attribute creation_time.



42
43
44
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 42

def creation_time
  @creation_time
end

#gcrnObject

Returns the value of attribute gcrn.



44
45
46
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 44

def gcrn
  @gcrn
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 46

def id
  @id
end

#resource_idObject

Returns the value of attribute resource_id.



48
49
50
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 48

def resource_id
  @resource_id
end

#resource_nameObject

Returns the value of attribute resource_name.



50
51
52
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 50

def resource_name
  @resource_name
end

#resource_typeObject

Returns the value of attribute resource_type.



52
53
54
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 52

def resource_type
  @resource_type
end

#resource_type_nameObject

Returns the value of attribute resource_type_name.



54
55
56
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 54

def resource_type_name
  @resource_type_name
end

#serviceObject

Returns the value of attribute service.



56
57
58
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 56

def service
  @service
end

#service_categoryObject

Returns the value of attribute service_category.



58
59
60
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 58

def service_category
  @service_category
end

#statusObject

Returns the value of attribute status.



60
61
62
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 60

def status
  @status
end

#tagsObject

Returns the value of attribute tags.



62
63
64
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 62

def tags
  @tags
end

#versionObject

Returns the value of attribute version.



64
65
66
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 64

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 67

def self.attribute_map
  {
    :'captured' => :'captured',
    :'cloud_groups' => :'cloud_groups',
    :'cloud_labels' => :'cloud_labels',
    :'cloud_scopes' => :'cloud_scopes',
    :'creation_time' => :'creation_time',
    :'gcrn' => :'gcrn',
    :'id' => :'id',
    :'resource_id' => :'resource_id',
    :'resource_name' => :'resource_name',
    :'resource_type' => :'resource_type',
    :'resource_type_name' => :'resource_type_name',
    :'service' => :'service',
    :'service_category' => :'service_category',
    :'status' => :'status',
    :'tags' => :'tags',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 260

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 94

def self.openapi_types
  {
    :'captured' => :'Time',
    :'cloud_groups' => :'Array<DomainCloudScope>',
    :'cloud_labels' => :'Array<ClassificationLabel>',
    :'cloud_scopes' => :'Array<ClassificationCloudScopeRule>',
    :'creation_time' => :'Time',
    :'gcrn' => :'String',
    :'id' => :'String',
    :'resource_id' => :'String',
    :'resource_name' => :'String',
    :'resource_type' => :'String',
    :'resource_type_name' => :'String',
    :'service' => :'String',
    :'service_category' => :'String',
    :'status' => :'String',
    :'tags' => :'Hash<String, String>',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      captured == o.captured &&
      cloud_groups == o.cloud_groups &&
      cloud_labels == o.cloud_labels &&
      cloud_scopes == o.cloud_scopes &&
      creation_time == o.creation_time &&
      gcrn == o.gcrn &&
      id == o.id &&
      resource_id == o.resource_id &&
      resource_name == o.resource_name &&
      resource_type == o.resource_type &&
      resource_type_name == o.resource_type_name &&
      service == o.service &&
      service_category == o.service_category &&
      status == o.status &&
      tags == o.tags &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 291

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 267

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 253

def hash
  [captured, cloud_groups, cloud_labels, cloud_scopes, creation_time, gcrn, id, resource_id, resource_name, resource_type, resource_type_name, service, service_category, status, tags, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 211

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 338

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



332
333
334
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 332

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
# File 'lib/crimson-falcon/models/evaluations_evaluation_resource.rb', line 218

def valid?
  true
end