Class: Falcon::EvaluationsRule

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/evaluations_rule.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EvaluationsRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::EvaluationsRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::EvaluationsRule`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alert_logic')
    self.alert_logic = attributes[:'alert_logic']
  end

  if attributes.key?(:'ciem_categories')
    if (value = attributes[:'ciem_categories']).is_a?(Array)
      self.ciem_categories = value
    end
  end

  if attributes.key?(:'controls')
    if (value = attributes[:'controls']).is_a?(Array)
      self.controls = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'override')
    self.override = attributes[:'override']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'policy_id')
    self.policy_id = attributes[:'policy_id']
  end

  if attributes.key?(:'remediation')
    self.remediation = attributes[:'remediation']
  end

  if attributes.key?(:'rule_group')
    if (value = attributes[:'rule_group']).is_a?(Array)
      self.rule_group = value
    end
  end

  if attributes.key?(:'threat')
    self.threat = attributes[:'threat']
  end
end

Instance Attribute Details

#alert_logicObject

Returns the value of attribute alert_logic.



34
35
36
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 34

def alert_logic
  @alert_logic
end

#ciem_categoriesObject

Returns the value of attribute ciem_categories.



36
37
38
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 36

def ciem_categories
  @ciem_categories
end

#controlsObject

Returns the value of attribute controls.



38
39
40
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 38

def controls
  @controls
end

#descriptionObject

Returns the value of attribute description.



40
41
42
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 40

def description
  @description
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 42

def id
  @id
end

#nameObject

Returns the value of attribute name.



44
45
46
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 44

def name
  @name
end

#originObject

Returns the value of attribute origin.



46
47
48
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 46

def origin
  @origin
end

#overrideObject

Returns the value of attribute override.



48
49
50
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 48

def override
  @override
end

#policyObject

Returns the value of attribute policy.



50
51
52
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 50

def policy
  @policy
end

#policy_idObject

Returns the value of attribute policy_id.



52
53
54
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 52

def policy_id
  @policy_id
end

#remediationObject

Returns the value of attribute remediation.



54
55
56
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 54

def remediation
  @remediation
end

#rule_groupObject

Returns the value of attribute rule_group.



56
57
58
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 56

def rule_group
  @rule_group
end

#threatObject

Returns the value of attribute threat.



58
59
60
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 58

def threat
  @threat
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 61

def self.attribute_map
  {
    :'alert_logic' => :'alert_logic',
    :'ciem_categories' => :'ciem_categories',
    :'controls' => :'controls',
    :'description' => :'description',
    :'id' => :'id',
    :'name' => :'name',
    :'origin' => :'origin',
    :'override' => :'override',
    :'policy' => :'policy',
    :'policy_id' => :'policy_id',
    :'remediation' => :'remediation',
    :'rule_group' => :'rule_group',
    :'threat' => :'threat'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 231

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 85

def self.openapi_types
  {
    :'alert_logic' => :'String',
    :'ciem_categories' => :'Array<String>',
    :'controls' => :'Array<PolicyframeworkControl>',
    :'description' => :'String',
    :'id' => :'String',
    :'name' => :'String',
    :'origin' => :'String',
    :'override' => :'EvaluationsRuleOverride',
    :'policy' => :'PolicyframeworkPolicyMetadata',
    :'policy_id' => :'Integer',
    :'remediation' => :'String',
    :'rule_group' => :'Array<PolicyframeworkRuleGroupMetadata>',
    :'threat' => :'EvaluationsThreat'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alert_logic == o.alert_logic &&
      ciem_categories == o.ciem_categories &&
      controls == o.controls &&
      description == o.description &&
      id == o.id &&
      name == o.name &&
      origin == o.origin &&
      override == o.override &&
      policy == o.policy &&
      policy_id == o.policy_id &&
      remediation == o.remediation &&
      rule_group == o.rule_group &&
      threat == o.threat
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 262

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 333

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 238

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 224

def hash
  [alert_logic, ciem_categories, controls, description, id, name, origin, override, policy, policy_id, remediation, rule_group, threat].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 185

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 309

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



303
304
305
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 303

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
# File 'lib/crimson-falcon/models/evaluations_rule.rb', line 192

def valid?
  true
end