Class: Falcon::EvaluationsRuleOverride
- Inherits:
-
Object
- Object
- Falcon::EvaluationsRuleOverride
- Defined in:
- lib/crimson-falcon/models/evaluations_rule_override.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#expiration_timestamp ⇒ Object
Returns the value of attribute expiration_timestamp.
-
#override_type ⇒ Object
Returns the value of attribute override_type.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#suppressed ⇒ Object
Returns the value of attribute suppressed.
-
#suppressed_by ⇒ Object
Returns the value of attribute suppressed_by.
-
#suppression_comment ⇒ Object
Returns the value of attribute suppression_comment.
-
#suppression_reason ⇒ Object
Returns the value of attribute suppression_reason.
-
#suppression_rule_id ⇒ Object
Returns the value of attribute suppression_rule_id.
-
#update_reason ⇒ Object
Returns the value of attribute update_reason.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EvaluationsRuleOverride
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EvaluationsRuleOverride
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::EvaluationsRuleOverride` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::EvaluationsRuleOverride`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'expiration_timestamp') self. = attributes[:'expiration_timestamp'] end if attributes.key?(:'override_type') self.override_type = attributes[:'override_type'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'suppressed') self.suppressed = attributes[:'suppressed'] end if attributes.key?(:'suppressed_by') self.suppressed_by = attributes[:'suppressed_by'] end if attributes.key?(:'suppression_comment') self.suppression_comment = attributes[:'suppression_comment'] end if attributes.key?(:'suppression_reason') self.suppression_reason = attributes[:'suppression_reason'] end if attributes.key?(:'suppression_rule_id') self.suppression_rule_id = attributes[:'suppression_rule_id'] end if attributes.key?(:'update_reason') self.update_reason = attributes[:'update_reason'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 34 def created_at @created_at end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
36 37 38 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 36 def deleted_at @deleted_at end |
#expiration_timestamp ⇒ Object
Returns the value of attribute expiration_timestamp.
38 39 40 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 38 def @expiration_timestamp end |
#override_type ⇒ Object
Returns the value of attribute override_type.
40 41 42 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 40 def override_type @override_type end |
#severity ⇒ Object
Returns the value of attribute severity.
42 43 44 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 42 def severity @severity end |
#suppressed ⇒ Object
Returns the value of attribute suppressed.
44 45 46 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 44 def suppressed @suppressed end |
#suppressed_by ⇒ Object
Returns the value of attribute suppressed_by.
46 47 48 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 46 def suppressed_by @suppressed_by end |
#suppression_comment ⇒ Object
Returns the value of attribute suppression_comment.
48 49 50 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 48 def suppression_comment @suppression_comment end |
#suppression_reason ⇒ Object
Returns the value of attribute suppression_reason.
50 51 52 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 50 def suppression_reason @suppression_reason end |
#suppression_rule_id ⇒ Object
Returns the value of attribute suppression_rule_id.
52 53 54 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 52 def suppression_rule_id @suppression_rule_id end |
#update_reason ⇒ Object
Returns the value of attribute update_reason.
54 55 56 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 54 def update_reason @update_reason end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
56 57 58 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 56 def updated_at @updated_at end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 59 def self.attribute_map { :'created_at' => :'created_at', :'deleted_at' => :'deleted_at', :'expiration_timestamp' => :'expiration_timestamp', :'override_type' => :'override_type', :'severity' => :'severity', :'suppressed' => :'suppressed', :'suppressed_by' => :'suppressed_by', :'suppression_comment' => :'suppression_comment', :'suppression_reason' => :'suppression_reason', :'suppression_rule_id' => :'suppression_rule_id', :'update_reason' => :'update_reason', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 226 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 82 def self.openapi_types { :'created_at' => :'Time', :'deleted_at' => :'Time', :'expiration_timestamp' => :'Time', :'override_type' => :'String', :'severity' => :'Integer', :'suppressed' => :'Boolean', :'suppressed_by' => :'String', :'suppression_comment' => :'String', :'suppression_reason' => :'String', :'suppression_rule_id' => :'String', :'update_reason' => :'String', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && deleted_at == o.deleted_at && == o. && override_type == o.override_type && severity == o.severity && suppressed == o.suppressed && suppressed_by == o.suppressed_by && suppression_comment == o.suppression_comment && suppression_reason == o.suppression_reason && suppression_rule_id == o.suppression_rule_id && update_reason == o.update_reason && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 257 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
213 214 215 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 213 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 219 def hash [created_at, deleted_at, , override_type, severity, suppressed, suppressed_by, suppression_comment, suppression_reason, suppression_rule_id, update_reason, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 171 def list_invalid_properties invalid_properties = Array.new if @suppressed_by.nil? invalid_properties.push('invalid value for "suppressed_by", suppressed_by cannot be nil.') end if @suppression_reason.nil? invalid_properties.push('invalid value for "suppression_reason", suppression_reason cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
304 305 306 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 304 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 298 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 |
# File 'lib/crimson-falcon/models/evaluations_rule_override.rb', line 186 def valid? return false if @suppressed_by.nil? return false if @suppression_reason.nil? true end |