Class: Falcon::ExecutionsExecutionResult
- Inherits:
-
Object
- Object
- Falcon::ExecutionsExecutionResult
- Defined in:
- lib/crimson-falcon/models/executions_execution_result.rb
Instance Attribute Summary collapse
-
#activities ⇒ Object
Details for the result of each activity node.
-
#ancestor_executions ⇒ Object
Populated when the execution origin is from a sub model.
-
#contains_mocks ⇒ Object
A boolean value indicating whether the workflow execution contains mocked result data for trigger or activities.
-
#definition_id ⇒ Object
Unique id of the workflow the execution is associated with.
-
#definition_name ⇒ Object
The name of the workflow the execution is associated with.
-
#definition_version ⇒ Object
Version of the definition that executed.
-
#end_timestamp ⇒ Object
Timestamp of when the execution completed.
-
#execution_id ⇒ Object
Unique id generated for the execution.
-
#flows ⇒ Object
Details for the result of each flow node.
-
#loops ⇒ Object
Details for the results of each loop in the workflow definition.
-
#output_data ⇒ Object
Output from this workflow execution.
-
#retryable ⇒ Object
A boolean value indicating whether the failed workflow execution is retryable.
-
#start_timestamp ⇒ Object
Timestamp of when the execution first started.
-
#status ⇒ Object
Overall status for the execution.
-
#summary ⇒ Object
Execution summary if defined in the workflow definition.
-
#tested_entity ⇒ Object
indicates the entity (definition or activity) being tested, if any.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExecutionsExecutionResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ExecutionsExecutionResult
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 143 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ExecutionsExecutionResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ExecutionsExecutionResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'activities') if (value = attributes[:'activities']).is_a?(Array) self.activities = value end end if attributes.key?(:'ancestor_executions') if (value = attributes[:'ancestor_executions']).is_a?(Array) self.ancestor_executions = value end end if attributes.key?(:'contains_mocks') self.contains_mocks = attributes[:'contains_mocks'] end if attributes.key?(:'definition_id') self.definition_id = attributes[:'definition_id'] end if attributes.key?(:'definition_name') self.definition_name = attributes[:'definition_name'] end if attributes.key?(:'definition_version') self.definition_version = attributes[:'definition_version'] end if attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] end if attributes.key?(:'execution_id') self.execution_id = attributes[:'execution_id'] end if attributes.key?(:'flows') if (value = attributes[:'flows']).is_a?(Array) self.flows = value end end if attributes.key?(:'loops') if (value = attributes[:'loops']).is_a?(Array) self.loops = value end end if attributes.key?(:'output_data') self.output_data = attributes[:'output_data'] end if attributes.key?(:'retryable') self.retryable = attributes[:'retryable'] end if attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'summary') self.summary = attributes[:'summary'] end if attributes.key?(:'tested_entity') self.tested_entity = attributes[:'tested_entity'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end end |
Instance Attribute Details
#activities ⇒ Object
Details for the result of each activity node.
35 36 37 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 35 def activities @activities end |
#ancestor_executions ⇒ Object
Populated when the execution origin is from a sub model.
38 39 40 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 38 def ancestor_executions @ancestor_executions end |
#contains_mocks ⇒ Object
A boolean value indicating whether the workflow execution contains mocked result data for trigger or activities
41 42 43 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 41 def contains_mocks @contains_mocks end |
#definition_id ⇒ Object
Unique id of the workflow the execution is associated with.
44 45 46 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 44 def definition_id @definition_id end |
#definition_name ⇒ Object
The name of the workflow the execution is associated with.
47 48 49 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 47 def definition_name @definition_name end |
#definition_version ⇒ Object
Version of the definition that executed.
50 51 52 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 50 def definition_version @definition_version end |
#end_timestamp ⇒ Object
Timestamp of when the execution completed. Only present when status is an end state.
53 54 55 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 53 def @end_timestamp end |
#execution_id ⇒ Object
Unique id generated for the execution.
56 57 58 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 56 def execution_id @execution_id end |
#flows ⇒ Object
Details for the result of each flow node.
59 60 61 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 59 def flows @flows end |
#loops ⇒ Object
Details for the results of each loop in the workflow definition.
62 63 64 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 62 def loops @loops end |
#output_data ⇒ Object
Output from this workflow execution
65 66 67 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 65 def output_data @output_data end |
#retryable ⇒ Object
A boolean value indicating whether the failed workflow execution is retryable
68 69 70 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 68 def retryable @retryable end |
#start_timestamp ⇒ Object
Timestamp of when the execution first started.
71 72 73 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 71 def @start_timestamp end |
#status ⇒ Object
Overall status for the execution.
74 75 76 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 74 def status @status end |
#summary ⇒ Object
Execution summary if defined in the workflow definition
77 78 79 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 77 def summary @summary end |
#tested_entity ⇒ Object
indicates the entity (definition or activity) being tested, if any
80 81 82 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 80 def tested_entity @tested_entity end |
#trigger ⇒ Object
Returns the value of attribute trigger.
82 83 84 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 82 def trigger @trigger end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
108 109 110 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 108 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 85 def self.attribute_map { :'activities' => :'activities', :'ancestor_executions' => :'ancestor_executions', :'contains_mocks' => :'contains_mocks', :'definition_id' => :'definition_id', :'definition_name' => :'definition_name', :'definition_version' => :'definition_version', :'end_timestamp' => :'end_timestamp', :'execution_id' => :'execution_id', :'flows' => :'flows', :'loops' => :'loops', :'output_data' => :'output_data', :'retryable' => :'retryable', :'start_timestamp' => :'start_timestamp', :'status' => :'status', :'summary' => :'summary', :'tested_entity' => :'tested_entity', :'trigger' => :'trigger' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
345 346 347 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 345 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 136 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 113 def self.openapi_types { :'activities' => :'Array<ExecutionsActivityExecutionResult>', :'ancestor_executions' => :'Array<ExecutionsAncestorExecution>', :'contains_mocks' => :'Boolean', :'definition_id' => :'String', :'definition_name' => :'String', :'definition_version' => :'Integer', :'end_timestamp' => :'Time', :'execution_id' => :'String', :'flows' => :'Array<ExecutionsFlowExecutionResult>', :'loops' => :'Array<ExecutionsLoopResult>', :'output_data' => :'Object', :'retryable' => :'Boolean', :'start_timestamp' => :'Time', :'status' => :'String', :'summary' => :'String', :'tested_entity' => :'String', :'trigger' => :'ExecutionsTriggerResult' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 308 def ==(o) return true if self.equal?(o) self.class == o.class && activities == o.activities && ancestor_executions == o.ancestor_executions && contains_mocks == o.contains_mocks && definition_id == o.definition_id && definition_name == o.definition_name && definition_version == o.definition_version && == o. && execution_id == o.execution_id && flows == o.flows && loops == o.loops && output_data == o.output_data && retryable == o.retryable && == o. && status == o.status && summary == o.summary && tested_entity == o.tested_entity && trigger == o.trigger end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 376 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 447 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 352 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
332 333 334 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 332 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
338 339 340 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 338 def hash [activities, ancestor_executions, contains_mocks, definition_id, definition_name, definition_version, , execution_id, flows, loops, output_data, retryable, , status, summary, tested_entity, trigger].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 235 def list_invalid_properties invalid_properties = Array.new if @activities.nil? invalid_properties.push('invalid value for "activities", activities cannot be nil.') end if @ancestor_executions.nil? invalid_properties.push('invalid value for "ancestor_executions", ancestor_executions cannot be nil.') end if @contains_mocks.nil? invalid_properties.push('invalid value for "contains_mocks", contains_mocks cannot be nil.') end if @definition_id.nil? invalid_properties.push('invalid value for "definition_id", definition_id cannot be nil.') end if @definition_name.nil? invalid_properties.push('invalid value for "definition_name", definition_name cannot be nil.') end if @definition_version.nil? invalid_properties.push('invalid value for "definition_version", definition_version cannot be nil.') end if @execution_id.nil? invalid_properties.push('invalid value for "execution_id", execution_id cannot be nil.') end if @loops.nil? invalid_properties.push('invalid value for "loops", loops cannot be nil.') end if @retryable.nil? invalid_properties.push('invalid value for "retryable", retryable cannot be nil.') end if @start_timestamp.nil? invalid_properties.push('invalid value for "start_timestamp", start_timestamp cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @trigger.nil? invalid_properties.push('invalid value for "trigger", trigger cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
423 424 425 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 423 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 429 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
417 418 419 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 417 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/crimson-falcon/models/executions_execution_result.rb', line 290 def valid? return false if @activities.nil? return false if @ancestor_executions.nil? return false if @contains_mocks.nil? return false if @definition_id.nil? return false if @definition_name.nil? return false if @definition_version.nil? return false if @execution_id.nil? return false if @loops.nil? return false if @retryable.nil? return false if @start_timestamp.nil? return false if @status.nil? return false if @trigger.nil? true end |