Class: Falcon::ExecutionsTriggerResult

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/executions_trigger_result.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExecutionsTriggerResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ExecutionsTriggerResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ExecutionsTriggerResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'end_timestamp')
    self.end_timestamp = attributes[:'end_timestamp']
  end

  if attributes.key?(:'error_code')
    self.error_code = attributes[:'error_code']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'mocked')
    self.mocked = attributes[:'mocked']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'node_id')
    self.node_id = attributes[:'node_id']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'start_timestamp')
    self.start_timestamp = attributes[:'start_timestamp']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'ui_status')
    self.ui_status = attributes[:'ui_status']
  end
end

Instance Attribute Details

#end_timestampObject

Timestamp of when the execution completed. Only present when status is an end state.



35
36
37
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 35

def end_timestamp
  @end_timestamp
end

#error_codeObject

When a node execution is in an error status this field is present and provides an error code that can be used to determine details why the failure occurred.



38
39
40
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 38

def error_code
  @error_code
end

#error_messageObject

When a node execution is in an error status this field is present and provides a user friendly error message.



41
42
43
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 41

def error_message
  @error_message
end

#idObject

Unique identifier for the selected trigger as provided by the triggers API



44
45
46
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 44

def id
  @id
end

#mockedObject

Whether this node’s result is mocked



47
48
49
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 47

def mocked
  @mocked
end

#nameObject

Display name of the trigger



50
51
52
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 50

def name
  @name
end

#node_idObject

Unique id of the node as specified in the definition.



53
54
55
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 53

def node_id
  @node_id
end

#resultObject

Opaque blob for result of trigger. Structured according to the trigger’s JSON schema’.



56
57
58
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 56

def result
  @result
end

#start_timestampObject

Timestamp of when the execution first started.



59
60
61
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 59

def start_timestamp
  @start_timestamp
end

#statusObject

Current status of execution for the activity.



62
63
64
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 62

def status
  @status
end

#typeObject

Type of the trigger



65
66
67
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 65

def type
  @type
end

#ui_statusObject

Current status of execution for the activity rendered in the UI.



68
69
70
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 68

def ui_status
  @ui_status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 111

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 93

def self.attribute_map
  {
    :'end_timestamp' => :'end_timestamp',
    :'error_code' => :'error_code',
    :'error_message' => :'error_message',
    :'id' => :'id',
    :'mocked' => :'mocked',
    :'name' => :'name',
    :'node_id' => :'node_id',
    :'result' => :'result',
    :'start_timestamp' => :'start_timestamp',
    :'status' => :'status',
    :'type' => :'type',
    :'ui_status' => :'ui_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 294

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 134

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 116

def self.openapi_types
  {
    :'end_timestamp' => :'Time',
    :'error_code' => :'Integer',
    :'error_message' => :'String',
    :'id' => :'String',
    :'mocked' => :'Boolean',
    :'name' => :'String',
    :'node_id' => :'String',
    :'result' => :'Object',
    :'start_timestamp' => :'Time',
    :'status' => :'String',
    :'type' => :'String',
    :'ui_status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      end_timestamp == o.end_timestamp &&
      error_code == o.error_code &&
      error_message == o.error_message &&
      id == o.id &&
      mocked == o.mocked &&
      name == o.name &&
      node_id == o.node_id &&
      result == o.result &&
      start_timestamp == o.start_timestamp &&
      status == o.status &&
      type == o.type &&
      ui_status == o.ui_status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 325

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 396

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 287

def hash
  [end_timestamp, error_code, error_message, id, mocked, name, node_id, result, start_timestamp, status, type, ui_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @node_id.nil?
    invalid_properties.push('invalid value for "node_id", node_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @ui_status.nil?
    invalid_properties.push('invalid value for "ui_status", ui_status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 372

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 378

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



366
367
368
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 366

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
# File 'lib/crimson-falcon/models/executions_trigger_result.rb', line 228

def valid?
  return false if @name.nil?
  return false if @node_id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["Pending", "Succeeded", "Failed", "Skipped"])
  return false unless status_validator.valid?(@status)
  return false if @ui_status.nil?
  ui_status_validator = EnumAttributeValidator.new('String', ["Pending", "Action Performed", "Executing", "Error", "Skipped", "Retrying"])
  return false unless ui_status_validator.valid?(@ui_status)
  true
end