Class: Falcon::FalconxActor

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/falconx_actor.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FalconxActor

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxActor` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxActor`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'first_activity_timestamp')
    self.first_activity_timestamp = attributes[:'first_activity_timestamp']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'image_artifact_id')
    self.image_artifact_id = attributes[:'image_artifact_id']
  end

  if attributes.key?(:'known_as')
    self.known_as = attributes[:'known_as']
  end

  if attributes.key?(:'last_activity_timestamp')
    self.last_activity_timestamp = attributes[:'last_activity_timestamp']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'origins')
    if (value = attributes[:'origins']).is_a?(Array)
      self.origins = value
    end
  end

  if attributes.key?(:'short_description')
    self.short_description = attributes[:'short_description']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'target_countries')
    if (value = attributes[:'target_countries']).is_a?(Array)
      self.target_countries = value
    end
  end

  if attributes.key?(:'target_industries')
    if (value = attributes[:'target_industries']).is_a?(Array)
      self.target_industries = value
    end
  end

  if attributes.key?(:'thumbnail_artifact_id')
    self.thumbnail_artifact_id = attributes[:'thumbnail_artifact_id']
  end
end

Instance Attribute Details

#created_timestampObject

Returns the value of attribute created_timestamp.



34
35
36
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 34

def created_timestamp
  @created_timestamp
end

#descriptionObject

Returns the value of attribute description.



36
37
38
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 36

def description
  @description
end

#first_activity_timestampObject

Returns the value of attribute first_activity_timestamp.



38
39
40
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 38

def first_activity_timestamp
  @first_activity_timestamp
end

#idObject

Returns the value of attribute id.



40
41
42
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 40

def id
  @id
end

#image_artifact_idObject

Returns the value of attribute image_artifact_id.



42
43
44
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 42

def image_artifact_id
  @image_artifact_id
end

#known_asObject

Returns the value of attribute known_as.



44
45
46
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 44

def known_as
  @known_as
end

#last_activity_timestampObject

Returns the value of attribute last_activity_timestamp.



46
47
48
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 46

def last_activity_timestamp
  @last_activity_timestamp
end

#nameObject

Returns the value of attribute name.



48
49
50
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 48

def name
  @name
end

#originsObject

Returns the value of attribute origins.



50
51
52
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 50

def origins
  @origins
end

#short_descriptionObject

Returns the value of attribute short_description.



52
53
54
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 52

def short_description
  @short_description
end

#slugObject

Returns the value of attribute slug.



54
55
56
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 54

def slug
  @slug
end

#target_countriesObject

Returns the value of attribute target_countries.



56
57
58
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 56

def target_countries
  @target_countries
end

#target_industriesObject

Returns the value of attribute target_industries.



58
59
60
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 58

def target_industries
  @target_industries
end

#thumbnail_artifact_idObject

Returns the value of attribute thumbnail_artifact_id.



60
61
62
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 60

def thumbnail_artifact_id
  @thumbnail_artifact_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 63

def self.attribute_map
  {
    :'created_timestamp' => :'created_timestamp',
    :'description' => :'description',
    :'first_activity_timestamp' => :'first_activity_timestamp',
    :'id' => :'id',
    :'image_artifact_id' => :'image_artifact_id',
    :'known_as' => :'known_as',
    :'last_activity_timestamp' => :'last_activity_timestamp',
    :'name' => :'name',
    :'origins' => :'origins',
    :'short_description' => :'short_description',
    :'slug' => :'slug',
    :'target_countries' => :'target_countries',
    :'target_industries' => :'target_industries',
    :'thumbnail_artifact_id' => :'thumbnail_artifact_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 240

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 88

def self.openapi_types
  {
    :'created_timestamp' => :'String',
    :'description' => :'String',
    :'first_activity_timestamp' => :'String',
    :'id' => :'Integer',
    :'image_artifact_id' => :'String',
    :'known_as' => :'String',
    :'last_activity_timestamp' => :'String',
    :'name' => :'String',
    :'origins' => :'Array<FalconxEntity>',
    :'short_description' => :'String',
    :'slug' => :'String',
    :'target_countries' => :'Array<FalconxEntity>',
    :'target_industries' => :'Array<FalconxEntity>',
    :'thumbnail_artifact_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_timestamp == o.created_timestamp &&
      description == o.description &&
      first_activity_timestamp == o.first_activity_timestamp &&
      id == o.id &&
      image_artifact_id == o.image_artifact_id &&
      known_as == o.known_as &&
      last_activity_timestamp == o.last_activity_timestamp &&
      name == o.name &&
      origins == o.origins &&
      short_description == o.short_description &&
      slug == o.slug &&
      target_countries == o.target_countries &&
      target_industries == o.target_industries &&
      thumbnail_artifact_id == o.thumbnail_artifact_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 271

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 342

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 247

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 233

def hash
  [created_timestamp, description, first_activity_timestamp, id, image_artifact_id, known_as, last_activity_timestamp, name, origins, short_description, slug, target_countries, target_industries, thumbnail_artifact_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 193

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 318

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



312
313
314
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 312

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
# File 'lib/crimson-falcon/models/falconx_actor.rb', line 200

def valid?
  true
end