Class: Falcon::FalconxExtractedFile
- Inherits:
-
Object
- Object
- Falcon::FalconxExtractedFile
- Defined in:
- lib/crimson-falcon/models/falconx_extracted_file.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#file_available_to_download ⇒ Object
Returns the value of attribute file_available_to_download.
-
#file_path ⇒ Object
Returns the value of attribute file_path.
-
#file_size ⇒ Object
Returns the value of attribute file_size.
-
#md5 ⇒ Object
Returns the value of attribute md5.
-
#name ⇒ Object
Returns the value of attribute name.
-
#runtime_process ⇒ Object
Returns the value of attribute runtime_process.
-
#sha1 ⇒ Object
Returns the value of attribute sha1.
-
#sha256 ⇒ Object
Returns the value of attribute sha256.
-
#threat_level ⇒ Object
Returns the value of attribute threat_level.
-
#threat_level_readable ⇒ Object
Returns the value of attribute threat_level_readable.
-
#type_tags ⇒ Object
Returns the value of attribute type_tags.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FalconxExtractedFile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FalconxExtractedFile
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxExtractedFile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxExtractedFile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'file_available_to_download') self.file_available_to_download = attributes[:'file_available_to_download'] end if attributes.key?(:'file_path') self.file_path = attributes[:'file_path'] end if attributes.key?(:'file_size') self.file_size = attributes[:'file_size'] end if attributes.key?(:'md5') self.md5 = attributes[:'md5'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'runtime_process') self.runtime_process = attributes[:'runtime_process'] end if attributes.key?(:'sha1') self.sha1 = attributes[:'sha1'] end if attributes.key?(:'sha256') self.sha256 = attributes[:'sha256'] end if attributes.key?(:'threat_level') self.threat_level = attributes[:'threat_level'] end if attributes.key?(:'threat_level_readable') self.threat_level_readable = attributes[:'threat_level_readable'] end if attributes.key?(:'type_tags') if (value = attributes[:'type_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
34 35 36 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 34 def description @description end |
#file_available_to_download ⇒ Object
Returns the value of attribute file_available_to_download.
36 37 38 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 36 def file_available_to_download @file_available_to_download end |
#file_path ⇒ Object
Returns the value of attribute file_path.
38 39 40 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 38 def file_path @file_path end |
#file_size ⇒ Object
Returns the value of attribute file_size.
40 41 42 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 40 def file_size @file_size end |
#md5 ⇒ Object
Returns the value of attribute md5.
42 43 44 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 42 def md5 @md5 end |
#name ⇒ Object
Returns the value of attribute name.
44 45 46 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 44 def name @name end |
#runtime_process ⇒ Object
Returns the value of attribute runtime_process.
46 47 48 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 46 def runtime_process @runtime_process end |
#sha1 ⇒ Object
Returns the value of attribute sha1.
48 49 50 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 48 def sha1 @sha1 end |
#sha256 ⇒ Object
Returns the value of attribute sha256.
50 51 52 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 50 def sha256 @sha256 end |
#threat_level ⇒ Object
Returns the value of attribute threat_level.
52 53 54 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 52 def threat_level @threat_level end |
#threat_level_readable ⇒ Object
Returns the value of attribute threat_level_readable.
54 55 56 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 54 def threat_level_readable @threat_level_readable end |
#type_tags ⇒ Object
Returns the value of attribute type_tags.
56 57 58 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 56 def @type_tags end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 59 def self.attribute_map { :'description' => :'description', :'file_available_to_download' => :'file_available_to_download', :'file_path' => :'file_path', :'file_size' => :'file_size', :'md5' => :'md5', :'name' => :'name', :'runtime_process' => :'runtime_process', :'sha1' => :'sha1', :'sha256' => :'sha256', :'threat_level' => :'threat_level', :'threat_level_readable' => :'threat_level_readable', :'type_tags' => :'type_tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 218 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 82 def self.openapi_types { :'description' => :'String', :'file_available_to_download' => :'Boolean', :'file_path' => :'String', :'file_size' => :'Integer', :'md5' => :'String', :'name' => :'String', :'runtime_process' => :'String', :'sha1' => :'String', :'sha256' => :'String', :'threat_level' => :'Integer', :'threat_level_readable' => :'String', :'type_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && file_available_to_download == o.file_available_to_download && file_path == o.file_path && file_size == o.file_size && md5 == o.md5 && name == o.name && runtime_process == o.runtime_process && sha1 == o.sha1 && sha256 == o.sha256 && threat_level == o.threat_level && threat_level_readable == o.threat_level_readable && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 249 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 320 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 211 def hash [description, file_available_to_download, file_path, file_size, md5, name, runtime_process, sha1, sha256, threat_level, threat_level_readable, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 173 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
296 297 298 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 296 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 290 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 |
# File 'lib/crimson-falcon/models/falconx_extracted_file.rb', line 180 def valid? true end |