Class: Falcon::FalconxProcess

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/falconx_process.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FalconxProcess

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/crimson-falcon/models/falconx_process.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxProcess` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxProcess`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amsi_calls')
    if (value = attributes[:'amsi_calls']).is_a?(Array)
      self.amsi_calls = value
    end
  end

  if attributes.key?(:'command_line')
    self.command_line = attributes[:'command_line']
  end

  if attributes.key?(:'file_accesses')
    if (value = attributes[:'file_accesses']).is_a?(Array)
      self.file_accesses = value
    end
  end

  if attributes.key?(:'handles')
    if (value = attributes[:'handles']).is_a?(Array)
      self.handles = value
    end
  end

  if attributes.key?(:'icon_artifact_id')
    self.icon_artifact_id = attributes[:'icon_artifact_id']
  end

  if attributes.key?(:'modules')
    if (value = attributes[:'modules']).is_a?(Array)
      self.modules = value
    end
  end

  if attributes.key?(:'mutants')
    if (value = attributes[:'mutants']).is_a?(Array)
      self.mutants = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'normalized_path')
    self.normalized_path = attributes[:'normalized_path']
  end

  if attributes.key?(:'parent_uid')
    self.parent_uid = attributes[:'parent_uid']
  end

  if attributes.key?(:'pid')
    self.pid = attributes[:'pid']
  end

  if attributes.key?(:'process_flags')
    if (value = attributes[:'process_flags']).is_a?(Array)
      self.process_flags = value
    end
  end

  if attributes.key?(:'registry')
    if (value = attributes[:'registry']).is_a?(Array)
      self.registry = value
    end
  end

  if attributes.key?(:'script_calls')
    if (value = attributes[:'script_calls']).is_a?(Array)
      self.script_calls = value
    end
  end

  if attributes.key?(:'sha256')
    self.sha256 = attributes[:'sha256']
  end

  if attributes.key?(:'streams')
    if (value = attributes[:'streams']).is_a?(Array)
      self.streams = value
    end
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  end
end

Instance Attribute Details

#amsi_callsObject

Returns the value of attribute amsi_calls.



34
35
36
# File 'lib/crimson-falcon/models/falconx_process.rb', line 34

def amsi_calls
  @amsi_calls
end

#command_lineObject

Returns the value of attribute command_line.



36
37
38
# File 'lib/crimson-falcon/models/falconx_process.rb', line 36

def command_line
  @command_line
end

#file_accessesObject

Returns the value of attribute file_accesses.



38
39
40
# File 'lib/crimson-falcon/models/falconx_process.rb', line 38

def file_accesses
  @file_accesses
end

#handlesObject

Returns the value of attribute handles.



40
41
42
# File 'lib/crimson-falcon/models/falconx_process.rb', line 40

def handles
  @handles
end

#icon_artifact_idObject

Returns the value of attribute icon_artifact_id.



42
43
44
# File 'lib/crimson-falcon/models/falconx_process.rb', line 42

def icon_artifact_id
  @icon_artifact_id
end

#modulesObject

Returns the value of attribute modules.



44
45
46
# File 'lib/crimson-falcon/models/falconx_process.rb', line 44

def modules
  @modules
end

#mutantsObject

Returns the value of attribute mutants.



46
47
48
# File 'lib/crimson-falcon/models/falconx_process.rb', line 46

def mutants
  @mutants
end

#nameObject

Returns the value of attribute name.



48
49
50
# File 'lib/crimson-falcon/models/falconx_process.rb', line 48

def name
  @name
end

#normalized_pathObject

Returns the value of attribute normalized_path.



50
51
52
# File 'lib/crimson-falcon/models/falconx_process.rb', line 50

def normalized_path
  @normalized_path
end

#parent_uidObject

Returns the value of attribute parent_uid.



52
53
54
# File 'lib/crimson-falcon/models/falconx_process.rb', line 52

def parent_uid
  @parent_uid
end

#pidObject

Returns the value of attribute pid.



54
55
56
# File 'lib/crimson-falcon/models/falconx_process.rb', line 54

def pid
  @pid
end

#process_flagsObject

Returns the value of attribute process_flags.



56
57
58
# File 'lib/crimson-falcon/models/falconx_process.rb', line 56

def process_flags
  @process_flags
end

#registryObject

Returns the value of attribute registry.



58
59
60
# File 'lib/crimson-falcon/models/falconx_process.rb', line 58

def registry
  @registry
end

#script_callsObject

Returns the value of attribute script_calls.



60
61
62
# File 'lib/crimson-falcon/models/falconx_process.rb', line 60

def script_calls
  @script_calls
end

#sha256Object

Returns the value of attribute sha256.



62
63
64
# File 'lib/crimson-falcon/models/falconx_process.rb', line 62

def sha256
  @sha256
end

#streamsObject

Returns the value of attribute streams.



64
65
66
# File 'lib/crimson-falcon/models/falconx_process.rb', line 64

def streams
  @streams
end

#uidObject

Returns the value of attribute uid.



66
67
68
# File 'lib/crimson-falcon/models/falconx_process.rb', line 66

def uid
  @uid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/falconx_process.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/falconx_process.rb', line 69

def self.attribute_map
  {
    :'amsi_calls' => :'amsi_calls',
    :'command_line' => :'command_line',
    :'file_accesses' => :'file_accesses',
    :'handles' => :'handles',
    :'icon_artifact_id' => :'icon_artifact_id',
    :'modules' => :'modules',
    :'mutants' => :'mutants',
    :'name' => :'name',
    :'normalized_path' => :'normalized_path',
    :'parent_uid' => :'parent_uid',
    :'pid' => :'pid',
    :'process_flags' => :'process_flags',
    :'registry' => :'registry',
    :'script_calls' => :'script_calls',
    :'sha256' => :'sha256',
    :'streams' => :'streams',
    :'uid' => :'uid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
# File 'lib/crimson-falcon/models/falconx_process.rb', line 279

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/falconx_process.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/falconx_process.rb', line 97

def self.openapi_types
  {
    :'amsi_calls' => :'Array<FalconxAMSICall>',
    :'command_line' => :'String',
    :'file_accesses' => :'Array<FalconxFileAccess>',
    :'handles' => :'Array<FalconxHandle>',
    :'icon_artifact_id' => :'String',
    :'modules' => :'Array<FalconxModule>',
    :'mutants' => :'Array<String>',
    :'name' => :'String',
    :'normalized_path' => :'String',
    :'parent_uid' => :'String',
    :'pid' => :'Integer',
    :'process_flags' => :'Array<FalconxProcessFlag>',
    :'registry' => :'Array<FalconxRegistry>',
    :'script_calls' => :'Array<FalconxScriptCall>',
    :'sha256' => :'String',
    :'streams' => :'Array<FalconxStream>',
    :'uid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/crimson-falcon/models/falconx_process.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amsi_calls == o.amsi_calls &&
      command_line == o.command_line &&
      file_accesses == o.file_accesses &&
      handles == o.handles &&
      icon_artifact_id == o.icon_artifact_id &&
      modules == o.modules &&
      mutants == o.mutants &&
      name == o.name &&
      normalized_path == o.normalized_path &&
      parent_uid == o.parent_uid &&
      pid == o.pid &&
      process_flags == o.process_flags &&
      registry == o.registry &&
      script_calls == o.script_calls &&
      sha256 == o.sha256 &&
      streams == o.streams &&
      uid == o.uid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/crimson-falcon/models/falconx_process.rb', line 310

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/crimson-falcon/models/falconx_process.rb', line 381

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/models/falconx_process.rb', line 286

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/crimson-falcon/models/falconx_process.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/crimson-falcon/models/falconx_process.rb', line 272

def hash
  [amsi_calls, command_line, file_accesses, handles, icon_artifact_id, modules, mutants, name, normalized_path, parent_uid, pid, process_flags, registry, script_calls, sha256, streams, uid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
# File 'lib/crimson-falcon/models/falconx_process.rb', line 229

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
# File 'lib/crimson-falcon/models/falconx_process.rb', line 357

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/crimson-falcon/models/falconx_process.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/crimson-falcon/models/falconx_process.rb', line 351

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
# File 'lib/crimson-falcon/models/falconx_process.rb', line 236

def valid?
  true
end