Class: Falcon::FalconxReportV1
- Inherits:
-
Object
- Object
- Falcon::FalconxReportV1
- Defined in:
- lib/crimson-falcon/models/falconx_report_v1.rb
Instance Attribute Summary collapse
-
#ai_summary ⇒ Object
Returns the value of attribute ai_summary.
-
#aid ⇒ Object
Returns the value of attribute aid.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
-
#has_recording ⇒ Object
Returns the value of attribute has_recording.
-
#id ⇒ Object
Returns the value of attribute id.
-
#index_timestamp ⇒ Object
Returns the value of attribute index_timestamp.
-
#intel ⇒ Object
Returns the value of attribute intel.
-
#intelx ⇒ Object
Returns the value of attribute intelx.
-
#ioc_report_broad_csv_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_csv_artifact_id.
-
#ioc_report_broad_json_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_json_artifact_id.
-
#ioc_report_broad_maec_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_maec_artifact_id.
-
#ioc_report_broad_stix_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_stix_artifact_id.
-
#ioc_report_strict_csv_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_csv_artifact_id.
-
#ioc_report_strict_json_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_json_artifact_id.
-
#ioc_report_strict_maec_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_maec_artifact_id.
-
#ioc_report_strict_stix_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_stix_artifact_id.
-
#malquery ⇒ Object
Returns the value of attribute malquery.
-
#origin ⇒ Object
Returns the value of attribute origin.
-
#sandbox ⇒ Object
Returns the value of attribute sandbox.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#threat_graph ⇒ Object
Returns the value of attribute threat_graph.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#user_name ⇒ Object
Returns the value of attribute user_name.
-
#user_tags ⇒ Object
Returns the value of attribute user_tags.
-
#user_uuid ⇒ Object
Returns the value of attribute user_uuid.
-
#verdict ⇒ Object
Returns the value of attribute verdict.
-
#verdict_source ⇒ Object
Returns the value of attribute verdict_source.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FalconxReportV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FalconxReportV1
Initializes the object
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 171 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxReportV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxReportV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ai_summary') self.ai_summary = attributes[:'ai_summary'] end if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'created_timestamp') self. = attributes[:'created_timestamp'] end if attributes.key?(:'has_recording') self.has_recording = attributes[:'has_recording'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'index_timestamp') self. = attributes[:'index_timestamp'] end if attributes.key?(:'intel') if (value = attributes[:'intel']).is_a?(Array) self.intel = value end end if attributes.key?(:'intelx') self.intelx = attributes[:'intelx'] end if attributes.key?(:'ioc_report_broad_csv_artifact_id') self.ioc_report_broad_csv_artifact_id = attributes[:'ioc_report_broad_csv_artifact_id'] end if attributes.key?(:'ioc_report_broad_json_artifact_id') self.ioc_report_broad_json_artifact_id = attributes[:'ioc_report_broad_json_artifact_id'] end if attributes.key?(:'ioc_report_broad_maec_artifact_id') self.ioc_report_broad_maec_artifact_id = attributes[:'ioc_report_broad_maec_artifact_id'] end if attributes.key?(:'ioc_report_broad_stix_artifact_id') self.ioc_report_broad_stix_artifact_id = attributes[:'ioc_report_broad_stix_artifact_id'] end if attributes.key?(:'ioc_report_strict_csv_artifact_id') self.ioc_report_strict_csv_artifact_id = attributes[:'ioc_report_strict_csv_artifact_id'] end if attributes.key?(:'ioc_report_strict_json_artifact_id') self.ioc_report_strict_json_artifact_id = attributes[:'ioc_report_strict_json_artifact_id'] end if attributes.key?(:'ioc_report_strict_maec_artifact_id') self.ioc_report_strict_maec_artifact_id = attributes[:'ioc_report_strict_maec_artifact_id'] end if attributes.key?(:'ioc_report_strict_stix_artifact_id') self.ioc_report_strict_stix_artifact_id = attributes[:'ioc_report_strict_stix_artifact_id'] end if attributes.key?(:'malquery') if (value = attributes[:'malquery']).is_a?(Array) self.malquery = value end end if attributes.key?(:'origin') self.origin = attributes[:'origin'] end if attributes.key?(:'sandbox') if (value = attributes[:'sandbox']).is_a?(Array) self.sandbox = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'threat_graph') self.threat_graph = attributes[:'threat_graph'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'user_uuid') self.user_uuid = attributes[:'user_uuid'] end if attributes.key?(:'verdict') self.verdict = attributes[:'verdict'] end if attributes.key?(:'verdict_source') self.verdict_source = attributes[:'verdict_source'] end end |
Instance Attribute Details
#ai_summary ⇒ Object
Returns the value of attribute ai_summary.
34 35 36 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 34 def ai_summary @ai_summary end |
#aid ⇒ Object
Returns the value of attribute aid.
36 37 38 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 36 def aid @aid end |
#cid ⇒ Object
Returns the value of attribute cid.
38 39 40 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 38 def cid @cid end |
#created_timestamp ⇒ Object
Returns the value of attribute created_timestamp.
40 41 42 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 40 def @created_timestamp end |
#has_recording ⇒ Object
Returns the value of attribute has_recording.
42 43 44 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 42 def has_recording @has_recording end |
#id ⇒ Object
Returns the value of attribute id.
44 45 46 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 44 def id @id end |
#index_timestamp ⇒ Object
Returns the value of attribute index_timestamp.
46 47 48 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 46 def @index_timestamp end |
#intel ⇒ Object
Returns the value of attribute intel.
48 49 50 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 48 def intel @intel end |
#intelx ⇒ Object
Returns the value of attribute intelx.
50 51 52 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 50 def intelx @intelx end |
#ioc_report_broad_csv_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_csv_artifact_id.
52 53 54 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 52 def ioc_report_broad_csv_artifact_id @ioc_report_broad_csv_artifact_id end |
#ioc_report_broad_json_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_json_artifact_id.
54 55 56 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 54 def ioc_report_broad_json_artifact_id @ioc_report_broad_json_artifact_id end |
#ioc_report_broad_maec_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_maec_artifact_id.
56 57 58 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 56 def ioc_report_broad_maec_artifact_id @ioc_report_broad_maec_artifact_id end |
#ioc_report_broad_stix_artifact_id ⇒ Object
Returns the value of attribute ioc_report_broad_stix_artifact_id.
58 59 60 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 58 def ioc_report_broad_stix_artifact_id @ioc_report_broad_stix_artifact_id end |
#ioc_report_strict_csv_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_csv_artifact_id.
60 61 62 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 60 def ioc_report_strict_csv_artifact_id @ioc_report_strict_csv_artifact_id end |
#ioc_report_strict_json_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_json_artifact_id.
62 63 64 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 62 def ioc_report_strict_json_artifact_id @ioc_report_strict_json_artifact_id end |
#ioc_report_strict_maec_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_maec_artifact_id.
64 65 66 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 64 def ioc_report_strict_maec_artifact_id @ioc_report_strict_maec_artifact_id end |
#ioc_report_strict_stix_artifact_id ⇒ Object
Returns the value of attribute ioc_report_strict_stix_artifact_id.
66 67 68 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 66 def ioc_report_strict_stix_artifact_id @ioc_report_strict_stix_artifact_id end |
#malquery ⇒ Object
Returns the value of attribute malquery.
68 69 70 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 68 def malquery @malquery end |
#origin ⇒ Object
Returns the value of attribute origin.
70 71 72 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 70 def origin @origin end |
#sandbox ⇒ Object
Returns the value of attribute sandbox.
72 73 74 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 72 def sandbox @sandbox end |
#tags ⇒ Object
Returns the value of attribute tags.
74 75 76 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 74 def @tags end |
#threat_graph ⇒ Object
Returns the value of attribute threat_graph.
76 77 78 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 76 def threat_graph @threat_graph end |
#user_id ⇒ Object
Returns the value of attribute user_id.
78 79 80 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 78 def user_id @user_id end |
#user_name ⇒ Object
Returns the value of attribute user_name.
80 81 82 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 80 def user_name @user_name end |
#user_tags ⇒ Object
Returns the value of attribute user_tags.
82 83 84 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 82 def @user_tags end |
#user_uuid ⇒ Object
Returns the value of attribute user_uuid.
84 85 86 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 84 def user_uuid @user_uuid end |
#verdict ⇒ Object
Returns the value of attribute verdict.
86 87 88 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 86 def verdict @verdict end |
#verdict_source ⇒ Object
Returns the value of attribute verdict_source.
88 89 90 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 88 def verdict_source @verdict_source end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 125 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 91 def self.attribute_map { :'ai_summary' => :'ai_summary', :'aid' => :'aid', :'cid' => :'cid', :'created_timestamp' => :'created_timestamp', :'has_recording' => :'has_recording', :'id' => :'id', :'index_timestamp' => :'index_timestamp', :'intel' => :'intel', :'intelx' => :'intelx', :'ioc_report_broad_csv_artifact_id' => :'ioc_report_broad_csv_artifact_id', :'ioc_report_broad_json_artifact_id' => :'ioc_report_broad_json_artifact_id', :'ioc_report_broad_maec_artifact_id' => :'ioc_report_broad_maec_artifact_id', :'ioc_report_broad_stix_artifact_id' => :'ioc_report_broad_stix_artifact_id', :'ioc_report_strict_csv_artifact_id' => :'ioc_report_strict_csv_artifact_id', :'ioc_report_strict_json_artifact_id' => :'ioc_report_strict_json_artifact_id', :'ioc_report_strict_maec_artifact_id' => :'ioc_report_strict_maec_artifact_id', :'ioc_report_strict_stix_artifact_id' => :'ioc_report_strict_stix_artifact_id', :'malquery' => :'malquery', :'origin' => :'origin', :'sandbox' => :'sandbox', :'tags' => :'tags', :'threat_graph' => :'threat_graph', :'user_id' => :'user_id', :'user_name' => :'user_name', :'user_tags' => :'user_tags', :'user_uuid' => :'user_uuid', :'verdict' => :'verdict', :'verdict_source' => :'verdict_source' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 370 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
164 165 166 167 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 164 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 130 def self.openapi_types { :'ai_summary' => :'FalconxAISummary', :'aid' => :'String', :'cid' => :'String', :'created_timestamp' => :'String', :'has_recording' => :'Boolean', :'id' => :'String', :'index_timestamp' => :'String', :'intel' => :'Array<FalconxIntelReportV1>', :'intelx' => :'FalconxIntelXReportV1', :'ioc_report_broad_csv_artifact_id' => :'String', :'ioc_report_broad_json_artifact_id' => :'String', :'ioc_report_broad_maec_artifact_id' => :'String', :'ioc_report_broad_stix_artifact_id' => :'String', :'ioc_report_strict_csv_artifact_id' => :'String', :'ioc_report_strict_json_artifact_id' => :'String', :'ioc_report_strict_maec_artifact_id' => :'String', :'ioc_report_strict_stix_artifact_id' => :'String', :'malquery' => :'Array<FalconxMalqueryReportV1>', :'origin' => :'String', :'sandbox' => :'Array<FalconxSandboxReportV1>', :'tags' => :'Array<String>', :'threat_graph' => :'FalconxThreatGraphReportV1', :'user_id' => :'String', :'user_name' => :'String', :'user_tags' => :'Array<String>', :'user_uuid' => :'String', :'verdict' => :'String', :'verdict_source' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && ai_summary == o.ai_summary && aid == o.aid && cid == o.cid && == o. && has_recording == o.has_recording && id == o.id && == o. && intel == o.intel && intelx == o.intelx && ioc_report_broad_csv_artifact_id == o.ioc_report_broad_csv_artifact_id && ioc_report_broad_json_artifact_id == o.ioc_report_broad_json_artifact_id && ioc_report_broad_maec_artifact_id == o.ioc_report_broad_maec_artifact_id && ioc_report_broad_stix_artifact_id == o.ioc_report_broad_stix_artifact_id && ioc_report_strict_csv_artifact_id == o.ioc_report_strict_csv_artifact_id && ioc_report_strict_json_artifact_id == o.ioc_report_strict_json_artifact_id && ioc_report_strict_maec_artifact_id == o.ioc_report_strict_maec_artifact_id && ioc_report_strict_stix_artifact_id == o.ioc_report_strict_stix_artifact_id && malquery == o.malquery && origin == o.origin && sandbox == o.sandbox && == o. && threat_graph == o.threat_graph && user_id == o.user_id && user_name == o.user_name && == o. && user_uuid == o.user_uuid && verdict == o.verdict && verdict_source == o.verdict_source end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 401 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 472 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 377 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
357 358 359 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 357 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
363 364 365 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 363 def hash [ai_summary, aid, cid, , has_recording, id, , intel, intelx, ioc_report_broad_csv_artifact_id, ioc_report_broad_json_artifact_id, ioc_report_broad_maec_artifact_id, ioc_report_broad_stix_artifact_id, ioc_report_strict_csv_artifact_id, ioc_report_strict_json_artifact_id, ioc_report_strict_maec_artifact_id, ioc_report_strict_stix_artifact_id, malquery, origin, sandbox, , threat_graph, user_id, user_name, , user_uuid, verdict, verdict_source].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
309 310 311 312 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 309 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
448 449 450 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 448 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 442 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
316 317 318 |
# File 'lib/crimson-falcon/models/falconx_report_v1.rb', line 316 def valid? true end |