Class: Falcon::FalconxSubmissionV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/falconx_submission_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FalconxSubmissionV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxSubmissionV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxSubmissionV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_detect_environment')
    self.auto_detect_environment = attributes[:'auto_detect_environment']
  else
    self.auto_detect_environment = false
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'error_origin')
    self.error_origin = attributes[:'error_origin']
  end

  if attributes.key?(:'error_type')
    self.error_type = attributes[:'error_type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'index_timestamp')
    self.index_timestamp = attributes[:'index_timestamp']
  end

  if attributes.key?(:'interactive_phase')
    self.interactive_phase = attributes[:'interactive_phase']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'sandbox')
    if (value = attributes[:'sandbox']).is_a?(Array)
      self.sandbox = value
    end
  end

  if attributes.key?(:'send_email_notification')
    self.send_email_notification = attributes[:'send_email_notification']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'user_uuid')
    self.user_uuid = attributes[:'user_uuid']
  end
end

Instance Attribute Details

#auto_detect_environmentObject

Returns the value of attribute auto_detect_environment.



34
35
36
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 34

def auto_detect_environment
  @auto_detect_environment
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 36

def cid
  @cid
end

#created_timestampObject

Returns the value of attribute created_timestamp.



38
39
40
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 38

def created_timestamp
  @created_timestamp
end

#error_messageObject

Returns the value of attribute error_message.



40
41
42
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 40

def error_message
  @error_message
end

#error_originObject

Returns the value of attribute error_origin.



42
43
44
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 42

def error_origin
  @error_origin
end

#error_typeObject

Returns the value of attribute error_type.



44
45
46
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 44

def error_type
  @error_type
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 46

def id
  @id
end

#index_timestampObject

Returns the value of attribute index_timestamp.



48
49
50
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 48

def index_timestamp
  @index_timestamp
end

#interactive_phaseObject

Returns the value of attribute interactive_phase.



50
51
52
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 50

def interactive_phase
  @interactive_phase
end

#originObject

Returns the value of attribute origin.



52
53
54
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 52

def origin
  @origin
end

#sandboxObject

Returns the value of attribute sandbox.



54
55
56
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 54

def sandbox
  @sandbox
end

#send_email_notificationObject

Returns the value of attribute send_email_notification.



56
57
58
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 56

def send_email_notification
  @send_email_notification
end

#stateObject

Returns the value of attribute state.



58
59
60
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 58

def state
  @state
end

#user_idObject

Returns the value of attribute user_id.



60
61
62
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 60

def user_id
  @user_id
end

#user_nameObject

Returns the value of attribute user_name.



62
63
64
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 62

def user_name
  @user_name
end

#user_tagsObject

Returns the value of attribute user_tags.



64
65
66
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 64

def user_tags
  @user_tags
end

#user_uuidObject

Returns the value of attribute user_uuid.



66
67
68
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 66

def user_uuid
  @user_uuid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 69

def self.attribute_map
  {
    :'auto_detect_environment' => :'auto_detect_environment',
    :'cid' => :'cid',
    :'created_timestamp' => :'created_timestamp',
    :'error_message' => :'error_message',
    :'error_origin' => :'error_origin',
    :'error_type' => :'error_type',
    :'id' => :'id',
    :'index_timestamp' => :'index_timestamp',
    :'interactive_phase' => :'interactive_phase',
    :'origin' => :'origin',
    :'sandbox' => :'sandbox',
    :'send_email_notification' => :'send_email_notification',
    :'state' => :'state',
    :'user_id' => :'user_id',
    :'user_name' => :'user_name',
    :'user_tags' => :'user_tags',
    :'user_uuid' => :'user_uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 267

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 97

def self.openapi_types
  {
    :'auto_detect_environment' => :'Boolean',
    :'cid' => :'String',
    :'created_timestamp' => :'String',
    :'error_message' => :'String',
    :'error_origin' => :'String',
    :'error_type' => :'String',
    :'id' => :'String',
    :'index_timestamp' => :'String',
    :'interactive_phase' => :'String',
    :'origin' => :'String',
    :'sandbox' => :'Array<FalconxSandboxParametersV1>',
    :'send_email_notification' => :'Boolean',
    :'state' => :'String',
    :'user_id' => :'String',
    :'user_name' => :'String',
    :'user_tags' => :'Array<String>',
    :'user_uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_detect_environment == o.auto_detect_environment &&
      cid == o.cid &&
      created_timestamp == o.created_timestamp &&
      error_message == o.error_message &&
      error_origin == o.error_origin &&
      error_type == o.error_type &&
      id == o.id &&
      index_timestamp == o.index_timestamp &&
      interactive_phase == o.interactive_phase &&
      origin == o.origin &&
      sandbox == o.sandbox &&
      send_email_notification == o.send_email_notification &&
      state == o.state &&
      user_id == o.user_id &&
      user_name == o.user_name &&
      user_tags == o.user_tags &&
      user_uuid == o.user_uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 298

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 369

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 274

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 260

def hash
  [auto_detect_environment, cid, created_timestamp, error_message, error_origin, error_type, id, index_timestamp, interactive_phase, origin, sandbox, send_email_notification, state, user_id, user_name, user_tags, user_uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 217

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 345

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



339
340
341
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 339

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
# File 'lib/crimson-falcon/models/falconx_submission_v1.rb', line 224

def valid?
  true
end