Class: Falcon::FalconxSummaryReportV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/falconx_summary_report_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FalconxSummaryReportV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FalconxSummaryReportV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FalconxSummaryReportV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'has_recording')
    self.has_recording = attributes[:'has_recording']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'intel')
    if (value = attributes[:'intel']).is_a?(Array)
      self.intel = value
    end
  end

  if attributes.key?(:'ioc_report_broad_csv_artifact_id')
    self.ioc_report_broad_csv_artifact_id = attributes[:'ioc_report_broad_csv_artifact_id']
  end

  if attributes.key?(:'ioc_report_broad_json_artifact_id')
    self.ioc_report_broad_json_artifact_id = attributes[:'ioc_report_broad_json_artifact_id']
  end

  if attributes.key?(:'ioc_report_broad_maec_artifact_id')
    self.ioc_report_broad_maec_artifact_id = attributes[:'ioc_report_broad_maec_artifact_id']
  end

  if attributes.key?(:'ioc_report_broad_stix_artifact_id')
    self.ioc_report_broad_stix_artifact_id = attributes[:'ioc_report_broad_stix_artifact_id']
  end

  if attributes.key?(:'ioc_report_strict_csv_artifact_id')
    self.ioc_report_strict_csv_artifact_id = attributes[:'ioc_report_strict_csv_artifact_id']
  end

  if attributes.key?(:'ioc_report_strict_json_artifact_id')
    self.ioc_report_strict_json_artifact_id = attributes[:'ioc_report_strict_json_artifact_id']
  end

  if attributes.key?(:'ioc_report_strict_maec_artifact_id')
    self.ioc_report_strict_maec_artifact_id = attributes[:'ioc_report_strict_maec_artifact_id']
  end

  if attributes.key?(:'ioc_report_strict_stix_artifact_id')
    self.ioc_report_strict_stix_artifact_id = attributes[:'ioc_report_strict_stix_artifact_id']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'sandbox')
    if (value = attributes[:'sandbox']).is_a?(Array)
      self.sandbox = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'verdict')
    self.verdict = attributes[:'verdict']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



34
35
36
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 34

def cid
  @cid
end

#created_timestampObject

Returns the value of attribute created_timestamp.



36
37
38
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 36

def created_timestamp
  @created_timestamp
end

#has_recordingObject

Returns the value of attribute has_recording.



38
39
40
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 38

def has_recording
  @has_recording
end

#idObject

Returns the value of attribute id.



40
41
42
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 40

def id
  @id
end

#intelObject

Returns the value of attribute intel.



42
43
44
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 42

def intel
  @intel
end

#ioc_report_broad_csv_artifact_idObject

Returns the value of attribute ioc_report_broad_csv_artifact_id.



44
45
46
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 44

def ioc_report_broad_csv_artifact_id
  @ioc_report_broad_csv_artifact_id
end

#ioc_report_broad_json_artifact_idObject

Returns the value of attribute ioc_report_broad_json_artifact_id.



46
47
48
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 46

def ioc_report_broad_json_artifact_id
  @ioc_report_broad_json_artifact_id
end

#ioc_report_broad_maec_artifact_idObject

Returns the value of attribute ioc_report_broad_maec_artifact_id.



48
49
50
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 48

def ioc_report_broad_maec_artifact_id
  @ioc_report_broad_maec_artifact_id
end

#ioc_report_broad_stix_artifact_idObject

Returns the value of attribute ioc_report_broad_stix_artifact_id.



50
51
52
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 50

def ioc_report_broad_stix_artifact_id
  @ioc_report_broad_stix_artifact_id
end

#ioc_report_strict_csv_artifact_idObject

Returns the value of attribute ioc_report_strict_csv_artifact_id.



52
53
54
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 52

def ioc_report_strict_csv_artifact_id
  @ioc_report_strict_csv_artifact_id
end

#ioc_report_strict_json_artifact_idObject

Returns the value of attribute ioc_report_strict_json_artifact_id.



54
55
56
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 54

def ioc_report_strict_json_artifact_id
  @ioc_report_strict_json_artifact_id
end

#ioc_report_strict_maec_artifact_idObject

Returns the value of attribute ioc_report_strict_maec_artifact_id.



56
57
58
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 56

def ioc_report_strict_maec_artifact_id
  @ioc_report_strict_maec_artifact_id
end

#ioc_report_strict_stix_artifact_idObject

Returns the value of attribute ioc_report_strict_stix_artifact_id.



58
59
60
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 58

def ioc_report_strict_stix_artifact_id
  @ioc_report_strict_stix_artifact_id
end

#originObject

Returns the value of attribute origin.



60
61
62
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 60

def origin
  @origin
end

#sandboxObject

Returns the value of attribute sandbox.



62
63
64
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 62

def sandbox
  @sandbox
end

#tagsObject

Returns the value of attribute tags.



64
65
66
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 64

def tags
  @tags
end

#user_idObject

Returns the value of attribute user_id.



66
67
68
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 66

def user_id
  @user_id
end

#user_nameObject

Returns the value of attribute user_name.



68
69
70
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 68

def user_name
  @user_name
end

#user_tagsObject

Returns the value of attribute user_tags.



70
71
72
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 70

def user_tags
  @user_tags
end

#verdictObject

Returns the value of attribute verdict.



72
73
74
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 72

def verdict
  @verdict
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 75

def self.attribute_map
  {
    :'cid' => :'cid',
    :'created_timestamp' => :'created_timestamp',
    :'has_recording' => :'has_recording',
    :'id' => :'id',
    :'intel' => :'intel',
    :'ioc_report_broad_csv_artifact_id' => :'ioc_report_broad_csv_artifact_id',
    :'ioc_report_broad_json_artifact_id' => :'ioc_report_broad_json_artifact_id',
    :'ioc_report_broad_maec_artifact_id' => :'ioc_report_broad_maec_artifact_id',
    :'ioc_report_broad_stix_artifact_id' => :'ioc_report_broad_stix_artifact_id',
    :'ioc_report_strict_csv_artifact_id' => :'ioc_report_strict_csv_artifact_id',
    :'ioc_report_strict_json_artifact_id' => :'ioc_report_strict_json_artifact_id',
    :'ioc_report_strict_maec_artifact_id' => :'ioc_report_strict_maec_artifact_id',
    :'ioc_report_strict_stix_artifact_id' => :'ioc_report_strict_stix_artifact_id',
    :'origin' => :'origin',
    :'sandbox' => :'sandbox',
    :'tags' => :'tags',
    :'user_id' => :'user_id',
    :'user_name' => :'user_name',
    :'user_tags' => :'user_tags',
    :'verdict' => :'verdict'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 296

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 106

def self.openapi_types
  {
    :'cid' => :'String',
    :'created_timestamp' => :'String',
    :'has_recording' => :'Boolean',
    :'id' => :'String',
    :'intel' => :'Array<FalconxIntelSummaryReportV1>',
    :'ioc_report_broad_csv_artifact_id' => :'String',
    :'ioc_report_broad_json_artifact_id' => :'String',
    :'ioc_report_broad_maec_artifact_id' => :'String',
    :'ioc_report_broad_stix_artifact_id' => :'String',
    :'ioc_report_strict_csv_artifact_id' => :'String',
    :'ioc_report_strict_json_artifact_id' => :'String',
    :'ioc_report_strict_maec_artifact_id' => :'String',
    :'ioc_report_strict_stix_artifact_id' => :'String',
    :'origin' => :'String',
    :'sandbox' => :'Array<FalconxSandboxSummaryReportV1>',
    :'tags' => :'Array<String>',
    :'user_id' => :'String',
    :'user_name' => :'String',
    :'user_tags' => :'Array<String>',
    :'verdict' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      created_timestamp == o.created_timestamp &&
      has_recording == o.has_recording &&
      id == o.id &&
      intel == o.intel &&
      ioc_report_broad_csv_artifact_id == o.ioc_report_broad_csv_artifact_id &&
      ioc_report_broad_json_artifact_id == o.ioc_report_broad_json_artifact_id &&
      ioc_report_broad_maec_artifact_id == o.ioc_report_broad_maec_artifact_id &&
      ioc_report_broad_stix_artifact_id == o.ioc_report_broad_stix_artifact_id &&
      ioc_report_strict_csv_artifact_id == o.ioc_report_strict_csv_artifact_id &&
      ioc_report_strict_json_artifact_id == o.ioc_report_strict_json_artifact_id &&
      ioc_report_strict_maec_artifact_id == o.ioc_report_strict_maec_artifact_id &&
      ioc_report_strict_stix_artifact_id == o.ioc_report_strict_stix_artifact_id &&
      origin == o.origin &&
      sandbox == o.sandbox &&
      tags == o.tags &&
      user_id == o.user_id &&
      user_name == o.user_name &&
      user_tags == o.user_tags &&
      verdict == o.verdict
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 327

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 289

def hash
  [cid, created_timestamp, has_recording, id, intel, ioc_report_broad_csv_artifact_id, ioc_report_broad_json_artifact_id, ioc_report_broad_maec_artifact_id, ioc_report_broad_stix_artifact_id, ioc_report_strict_csv_artifact_id, ioc_report_strict_json_artifact_id, ioc_report_strict_maec_artifact_id, ioc_report_strict_stix_artifact_id, origin, sandbox, tags, user_id, user_name, user_tags, verdict].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



243
244
245
246
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 243

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 374

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



368
369
370
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 368

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



250
251
252
# File 'lib/crimson-falcon/models/falconx_summary_report_v1.rb', line 250

def valid?
  true
end