Class: Falcon::FoundryLogscale
- Inherits:
-
Object
- Object
- Falcon::FoundryLogscale
- Defined in:
- lib/crimson-falcon/api/foundry_logscale.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_saved_searches_dynamic_execute_alt_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a dynamic saved search.
-
#create_saved_searches_dynamic_execute_alt_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a dynamic saved search.
-
#create_saved_searches_dynamic_execute_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a dynamic saved search.
-
#create_saved_searches_dynamic_execute_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a dynamic saved search.
-
#create_saved_searches_execute_alt_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a saved search.
-
#create_saved_searches_execute_alt_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a saved search.
-
#create_saved_searches_execute_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a saved search.
-
#create_saved_searches_execute_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a saved search.
-
#create_saved_searches_ingest_alt_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Populate a saved search.
-
#create_saved_searches_ingest_alt_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Populate a saved search.
-
#create_saved_searches_ingest_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Populate a saved search.
-
#create_saved_searches_ingest_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Populate a saved search.
-
#get_saved_searches_execute_alt_v1(job_id, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Get the results of a saved search.
-
#get_saved_searches_execute_alt_v1_with_http_info(job_id, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Get the results of a saved search.
-
#get_saved_searches_execute_v1(job_id, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Get the results of a saved search.
-
#get_saved_searches_execute_v1_with_http_info(job_id, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Get the results of a saved search.
-
#get_saved_searches_job_results_download_alt_v1(job_id, opts = {}) ⇒ File
Get the results of a saved search as a file.
-
#get_saved_searches_job_results_download_alt_v1_with_http_info(job_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get the results of a saved search as a file.
-
#get_saved_searches_job_results_download_v1(job_id, opts = {}) ⇒ File
Get the results of a saved search as a file.
-
#get_saved_searches_job_results_download_v1_with_http_info(job_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get the results of a saved search as a file.
-
#ingest_data_async_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Asynchronously ingest data into the application repository.
-
#ingest_data_async_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Asynchronously ingest data into the application repository.
-
#ingest_data_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Synchronously ingest data into the application repository.
-
#ingest_data_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Synchronously ingest data into the application repository.
-
#initialize(api_client = ApiClient.default) ⇒ FoundryLogscale
constructor
A new instance of FoundryLogscale.
-
#list_repos_v1(opts = {}) ⇒ ApidomainRepoViewListItemWrapperV1
Lists available repositories and views.
-
#list_repos_v1_with_http_info(opts = {}) ⇒ Array<(ApidomainRepoViewListItemWrapperV1, Integer, Hash)>
Lists available repositories and views.
-
#list_view_v1(opts = {}) ⇒ ApidomainRepoViewListItemWrapperV1
List views.
-
#list_view_v1_with_http_info(opts = {}) ⇒ Array<(ApidomainRepoViewListItemWrapperV1, Integer, Hash)>
List views.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FoundryLogscale
Returns a new instance of FoundryLogscale.
35 36 37 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 33 def api_client @api_client end |
Instance Method Details
#create_saved_searches_dynamic_execute_alt_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a dynamic saved search
50 51 52 53 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 50 def create_saved_searches_dynamic_execute_alt_v1(body, opts = {}) data, _status_code, _headers = create_saved_searches_dynamic_execute_alt_v1_with_http_info(body, opts) data end |
#create_saved_searches_dynamic_execute_alt_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a dynamic saved search
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 67 def create_saved_searches_dynamic_execute_alt_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_dynamic_execute_alt_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FoundryLogscale.create_saved_searches_dynamic_execute_alt_v1" end allowable_values = ["sync", "async", "async_offload"] if @api_client.config.client_side_validation && opts[:'mode'] && !allowable_values.include?(opts[:'mode']) fail ArgumentError, "invalid value for \"mode\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_dynamic_execute_alt_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_dynamic_execute_alt_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches-dynamic-execute/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'include_schema_generation'] = opts[:'include_schema_generation'] if !opts[:'include_schema_generation'].nil? query_params[:'include_test_data'] = opts[:'include_test_data'] if !opts[:'include_test_data'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? query_params[:'mode'] = opts[:'mode'] if !opts[:'mode'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_dynamic_execute_alt_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_dynamic_execute_alt_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_saved_searches_dynamic_execute_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a dynamic saved search
152 153 154 155 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 152 def create_saved_searches_dynamic_execute_v1(body, opts = {}) data, _status_code, _headers = create_saved_searches_dynamic_execute_v1_with_http_info(body, opts) data end |
#create_saved_searches_dynamic_execute_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a dynamic saved search
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 169 def create_saved_searches_dynamic_execute_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_dynamic_execute_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FoundryLogscale.create_saved_searches_dynamic_execute_v1" end allowable_values = ["sync", "async", "async_offload"] if @api_client.config.client_side_validation && opts[:'mode'] && !allowable_values.include?(opts[:'mode']) fail ArgumentError, "invalid value for \"mode\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_dynamic_execute_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_dynamic_execute_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches/execute-dynamic/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'include_schema_generation'] = opts[:'include_schema_generation'] if !opts[:'include_schema_generation'].nil? query_params[:'include_test_data'] = opts[:'include_test_data'] if !opts[:'include_test_data'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? query_params[:'mode'] = opts[:'mode'] if !opts[:'mode'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_dynamic_execute_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_dynamic_execute_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_saved_searches_execute_alt_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a saved search
253 254 255 256 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 253 def create_saved_searches_execute_alt_v1(body, opts = {}) data, _status_code, _headers = create_saved_searches_execute_alt_v1_with_http_info(body, opts) data end |
#create_saved_searches_execute_alt_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a saved search
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 269 def create_saved_searches_execute_alt_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_execute_alt_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FoundryLogscale.create_saved_searches_execute_alt_v1" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_execute_alt_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_execute_alt_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches-execute/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'detailed'] = opts[:'detailed'] if !opts[:'detailed'].nil? query_params[:'include_test_data'] = opts[:'include_test_data'] if !opts[:'include_test_data'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_execute_alt_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_execute_alt_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_saved_searches_execute_v1(body, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Execute a saved search
348 349 350 351 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 348 def create_saved_searches_execute_v1(body, opts = {}) data, _status_code, _headers = create_saved_searches_execute_v1_with_http_info(body, opts) data end |
#create_saved_searches_execute_v1_with_http_info(body, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Execute a saved search
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 364 def create_saved_searches_execute_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_execute_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FoundryLogscale.create_saved_searches_execute_v1" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_execute_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.create_saved_searches_execute_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches/execute/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'detailed'] = opts[:'detailed'] if !opts[:'detailed'].nil? query_params[:'include_test_data'] = opts[:'include_test_data'] if !opts[:'include_test_data'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_execute_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_execute_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_saved_searches_ingest_alt_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Populate a saved search
436 437 438 439 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 436 def create_saved_searches_ingest_alt_v1(opts = {}) data, _status_code, _headers = create_saved_searches_ingest_alt_v1_with_http_info(opts) data end |
#create_saved_searches_ingest_alt_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Populate a saved search
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 445 def create_saved_searches_ingest_alt_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_ingest_alt_v1 ...' end # resource path local_var_path = '/loggingapi/entities/saved-searches-ingest/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientDataIngestResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_ingest_alt_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_ingest_alt_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_saved_searches_ingest_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Populate a saved search
494 495 496 497 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 494 def create_saved_searches_ingest_v1(opts = {}) data, _status_code, _headers = create_saved_searches_ingest_v1_with_http_info(opts) data end |
#create_saved_searches_ingest_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Populate a saved search
503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 503 def create_saved_searches_ingest_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.create_saved_searches_ingest_v1 ...' end # resource path local_var_path = '/loggingapi/entities/saved-searches/ingest/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientDataIngestResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.create_saved_searches_ingest_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#create_saved_searches_ingest_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_saved_searches_execute_alt_v1(job_id, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Get the results of a saved search
560 561 562 563 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 560 def get_saved_searches_execute_alt_v1(job_id, opts = {}) data, _status_code, _headers = get_saved_searches_execute_alt_v1_with_http_info(job_id, opts) data end |
#get_saved_searches_execute_alt_v1_with_http_info(job_id, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Get the results of a saved search
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 577 def get_saved_searches_execute_alt_v1_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.get_saved_searches_execute_alt_v1 ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling FoundryLogscale.get_saved_searches_execute_alt_v1" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.get_saved_searches_execute_alt_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.get_saved_searches_execute_alt_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches-execute/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'job_id'] = job_id query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'job_status_only'] = opts[:'job_status_only'] if !opts[:'job_status_only'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.get_saved_searches_execute_alt_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#get_saved_searches_execute_alt_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_saved_searches_execute_v1(job_id, opts = {}) ⇒ ApidomainQueryResponseWrapperV1
Get the results of a saved search
654 655 656 657 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 654 def get_saved_searches_execute_v1(job_id, opts = {}) data, _status_code, _headers = get_saved_searches_execute_v1_with_http_info(job_id, opts) data end |
#get_saved_searches_execute_v1_with_http_info(job_id, opts = {}) ⇒ Array<(ApidomainQueryResponseWrapperV1, Integer, Hash)>
Get the results of a saved search
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 671 def get_saved_searches_execute_v1_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.get_saved_searches_execute_v1 ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling FoundryLogscale.get_saved_searches_execute_v1" end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.get_saved_searches_execute_v1, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_cs_useruuid'].nil? && opts[:'x_cs_useruuid'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_cs_useruuid"]" when calling FoundryLogscale.get_saved_searches_execute_v1, the character length must be great than or equal to 36.' end # resource path local_var_path = '/loggingapi/entities/saved-searches/execute/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'job_id'] = job_id query_params[:'app_id'] = opts[:'app_id'] if !opts[:'app_id'].nil? query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'job_status_only'] = opts[:'job_status_only'] if !opts[:'job_status_only'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'match_response_schema'] = opts[:'match_response_schema'] if !opts[:'match_response_schema'].nil? query_params[:'metadata'] = opts[:'metadata'] if !opts[:'metadata'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApidomainQueryResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.get_saved_searches_execute_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#get_saved_searches_execute_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_saved_searches_job_results_download_alt_v1(job_id, opts = {}) ⇒ File
Get the results of a saved search as a file
742 743 744 745 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 742 def get_saved_searches_job_results_download_alt_v1(job_id, opts = {}) data, _status_code, _headers = get_saved_searches_job_results_download_alt_v1_with_http_info(job_id, opts) data end |
#get_saved_searches_job_results_download_alt_v1_with_http_info(job_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get the results of a saved search as a file
753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 753 def get_saved_searches_job_results_download_alt_v1_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.get_saved_searches_job_results_download_alt_v1 ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling FoundryLogscale.get_saved_searches_job_results_download_alt_v1" end allowable_values = ["json", "csv"] if @api_client.config.client_side_validation && opts[:'result_format'] && !allowable_values.include?(opts[:'result_format']) fail ArgumentError, "invalid value for \"result_format\", must be one of #{allowable_values}" end # resource path local_var_path = '/loggingapi/entities/saved-searches-job-results-download/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'job_id'] = job_id query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'result_format'] = opts[:'result_format'] if !opts[:'result_format'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream', 'text/csv', 'application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'File' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.get_saved_searches_job_results_download_alt_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#get_saved_searches_job_results_download_alt_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_saved_searches_job_results_download_v1(job_id, opts = {}) ⇒ File
Get the results of a saved search as a file
814 815 816 817 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 814 def get_saved_searches_job_results_download_v1(job_id, opts = {}) data, _status_code, _headers = get_saved_searches_job_results_download_v1_with_http_info(job_id, opts) data end |
#get_saved_searches_job_results_download_v1_with_http_info(job_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get the results of a saved search as a file
825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 825 def get_saved_searches_job_results_download_v1_with_http_info(job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.get_saved_searches_job_results_download_v1 ...' end # verify the required parameter 'job_id' is set if @api_client.config.client_side_validation && job_id.nil? fail ArgumentError, "Missing the required parameter 'job_id' when calling FoundryLogscale.get_saved_searches_job_results_download_v1" end allowable_values = ["json", "csv"] if @api_client.config.client_side_validation && opts[:'result_format'] && !allowable_values.include?(opts[:'result_format']) fail ArgumentError, "invalid value for \"result_format\", must be one of #{allowable_values}" end # resource path local_var_path = '/loggingapi/entities/saved-searches/job-results-download/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'job_id'] = job_id query_params[:'infer_json_types'] = opts[:'infer_json_types'] if !opts[:'infer_json_types'].nil? query_params[:'result_format'] = opts[:'result_format'] if !opts[:'result_format'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream', 'text/csv', 'application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'File' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.get_saved_searches_job_results_download_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#get_saved_searches_job_results_download_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ingest_data_async_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Asynchronously ingest data into the application repository
889 890 891 892 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 889 def ingest_data_async_v1(opts = {}) data, _status_code, _headers = ingest_data_async_v1_with_http_info(opts) data end |
#ingest_data_async_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Asynchronously ingest data into the application repository
903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 903 def ingest_data_async_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.ingest_data_async_v1 ...' end # resource path local_var_path = '/loggingapi/entities/data-ingestion/ingest-async/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['data_content'] = opts[:'data_content'] if !opts[:'data_content'].nil? form_params['data_file'] = opts[:'data_file'] if !opts[:'data_file'].nil? form_params['repo'] = opts[:'repo'] if !opts[:'repo'].nil? form_params['tag'] = @api_client.build_collection_param(opts[:'tag'], :csv) if !opts[:'tag'].nil? form_params['tag_source'] = opts[:'tag_source'] if !opts[:'tag_source'].nil? form_params['test_data'] = opts[:'test_data'] if !opts[:'test_data'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientDataIngestResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.ingest_data_async_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#ingest_data_async_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ingest_data_v1(opts = {}) ⇒ ClientDataIngestResponseWrapperV1
Synchronously ingest data into the application repository
966 967 968 969 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 966 def ingest_data_v1(opts = {}) data, _status_code, _headers = ingest_data_v1_with_http_info(opts) data end |
#ingest_data_v1_with_http_info(opts = {}) ⇒ Array<(ClientDataIngestResponseWrapperV1, Integer, Hash)>
Synchronously ingest data into the application repository
979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 979 def ingest_data_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.ingest_data_v1 ...' end # resource path local_var_path = '/loggingapi/entities/data-ingestion/ingest/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['data_content'] = opts[:'data_content'] if !opts[:'data_content'].nil? form_params['data_file'] = opts[:'data_file'] if !opts[:'data_file'].nil? form_params['tag'] = @api_client.build_collection_param(opts[:'tag'], :csv) if !opts[:'tag'].nil? form_params['tag_source'] = opts[:'tag_source'] if !opts[:'tag_source'].nil? form_params['test_data'] = opts[:'test_data'] if !opts[:'test_data'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ClientDataIngestResponseWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.ingest_data_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#ingest_data_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_repos_v1(opts = {}) ⇒ ApidomainRepoViewListItemWrapperV1
Lists available repositories and views
1037 1038 1039 1040 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 1037 def list_repos_v1(opts = {}) data, _status_code, _headers = list_repos_v1_with_http_info(opts) data end |
#list_repos_v1_with_http_info(opts = {}) ⇒ Array<(ApidomainRepoViewListItemWrapperV1, Integer, Hash)>
Lists available repositories and views
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 1046 def list_repos_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.list_repos_v1 ...' end # resource path local_var_path = '/loggingapi/combined/repos/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'check_test_data'] = opts[:'check_test_data'] if !opts[:'check_test_data'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApidomainRepoViewListItemWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.list_repos_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#list_repos_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_view_v1(opts = {}) ⇒ ApidomainRepoViewListItemWrapperV1
List views
1095 1096 1097 1098 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 1095 def list_view_v1(opts = {}) data, _status_code, _headers = list_view_v1_with_http_info(opts) data end |
#list_view_v1_with_http_info(opts = {}) ⇒ Array<(ApidomainRepoViewListItemWrapperV1, Integer, Hash)>
List views
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 |
# File 'lib/crimson-falcon/api/foundry_logscale.rb', line 1104 def list_view_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FoundryLogscale.list_view_v1 ...' end # resource path local_var_path = '/loggingapi/entities/views/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'check_test_data'] = opts[:'check_test_data'] if !opts[:'check_test_data'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApidomainRepoViewListItemWrapperV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"FoundryLogscale.list_view_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FoundryLogscale#list_view_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |