Class: Falcon::FwmgrApiNetworkLocationCreateRequestV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FwmgrApiNetworkLocationCreateRequestV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FwmgrApiNetworkLocationCreateRequestV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FwmgrApiNetworkLocationCreateRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connection_types')
    self.connection_types = attributes[:'connection_types']
  end

  if attributes.key?(:'default_gateways')
    if (value = attributes[:'default_gateways']).is_a?(Array)
      self.default_gateways = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'dhcp_servers')
    if (value = attributes[:'dhcp_servers']).is_a?(Array)
      self.dhcp_servers = value
    end
  end

  if attributes.key?(:'dns_resolution_targets')
    self.dns_resolution_targets = attributes[:'dns_resolution_targets']
  end

  if attributes.key?(:'dns_servers')
    if (value = attributes[:'dns_servers']).is_a?(Array)
      self.dns_servers = value
    end
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'host_addresses')
    if (value = attributes[:'host_addresses']).is_a?(Array)
      self.host_addresses = value
    end
  end

  if attributes.key?(:'https_reachable_hosts')
    self.https_reachable_hosts = attributes[:'https_reachable_hosts']
  end

  if attributes.key?(:'icmp_request_targets')
    self.icmp_request_targets = attributes[:'icmp_request_targets']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#connection_typesObject

Returns the value of attribute connection_types.



34
35
36
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 34

def connection_types
  @connection_types
end

#default_gatewaysObject

Returns the value of attribute default_gateways.



36
37
38
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 36

def default_gateways
  @default_gateways
end

#descriptionObject

Returns the value of attribute description.



38
39
40
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 38

def description
  @description
end

#dhcp_serversObject

Returns the value of attribute dhcp_servers.



40
41
42
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 40

def dhcp_servers
  @dhcp_servers
end

#dns_resolution_targetsObject

Returns the value of attribute dns_resolution_targets.



42
43
44
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 42

def dns_resolution_targets
  @dns_resolution_targets
end

#dns_serversObject

Returns the value of attribute dns_servers.



44
45
46
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 44

def dns_servers
  @dns_servers
end

#enabledObject

Returns the value of attribute enabled.



46
47
48
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 46

def enabled
  @enabled
end

#host_addressesObject

Returns the value of attribute host_addresses.



48
49
50
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 48

def host_addresses
  @host_addresses
end

#https_reachable_hostsObject

Returns the value of attribute https_reachable_hosts.



50
51
52
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 50

def https_reachable_hosts
  @https_reachable_hosts
end

#icmp_request_targetsObject

Returns the value of attribute icmp_request_targets.



52
53
54
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 52

def icmp_request_targets
  @icmp_request_targets
end

#nameObject

Returns the value of attribute name.



54
55
56
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 54

def name
  @name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 57

def self.attribute_map
  {
    :'connection_types' => :'connection_types',
    :'default_gateways' => :'default_gateways',
    :'description' => :'description',
    :'dhcp_servers' => :'dhcp_servers',
    :'dns_resolution_targets' => :'dns_resolution_targets',
    :'dns_servers' => :'dns_servers',
    :'enabled' => :'enabled',
    :'host_addresses' => :'host_addresses',
    :'https_reachable_hosts' => :'https_reachable_hosts',
    :'icmp_request_targets' => :'icmp_request_targets',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 270

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 79

def self.openapi_types
  {
    :'connection_types' => :'FwmgrDomainConnectionType',
    :'default_gateways' => :'Array<String>',
    :'description' => :'String',
    :'dhcp_servers' => :'Array<String>',
    :'dns_resolution_targets' => :'FwmgrDomainDNSResolutionTargets',
    :'dns_servers' => :'Array<String>',
    :'enabled' => :'Boolean',
    :'host_addresses' => :'Array<String>',
    :'https_reachable_hosts' => :'FwmgrDomainHTTPSHosts',
    :'icmp_request_targets' => :'FwmgrDomainICMPTargets',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connection_types == o.connection_types &&
      default_gateways == o.default_gateways &&
      description == o.description &&
      dhcp_servers == o.dhcp_servers &&
      dns_resolution_targets == o.dns_resolution_targets &&
      dns_servers == o.dns_servers &&
      enabled == o.enabled &&
      host_addresses == o.host_addresses &&
      https_reachable_hosts == o.https_reachable_hosts &&
      icmp_request_targets == o.icmp_request_targets &&
      name == o.name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 301

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 372

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 277

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 263

def hash
  [connection_types, default_gateways, description, dhcp_servers, dns_resolution_targets, dns_servers, enabled, host_addresses, https_reachable_hosts, icmp_request_targets, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  if @connection_types.nil?
    invalid_properties.push('invalid value for "connection_types", connection_types cannot be nil.')
  end

  if @default_gateways.nil?
    invalid_properties.push('invalid value for "default_gateways", default_gateways cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @dhcp_servers.nil?
    invalid_properties.push('invalid value for "dhcp_servers", dhcp_servers cannot be nil.')
  end

  if @dns_resolution_targets.nil?
    invalid_properties.push('invalid value for "dns_resolution_targets", dns_resolution_targets cannot be nil.')
  end

  if @dns_servers.nil?
    invalid_properties.push('invalid value for "dns_servers", dns_servers cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @host_addresses.nil?
    invalid_properties.push('invalid value for "host_addresses", host_addresses cannot be nil.')
  end

  if @https_reachable_hosts.nil?
    invalid_properties.push('invalid value for "https_reachable_hosts", https_reachable_hosts cannot be nil.')
  end

  if @icmp_request_targets.nil?
    invalid_properties.push('invalid value for "icmp_request_targets", icmp_request_targets cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 348

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



342
343
344
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 342

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/crimson-falcon/models/fwmgr_api_network_location_create_request_v1.rb', line 222

def valid?
  return false if @connection_types.nil?
  return false if @default_gateways.nil?
  return false if @description.nil?
  return false if @dhcp_servers.nil?
  return false if @dns_resolution_targets.nil?
  return false if @dns_servers.nil?
  return false if @enabled.nil?
  return false if @host_addresses.nil?
  return false if @https_reachable_hosts.nil?
  return false if @icmp_request_targets.nil?
  return false if @name.nil?
  true
end