Class: Falcon::FwmgrApiRuleCreateRequestV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FwmgrApiRuleCreateRequestV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::FwmgrApiRuleCreateRequestV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::FwmgrApiRuleCreateRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'address_family')
    self.address_family = attributes[:'address_family']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'fields')
    if (value = attributes[:'fields']).is_a?(Array)
      self.fields = value
    end
  end

  if attributes.key?(:'fqdn')
    self.fqdn = attributes[:'fqdn']
  end

  if attributes.key?(:'fqdn_enabled')
    self.fqdn_enabled = attributes[:'fqdn_enabled']
  end

  if attributes.key?(:'icmp')
    self.icmp = attributes[:'icmp']
  end

  if attributes.key?(:'local_address')
    if (value = attributes[:'local_address']).is_a?(Array)
      self.local_address = value
    end
  end

  if attributes.key?(:'local_port')
    if (value = attributes[:'local_port']).is_a?(Array)
      self.local_port = value
    end
  end

  if attributes.key?(:'log')
    self.log = attributes[:'log']
  end

  if attributes.key?(:'monitor')
    self.monitor = attributes[:'monitor']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  end

  if attributes.key?(:'remote_address')
    if (value = attributes[:'remote_address']).is_a?(Array)
      self.remote_address = value
    end
  end

  if attributes.key?(:'remote_port')
    if (value = attributes[:'remote_port']).is_a?(Array)
      self.remote_port = value
    end
  end

  if attributes.key?(:'temp_id')
    self.temp_id = attributes[:'temp_id']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



34
35
36
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 34

def action
  @action
end

#address_familyObject

Returns the value of attribute address_family.



36
37
38
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 36

def address_family
  @address_family
end

#descriptionObject

Returns the value of attribute description.



38
39
40
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 38

def description
  @description
end

#directionObject

Returns the value of attribute direction.



40
41
42
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 40

def direction
  @direction
end

#enabledObject

Returns the value of attribute enabled.



42
43
44
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 42

def enabled
  @enabled
end

#fieldsObject

Returns the value of attribute fields.



44
45
46
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 44

def fields
  @fields
end

#fqdnObject

Returns the value of attribute fqdn.



46
47
48
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 46

def fqdn
  @fqdn
end

#fqdn_enabledObject

Returns the value of attribute fqdn_enabled.



48
49
50
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 48

def fqdn_enabled
  @fqdn_enabled
end

#icmpObject

Returns the value of attribute icmp.



50
51
52
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 50

def icmp
  @icmp
end

#local_addressObject

Returns the value of attribute local_address.



52
53
54
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 52

def local_address
  @local_address
end

#local_portObject

Returns the value of attribute local_port.



54
55
56
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 54

def local_port
  @local_port
end

#logObject

Returns the value of attribute log.



56
57
58
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 56

def log
  @log
end

#monitorObject

Returns the value of attribute monitor.



58
59
60
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 58

def monitor
  @monitor
end

#nameObject

Returns the value of attribute name.



60
61
62
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 60

def name
  @name
end

#protocolObject

Returns the value of attribute protocol.



62
63
64
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 62

def protocol
  @protocol
end

#remote_addressObject

Returns the value of attribute remote_address.



64
65
66
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 64

def remote_address
  @remote_address
end

#remote_portObject

Returns the value of attribute remote_port.



66
67
68
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 66

def remote_port
  @remote_port
end

#temp_idObject

Returns the value of attribute temp_id.



68
69
70
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 68

def temp_id
  @temp_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 95

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 71

def self.attribute_map
  {
    :'action' => :'action',
    :'address_family' => :'address_family',
    :'description' => :'description',
    :'direction' => :'direction',
    :'enabled' => :'enabled',
    :'fields' => :'fields',
    :'fqdn' => :'fqdn',
    :'fqdn_enabled' => :'fqdn_enabled',
    :'icmp' => :'icmp',
    :'local_address' => :'local_address',
    :'local_port' => :'local_port',
    :'log' => :'log',
    :'monitor' => :'monitor',
    :'name' => :'name',
    :'protocol' => :'protocol',
    :'remote_address' => :'remote_address',
    :'remote_port' => :'remote_port',
    :'temp_id' => :'temp_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



370
371
372
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 370

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 100

def self.openapi_types
  {
    :'action' => :'String',
    :'address_family' => :'String',
    :'description' => :'String',
    :'direction' => :'String',
    :'enabled' => :'Boolean',
    :'fields' => :'Array<FwmgrApiWorkaroundUIFieldValue>',
    :'fqdn' => :'String',
    :'fqdn_enabled' => :'Boolean',
    :'icmp' => :'FwmgrDomainICMP',
    :'local_address' => :'Array<FwmgrDomainAddressRange>',
    :'local_port' => :'Array<FwmgrDomainPortRange>',
    :'log' => :'Boolean',
    :'monitor' => :'FwmgrDomainMonitoring',
    :'name' => :'String',
    :'protocol' => :'String',
    :'remote_address' => :'Array<FwmgrDomainAddressRange>',
    :'remote_port' => :'Array<FwmgrDomainPortRange>',
    :'temp_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      address_family == o.address_family &&
      description == o.description &&
      direction == o.direction &&
      enabled == o.enabled &&
      fields == o.fields &&
      fqdn == o.fqdn &&
      fqdn_enabled == o.fqdn_enabled &&
      icmp == o.icmp &&
      local_address == o.local_address &&
      local_port == o.local_port &&
      log == o.log &&
      monitor == o.monitor &&
      name == o.name &&
      protocol == o.protocol &&
      remote_address == o.remote_address &&
      remote_port == o.remote_port &&
      temp_id == o.temp_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 401

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 472

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 377

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


357
358
359
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 357

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



363
364
365
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 363

def hash
  [action, address_family, description, direction, enabled, fields, fqdn, fqdn_enabled, icmp, local_address, local_port, log, monitor, name, protocol, remote_address, remote_port, temp_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 229

def list_invalid_properties
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @address_family.nil?
    invalid_properties.push('invalid value for "address_family", address_family cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @fields.nil?
    invalid_properties.push('invalid value for "fields", fields cannot be nil.')
  end

  if @fqdn.nil?
    invalid_properties.push('invalid value for "fqdn", fqdn cannot be nil.')
  end

  if @fqdn_enabled.nil?
    invalid_properties.push('invalid value for "fqdn_enabled", fqdn_enabled cannot be nil.')
  end

  if @icmp.nil?
    invalid_properties.push('invalid value for "icmp", icmp cannot be nil.')
  end

  if @local_address.nil?
    invalid_properties.push('invalid value for "local_address", local_address cannot be nil.')
  end

  if @local_port.nil?
    invalid_properties.push('invalid value for "local_port", local_port cannot be nil.')
  end

  if @log.nil?
    invalid_properties.push('invalid value for "log", log cannot be nil.')
  end

  if @monitor.nil?
    invalid_properties.push('invalid value for "monitor", monitor cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @protocol.nil?
    invalid_properties.push('invalid value for "protocol", protocol cannot be nil.')
  end

  if @remote_address.nil?
    invalid_properties.push('invalid value for "remote_address", remote_address cannot be nil.')
  end

  if @remote_port.nil?
    invalid_properties.push('invalid value for "remote_port", remote_port cannot be nil.')
  end

  if @temp_id.nil?
    invalid_properties.push('invalid value for "temp_id", temp_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



448
449
450
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 448

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 454

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



442
443
444
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 442

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/crimson-falcon/models/fwmgr_api_rule_create_request_v1.rb', line 308

def valid?
  return false if @action.nil?
  return false if @address_family.nil?
  return false if @description.nil?
  return false if @direction.nil?
  return false if @enabled.nil?
  return false if @fields.nil?
  return false if @fqdn.nil?
  return false if @fqdn_enabled.nil?
  return false if @icmp.nil?
  return false if @local_address.nil?
  return false if @local_port.nil?
  return false if @log.nil?
  return false if @monitor.nil?
  return false if @name.nil?
  return false if @protocol.nil?
  return false if @remote_address.nil?
  return false if @remote_port.nil?
  return false if @temp_id.nil?
  true
end