Class: Falcon::GraphConfiguredActivity
- Inherits:
-
Object
- Object
- Falcon::GraphConfiguredActivity
- Defined in:
- lib/crimson-falcon/models/graph_configured_activity.rb
Instance Attribute Summary collapse
-
#_class ⇒ Object
The class of activity.
-
#continue_on_error ⇒ Object
If set to true, an error on the action will not send an error token to children.
-
#default_name ⇒ Object
The name of the activity type which is not user editable.
-
#flows ⇒ Object
Returns the value of attribute flows.
-
#id ⇒ Object
The unique identifier of the selected activity that is being configured.
-
#inline_configuration ⇒ Object
Returns the value of attribute inline_configuration.
-
#max_seconds ⇒ Object
Maximum seconds to wait for an async process to finish.
-
#mock_output ⇒ Object
Returns the value of attribute mock_output.
-
#name ⇒ Object
Optional user provided name for the activity, if not specified a default of the name for that Activity will be used.
-
#node_id ⇒ Object
Returns the value of attribute node_id.
-
#position ⇒ Object
Returns the value of attribute position.
-
#properties ⇒ Object
Dynamic payload providing values needed to configure the activity for execution.
-
#version_constraint ⇒ Object
Semantic version constraint of the activity, can be an explicit version or a version constraint.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GraphConfiguredActivity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GraphConfiguredActivity
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::GraphConfiguredActivity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::GraphConfiguredActivity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_class') self._class = attributes[:'_class'] end if attributes.key?(:'continue_on_error') self.continue_on_error = attributes[:'continue_on_error'] end if attributes.key?(:'default_name') self.default_name = attributes[:'default_name'] end if attributes.key?(:'flows') self.flows = attributes[:'flows'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'inline_configuration') self.inline_configuration = attributes[:'inline_configuration'] end if attributes.key?(:'max_seconds') self.max_seconds = attributes[:'max_seconds'] end if attributes.key?(:'mock_output') self.mock_output = attributes[:'mock_output'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'node_id') self.node_id = attributes[:'node_id'] end if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'properties') self.properties = attributes[:'properties'] end if attributes.key?(:'version_constraint') self.version_constraint = attributes[:'version_constraint'] end end |
Instance Attribute Details
#_class ⇒ Object
The class of activity. If undefined it is an ActivityClassDefault
35 36 37 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 35 def _class @_class end |
#continue_on_error ⇒ Object
If set to true, an error on the action will not send an error token to children
38 39 40 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 38 def continue_on_error @continue_on_error end |
#default_name ⇒ Object
The name of the activity type which is not user editable.
41 42 43 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 41 def default_name @default_name end |
#flows ⇒ Object
Returns the value of attribute flows.
43 44 45 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 43 def flows @flows end |
#id ⇒ Object
The unique identifier of the selected activity that is being configured.
46 47 48 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 46 def id @id end |
#inline_configuration ⇒ Object
Returns the value of attribute inline_configuration.
48 49 50 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 48 def inline_configuration @inline_configuration end |
#max_seconds ⇒ Object
Maximum seconds to wait for an async process to finish. Overrides default async_max_seconds on Activity seed.
51 52 53 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 51 def max_seconds @max_seconds end |
#mock_output ⇒ Object
Returns the value of attribute mock_output.
53 54 55 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 53 def mock_output @mock_output end |
#name ⇒ Object
Optional user provided name for the activity, if not specified a default of the name for that Activity will be used.
56 57 58 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 56 def name @name end |
#node_id ⇒ Object
Returns the value of attribute node_id.
58 59 60 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 58 def node_id @node_id end |
#position ⇒ Object
Returns the value of attribute position.
60 61 62 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 60 def position @position end |
#properties ⇒ Object
Dynamic payload providing values needed to configure the activity for execution. The structure of this data is dictated by the JSON Schema defined for the selected Activity.
63 64 65 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 63 def properties @properties end |
#version_constraint ⇒ Object
Semantic version constraint of the activity, can be an explicit version or a version constraint. If unspecified the latest activity <= 1.0.0 is used.
66 67 68 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 66 def version_constraint @version_constraint end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 88 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 69 def self.attribute_map { :'_class' => :'class', :'continue_on_error' => :'continue_on_error', :'default_name' => :'default_name', :'flows' => :'flows', :'id' => :'id', :'inline_configuration' => :'inline_configuration', :'max_seconds' => :'max_seconds', :'mock_output' => :'mock_output', :'name' => :'name', :'node_id' => :'nodeID', :'position' => :'position', :'properties' => :'properties', :'version_constraint' => :'version_constraint' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 258 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 93 def self.openapi_types { :'_class' => :'String', :'continue_on_error' => :'Boolean', :'default_name' => :'String', :'flows' => :'Flows', :'id' => :'String', :'inline_configuration' => :'GraphInlineActivityConfig', :'max_seconds' => :'String', :'mock_output' => :'NodemocksReference', :'name' => :'String', :'node_id' => :'String', :'position' => :'GraphNodePosition', :'properties' => :'Object', :'version_constraint' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && _class == o._class && continue_on_error == o.continue_on_error && default_name == o.default_name && flows == o.flows && id == o.id && inline_configuration == o.inline_configuration && max_seconds == o.max_seconds && mock_output == o.mock_output && name == o.name && node_id == o.node_id && position == o.position && properties == o.properties && version_constraint == o.version_constraint end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 289 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 360 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 265 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 251 def hash [_class, continue_on_error, default_name, flows, id, inline_configuration, max_seconds, mock_output, name, node_id, position, properties, version_constraint].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 187 def list_invalid_properties invalid_properties = Array.new if @flows.nil? invalid_properties.push('invalid value for "flows", flows cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @node_id.nil? invalid_properties.push('invalid value for "node_id", node_id cannot be nil.') end if @properties.nil? invalid_properties.push('invalid value for "properties", properties cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
336 337 338 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 336 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
330 331 332 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 330 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 |
# File 'lib/crimson-falcon/models/graph_configured_activity.rb', line 214 def valid? return false if @flows.nil? return false if @id.nil? return false if @name.nil? return false if @node_id.nil? return false if @properties.nil? true end |