Class: Falcon::GraphConfiguredTrigger
- Inherits:
-
Object
- Object
- Falcon::GraphConfiguredTrigger
- Defined in:
- lib/crimson-falcon/models/graph_configured_trigger.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier for the selected trigger as provided by the triggers API.
-
#mock_output ⇒ Object
Returns the value of attribute mock_output.
-
#name ⇒ Object
Display name of the trigger.
-
#node_id ⇒ Object
Returns the value of attribute node_id.
-
#outgoing_flow ⇒ Object
Reference to the ID of the flow node outbound from the trigger.
-
#parameters ⇒ Object
Returns the value of attribute parameters.
-
#position ⇒ Object
Returns the value of attribute position.
-
#timer_event_definition ⇒ Object
Returns the value of attribute timer_event_definition.
-
#trigger_type ⇒ Object
The type of trigger, signal, scheduled, on demand, etc.
-
#version_constraint ⇒ Object
Semantic version constraint of the trigger, it can be an explicit version or a version constraint.
-
#webhook_config ⇒ Object
Returns the value of attribute webhook_config.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GraphConfiguredTrigger
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GraphConfiguredTrigger
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::GraphConfiguredTrigger` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::GraphConfiguredTrigger`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'mock_output') self.mock_output = attributes[:'mock_output'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'node_id') self.node_id = attributes[:'node_id'] end if attributes.key?(:'outgoing_flow') self.outgoing_flow = attributes[:'outgoing_flow'] end if attributes.key?(:'parameters') self.parameters = attributes[:'parameters'] end if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'timer_event_definition') self.timer_event_definition = attributes[:'timer_event_definition'] end if attributes.key?(:'trigger_type') self.trigger_type = attributes[:'trigger_type'] end if attributes.key?(:'version_constraint') self.version_constraint = attributes[:'version_constraint'] end if attributes.key?(:'webhook_config') self.webhook_config = attributes[:'webhook_config'] end end |
Instance Attribute Details
#id ⇒ Object
Unique identifier for the selected trigger as provided by the triggers API
35 36 37 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 35 def id @id end |
#mock_output ⇒ Object
Returns the value of attribute mock_output.
37 38 39 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 37 def mock_output @mock_output end |
#name ⇒ Object
Display name of the trigger
40 41 42 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 40 def name @name end |
#node_id ⇒ Object
Returns the value of attribute node_id.
42 43 44 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 42 def node_id @node_id end |
#outgoing_flow ⇒ Object
Reference to the ID of the flow node outbound from the trigger.
45 46 47 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 45 def outgoing_flow @outgoing_flow end |
#parameters ⇒ Object
Returns the value of attribute parameters.
47 48 49 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 47 def parameters @parameters end |
#position ⇒ Object
Returns the value of attribute position.
49 50 51 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 49 def position @position end |
#timer_event_definition ⇒ Object
Returns the value of attribute timer_event_definition.
51 52 53 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 51 def timer_event_definition @timer_event_definition end |
#trigger_type ⇒ Object
The type of trigger, signal, scheduled, on demand, etc
54 55 56 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 54 def trigger_type @trigger_type end |
#version_constraint ⇒ Object
Semantic version constraint of the trigger, it can be an explicit version or a version constraint. If unspecified the evaluator will use the latest version <= 1.0.0
57 58 59 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 57 def version_constraint @version_constraint end |
#webhook_config ⇒ Object
Returns the value of attribute webhook_config.
59 60 61 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 59 def webhook_config @webhook_config end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 62 def self.attribute_map { :'id' => :'id', :'mock_output' => :'mock_output', :'name' => :'name', :'node_id' => :'nodeID', :'outgoing_flow' => :'outgoing_flow', :'parameters' => :'parameters', :'position' => :'position', :'timer_event_definition' => :'timer_event_definition', :'trigger_type' => :'trigger_type', :'version_constraint' => :'version_constraint', :'webhook_config' => :'webhook_config' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 227 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 84 def self.openapi_types { :'id' => :'String', :'mock_output' => :'NodemocksReference', :'name' => :'String', :'node_id' => :'String', :'outgoing_flow' => :'String', :'parameters' => :'JsonschemaSchema', :'position' => :'GraphNodePosition', :'timer_event_definition' => :'GraphTimerEventDefinition', :'trigger_type' => :'String', :'version_constraint' => :'String', :'webhook_config' => :'GraphWebhookTriggerDefinition' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && mock_output == o.mock_output && name == o.name && node_id == o.node_id && outgoing_flow == o.outgoing_flow && parameters == o.parameters && position == o.position && timer_event_definition == o.timer_event_definition && trigger_type == o.trigger_type && version_constraint == o.version_constraint && webhook_config == o.webhook_config end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 258 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 329 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 234 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 220 def hash [id, mock_output, name, node_id, outgoing_flow, parameters, position, timer_event_definition, trigger_type, version_constraint, webhook_config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 168 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @node_id.nil? invalid_properties.push('invalid value for "node_id", node_id cannot be nil.') end if @outgoing_flow.nil? invalid_properties.push('invalid value for "outgoing_flow", outgoing_flow cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
305 306 307 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 305 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
299 300 301 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 299 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 |
# File 'lib/crimson-falcon/models/graph_configured_trigger.rb', line 187 def valid? return false if @name.nil? return false if @node_id.nil? return false if @outgoing_flow.nil? true end |