Class: Falcon::GraphValidationError

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/graph_validation_error.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GraphValidationError

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::GraphValidationError` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::GraphValidationError`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'node_id')
    self.node_id = attributes[:'node_id']
  end

  if attributes.key?(:'parent_node_id')
    self.parent_node_id = attributes[:'parent_node_id']
  end

  if attributes.key?(:'property')
    self.property = attributes[:'property']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'undefined_reference')
    self.undefined_reference = attributes[:'undefined_reference']
  end
end

Instance Attribute Details

#cidObject

The cid the validation error applies to if it is not the CID managing the workflow



35
36
37
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 35

def cid
  @cid
end

#codeObject

identifier for UI to indicate reason for node being invalid.



38
39
40
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 38

def code
  @code
end

#display_nameObject

Display name for the property if it exists in a trigger or activity



41
42
43
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 41

def display_name
  @display_name
end

#levelObject

Level is used to indicate if this is an error or warning validation. If empty it should be assumed to be Error Level



44
45
46
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 44

def level
  @level
end

#messageObject

Detail of why the node is invalid.



47
48
49
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 47

def message
  @message
end

#node_idObject

ID of the node in the graph that has been invalidated.



50
51
52
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 50

def node_id
  @node_id
end

#parent_node_idObject

ID of the parent node in the graph that resulted in a child node being invalidated.



53
54
55
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 53

def parent_node_id
  @parent_node_id
end

#propertyObject

Used to specify an exact property that is invalid for fql evaluation



56
57
58
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 56

def property
  @property
end

#resource_idObject

Resource ID for property if it exists, e.g. trigger ID or activity ID



59
60
61
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 59

def resource_id
  @resource_id
end

#undefined_referenceObject

Undefined Reference for property which is now undefined



62
63
64
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 62

def undefined_reference
  @undefined_reference
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 65

def self.attribute_map
  {
    :'cid' => :'cid',
    :'code' => :'code',
    :'display_name' => :'display_name',
    :'level' => :'level',
    :'message' => :'message',
    :'node_id' => :'node_id',
    :'parent_node_id' => :'parent_node_id',
    :'property' => :'property',
    :'resource_id' => :'resource_id',
    :'undefined_reference' => :'undefined_reference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 213

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 86

def self.openapi_types
  {
    :'cid' => :'String',
    :'code' => :'Integer',
    :'display_name' => :'String',
    :'level' => :'String',
    :'message' => :'String',
    :'node_id' => :'String',
    :'parent_node_id' => :'String',
    :'property' => :'String',
    :'resource_id' => :'String',
    :'undefined_reference' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      code == o.code &&
      display_name == o.display_name &&
      level == o.level &&
      message == o.message &&
      node_id == o.node_id &&
      parent_node_id == o.parent_node_id &&
      property == o.property &&
      resource_id == o.resource_id &&
      undefined_reference == o.undefined_reference
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 244

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 315

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 220

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 206

def hash
  [cid, code, display_name, level, message, node_id, parent_node_id, property, resource_id, undefined_reference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 291

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



285
286
287
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 285

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
# File 'lib/crimson-falcon/models/graph_validation_error.rb', line 176

def valid?
  return false if @message.nil?
  true
end