Class: Falcon::HostGroupsHostGroupV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/host_groups_host_group_v1.rb

Overview

A host group which targets a set of devices either through a dynamic assignment rule or a static set of hosts

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HostGroupsHostGroupV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::HostGroupsHostGroupV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::HostGroupsHostGroupV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'assignment_rule')
    self.assignment_rule = attributes[:'assignment_rule']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'group_type')
    self.group_type = attributes[:'group_type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'modified_timestamp')
    self.modified_timestamp = attributes[:'modified_timestamp']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#assignment_ruleObject

The assignment rule of a group



36
37
38
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 36

def assignment_rule
  @assignment_rule
end

#created_byObject

The email of the user which created the policy



39
40
41
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 39

def created_by
  @created_by
end

#created_timestampObject

The time at which the policy was created



42
43
44
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 42

def created_timestamp
  @created_timestamp
end

#descriptionObject

An additional description of the group or the devices it targets



45
46
47
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 45

def description
  @description
end

#group_typeObject

The method by which this host group is managed



48
49
50
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 48

def group_type
  @group_type
end

#idObject

The identifier of this host group



51
52
53
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 51

def id
  @id
end

#modified_byObject

The email of the user which last modified the policy



54
55
56
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 54

def modified_by
  @modified_by
end

#modified_timestampObject

The time at which the policy was last modified



57
58
59
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 57

def modified_timestamp
  @modified_timestamp
end

#nameObject

The name of the group



60
61
62
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 60

def name
  @name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 100

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 85

def self.attribute_map
  {
    :'assignment_rule' => :'assignment_rule',
    :'created_by' => :'created_by',
    :'created_timestamp' => :'created_timestamp',
    :'description' => :'description',
    :'group_type' => :'group_type',
    :'id' => :'id',
    :'modified_by' => :'modified_by',
    :'modified_timestamp' => :'modified_timestamp',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 268

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 105

def self.openapi_types
  {
    :'assignment_rule' => :'String',
    :'created_by' => :'String',
    :'created_timestamp' => :'Time',
    :'description' => :'String',
    :'group_type' => :'String',
    :'id' => :'String',
    :'modified_by' => :'String',
    :'modified_timestamp' => :'Time',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      assignment_rule == o.assignment_rule &&
      created_by == o.created_by &&
      created_timestamp == o.created_timestamp &&
      description == o.description &&
      group_type == o.group_type &&
      id == o.id &&
      modified_by == o.modified_by &&
      modified_timestamp == o.modified_timestamp &&
      name == o.name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 299

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 370

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 255

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



261
262
263
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 261

def hash
  [assignment_rule, created_by, created_timestamp, description, group_type, id, modified_by, modified_timestamp, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @modified_timestamp.nil?
    invalid_properties.push('invalid value for "modified_timestamp", modified_timestamp cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 346

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



340
341
342
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 340

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/crimson-falcon/models/host_groups_host_group_v1.rb', line 214

def valid?
  return false if @created_by.nil?
  return false if @created_timestamp.nil?
  return false if @description.nil?
  group_type_validator = EnumAttributeValidator.new('String', ["static", "dynamic", "staticByID"])
  return false unless group_type_validator.valid?(@group_type)
  return false if @id.nil?
  return false if @modified_by.nil?
  return false if @modified_timestamp.nil?
  return false if @name.nil?
  true
end