Class: Falcon::IdentityProtection

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/identity_protection.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ IdentityProtection

Returns a new instance of IdentityProtection.



35
36
37
# File 'lib/crimson-falcon/api/identity_protection.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/identity_protection.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#api_preempt_proxy_delete_policy_rules(ids, opts = {}) ⇒ nil

Delete policy rules

Parameters:

  • ids (Array<String>)

    Rule IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


42
43
44
45
# File 'lib/crimson-falcon/api/identity_protection.rb', line 42

def api_preempt_proxy_delete_policy_rules(ids, opts = {})
  api_preempt_proxy_delete_policy_rules_with_http_info(ids, opts)
  nil
end

#api_preempt_proxy_delete_policy_rules_with_http_info(ids, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete policy rules

Parameters:

  • ids (Array<String>)

    Rule IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/crimson-falcon/api/identity_protection.rb', line 51

def api_preempt_proxy_delete_policy_rules_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IdentityProtection.api_preempt_proxy_delete_policy_rules ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling IdentityProtection.api_preempt_proxy_delete_policy_rules"
  end
  if @api_client.config.client_side_validation && ids.length > 100
    fail ArgumentError, 'invalid value for "ids" when calling IdentityProtection.api_preempt_proxy_delete_policy_rules, number of items must be less than or equal to 100.'
  end

  if @api_client.config.client_side_validation && ids.length < 1
    fail ArgumentError, 'invalid value for "ids" when calling IdentityProtection.api_preempt_proxy_delete_policy_rules, number of items must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/identity-protection/entities/policy-rules/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/json; charset=utf-8'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"IdentityProtection.api_preempt_proxy_delete_policy_rules",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IdentityProtection#api_preempt_proxy_delete_policy_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_preempt_proxy_get_policy_rules(ids, opts = {}) ⇒ nil

Get policy rules

Parameters:

  • ids (Array<String>)

    Rule IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


112
113
114
115
# File 'lib/crimson-falcon/api/identity_protection.rb', line 112

def api_preempt_proxy_get_policy_rules(ids, opts = {})
  api_preempt_proxy_get_policy_rules_with_http_info(ids, opts)
  nil
end

#api_preempt_proxy_get_policy_rules_query(opts = {}) ⇒ nil

Query policy rule IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :enabled (Boolean)

    Whether the rule is enabled

  • :simulation_mode (Boolean)

    Whether the rule is in simulation mode

  • :name (String)

    Rule name

Returns:

  • (nil)


184
185
186
187
# File 'lib/crimson-falcon/api/identity_protection.rb', line 184

def api_preempt_proxy_get_policy_rules_query(opts = {})
  api_preempt_proxy_get_policy_rules_query_with_http_info(opts)
  nil
end

#api_preempt_proxy_get_policy_rules_query_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Query policy rule IDs

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :enabled (Boolean)

    Whether the rule is enabled

  • :simulation_mode (Boolean)

    Whether the rule is in simulation mode

  • :name (String)

    Rule name

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/crimson-falcon/api/identity_protection.rb', line 195

def api_preempt_proxy_get_policy_rules_query_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IdentityProtection.api_preempt_proxy_get_policy_rules_query ...'
  end
  # resource path
  local_var_path = '/identity-protection/queries/policy-rules/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'enabled'] = opts[:'enabled'] if !opts[:'enabled'].nil?
  query_params[:'simulation_mode'] = opts[:'simulation_mode'] if !opts[:'simulation_mode'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/json; charset=utf-8'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"IdentityProtection.api_preempt_proxy_get_policy_rules_query",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IdentityProtection#api_preempt_proxy_get_policy_rules_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_preempt_proxy_get_policy_rules_with_http_info(ids, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get policy rules

Parameters:

  • ids (Array<String>)

    Rule IDs

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/crimson-falcon/api/identity_protection.rb', line 121

def api_preempt_proxy_get_policy_rules_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IdentityProtection.api_preempt_proxy_get_policy_rules ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling IdentityProtection.api_preempt_proxy_get_policy_rules"
  end
  if @api_client.config.client_side_validation && ids.length > 100
    fail ArgumentError, 'invalid value for "ids" when calling IdentityProtection.api_preempt_proxy_get_policy_rules, number of items must be less than or equal to 100.'
  end

  if @api_client.config.client_side_validation && ids.length < 1
    fail ArgumentError, 'invalid value for "ids" when calling IdentityProtection.api_preempt_proxy_get_policy_rules, number of items must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/identity-protection/entities/policy-rules/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/json; charset=utf-8'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"IdentityProtection.api_preempt_proxy_get_policy_rules",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IdentityProtection#api_preempt_proxy_get_policy_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_preempt_proxy_post_graphql(body, opts = {}) ⇒ nil

Identity Protection GraphQL API. Allows to retrieve entities, timeline activities, identity-based incidents and security assessment. Allows to perform actions on entities and identity-based incidents.

Parameters:

Returns:

  • (nil)


246
247
248
249
# File 'lib/crimson-falcon/api/identity_protection.rb', line 246

def api_preempt_proxy_post_graphql(body, opts = {})
  api_preempt_proxy_post_graphql_with_http_info(body, opts)
  nil
end

#api_preempt_proxy_post_graphql_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Identity Protection GraphQL API. Allows to retrieve entities, timeline activities, identity-based incidents and security assessment. Allows to perform actions on entities and identity-based incidents.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/crimson-falcon/api/identity_protection.rb', line 255

def api_preempt_proxy_post_graphql_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IdentityProtection.api_preempt_proxy_post_graphql ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling IdentityProtection.api_preempt_proxy_post_graphql"
  end
  # resource path
  local_var_path = '/identity-protection/combined/graphql/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/json; charset=utf-8'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"IdentityProtection.api_preempt_proxy_post_graphql",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IdentityProtection#api_preempt_proxy_post_graphql\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#api_preempt_proxy_post_policy_rules(body, opts = {}) ⇒ nil

Create policy rule

Parameters:

Returns:

  • (nil)


312
313
314
315
# File 'lib/crimson-falcon/api/identity_protection.rb', line 312

def api_preempt_proxy_post_policy_rules(body, opts = {})
  api_preempt_proxy_post_policy_rules_with_http_info(body, opts)
  nil
end

#api_preempt_proxy_post_policy_rules_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Create policy rule

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/crimson-falcon/api/identity_protection.rb', line 321

def api_preempt_proxy_post_policy_rules_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IdentityProtection.api_preempt_proxy_post_policy_rules ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling IdentityProtection.api_preempt_proxy_post_policy_rules"
  end
  # resource path
  local_var_path = '/identity-protection/entities/policy-rules/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/json; charset=utf-8'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"IdentityProtection.api_preempt_proxy_post_policy_rules",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IdentityProtection#api_preempt_proxy_post_policy_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end