Class: Falcon::IncidentResponseEntityV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/incident_response_entity_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IncidentResponseEntityV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 164

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::IncidentResponseEntityV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::IncidentResponseEntityV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'activity_end')
    self.activity_end = attributes[:'activity_end']
  end

  if attributes.key?(:'activity_start')
    self.activity_start = attributes[:'activity_start']
  end

  if attributes.key?(:'caused_by_incidents')
    if (value = attributes[:'caused_by_incidents']).is_a?(Array)
      self.caused_by_incidents = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'involves_adversaries')
    if (value = attributes[:'involves_adversaries']).is_a?(Array)
      self.involves_adversaries = value
    end
  end

  if attributes.key?(:'involves_threats')
    if (value = attributes[:'involves_threats']).is_a?(Array)
      self.involves_threats = value
    end
  end

  if attributes.key?(:'last_modified_at')
    self.last_modified_at = attributes[:'last_modified_at']
  end

  if attributes.key?(:'mitre_attack')
    if (value = attributes[:'mitre_attack']).is_a?(Array)
      self.mitre_attack = value
    end
  end

  if attributes.key?(:'motivations')
    if (value = attributes[:'motivations']).is_a?(Array)
      self.motivations = value
    end
  end

  if attributes.key?(:'objectives')
    if (value = attributes[:'objectives']).is_a?(Array)
      self.objectives = value
    end
  end

  if attributes.key?(:'publish_date')
    self.publish_date = attributes[:'publish_date']
  end

  if attributes.key?(:'reduced_time_stamp_granularity')
    self.reduced_time_stamp_granularity = attributes[:'reduced_time_stamp_granularity']
  end

  if attributes.key?(:'referenced_by_reports')
    if (value = attributes[:'referenced_by_reports']).is_a?(Array)
      self.referenced_by_reports = value
    end
  end

  if attributes.key?(:'references_notable_events')
    if (value = attributes[:'references_notable_events']).is_a?(Array)
      self.references_notable_events = value
    end
  end

  if attributes.key?(:'target_countries')
    if (value = attributes[:'target_countries']).is_a?(Array)
      self.target_countries = value
    end
  end

  if attributes.key?(:'target_industries')
    if (value = attributes[:'target_industries']).is_a?(Array)
      self.target_industries = value
    end
  end

  if attributes.key?(:'target_regions')
    if (value = attributes[:'target_regions']).is_a?(Array)
      self.target_regions = value
    end
  end

  if attributes.key?(:'targeting_profile')
    if (value = attributes[:'targeting_profile']).is_a?(Array)
      self.targeting_profile = value
    end
  end

  if attributes.key?(:'targets_vulnerabilities')
    if (value = attributes[:'targets_vulnerabilities']).is_a?(Array)
      self.targets_vulnerabilities = value
    end
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#activity_endObject

Unix timestamp (seconds) of the most recent event considered part of this incident’s activity. Granularity may be reduced; see ReducedTimeStampGranularity



35
36
37
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 35

def activity_end
  @activity_end
end

#activity_startObject

Unix timestamp (seconds) of the first event considered part of this incident’s activity. Granularity may be reduced; see ReducedTimeStampGranularity



38
39
40
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 38

def activity_start
  @activity_start
end

#caused_by_incidentsObject

Other incidents that are considered causes of this incident



41
42
43
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 41

def caused_by_incidents
  @caused_by_incidents
end

#created_atObject

Unix timestamp (seconds) when this incident record was created



44
45
46
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 44

def created_at
  @created_at
end

#idObject

Unique identifier of the incident



47
48
49
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 47

def id
  @id
end

#involves_adversariesObject

Adversaries attributed to or associated with this incident



50
51
52
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 50

def involves_adversaries
  @involves_adversaries
end

#involves_threatsObject

Malware families involved in this incident



53
54
55
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 53

def involves_threats
  @involves_threats
end

#last_modified_atObject

Unix timestamp (seconds) when this incident record was last modified



56
57
58
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 56

def last_modified_at
  @last_modified_at
end

#mitre_attackObject

MITRE ATT&CK tactics and techniques observed in this incident



59
60
61
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 59

def mitre_attack
  @mitre_attack
end

#motivationsObject

Adversary motivations associated with this incident (e.g. Criminal, State-Sponsored)



62
63
64
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 62

def motivations
  @motivations
end

#objectivesObject

Adversary objectives associated with this incident (e.g. Intelligence Gathering, Financial Crime)



65
66
67
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 65

def objectives
  @objectives
end

#publish_dateObject

Unix timestamp (seconds) when the incident was published



68
69
70
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 68

def publish_date
  @publish_date
end

#reduced_time_stamp_granularityObject

Granularity to which ActivityStart and ActivityEnd have been rounded. Possible values: Hour, Day, Week, Month, Quarter, Year



71
72
73
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 71

def reduced_time_stamp_granularity
  @reduced_time_stamp_granularity
end

#referenced_by_reportsObject

Intel reports that reference this incident



74
75
76
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 74

def referenced_by_reports
  @referenced_by_reports
end

#references_notable_eventsObject

Notable events referenced by this incident



77
78
79
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 77

def references_notable_events
  @references_notable_events
end

#target_countriesObject

Countries targeted by this incident



80
81
82
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 80

def target_countries
  @target_countries
end

#target_industriesObject

Industry verticals targeted by this incident



83
84
85
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 83

def target_industries
  @target_industries
end

#target_regionsObject

Geographic regions targeted by this incident



86
87
88
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 86

def target_regions
  @target_regions
end

#targeting_profileObject

Targeting profile of the incident. Possible values: Targeted, NonTargeted



89
90
91
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 89

def targeting_profile
  @targeting_profile
end

#targets_vulnerabilitiesObject

CVEs exploited during this incident



92
93
94
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 92

def targets_vulnerabilities
  @targets_vulnerabilities
end

#titleObject

Human-readable title describing the incident



95
96
97
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 95

def title
  @title
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 125

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 98

def self.attribute_map
  {
    :'activity_end' => :'ActivityEnd',
    :'activity_start' => :'ActivityStart',
    :'caused_by_incidents' => :'CausedByIncidents',
    :'created_at' => :'CreatedAt',
    :'id' => :'Id',
    :'involves_adversaries' => :'InvolvesAdversaries',
    :'involves_threats' => :'InvolvesThreats',
    :'last_modified_at' => :'LastModifiedAt',
    :'mitre_attack' => :'MitreAttack',
    :'motivations' => :'Motivations',
    :'objectives' => :'Objectives',
    :'publish_date' => :'PublishDate',
    :'reduced_time_stamp_granularity' => :'ReducedTimeStampGranularity',
    :'referenced_by_reports' => :'ReferencedByReports',
    :'references_notable_events' => :'ReferencesNotableEvents',
    :'target_countries' => :'TargetCountries',
    :'target_industries' => :'TargetIndustries',
    :'target_regions' => :'TargetRegions',
    :'targeting_profile' => :'TargetingProfile',
    :'targets_vulnerabilities' => :'TargetsVulnerabilities',
    :'title' => :'Title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



449
450
451
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 449

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



157
158
159
160
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 157

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 130

def self.openapi_types
  {
    :'activity_end' => :'Integer',
    :'activity_start' => :'Integer',
    :'caused_by_incidents' => :'Array<IncidentIncidentRef>',
    :'created_at' => :'Integer',
    :'id' => :'String',
    :'involves_adversaries' => :'Array<IncidentAdversaryRefV1>',
    :'involves_threats' => :'Array<IncidentMalwareRef>',
    :'last_modified_at' => :'Integer',
    :'mitre_attack' => :'Array<IncidentMitreAttackRef>',
    :'motivations' => :'Array<IncidentEnumRef>',
    :'objectives' => :'Array<IncidentEnumRef>',
    :'publish_date' => :'Integer',
    :'reduced_time_stamp_granularity' => :'String',
    :'referenced_by_reports' => :'Array<IncidentReportRef>',
    :'references_notable_events' => :'Array<IncidentNotableEventRef>',
    :'target_countries' => :'Array<IncidentEnumRef>',
    :'target_industries' => :'Array<IncidentEnumRef>',
    :'target_regions' => :'Array<IncidentEnumRef>',
    :'targeting_profile' => :'Array<IncidentEnumRef>',
    :'targets_vulnerabilities' => :'Array<IncidentVulnerabilityRef>',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 408

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      activity_end == o.activity_end &&
      activity_start == o.activity_start &&
      caused_by_incidents == o.caused_by_incidents &&
      created_at == o.created_at &&
      id == o.id &&
      involves_adversaries == o.involves_adversaries &&
      involves_threats == o.involves_threats &&
      last_modified_at == o.last_modified_at &&
      mitre_attack == o.mitre_attack &&
      motivations == o.motivations &&
      objectives == o.objectives &&
      publish_date == o.publish_date &&
      reduced_time_stamp_granularity == o.reduced_time_stamp_granularity &&
      referenced_by_reports == o.referenced_by_reports &&
      references_notable_events == o.references_notable_events &&
      target_countries == o.target_countries &&
      target_industries == o.target_industries &&
      target_regions == o.target_regions &&
      targeting_profile == o.targeting_profile &&
      targets_vulnerabilities == o.targets_vulnerabilities &&
      title == o.title
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 480

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 551

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 456

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


436
437
438
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 436

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



442
443
444
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 442

def hash
  [activity_end, activity_start, caused_by_incidents, created_at, id, involves_adversaries, involves_threats, last_modified_at, mitre_attack, motivations, objectives, publish_date, reduced_time_stamp_granularity, referenced_by_reports, references_notable_events, target_countries, target_industries, target_regions, targeting_profile, targets_vulnerabilities, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 290

def list_invalid_properties
  invalid_properties = Array.new
  if @activity_end.nil?
    invalid_properties.push('invalid value for "activity_end", activity_end cannot be nil.')
  end

  if @activity_start.nil?
    invalid_properties.push('invalid value for "activity_start", activity_start cannot be nil.')
  end

  if @caused_by_incidents.nil?
    invalid_properties.push('invalid value for "caused_by_incidents", caused_by_incidents cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @involves_adversaries.nil?
    invalid_properties.push('invalid value for "involves_adversaries", involves_adversaries cannot be nil.')
  end

  if @involves_threats.nil?
    invalid_properties.push('invalid value for "involves_threats", involves_threats cannot be nil.')
  end

  if @last_modified_at.nil?
    invalid_properties.push('invalid value for "last_modified_at", last_modified_at cannot be nil.')
  end

  if @mitre_attack.nil?
    invalid_properties.push('invalid value for "mitre_attack", mitre_attack cannot be nil.')
  end

  if @motivations.nil?
    invalid_properties.push('invalid value for "motivations", motivations cannot be nil.')
  end

  if @objectives.nil?
    invalid_properties.push('invalid value for "objectives", objectives cannot be nil.')
  end

  if @publish_date.nil?
    invalid_properties.push('invalid value for "publish_date", publish_date cannot be nil.')
  end

  if @reduced_time_stamp_granularity.nil?
    invalid_properties.push('invalid value for "reduced_time_stamp_granularity", reduced_time_stamp_granularity cannot be nil.')
  end

  if @referenced_by_reports.nil?
    invalid_properties.push('invalid value for "referenced_by_reports", referenced_by_reports cannot be nil.')
  end

  if @references_notable_events.nil?
    invalid_properties.push('invalid value for "references_notable_events", references_notable_events cannot be nil.')
  end

  if @target_countries.nil?
    invalid_properties.push('invalid value for "target_countries", target_countries cannot be nil.')
  end

  if @target_industries.nil?
    invalid_properties.push('invalid value for "target_industries", target_industries cannot be nil.')
  end

  if @target_regions.nil?
    invalid_properties.push('invalid value for "target_regions", target_regions cannot be nil.')
  end

  if @targeting_profile.nil?
    invalid_properties.push('invalid value for "targeting_profile", targeting_profile cannot be nil.')
  end

  if @targets_vulnerabilities.nil?
    invalid_properties.push('invalid value for "targets_vulnerabilities", targets_vulnerabilities cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



527
528
529
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 527

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 533

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



521
522
523
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 521

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/crimson-falcon/models/incident_response_entity_v1.rb', line 381

def valid?
  return false if @activity_end.nil?
  return false if @activity_start.nil?
  return false if @caused_by_incidents.nil?
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @involves_adversaries.nil?
  return false if @involves_threats.nil?
  return false if @last_modified_at.nil?
  return false if @mitre_attack.nil?
  return false if @motivations.nil?
  return false if @objectives.nil?
  return false if @publish_date.nil?
  return false if @reduced_time_stamp_granularity.nil?
  return false if @referenced_by_reports.nil?
  return false if @references_notable_events.nil?
  return false if @target_countries.nil?
  return false if @target_industries.nil?
  return false if @target_regions.nil?
  return false if @targeting_profile.nil?
  return false if @targets_vulnerabilities.nil?
  return false if @title.nil?
  true
end