Class: Falcon::IoaEventAggregate

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/ioa_event_aggregate.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IoaEventAggregate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::IoaEventAggregate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::IoaEventAggregate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid_severity')
    self.cid_severity = attributes[:'cid_severity']
  end

  if attributes.key?(:'confidence')
    self.confidence = attributes[:'confidence']
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.key?(:'first_timestamp')
    self.first_timestamp = attributes[:'first_timestamp']
  end

  if attributes.key?(:'join_keys')
    if (value = attributes[:'join_keys']).is_a?(Array)
      self.join_keys = value
    end
  end

  if attributes.key?(:'last_timestamp')
    self.last_timestamp = attributes[:'last_timestamp']
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'threatintel')
    self.threatintel = attributes[:'threatintel']
  end

  if attributes.key?(:'timestamps')
    if (value = attributes[:'timestamps']).is_a?(Array)
      self.timestamps = value
    end
  end
end

Instance Attribute Details

#cid_severityObject

Returns the value of attribute cid_severity.



34
35
36
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 34

def cid_severity
  @cid_severity
end

#confidenceObject

Returns the value of attribute confidence.



36
37
38
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 36

def confidence
  @confidence
end

#countObject

Returns the value of attribute count.



38
39
40
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 38

def count
  @count
end

#eventsObject

Returns the value of attribute events.



40
41
42
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 40

def events
  @events
end

#first_timestampObject

Returns the value of attribute first_timestamp.



42
43
44
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 42

def first_timestamp
  @first_timestamp
end

#join_keysObject

Returns the value of attribute join_keys.



44
45
46
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 44

def join_keys
  @join_keys
end

#last_timestampObject

Returns the value of attribute last_timestamp.



46
47
48
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 46

def last_timestamp
  @last_timestamp
end

#resourceObject

Returns the value of attribute resource.



48
49
50
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 48

def resource
  @resource
end

#scoreObject

Returns the value of attribute score.



50
51
52
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 50

def score
  @score
end

#threatintelObject

Returns the value of attribute threatintel.



52
53
54
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 52

def threatintel
  @threatintel
end

#timestampsObject

Returns the value of attribute timestamps.



54
55
56
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 54

def timestamps
  @timestamps
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 57

def self.attribute_map
  {
    :'cid_severity' => :'cid_severity',
    :'confidence' => :'confidence',
    :'count' => :'count',
    :'events' => :'events',
    :'first_timestamp' => :'first_timestamp',
    :'join_keys' => :'join_keys',
    :'last_timestamp' => :'last_timestamp',
    :'resource' => :'resource',
    :'score' => :'score',
    :'threatintel' => :'threatintel',
    :'timestamps' => :'timestamps'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 218

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 79

def self.openapi_types
  {
    :'cid_severity' => :'Integer',
    :'confidence' => :'Integer',
    :'count' => :'Integer',
    :'events' => :'Array<String>',
    :'first_timestamp' => :'String',
    :'join_keys' => :'Array<String>',
    :'last_timestamp' => :'String',
    :'resource' => :'Resource',
    :'score' => :'Integer',
    :'threatintel' => :'DetectionAggregateThreatIntel',
    :'timestamps' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid_severity == o.cid_severity &&
      confidence == o.confidence &&
      count == o.count &&
      events == o.events &&
      first_timestamp == o.first_timestamp &&
      join_keys == o.join_keys &&
      last_timestamp == o.last_timestamp &&
      resource == o.resource &&
      score == o.score &&
      threatintel == o.threatintel &&
      timestamps == o.timestamps
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 249

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 320

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 211

def hash
  [cid_severity, confidence, count, events, first_timestamp, join_keys, last_timestamp, resource, score, threatintel, timestamps].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  if @resource.nil?
    invalid_properties.push('invalid value for "resource", resource cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 296

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



290
291
292
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 290

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
# File 'lib/crimson-falcon/models/ioa_event_aggregate.rb', line 180

def valid?
  return false if @resource.nil?
  true
end