Class: Falcon::ItautomationPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_policy.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationPolicy`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'host_groups')
    if (value = attributes[:'host_groups']).is_a?(Array)
      self.host_groups = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.key?(:'modified_at')
    self.modified_at = attributes[:'modified_at']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'precedence')
    self.precedence = attributes[:'precedence']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end
end

Instance Attribute Details

#configObject

Returns the value of attribute config.



34
35
36
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 34

def config
  @config
end

#created_atObject

Timestamp when the policy was created. Example: 2025-01-23T18:49:26.785778Z



37
38
39
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 37

def created_at
  @created_at
end

#created_byObject

User who created the policy. Example: john.smith@crowdstrike.com



40
41
42
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 40

def created_by
  @created_by
end

#descriptionObject

Description of the policy. Example: windows policy check



43
44
45
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 43

def description
  @description
end

#host_groupsObject

List of host groups associated with this policy.Example: ‘g53b95555ef54ea682419ce990d267cc’



46
47
48
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 46

def host_groups
  @host_groups
end

#idObject

ID of the policy. Example: f64b95555ef54ea682619ce880d267cc



49
50
51
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 49

def id
  @id
end

#is_enabledObject

Whether the policy is enabled or disabled



52
53
54
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 52

def is_enabled
  @is_enabled
end

#modified_atObject

Timestamp when the policy was last modified. Example: 2025-01-23T18:49:26.785778Z



55
56
57
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 55

def modified_at
  @modified_at
end

#modified_byObject

User who last modified the policy. Example: john.smith@crowdstrike.com



58
59
60
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 58

def modified_by
  @modified_by
end

#nameObject

The name of the policy. Example: platform_policy



61
62
63
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 61

def name
  @name
end

#precedenceObject

Priority level of the policy



64
65
66
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 64

def precedence
  @precedence
end

#targetObject

The platform for the policy



67
68
69
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 67

def target
  @target
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 92

def self.attribute_map
  {
    :'config' => :'config',
    :'created_at' => :'created_at',
    :'created_by' => :'created_by',
    :'description' => :'description',
    :'host_groups' => :'host_groups',
    :'id' => :'id',
    :'is_enabled' => :'is_enabled',
    :'modified_at' => :'modified_at',
    :'modified_by' => :'modified_by',
    :'name' => :'name',
    :'precedence' => :'precedence',
    :'target' => :'target'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 303

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 115

def self.openapi_types
  {
    :'config' => :'ItautomationPolicyConfig',
    :'created_at' => :'String',
    :'created_by' => :'String',
    :'description' => :'String',
    :'host_groups' => :'Array<String>',
    :'id' => :'String',
    :'is_enabled' => :'Boolean',
    :'modified_at' => :'String',
    :'modified_by' => :'String',
    :'name' => :'String',
    :'precedence' => :'Integer',
    :'target' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 271

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      config == o.config &&
      created_at == o.created_at &&
      created_by == o.created_by &&
      description == o.description &&
      host_groups == o.host_groups &&
      id == o.id &&
      is_enabled == o.is_enabled &&
      modified_at == o.modified_at &&
      modified_by == o.modified_by &&
      name == o.name &&
      precedence == o.precedence &&
      target == o.target
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 334

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 405

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 310

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


290
291
292
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 290

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



296
297
298
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 296

def hash
  [config, created_at, created_by, description, host_groups, id, is_enabled, modified_at, modified_by, name, precedence, target].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 206

def list_invalid_properties
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @modified_at.nil?
    invalid_properties.push('invalid value for "modified_at", modified_at cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 381

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 387

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



375
376
377
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 375

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/crimson-falcon/models/itautomation_policy.rb', line 245

def valid?
  return false if @created_at.nil?
  return false if @created_by.nil?
  return false if @description.nil?
  return false if @id.nil?
  return false if @modified_at.nil?
  return false if @modified_by.nil?
  return false if @name.nil?
  return false if @target.nil?
  target_validator = EnumAttributeValidator.new('String', ["Windows", "Linux", "Mac"])
  return false unless target_validator.valid?(@target)
  true
end