Class: Falcon::ItautomationScript

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_script.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationScript

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationScript` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationScript`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action_type')
    self.action_type = attributes[:'action_type']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'file_ids')
    if (value = attributes[:'file_ids']).is_a?(Array)
      self.file_ids = value
    end
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'script_args')
    self.script_args = attributes[:'script_args']
  end

  if attributes.key?(:'script_file_id')
    self.script_file_id = attributes[:'script_file_id']
  end
end

Instance Attribute Details

#action_typeObject

The type of action to perform



35
36
37
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 35

def action_type
  @action_type
end

#contentObject

The script content to execute. Example: echo ‘Hello, World!’



38
39
40
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 38

def content
  @content
end

#file_idsObject

The list of file IDs to execute. Example: [‘f64b95555ef54ea682619ce880d267cc’, ‘a1b2c3d4e5f6g7h8i9j0k1l2m3n4o5p6’]



41
42
43
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 41

def file_ids
  @file_ids
end

#languageObject

The scripting language to use



44
45
46
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 44

def language
  @language
end

#script_argsObject

The arguments to execute the script file with.



47
48
49
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 47

def script_args
  @script_args
end

#script_file_idObject

The file ID of the script file to execute. Example: f64b95555ef54ea682619ce880d267cc



50
51
52
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 50

def script_file_id
  @script_file_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 75

def self.attribute_map
  {
    :'action_type' => :'action_type',
    :'content' => :'content',
    :'file_ids' => :'file_ids',
    :'language' => :'language',
    :'script_args' => :'script_args',
    :'script_file_id' => :'script_file_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 216

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 92

def self.openapi_types
  {
    :'action_type' => :'String',
    :'content' => :'String',
    :'file_ids' => :'Array<String>',
    :'language' => :'String',
    :'script_args' => :'String',
    :'script_file_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action_type == o.action_type &&
      content == o.content &&
      file_ids == o.file_ids &&
      language == o.language &&
      script_args == o.script_args &&
      script_file_id == o.script_file_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 247

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 318

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 209

def hash
  [action_type, content, file_ids, language, script_args, script_file_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 153

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 294

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 288

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
# File 'lib/crimson-falcon/models/itautomation_script.rb', line 160

def valid?
  action_type_validator = EnumAttributeValidator.new('String', ["script", "command", "script_file"])
  return false unless action_type_validator.valid?(@action_type)
  language_validator = EnumAttributeValidator.new('String', ["bash", "zsh", "powershell", "python"])
  return false unless language_validator.valid?(@language)
  true
end