Class: Falcon::ItautomationStartTaskExecutionRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_start_task_execution_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationStartTaskExecutionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationStartTaskExecutionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationStartTaskExecutionRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'discover_new_hosts')
    self.discover_new_hosts = attributes[:'discover_new_hosts']
  end

  if attributes.key?(:'discover_offline_hosts')
    self.discover_offline_hosts = attributes[:'discover_offline_hosts']
  end

  if attributes.key?(:'distribute')
    self.distribute = attributes[:'distribute']
  end

  if attributes.key?(:'execution_args')
    if (value = attributes[:'execution_args']).is_a?(Hash)
      self.execution_args = value
    end
  end

  if attributes.key?(:'expiration_interval')
    self.expiration_interval = attributes[:'expiration_interval']
  end

  if attributes.key?(:'guardrails')
    self.guardrails = attributes[:'guardrails']
  end

  if attributes.key?(:'scheduled_task_id')
    self.scheduled_task_id = attributes[:'scheduled_task_id']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  end

  if attributes.key?(:'trigger_condition')
    if (value = attributes[:'trigger_condition']).is_a?(Array)
      self.trigger_condition = value
    end
  end
end

Instance Attribute Details

#discover_new_hostsObject

Whether to discover new hosts for the scheduled task. Example: true



35
36
37
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 35

def discover_new_hosts
  @discover_new_hosts
end

#discover_offline_hostsObject

Whether to discover offline hosts for the scheduled task. Example: true



38
39
40
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 38

def discover_offline_hosts
  @discover_offline_hosts
end

#distributeObject

Whether to distribute the scheduled task. Example: true



41
42
43
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 41

def distribute
  @distribute
end

#execution_argsObject

Key-value pairs of argument values to pass to the execution. Example: ‘abc123’, ‘region’: ‘us-east-1’



44
45
46
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 44

def execution_args
  @execution_args
end

#expiration_intervalObject

Duration for which the task stays active. Once expired, new and offline hosts won’t be targeted. Example: 1m



47
48
49
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 47

def expiration_interval
  @expiration_interval
end

#guardrailsObject

Returns the value of attribute guardrails.



49
50
51
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 49

def guardrails
  @guardrails
end

#scheduled_task_idObject

Unique identifier of existing scheduled task. Scheduled task fields override all other request fields. Example: f64b95555ef54ea682619ce880d267cc



52
53
54
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 52

def scheduled_task_id
  @scheduled_task_id
end

#targetObject

Target filter in FQL format. Example: platform_name: ‘Windows’



55
56
57
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 55

def target
  @target
end

#task_idObject

Unique identifier of existing saved task. Example: f64b95555ef54ea682619ce880d267cc



58
59
60
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 58

def task_id
  @task_id
end

#trigger_conditionObject

Conditions that trigger remediation scripts execution



61
62
63
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 61

def trigger_condition
  @trigger_condition
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 64

def self.attribute_map
  {
    :'discover_new_hosts' => :'discover_new_hosts',
    :'discover_offline_hosts' => :'discover_offline_hosts',
    :'distribute' => :'distribute',
    :'execution_args' => :'execution_args',
    :'expiration_interval' => :'expiration_interval',
    :'guardrails' => :'guardrails',
    :'scheduled_task_id' => :'scheduled_task_id',
    :'target' => :'target',
    :'task_id' => :'task_id',
    :'trigger_condition' => :'trigger_condition'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 211

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 85

def self.openapi_types
  {
    :'discover_new_hosts' => :'Boolean',
    :'discover_offline_hosts' => :'Boolean',
    :'distribute' => :'Boolean',
    :'execution_args' => :'Hash<String, String>',
    :'expiration_interval' => :'String',
    :'guardrails' => :'FalconforitapiGuardrails',
    :'scheduled_task_id' => :'String',
    :'target' => :'String',
    :'task_id' => :'String',
    :'trigger_condition' => :'Array<FalconforitapiConditionGroup>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      discover_new_hosts == o.discover_new_hosts &&
      discover_offline_hosts == o.discover_offline_hosts &&
      distribute == o.distribute &&
      execution_args == o.execution_args &&
      expiration_interval == o.expiration_interval &&
      guardrails == o.guardrails &&
      scheduled_task_id == o.scheduled_task_id &&
      target == o.target &&
      task_id == o.task_id &&
      trigger_condition == o.trigger_condition
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 242

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 313

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 218

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 204

def hash
  [discover_new_hosts, discover_offline_hosts, distribute, execution_args, expiration_interval, guardrails, scheduled_task_id, target, task_id, trigger_condition].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 168

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 289

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



283
284
285
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 283

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
# File 'lib/crimson-falcon/models/itautomation_start_task_execution_request.rb', line 175

def valid?
  true
end