Class: Falcon::ItautomationTaskParameter

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_task_parameter.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationTaskParameter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 136

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationTaskParameter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationTaskParameter`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'custom_validation_message')
    self.custom_validation_message = attributes[:'custom_validation_message']
  end

  if attributes.key?(:'custom_validation_regex')
    self.custom_validation_regex = attributes[:'custom_validation_regex']
  end

  if attributes.key?(:'default_value')
    self.default_value = attributes[:'default_value']
  end

  if attributes.key?(:'format_hint')
    self.format_hint = attributes[:'format_hint']
  end

  if attributes.key?(:'input_type')
    self.input_type = attributes[:'input_type']
  end

  if attributes.key?(:'is_optional')
    self.is_optional = attributes[:'is_optional']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'options')
    if (value = attributes[:'options']).is_a?(Array)
      self.options = value
    end
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  end

  if attributes.key?(:'validation_type')
    self.validation_type = attributes[:'validation_type']
  end
end

Instance Attribute Details

#custom_validation_messageObject

Message to show on failure of custom validation regex. Example: API Key must be 32 alphanumeric characters



35
36
37
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 35

def custom_validation_message
  @custom_validation_message
end

#custom_validation_regexObject

Custom regex pattern to apply when input_type is text. Example: ^[A-Za-z0-9]32$



38
39
40
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 38

def custom_validation_regex
  @custom_validation_regex
end

#default_valueObject

Default value for the parameter. Example: default-api-key



41
42
43
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 41

def default_value
  @default_value
end

#format_hintObject

Format hint to help users enter valid input. Maximum 150 characters. Example: 32-character alphanumeric string



44
45
46
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 44

def format_hint
  @format_hint
end

#input_typeObject

Type of input field



47
48
49
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 47

def input_type
  @input_type
end

#is_optionalObject

Whether the parameter is optional. Example: true



50
51
52
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 50

def is_optional
  @is_optional
end

#keyObject

Unique identifier for the parameter, corresponds to placeholder used in task content. Example: api_key



53
54
55
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 53

def key
  @key
end

#labelObject

Human readable label for the parameter. Example: API Key



56
57
58
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 56

def label
  @label
end

#optionsObject

Available options for option inputs. Used only if input_type is option.



59
60
61
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 59

def options
  @options
end

#purposeObject

Purpose or usage description for UI display. Maximum 200 characters. Example: Enter your API key for authentication



62
63
64
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 62

def purpose
  @purpose
end

#validation_typeObject

Type of validation to apply when input_type is text



65
66
67
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 65

def validation_type
  @validation_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 107

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 90

def self.attribute_map
  {
    :'custom_validation_message' => :'custom_validation_message',
    :'custom_validation_regex' => :'custom_validation_regex',
    :'default_value' => :'default_value',
    :'format_hint' => :'format_hint',
    :'input_type' => :'input_type',
    :'is_optional' => :'is_optional',
    :'key' => :'key',
    :'label' => :'label',
    :'options' => :'options',
    :'purpose' => :'purpose',
    :'validation_type' => :'validation_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 306

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



129
130
131
132
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 129

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 112

def self.openapi_types
  {
    :'custom_validation_message' => :'String',
    :'custom_validation_regex' => :'String',
    :'default_value' => :'String',
    :'format_hint' => :'String',
    :'input_type' => :'String',
    :'is_optional' => :'Boolean',
    :'key' => :'String',
    :'label' => :'String',
    :'options' => :'Array<ItautomationParameterOption>',
    :'purpose' => :'String',
    :'validation_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 275

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      custom_validation_message == o.custom_validation_message &&
      custom_validation_regex == o.custom_validation_regex &&
      default_value == o.default_value &&
      format_hint == o.format_hint &&
      input_type == o.input_type &&
      is_optional == o.is_optional &&
      key == o.key &&
      label == o.label &&
      options == o.options &&
      purpose == o.purpose &&
      validation_type == o.validation_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 337

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 408

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 313

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


293
294
295
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 293

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



299
300
301
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 299

def hash
  [custom_validation_message, custom_validation_regex, default_value, format_hint, input_type, is_optional, key, label, options, purpose, validation_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 198

def list_invalid_properties
  invalid_properties = Array.new
  if @custom_validation_message.nil?
    invalid_properties.push('invalid value for "custom_validation_message", custom_validation_message cannot be nil.')
  end

  if @custom_validation_regex.nil?
    invalid_properties.push('invalid value for "custom_validation_regex", custom_validation_regex cannot be nil.')
  end

  if @default_value.nil?
    invalid_properties.push('invalid value for "default_value", default_value cannot be nil.')
  end

  if @input_type.nil?
    invalid_properties.push('invalid value for "input_type", input_type cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @options.nil?
    invalid_properties.push('invalid value for "options", options cannot be nil.')
  end

  if @validation_type.nil?
    invalid_properties.push('invalid value for "validation_type", validation_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 384

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



378
379
380
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 378

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/crimson-falcon/models/itautomation_task_parameter.rb', line 237

def valid?
  return false if @custom_validation_message.nil?
  return false if @custom_validation_regex.nil?
  return false if @default_value.nil?
  return false if @input_type.nil?
  input_type_validator = EnumAttributeValidator.new('String', ["text", "option"])
  return false unless input_type_validator.valid?(@input_type)
  return false if @key.nil?
  return false if @label.nil?
  return false if @options.nil?
  return false if @validation_type.nil?
  validation_type_validator = EnumAttributeValidator.new('String', ["text", "alphanumeric", "integer", "float", "ip", "filepath", "filepathwin", "filepathunix", "datetime", "semver", "macaddress", "uuid", "port", "winhost", "dnshost"])
  return false unless validation_type_validator.valid?(@validation_type)
  true
end