Class: Falcon::ItautomationTaskStageExecutionStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationTaskStageExecutionStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationTaskStageExecutionStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationTaskStageExecutionStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'completion_percentage')
    self.completion_percentage = attributes[:'completion_percentage']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'query_stage_stats')
    self.query_stage_stats = attributes[:'query_stage_stats']
  end

  if attributes.key?(:'remediation_stage_stats')
    self.remediation_stage_stats = attributes[:'remediation_stage_stats']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'total_host_count')
    self.total_host_count = attributes[:'total_host_count']
  end

  if attributes.key?(:'total_results')
    self.total_results = attributes[:'total_results']
  end

  if attributes.key?(:'verification_stage_stats')
    self.verification_stage_stats = attributes[:'verification_stage_stats']
  end

  if attributes.key?(:'verification_summary')
    self.verification_summary = attributes[:'verification_summary']
  end
end

Instance Attribute Details

#completion_percentageObject

Percentage of task execution completion. Example: 75.5



35
36
37
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 35

def completion_percentage
  @completion_percentage
end

#end_timeObject

Timestamp when execution completed. Example: 2025-01-23T18:49:26.785778Z



38
39
40
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 38

def end_time
  @end_time
end

#query_stage_statsObject

Returns the value of attribute query_stage_stats.



40
41
42
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 40

def query_stage_stats
  @query_stage_stats
end

#remediation_stage_statsObject

Returns the value of attribute remediation_stage_stats.



42
43
44
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 42

def remediation_stage_stats
  @remediation_stage_stats
end

#start_timeObject

Timestamp when execution started. Example: 2025-01-23T18:11:20.148439Z



45
46
47
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 45

def start_time
  @start_time
end

#statusObject

Current status of the task execution. Example: Running



48
49
50
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 48

def status
  @status
end

#total_host_countObject

Total number of hosts targeted by this execution



51
52
53
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 51

def total_host_count
  @total_host_count
end

#total_resultsObject

Total number of results across all hosts



54
55
56
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 54

def total_results
  @total_results
end

#verification_stage_statsObject

Returns the value of attribute verification_stage_stats.



56
57
58
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 56

def verification_stage_stats
  @verification_stage_stats
end

#verification_summaryObject

Returns the value of attribute verification_summary.



58
59
60
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 58

def verification_summary
  @verification_summary
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 61

def self.attribute_map
  {
    :'completion_percentage' => :'completion_percentage',
    :'end_time' => :'end_time',
    :'query_stage_stats' => :'query_stage_stats',
    :'remediation_stage_stats' => :'remediation_stage_stats',
    :'start_time' => :'start_time',
    :'status' => :'status',
    :'total_host_count' => :'total_host_count',
    :'total_results' => :'total_results',
    :'verification_stage_stats' => :'verification_stage_stats',
    :'verification_summary' => :'verification_summary'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 82

def self.openapi_types
  {
    :'completion_percentage' => :'Float',
    :'end_time' => :'Time',
    :'query_stage_stats' => :'ItautomationAggregateHostCount',
    :'remediation_stage_stats' => :'ItautomationAggregateHostCount',
    :'start_time' => :'Time',
    :'status' => :'String',
    :'total_host_count' => :'Integer',
    :'total_results' => :'Integer',
    :'verification_stage_stats' => :'ItautomationAggregateHostCount',
    :'verification_summary' => :'ItautomationVerificationSummary'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      completion_percentage == o.completion_percentage &&
      end_time == o.end_time &&
      query_stage_stats == o.query_stage_stats &&
      remediation_stage_stats == o.remediation_stage_stats &&
      start_time == o.start_time &&
      status == o.status &&
      total_host_count == o.total_host_count &&
      total_results == o.total_results &&
      verification_stage_stats == o.verification_stage_stats &&
      verification_summary == o.verification_summary
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 265

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 336

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 227

def hash
  [completion_percentage, end_time, query_stage_stats, remediation_stage_stats, start_time, status, total_host_count, total_results, verification_stage_stats, verification_summary].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 161

def list_invalid_properties
  invalid_properties = Array.new
  if @completion_percentage.nil?
    invalid_properties.push('invalid value for "completion_percentage", completion_percentage cannot be nil.')
  end

  if @end_time.nil?
    invalid_properties.push('invalid value for "end_time", end_time cannot be nil.')
  end

  if @start_time.nil?
    invalid_properties.push('invalid value for "start_time", start_time cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @total_host_count.nil?
    invalid_properties.push('invalid value for "total_host_count", total_host_count cannot be nil.')
  end

  if @verification_summary.nil?
    invalid_properties.push('invalid value for "verification_summary", verification_summary cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 312

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



306
307
308
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 306

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
# File 'lib/crimson-falcon/models/itautomation_task_stage_execution_status.rb', line 192

def valid?
  return false if @completion_percentage.nil?
  return false if @end_time.nil?
  return false if @start_time.nil?
  return false if @status.nil?
  return false if @total_host_count.nil?
  return false if @verification_summary.nil?
  true
end