Class: Falcon::ItautomationUpdateTaskGroupRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_update_task_group_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationUpdateTaskGroupRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationUpdateTaskGroupRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationUpdateTaskGroupRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_type')
    self.access_type = attributes[:'access_type']
  end

  if attributes.key?(:'add_assigned_user_group_ids')
    if (value = attributes[:'add_assigned_user_group_ids']).is_a?(Array)
      self.add_assigned_user_group_ids = value
    end
  end

  if attributes.key?(:'add_assigned_user_ids')
    if (value = attributes[:'add_assigned_user_ids']).is_a?(Array)
      self.add_assigned_user_ids = value
    end
  end

  if attributes.key?(:'add_task_ids')
    if (value = attributes[:'add_task_ids']).is_a?(Array)
      self.add_task_ids = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'remove_assigned_user_group_ids')
    if (value = attributes[:'remove_assigned_user_group_ids']).is_a?(Array)
      self.remove_assigned_user_group_ids = value
    end
  end

  if attributes.key?(:'remove_assigned_user_ids')
    if (value = attributes[:'remove_assigned_user_ids']).is_a?(Array)
      self.remove_assigned_user_ids = value
    end
  end

  if attributes.key?(:'remove_task_ids')
    if (value = attributes[:'remove_task_ids']).is_a?(Array)
      self.remove_task_ids = value
    end
  end
end

Instance Attribute Details

#access_typeObject

Access type of the group



35
36
37
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 35

def access_type
  @access_type
end

#add_assigned_user_group_idsObject

User group IDs to add to the group, when access_type is Shared. Use GET /it-automation/queries/it-user-groups/v1 to fetch user group IDs



38
39
40
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 38

def add_assigned_user_group_ids
  @add_assigned_user_group_ids
end

#add_assigned_user_idsObject

User IDs to add to the group, when access_type is Shared. Use GET /user-management/queries/users/v1 to fetch user IDs



41
42
43
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 41

def add_assigned_user_ids
  @add_assigned_user_ids
end

#add_task_idsObject

IDs of existing tasks to add to task group. Get task ids via GET /it-automation/queries/task-groups/v1



44
45
46
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 44

def add_task_ids
  @add_task_ids
end

#descriptionObject

Description of the task group



47
48
49
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 47

def description
  @description
end

#nameObject

Name of the task group



50
51
52
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 50

def name
  @name
end

#remove_assigned_user_group_idsObject

User group IDs to remove from the group, when access_type is Shared. Use GET /it-automation/queries/it-user-groups/v1 to fetch user group IDs



53
54
55
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 53

def remove_assigned_user_group_ids
  @remove_assigned_user_group_ids
end

#remove_assigned_user_idsObject

User IDs to remove from the group, when access_type is Shared. Use GET /user-management/queries/users/v1 to fetch user IDs



56
57
58
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 56

def remove_assigned_user_ids
  @remove_assigned_user_ids
end

#remove_task_idsObject

IDs of existing tasks to remove from task group. Get task ids via GET /it-automation/queries/task-groups/v1



59
60
61
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 59

def remove_task_ids
  @remove_task_ids
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 99

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 84

def self.attribute_map
  {
    :'access_type' => :'access_type',
    :'add_assigned_user_group_ids' => :'add_assigned_user_group_ids',
    :'add_assigned_user_ids' => :'add_assigned_user_ids',
    :'add_task_ids' => :'add_task_ids',
    :'description' => :'description',
    :'name' => :'name',
    :'remove_assigned_user_group_ids' => :'remove_assigned_user_group_ids',
    :'remove_assigned_user_ids' => :'remove_assigned_user_ids',
    :'remove_task_ids' => :'remove_task_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 244

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 104

def self.openapi_types
  {
    :'access_type' => :'String',
    :'add_assigned_user_group_ids' => :'Array<String>',
    :'add_assigned_user_ids' => :'Array<String>',
    :'add_task_ids' => :'Array<String>',
    :'description' => :'String',
    :'name' => :'String',
    :'remove_assigned_user_group_ids' => :'Array<String>',
    :'remove_assigned_user_ids' => :'Array<String>',
    :'remove_task_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_type == o.access_type &&
      add_assigned_user_group_ids == o.add_assigned_user_group_ids &&
      add_assigned_user_ids == o.add_assigned_user_ids &&
      add_task_ids == o.add_task_ids &&
      description == o.description &&
      name == o.name &&
      remove_assigned_user_group_ids == o.remove_assigned_user_group_ids &&
      remove_assigned_user_ids == o.remove_assigned_user_ids &&
      remove_task_ids == o.remove_task_ids
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 275

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 346

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 251

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 237

def hash
  [access_type, add_assigned_user_group_ids, add_assigned_user_ids, add_task_ids, description, name, remove_assigned_user_group_ids, remove_assigned_user_ids, remove_task_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 190

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 322

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 328

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



316
317
318
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 316

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
# File 'lib/crimson-falcon/models/itautomation_update_task_group_request.rb', line 197

def valid?
  access_type_validator = EnumAttributeValidator.new('String', ["Public", "Shared"])
  return false unless access_type_validator.valid?(@access_type)
  true
end