Class: Falcon::ItautomationUserGroup

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/itautomation_user_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItautomationUserGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ItautomationUserGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ItautomationUserGroup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'modified_time')
    self.modified_time = attributes[:'modified_time']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'task_group_ids')
    if (value = attributes[:'task_group_ids']).is_a?(Array)
      self.task_group_ids = value
    end
  end

  if attributes.key?(:'task_ids')
    if (value = attributes[:'task_ids']).is_a?(Array)
      self.task_ids = value
    end
  end

  if attributes.key?(:'users')
    if (value = attributes[:'users']).is_a?(Array)
      self.users = value
    end
  end
end

Instance Attribute Details

#created_byObject

ID of the user who created the user group. Example: john.smith@crowdstrike.com



35
36
37
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 35

def created_by
  @created_by
end

#created_timeObject

Timestamp of the user group creation. Example: 2025-01-23T18:49:26.785778Z



38
39
40
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 38

def created_time
  @created_time
end

#descriptionObject

Description of the user group



41
42
43
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 41

def description
  @description
end

#idObject

Unique identifier for the user group. Example: f64b95555ef54ea682619ce880d267cc



44
45
46
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 44

def id
  @id
end

#modified_byObject

ID of the user who last modified the user group. Example: jane.doe@crowdstrike.com



47
48
49
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 47

def modified_by
  @modified_by
end

#modified_timeObject

Timestamp of the last user group modification. Example: 2025-01-23T18:49:26.785778Z



50
51
52
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 50

def modified_time
  @modified_time
end

#nameObject

Name of the user group



53
54
55
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 53

def name
  @name
end

#task_group_idsObject

IDs of the task groups assigned to the user group



56
57
58
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 56

def task_group_ids
  @task_group_ids
end

#task_idsObject

IDs of the tasks assigned to the user group



59
60
61
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 59

def task_ids
  @task_ids
end

#usersObject

Membership info for each user in the group



62
63
64
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 62

def users
  @users
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 65

def self.attribute_map
  {
    :'created_by' => :'created_by',
    :'created_time' => :'created_time',
    :'description' => :'description',
    :'id' => :'id',
    :'modified_by' => :'modified_by',
    :'modified_time' => :'modified_time',
    :'name' => :'name',
    :'task_group_ids' => :'task_group_ids',
    :'task_ids' => :'task_ids',
    :'users' => :'users'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 249

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 86

def self.openapi_types
  {
    :'created_by' => :'String',
    :'created_time' => :'Time',
    :'description' => :'String',
    :'id' => :'String',
    :'modified_by' => :'String',
    :'modified_time' => :'Time',
    :'name' => :'String',
    :'task_group_ids' => :'Array<String>',
    :'task_ids' => :'Array<String>',
    :'users' => :'Array<ItautomationUserGroupMember>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_by == o.created_by &&
      created_time == o.created_time &&
      description == o.description &&
      id == o.id &&
      modified_by == o.modified_by &&
      modified_time == o.modified_time &&
      name == o.name &&
      task_group_ids == o.task_group_ids &&
      task_ids == o.task_ids &&
      users == o.users
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 280

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 351

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 242

def hash
  [created_by, created_time, description, id, modified_by, modified_time, name, task_group_ids, task_ids, users].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @modified_time.nil?
    invalid_properties.push('invalid value for "modified_time", modified_time cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @users.nil?
    invalid_properties.push('invalid value for "users", users cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 327

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



321
322
323
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 321

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
# File 'lib/crimson-falcon/models/itautomation_user_group.rb', line 206

def valid?
  return false if @created_by.nil?
  return false if @created_time.nil?
  return false if @id.nil?
  return false if @modified_by.nil?
  return false if @modified_time.nil?
  return false if @name.nil?
  return false if @users.nil?
  true
end