Class: Falcon::JsonschemaSubSchema

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/jsonschema_sub_schema.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JsonschemaSubSchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 319

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::JsonschemaSubSchema` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::JsonschemaSubSchema`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ref')
    self.ref = attributes[:'ref']
  end

  if attributes.key?(:'schema')
    self.schema = attributes[:'schema']
  end

  if attributes.key?(:'additional_items')
    self.additional_items = attributes[:'additional_items']
  end

  if attributes.key?(:'additional_properties')
    self.additional_properties = attributes[:'additional_properties']
  end

  if attributes.key?(:'all_of')
    if (value = attributes[:'all_of']).is_a?(Array)
      self.all_of = value
    end
  end

  if attributes.key?(:'any_of')
    if (value = attributes[:'any_of']).is_a?(Array)
      self.any_of = value
    end
  end

  if attributes.key?(:'binary_encoding')
    self.binary_encoding = attributes[:'binary_encoding']
  end

  if attributes.key?(:'const')
    self.const = attributes[:'const']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'dependencies')
    if (value = attributes[:'dependencies']).is_a?(Hash)
      self.dependencies = value
    end
  end

  if attributes.key?(:'deprecated')
    self.deprecated = attributes[:'deprecated']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'_else')
    self._else = attributes[:'_else']
  end

  if attributes.key?(:'enum')
    if (value = attributes[:'enum']).is_a?(Array)
      self.enum = value
    end
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'examples')
    if (value = attributes[:'examples']).is_a?(Array)
      self.examples = value
    end
  end

  if attributes.key?(:'exclusive_maximum')
    self.exclusive_maximum = attributes[:'exclusive_maximum']
  end

  if attributes.key?(:'exclusive_minimum')
    self.exclusive_minimum = attributes[:'exclusive_minimum']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'_if')
    self._if = attributes[:'_if']
  end

  if attributes.key?(:'items')
    self.items = attributes[:'items']
  end

  if attributes.key?(:'max_items')
    self.max_items = attributes[:'max_items']
  end

  if attributes.key?(:'max_length')
    self.max_length = attributes[:'max_length']
  end

  if attributes.key?(:'max_properties')
    self.max_properties = attributes[:'max_properties']
  end

  if attributes.key?(:'maximum')
    self.maximum = attributes[:'maximum']
  end

  if attributes.key?(:'media')
    self.media = attributes[:'media']
  end

  if attributes.key?(:'min_items')
    self.min_items = attributes[:'min_items']
  end

  if attributes.key?(:'min_length')
    self.min_length = attributes[:'min_length']
  end

  if attributes.key?(:'min_properties')
    self.min_properties = attributes[:'min_properties']
  end

  if attributes.key?(:'minimum')
    self.minimum = attributes[:'minimum']
  end

  if attributes.key?(:'multiple_of')
    self.multiple_of = attributes[:'multiple_of']
  end

  if attributes.key?(:'_not')
    self._not = attributes[:'_not']
  end

  if attributes.key?(:'one_of')
    if (value = attributes[:'one_of']).is_a?(Array)
      self.one_of = value
    end
  end

  if attributes.key?(:'pattern')
    self.pattern = attributes[:'pattern']
  end

  if attributes.key?(:'pattern_properties')
    if (value = attributes[:'pattern_properties']).is_a?(Hash)
      self.pattern_properties = value
    end
  end

  if attributes.key?(:'properties')
    if (value = attributes[:'properties']).is_a?(Hash)
      self.properties = value
    end
  end

  if attributes.key?(:'required')
    if (value = attributes[:'required']).is_a?(Array)
      self.required = value
    end
  end

  if attributes.key?(:'_then')
    self._then = attributes[:'_then']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'ui_component')
    self.ui_component = attributes[:'ui_component']
  end

  if attributes.key?(:'unique_items')
    self.unique_items = attributes[:'unique_items']
  end

  if attributes.key?(:'x_cs_authorization')
    self.x_cs_authorization = attributes[:'x_cs_authorization']
  end

  if attributes.key?(:'x_cs_can_create')
    self.x_cs_can_create = attributes[:'x_cs_can_create']
  end

  if attributes.key?(:'x_cs_condition_group_fields')
    self.x_cs_condition_group_fields = attributes[:'x_cs_condition_group_fields']
  end

  if attributes.key?(:'x_cs_default_table_column')
    self.x_cs_default_table_column = attributes[:'x_cs_default_table_column']
  end

  if attributes.key?(:'x_cs_do_not_hide')
    self.x_cs_do_not_hide = attributes[:'x_cs_do_not_hide']
  end

  if attributes.key?(:'x_cs_immutable')
    self.x_cs_immutable = attributes[:'x_cs_immutable']
  end

  if attributes.key?(:'x_cs_indexable')
    self.x_cs_indexable = attributes[:'x_cs_indexable']
  end

  if attributes.key?(:'x_cs_indexable_fields')
    if (value = attributes[:'x_cs_indexable_fields']).is_a?(Array)
      self.x_cs_indexable_fields = value
    end
  end

  if attributes.key?(:'x_cs_max_duration')
    self.x_cs_max_duration = attributes[:'x_cs_max_duration']
  end

  if attributes.key?(:'x_cs_min_duration')
    self.x_cs_min_duration = attributes[:'x_cs_min_duration']
  end

  if attributes.key?(:'x_cs_not_parameterizable')
    self.x_cs_not_parameterizable = attributes[:'x_cs_not_parameterizable']
  end

  if attributes.key?(:'x_cs_openapi')
    self.x_cs_openapi = attributes[:'x_cs_openapi']
  end

  if attributes.key?(:'x_cs_order')
    if (value = attributes[:'x_cs_order']).is_a?(Array)
      self.x_cs_order = value
    end
  end

  if attributes.key?(:'x_cs_pivot')
    self.x_cs_pivot = attributes[:'x_cs_pivot']
  end

  if attributes.key?(:'x_cs_queryable')
    self.x_cs_queryable = attributes[:'x_cs_queryable']
  end

  if attributes.key?(:'x_cs_semantic_data')
    self.x_cs_semantic_data = attributes[:'x_cs_semantic_data']
  end

  if attributes.key?(:'x_cs_signals')
    self.x_cs_signals = attributes[:'x_cs_signals']
  end

  if attributes.key?(:'x_cs_signals_category')
    self.x_cs_signals_category = attributes[:'x_cs_signals_category']
  end

  if attributes.key?(:'x_cs_signals_operators')
    if (value = attributes[:'x_cs_signals_operators']).is_a?(Array)
      self.x_cs_signals_operators = value
    end
  end

  if attributes.key?(:'x_cs_signals_sub_category')
    self.x_cs_signals_sub_category = attributes[:'x_cs_signals_sub_category']
  end

  if attributes.key?(:'x_cs_tags')
    if (value = attributes[:'x_cs_tags']).is_a?(Array)
      self.x_cs_tags = value
    end
  end

  if attributes.key?(:'x_cs_ui')
    self.x_cs_ui = attributes[:'x_cs_ui']
  end

  if attributes.key?(:'x_cs_workflow')
    self.x_cs_workflow = attributes[:'x_cs_workflow']
  end
end

Instance Attribute Details

#_elseObject

Returns the value of attribute _else.



58
59
60
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 58

def _else
  @_else
end

#_ifObject

Returns the value of attribute _if.



72
73
74
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 72

def _if
  @_if
end

#_notObject

Returns the value of attribute _not.



96
97
98
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 96

def _not
  @_not
end

#_thenObject

Returns the value of attribute _then.



108
109
110
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 108

def _then
  @_then
end

#additional_itemsObject

Returns the value of attribute additional_items.



38
39
40
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 38

def additional_items
  @additional_items
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



40
41
42
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 40

def additional_properties
  @additional_properties
end

#all_ofObject

Returns the value of attribute all_of.



42
43
44
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 42

def all_of
  @all_of
end

#any_ofObject

Returns the value of attribute any_of.



44
45
46
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 44

def any_of
  @any_of
end

#binary_encodingObject

Returns the value of attribute binary_encoding.



46
47
48
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 46

def binary_encoding
  @binary_encoding
end

#constObject

Returns the value of attribute const.



48
49
50
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 48

def const
  @const
end

#defaultObject

Returns the value of attribute default.



50
51
52
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 50

def default
  @default
end

#dependenciesObject

Returns the value of attribute dependencies.



52
53
54
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 52

def dependencies
  @dependencies
end

#deprecatedObject

Returns the value of attribute deprecated.



54
55
56
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 54

def deprecated
  @deprecated
end

#descriptionObject

Returns the value of attribute description.



56
57
58
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 56

def description
  @description
end

#enumObject

Returns the value of attribute enum.



60
61
62
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 60

def enum
  @enum
end

#error_messageObject

Returns the value of attribute error_message.



62
63
64
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 62

def error_message
  @error_message
end

#examplesObject

Returns the value of attribute examples.



64
65
66
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 64

def examples
  @examples
end

#exclusive_maximumObject

Returns the value of attribute exclusive_maximum.



66
67
68
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 66

def exclusive_maximum
  @exclusive_maximum
end

#exclusive_minimumObject

Returns the value of attribute exclusive_minimum.



68
69
70
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 68

def exclusive_minimum
  @exclusive_minimum
end

#formatObject

Returns the value of attribute format.



70
71
72
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 70

def format
  @format
end

#itemsObject

Returns the value of attribute items.



74
75
76
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 74

def items
  @items
end

#max_itemsObject

Returns the value of attribute max_items.



76
77
78
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 76

def max_items
  @max_items
end

#max_lengthObject

Returns the value of attribute max_length.



78
79
80
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 78

def max_length
  @max_length
end

#max_propertiesObject

Returns the value of attribute max_properties.



80
81
82
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 80

def max_properties
  @max_properties
end

#maximumObject

Returns the value of attribute maximum.



82
83
84
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 82

def maximum
  @maximum
end

#mediaObject

Returns the value of attribute media.



84
85
86
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 84

def media
  @media
end

#min_itemsObject

Returns the value of attribute min_items.



86
87
88
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 86

def min_items
  @min_items
end

#min_lengthObject

Returns the value of attribute min_length.



88
89
90
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 88

def min_length
  @min_length
end

#min_propertiesObject

Returns the value of attribute min_properties.



90
91
92
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 90

def min_properties
  @min_properties
end

#minimumObject

Returns the value of attribute minimum.



92
93
94
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 92

def minimum
  @minimum
end

#multiple_ofObject

Returns the value of attribute multiple_of.



94
95
96
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 94

def multiple_of
  @multiple_of
end

#one_ofObject

Returns the value of attribute one_of.



98
99
100
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 98

def one_of
  @one_of
end

#patternObject

Returns the value of attribute pattern.



100
101
102
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 100

def pattern
  @pattern
end

#pattern_propertiesObject

Returns the value of attribute pattern_properties.



102
103
104
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 102

def pattern_properties
  @pattern_properties
end

#propertiesObject

Returns the value of attribute properties.



104
105
106
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 104

def properties
  @properties
end

#refObject

Returns the value of attribute ref.



34
35
36
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 34

def ref
  @ref
end

#requiredObject

Returns the value of attribute required.



106
107
108
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 106

def required
  @required
end

#schemaObject

Returns the value of attribute schema.



36
37
38
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 36

def schema
  @schema
end

#titleObject

Returns the value of attribute title.



110
111
112
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 110

def title
  @title
end

#typeObject

Returns the value of attribute type.



112
113
114
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 112

def type
  @type
end

#ui_componentObject

Returns the value of attribute ui_component.



114
115
116
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 114

def ui_component
  @ui_component
end

#unique_itemsObject

Returns the value of attribute unique_items.



116
117
118
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 116

def unique_items
  @unique_items
end

#x_cs_authorizationObject

Returns the value of attribute x_cs_authorization.



118
119
120
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 118

def x_cs_authorization
  @x_cs_authorization
end

#x_cs_can_createObject

Returns the value of attribute x_cs_can_create.



120
121
122
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 120

def x_cs_can_create
  @x_cs_can_create
end

#x_cs_condition_group_fieldsObject

Returns the value of attribute x_cs_condition_group_fields.



122
123
124
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 122

def x_cs_condition_group_fields
  @x_cs_condition_group_fields
end

#x_cs_default_table_columnObject

Returns the value of attribute x_cs_default_table_column.



124
125
126
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 124

def x_cs_default_table_column
  @x_cs_default_table_column
end

#x_cs_do_not_hideObject

Returns the value of attribute x_cs_do_not_hide.



126
127
128
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 126

def x_cs_do_not_hide
  @x_cs_do_not_hide
end

#x_cs_immutableObject

Returns the value of attribute x_cs_immutable.



128
129
130
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 128

def x_cs_immutable
  @x_cs_immutable
end

#x_cs_indexableObject

Returns the value of attribute x_cs_indexable.



130
131
132
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 130

def x_cs_indexable
  @x_cs_indexable
end

#x_cs_indexable_fieldsObject

Returns the value of attribute x_cs_indexable_fields.



132
133
134
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 132

def x_cs_indexable_fields
  @x_cs_indexable_fields
end

#x_cs_max_durationObject

Returns the value of attribute x_cs_max_duration.



134
135
136
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 134

def x_cs_max_duration
  @x_cs_max_duration
end

#x_cs_min_durationObject

Returns the value of attribute x_cs_min_duration.



136
137
138
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 136

def x_cs_min_duration
  @x_cs_min_duration
end

#x_cs_not_parameterizableObject

Returns the value of attribute x_cs_not_parameterizable.



138
139
140
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 138

def x_cs_not_parameterizable
  @x_cs_not_parameterizable
end

#x_cs_openapiObject

Returns the value of attribute x_cs_openapi.



140
141
142
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 140

def x_cs_openapi
  @x_cs_openapi
end

#x_cs_orderObject

Returns the value of attribute x_cs_order.



142
143
144
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 142

def x_cs_order
  @x_cs_order
end

#x_cs_pivotObject

Returns the value of attribute x_cs_pivot.



144
145
146
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 144

def x_cs_pivot
  @x_cs_pivot
end

#x_cs_queryableObject

Returns the value of attribute x_cs_queryable.



146
147
148
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 146

def x_cs_queryable
  @x_cs_queryable
end

#x_cs_semantic_dataObject

Returns the value of attribute x_cs_semantic_data.



148
149
150
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 148

def x_cs_semantic_data
  @x_cs_semantic_data
end

#x_cs_signalsObject

Returns the value of attribute x_cs_signals.



150
151
152
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 150

def x_cs_signals
  @x_cs_signals
end

#x_cs_signals_categoryObject

Returns the value of attribute x_cs_signals_category.



152
153
154
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 152

def x_cs_signals_category
  @x_cs_signals_category
end

#x_cs_signals_operatorsObject

Returns the value of attribute x_cs_signals_operators.



154
155
156
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 154

def x_cs_signals_operators
  @x_cs_signals_operators
end

#x_cs_signals_sub_categoryObject

Returns the value of attribute x_cs_signals_sub_category.



156
157
158
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 156

def x_cs_signals_sub_category
  @x_cs_signals_sub_category
end

#x_cs_tagsObject

Returns the value of attribute x_cs_tags.



158
159
160
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 158

def x_cs_tags
  @x_cs_tags
end

#x_cs_uiObject

Returns the value of attribute x_cs_ui.



160
161
162
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 160

def x_cs_ui
  @x_cs_ui
end

#x_cs_workflowObject

Returns the value of attribute x_cs_workflow.



162
163
164
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 162

def x_cs_workflow
  @x_cs_workflow
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



236
237
238
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 236

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 165

def self.attribute_map
  {
    :'ref' => :'$ref',
    :'schema' => :'$schema',
    :'additional_items' => :'additionalItems',
    :'additional_properties' => :'additionalProperties',
    :'all_of' => :'allOf',
    :'any_of' => :'anyOf',
    :'binary_encoding' => :'binaryEncoding',
    :'const' => :'const',
    :'default' => :'default',
    :'dependencies' => :'dependencies',
    :'deprecated' => :'deprecated',
    :'description' => :'description',
    :'_else' => :'else',
    :'enum' => :'enum',
    :'error_message' => :'errorMessage',
    :'examples' => :'examples',
    :'exclusive_maximum' => :'exclusiveMaximum',
    :'exclusive_minimum' => :'exclusiveMinimum',
    :'format' => :'format',
    :'_if' => :'if',
    :'items' => :'items',
    :'max_items' => :'maxItems',
    :'max_length' => :'maxLength',
    :'max_properties' => :'maxProperties',
    :'maximum' => :'maximum',
    :'media' => :'media',
    :'min_items' => :'minItems',
    :'min_length' => :'minLength',
    :'min_properties' => :'minProperties',
    :'minimum' => :'minimum',
    :'multiple_of' => :'multipleOf',
    :'_not' => :'not',
    :'one_of' => :'oneOf',
    :'pattern' => :'pattern',
    :'pattern_properties' => :'patternProperties',
    :'properties' => :'properties',
    :'required' => :'required',
    :'_then' => :'then',
    :'title' => :'title',
    :'type' => :'type',
    :'ui_component' => :'ui:component',
    :'unique_items' => :'uniqueItems',
    :'x_cs_authorization' => :'x-cs-authorization',
    :'x_cs_can_create' => :'x-cs-can-create',
    :'x_cs_condition_group_fields' => :'x-cs-condition-group-fields',
    :'x_cs_default_table_column' => :'x-cs-default-table-column',
    :'x_cs_do_not_hide' => :'x-cs-do-not-hide',
    :'x_cs_immutable' => :'x-cs-immutable',
    :'x_cs_indexable' => :'x-cs-indexable',
    :'x_cs_indexable_fields' => :'x-cs-indexable-fields',
    :'x_cs_max_duration' => :'x-cs-max-duration',
    :'x_cs_min_duration' => :'x-cs-min-duration',
    :'x_cs_not_parameterizable' => :'x-cs-not-parameterizable',
    :'x_cs_openapi' => :'x-cs-openapi',
    :'x_cs_order' => :'x-cs-order',
    :'x_cs_pivot' => :'x-cs-pivot',
    :'x_cs_queryable' => :'x-cs-queryable',
    :'x_cs_semantic_data' => :'x-cs-semantic-data',
    :'x_cs_signals' => :'x-cs-signals',
    :'x_cs_signals_category' => :'x-cs-signals-category',
    :'x_cs_signals_operators' => :'x-cs-signals-operators',
    :'x_cs_signals_sub_category' => :'x-cs-signals-subCategory',
    :'x_cs_tags' => :'x-cs-tags',
    :'x_cs_ui' => :'x-cs-ui',
    :'x_cs_workflow' => :'x-cs-workflow'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



719
720
721
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 719

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



312
313
314
315
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 312

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 241

def self.openapi_types
  {
    :'ref' => :'String',
    :'schema' => :'String',
    :'additional_items' => :'String',
    :'additional_properties' => :'String',
    :'all_of' => :'Array<JsonschemaSubSchema>',
    :'any_of' => :'Array<JsonschemaSubSchema>',
    :'binary_encoding' => :'String',
    :'const' => :'Object',
    :'default' => :'Object',
    :'dependencies' => :'Hash<String, JsonschemaSubSchema>',
    :'deprecated' => :'Boolean',
    :'description' => :'String',
    :'_else' => :'JsonschemaSubSchema',
    :'enum' => :'Array<Object>',
    :'error_message' => :'String',
    :'examples' => :'Array<Object>',
    :'exclusive_maximum' => :'Boolean',
    :'exclusive_minimum' => :'Boolean',
    :'format' => :'String',
    :'_if' => :'JsonschemaSubSchema',
    :'items' => :'JsonschemaSubSchema',
    :'max_items' => :'Integer',
    :'max_length' => :'Integer',
    :'max_properties' => :'Integer',
    :'maximum' => :'Integer',
    :'media' => :'JsonschemaSubSchema',
    :'min_items' => :'Integer',
    :'min_length' => :'Integer',
    :'min_properties' => :'Integer',
    :'minimum' => :'Integer',
    :'multiple_of' => :'Integer',
    :'_not' => :'JsonschemaSubSchema',
    :'one_of' => :'Array<JsonschemaSubSchema>',
    :'pattern' => :'String',
    :'pattern_properties' => :'Hash<String, JsonschemaSubSchema>',
    :'properties' => :'Hash<String, JsonschemaSubSchema>',
    :'required' => :'Array<String>',
    :'_then' => :'JsonschemaSubSchema',
    :'title' => :'String',
    :'type' => :'String',
    :'ui_component' => :'String',
    :'unique_items' => :'Boolean',
    :'x_cs_authorization' => :'JsonschemaAuthorization',
    :'x_cs_can_create' => :'Boolean',
    :'x_cs_condition_group_fields' => :'JsonschemaConditionGroupFields',
    :'x_cs_default_table_column' => :'Boolean',
    :'x_cs_do_not_hide' => :'Boolean',
    :'x_cs_immutable' => :'Boolean',
    :'x_cs_indexable' => :'Boolean',
    :'x_cs_indexable_fields' => :'Array<JsonschemaCollectionIndexField>',
    :'x_cs_max_duration' => :'Integer',
    :'x_cs_min_duration' => :'Integer',
    :'x_cs_not_parameterizable' => :'Boolean',
    :'x_cs_openapi' => :'JsonschemaOpenAPIExtensions',
    :'x_cs_order' => :'Array<String>',
    :'x_cs_pivot' => :'JsonschemaPivot',
    :'x_cs_queryable' => :'JsonschemaQueryConfig',
    :'x_cs_semantic_data' => :'JsonschemaSemanticData',
    :'x_cs_signals' => :'JsonschemaSignalsExtensions',
    :'x_cs_signals_category' => :'String',
    :'x_cs_signals_operators' => :'Array<String>',
    :'x_cs_signals_sub_category' => :'String',
    :'x_cs_tags' => :'Array<String>',
    :'x_cs_ui' => :'JsonschemaUIExtensions',
    :'x_cs_workflow' => :'JsonschemaWorkflowExtensions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 634

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ref == o.ref &&
      schema == o.schema &&
      additional_items == o.additional_items &&
      additional_properties == o.additional_properties &&
      all_of == o.all_of &&
      any_of == o.any_of &&
      binary_encoding == o.binary_encoding &&
      const == o.const &&
      default == o.default &&
      dependencies == o.dependencies &&
      deprecated == o.deprecated &&
      description == o.description &&
      _else == o._else &&
      enum == o.enum &&
      error_message == o.error_message &&
      examples == o.examples &&
      exclusive_maximum == o.exclusive_maximum &&
      exclusive_minimum == o.exclusive_minimum &&
      format == o.format &&
      _if == o._if &&
      items == o.items &&
      max_items == o.max_items &&
      max_length == o.max_length &&
      max_properties == o.max_properties &&
      maximum == o.maximum &&
      media == o.media &&
      min_items == o.min_items &&
      min_length == o.min_length &&
      min_properties == o.min_properties &&
      minimum == o.minimum &&
      multiple_of == o.multiple_of &&
      _not == o._not &&
      one_of == o.one_of &&
      pattern == o.pattern &&
      pattern_properties == o.pattern_properties &&
      properties == o.properties &&
      required == o.required &&
      _then == o._then &&
      title == o.title &&
      type == o.type &&
      ui_component == o.ui_component &&
      unique_items == o.unique_items &&
      x_cs_authorization == o.x_cs_authorization &&
      x_cs_can_create == o.x_cs_can_create &&
      x_cs_condition_group_fields == o.x_cs_condition_group_fields &&
      x_cs_default_table_column == o.x_cs_default_table_column &&
      x_cs_do_not_hide == o.x_cs_do_not_hide &&
      x_cs_immutable == o.x_cs_immutable &&
      x_cs_indexable == o.x_cs_indexable &&
      x_cs_indexable_fields == o.x_cs_indexable_fields &&
      x_cs_max_duration == o.x_cs_max_duration &&
      x_cs_min_duration == o.x_cs_min_duration &&
      x_cs_not_parameterizable == o.x_cs_not_parameterizable &&
      x_cs_openapi == o.x_cs_openapi &&
      x_cs_order == o.x_cs_order &&
      x_cs_pivot == o.x_cs_pivot &&
      x_cs_queryable == o.x_cs_queryable &&
      x_cs_semantic_data == o.x_cs_semantic_data &&
      x_cs_signals == o.x_cs_signals &&
      x_cs_signals_category == o.x_cs_signals_category &&
      x_cs_signals_operators == o.x_cs_signals_operators &&
      x_cs_signals_sub_category == o.x_cs_signals_sub_category &&
      x_cs_tags == o.x_cs_tags &&
      x_cs_ui == o.x_cs_ui &&
      x_cs_workflow == o.x_cs_workflow
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 750

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



821
822
823
824
825
826
827
828
829
830
831
832
833
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 821

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 726

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


706
707
708
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 706

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



712
713
714
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 712

def hash
  [ref, schema, additional_items, additional_properties, all_of, any_of, binary_encoding, const, default, dependencies, deprecated, description, _else, enum, error_message, examples, exclusive_maximum, exclusive_minimum, format, _if, items, max_items, max_length, max_properties, maximum, media, min_items, min_length, min_properties, minimum, multiple_of, _not, one_of, pattern, pattern_properties, properties, required, _then, title, type, ui_component, unique_items, x_cs_authorization, x_cs_can_create, x_cs_condition_group_fields, x_cs_default_table_column, x_cs_do_not_hide, x_cs_immutable, x_cs_indexable, x_cs_indexable_fields, x_cs_max_duration, x_cs_min_duration, x_cs_not_parameterizable, x_cs_openapi, x_cs_order, x_cs_pivot, x_cs_queryable, x_cs_semantic_data, x_cs_signals, x_cs_signals_category, x_cs_signals_operators, x_cs_signals_sub_category, x_cs_tags, x_cs_ui, x_cs_workflow].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



621
622
623
624
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 621

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



797
798
799
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 797

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 803

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



791
792
793
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 791

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



628
629
630
# File 'lib/crimson-falcon/models/jsonschema_sub_schema.rb', line 628

def valid?
  true
end