Class: Falcon::KnowledgeBaseAuditEvents

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/knowledge_base_audit_events.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ KnowledgeBaseAuditEvents

Returns a new instance of KnowledgeBaseAuditEvents.



35
36
37
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#aggregates_knowledge_base_audit_events_v1(body, opts = {}) ⇒ MsaAggregatesResponse

Aggregate knowledge base audit events based on the provided msa criteria.

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregate requests for knowledge base audit event data.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



43
44
45
46
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 43

def aggregates_knowledge_base_audit_events_v1(body, opts = {})
  data, _status_code, _headers = aggregates_knowledge_base_audit_events_v1_with_http_info(body, opts)
  data
end

#aggregates_knowledge_base_audit_events_v1_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>

Aggregate knowledge base audit events based on the provided msa criteria.

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregate requests for knowledge base audit event data.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:

  • (Array<(MsaAggregatesResponse, Integer, Hash)>)

    MsaAggregatesResponse data, response status code and response headers



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 53

def aggregates_knowledge_base_audit_events_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBaseAuditEvents.aggregates_knowledge_base_audit_events_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling KnowledgeBaseAuditEvents.aggregates_knowledge_base_audit_events_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/aggregates/knowledge_base_audit_events/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'MsaAggregatesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBaseAuditEvents.aggregates_knowledge_base_audit_events_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBaseAuditEvents#aggregates_knowledge_base_audit_events_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#combined_knowledge_base_audit_events_v1(knowledge_base_id, opts = {}) ⇒ DomainReplyCombinedKnowledgeBaseAuditEventsResponse

Get knowledge base audit events with full event details and pagination.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base to get audit events for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return events.

  • :limit (Integer)

    Number of events to return. (default to 10)

  • :sort (String)

    Sort order. Ex: &#39;created_at|desc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



116
117
118
119
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 116

def combined_knowledge_base_audit_events_v1(knowledge_base_id, opts = {})
  data, _status_code, _headers = combined_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts)
  data
end

#combined_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts = {}) ⇒ Array<(DomainReplyCombinedKnowledgeBaseAuditEventsResponse, Integer, Hash)>

Get knowledge base audit events with full event details and pagination.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base to get audit events for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return events.

  • :limit (Integer)

    Number of events to return. (default to 10)

  • :sort (String)

    Sort order. Ex: &#39;created_at|desc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 130

def combined_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBaseAuditEvents.combined_knowledge_base_audit_events_v1 ...'
  end
  # verify the required parameter 'knowledge_base_id' is set
  if @api_client.config.client_side_validation && knowledge_base_id.nil?
    fail ArgumentError, "Missing the required parameter 'knowledge_base_id' when calling KnowledgeBaseAuditEvents.combined_knowledge_base_audit_events_v1"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 500
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBaseAuditEvents.combined_knowledge_base_audit_events_v1, must be smaller than or equal to 500.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBaseAuditEvents.combined_knowledge_base_audit_events_v1, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/agentic-studio/combined/knowledge_base_audit_events/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'knowledge_base_id'] = knowledge_base_id
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyCombinedKnowledgeBaseAuditEventsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBaseAuditEvents.combined_knowledge_base_audit_events_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBaseAuditEvents#combined_knowledge_base_audit_events_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_knowledge_base_audit_events_v1(knowledge_base_id, ids, opts = {}) ⇒ DomainReplyEntitiesKnowledgeBaseAuditEventsResponse

Retrieve knowledge base audit event entities by their IDs.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base

  • ids (Array<String>)

    IDs of audit events to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



198
199
200
201
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 198

def entities_knowledge_base_audit_events_v1(knowledge_base_id, ids, opts = {})
  data, _status_code, _headers = entities_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, ids, opts)
  data
end

#entities_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, ids, opts = {}) ⇒ Array<(DomainReplyEntitiesKnowledgeBaseAuditEventsResponse, Integer, Hash)>

Retrieve knowledge base audit event entities by their IDs.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base

  • ids (Array<String>)

    IDs of audit events to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 209

def entities_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBaseAuditEvents.entities_knowledge_base_audit_events_v1 ...'
  end
  # verify the required parameter 'knowledge_base_id' is set
  if @api_client.config.client_side_validation && knowledge_base_id.nil?
    fail ArgumentError, "Missing the required parameter 'knowledge_base_id' when calling KnowledgeBaseAuditEvents.entities_knowledge_base_audit_events_v1"
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling KnowledgeBaseAuditEvents.entities_knowledge_base_audit_events_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/entities/knowledge_base_audit_events/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'knowledge_base_id'] = knowledge_base_id
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyEntitiesKnowledgeBaseAuditEventsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBaseAuditEvents.entities_knowledge_base_audit_events_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBaseAuditEvents#entities_knowledge_base_audit_events_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#queries_knowledge_base_audit_events_v1(knowledge_base_id, opts = {}) ⇒ DomainReplyQueryKnowledgeBaseAuditEventsResponse

Query knowledge base audit event IDs with pagination and filtering.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base to query audit events for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return ids.

  • :limit (Integer)

    Number of IDs to return. (default to 10)

  • :sort (String)

    Sort order. Ex: &#39;created_at|desc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



273
274
275
276
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 273

def queries_knowledge_base_audit_events_v1(knowledge_base_id, opts = {})
  data, _status_code, _headers = queries_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts)
  data
end

#queries_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts = {}) ⇒ Array<(DomainReplyQueryKnowledgeBaseAuditEventsResponse, Integer, Hash)>

Query knowledge base audit event IDs with pagination and filtering.

Parameters:

  • knowledge_base_id (String)

    ID of the knowledge base to query audit events for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return ids.

  • :limit (Integer)

    Number of IDs to return. (default to 10)

  • :sort (String)

    Sort order. Ex: &#39;created_at|desc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include audit events for deleted knowledge bases. Defaults to false. (default to false)

Returns:



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/crimson-falcon/api/knowledge_base_audit_events.rb', line 287

def queries_knowledge_base_audit_events_v1_with_http_info(knowledge_base_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBaseAuditEvents.queries_knowledge_base_audit_events_v1 ...'
  end
  # verify the required parameter 'knowledge_base_id' is set
  if @api_client.config.client_side_validation && knowledge_base_id.nil?
    fail ArgumentError, "Missing the required parameter 'knowledge_base_id' when calling KnowledgeBaseAuditEvents.queries_knowledge_base_audit_events_v1"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 500
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBaseAuditEvents.queries_knowledge_base_audit_events_v1, must be smaller than or equal to 500.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBaseAuditEvents.queries_knowledge_base_audit_events_v1, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/agentic-studio/queries/knowledge_base_audit_events/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'knowledge_base_id'] = knowledge_base_id
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyQueryKnowledgeBaseAuditEventsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBaseAuditEvents.queries_knowledge_base_audit_events_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBaseAuditEvents#queries_knowledge_base_audit_events_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end