Class: Falcon::KnowledgeBases

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/knowledge_bases.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ KnowledgeBases

Returns a new instance of KnowledgeBases.



35
36
37
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#aggregates_knowledge_bases_v1(body, opts = {}) ⇒ MsaAggregatesResponse

Aggregate knowledge bases based on the provided msa criteria.

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregate requests for knowledge base data.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:



43
44
45
46
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 43

def aggregates_knowledge_bases_v1(body, opts = {})
  data, _status_code, _headers = aggregates_knowledge_bases_v1_with_http_info(body, opts)
  data
end

#aggregates_knowledge_bases_v1_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>

Aggregate knowledge bases based on the provided msa criteria.

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregate requests for knowledge base data.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:

  • (Array<(MsaAggregatesResponse, Integer, Hash)>)

    MsaAggregatesResponse data, response status code and response headers



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 53

def aggregates_knowledge_bases_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBases.aggregates_knowledge_bases_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling KnowledgeBases.aggregates_knowledge_bases_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/aggregates/knowledge_bases/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'MsaAggregatesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBases.aggregates_knowledge_bases_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBases#aggregates_knowledge_bases_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_knowledge_bases_create_v1(body, opts = {}) ⇒ DomainReplyEntitiesKnowledgeBasesResponse

Create or update a knowledge base. For deletion, provide knowledge base with IsDeleted=true.

Parameters:

  • body (DomainKnowledgeBase)

    Knowledge base definition to create or update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



111
112
113
114
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 111

def entities_knowledge_bases_create_v1(body, opts = {})
  data, _status_code, _headers = entities_knowledge_bases_create_v1_with_http_info(body, opts)
  data
end

#entities_knowledge_bases_create_v1_with_http_info(body, opts = {}) ⇒ Array<(DomainReplyEntitiesKnowledgeBasesResponse, Integer, Hash)>

Create or update a knowledge base. For deletion, provide knowledge base with IsDeleted&#x3D;true.

Parameters:

  • body (DomainKnowledgeBase)

    Knowledge base definition to create or update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 120

def entities_knowledge_bases_create_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBases.entities_knowledge_bases_create_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling KnowledgeBases.entities_knowledge_bases_create_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/entities/knowledge_bases/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyEntitiesKnowledgeBasesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBases.entities_knowledge_bases_create_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBases#entities_knowledge_bases_create_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_knowledge_bases_update_v1(body, opts = {}) ⇒ DomainReplyEntitiesKnowledgeBasesResponse

Update an existing knowledge base.

Parameters:

  • body (DomainKnowledgeBase)

    Knowledge base definition with updated fields

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



177
178
179
180
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 177

def entities_knowledge_bases_update_v1(body, opts = {})
  data, _status_code, _headers = entities_knowledge_bases_update_v1_with_http_info(body, opts)
  data
end

#entities_knowledge_bases_update_v1_with_http_info(body, opts = {}) ⇒ Array<(DomainReplyEntitiesKnowledgeBasesResponse, Integer, Hash)>

Update an existing knowledge base.

Parameters:

  • body (DomainKnowledgeBase)

    Knowledge base definition with updated fields

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 186

def entities_knowledge_bases_update_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBases.entities_knowledge_bases_update_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling KnowledgeBases.entities_knowledge_bases_update_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/entities/knowledge_bases/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyEntitiesKnowledgeBasesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBases.entities_knowledge_bases_update_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBases#entities_knowledge_bases_update_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#entities_knowledge_bases_v1(ids, opts = {}) ⇒ DomainReplyEntitiesKnowledgeBasesResponse

Retrieve knowledge base entities for the provided id.

Parameters:

  • ids (Array<String>)

    IDs of entities to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:



244
245
246
247
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 244

def entities_knowledge_bases_v1(ids, opts = {})
  data, _status_code, _headers = entities_knowledge_bases_v1_with_http_info(ids, opts)
  data
end

#entities_knowledge_bases_v1_with_http_info(ids, opts = {}) ⇒ Array<(DomainReplyEntitiesKnowledgeBasesResponse, Integer, Hash)>

Retrieve knowledge base entities for the provided id.

Parameters:

  • ids (Array<String>)

    IDs of entities to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 254

def entities_knowledge_bases_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBases.entities_knowledge_bases_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling KnowledgeBases.entities_knowledge_bases_v1"
  end
  # resource path
  local_var_path = '/agentic-studio/entities/knowledge_bases/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyEntitiesKnowledgeBasesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBases.entities_knowledge_bases_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBases#entities_knowledge_bases_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#queries_knowledge_bases_v1(opts = {}) ⇒ DomainReplyQueryKnowledgeBasesResponse

Query knowledge bases based on the provided filters.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return ids.

  • :limit (Integer)

    Number of IDs to return. Offset + limit should NOT be above 10K. (default to 10)

  • :sort (String)

    Possible order by fields: name, created_at. Ex: &#39;created_at|desc&#39; or &#39;name|asc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:



312
313
314
315
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 312

def queries_knowledge_bases_v1(opts = {})
  data, _status_code, _headers = queries_knowledge_bases_v1_with_http_info(opts)
  data
end

#queries_knowledge_bases_v1_with_http_info(opts = {}) ⇒ Array<(DomainReplyQueryKnowledgeBasesResponse, Integer, Hash)>

Query knowledge bases based on the provided filters.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    Starting index of overall result set from which to return ids.

  • :limit (Integer)

    Number of IDs to return. Offset + limit should NOT be above 10K. (default to 10)

  • :sort (String)

    Possible order by fields: name, created_at. Ex: &#39;created_at|desc&#39; or &#39;name|asc&#39;.

  • :filter (String)

    FQL query specifying the filter parameters.

  • :include_deleted (Boolean)

    Include deleted knowledge bases in the result. Defaults to false. (default to false)

Returns:



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/crimson-falcon/api/knowledge_bases.rb', line 325

def queries_knowledge_bases_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KnowledgeBases.queries_knowledge_bases_v1 ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 500
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBases.queries_knowledge_bases_v1, must be smaller than or equal to 500.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling KnowledgeBases.queries_knowledge_bases_v1, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/agentic-studio/queries/knowledge_bases/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'include_deleted'] = opts[:'include_deleted'] if !opts[:'include_deleted'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainReplyQueryKnowledgeBasesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"KnowledgeBases.queries_knowledge_bases_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KnowledgeBases#queries_knowledge_bases_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end