Class: Falcon::MalqueryRateLimitsMeta

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/malquery_rate_limits_meta.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MalqueryRateLimitsMeta

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::MalqueryRateLimitsMeta` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::MalqueryRateLimitsMeta`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'days_left')
    self.days_left = attributes[:'days_left']
  end

  if attributes.key?(:'download_count')
    self.download_count = attributes[:'download_count']
  end

  if attributes.key?(:'download_counts')
    if (value = attributes[:'download_counts']).is_a?(Array)
      self.download_counts = value
    end
  end

  if attributes.key?(:'download_limit')
    self.download_limit = attributes[:'download_limit']
  end

  if attributes.key?(:'hunt_count')
    self.hunt_count = attributes[:'hunt_count']
  end

  if attributes.key?(:'hunt_counts')
    if (value = attributes[:'hunt_counts']).is_a?(Array)
      self.hunt_counts = value
    end
  end

  if attributes.key?(:'hunt_limit')
    self.hunt_limit = attributes[:'hunt_limit']
  end

  if attributes.key?(:'monitor_count')
    self.monitor_count = attributes[:'monitor_count']
  end

  if attributes.key?(:'monitor_limit')
    self.monitor_limit = attributes[:'monitor_limit']
  end

  if attributes.key?(:'refresh_time')
    self.refresh_time = attributes[:'refresh_time']
  end
end

Instance Attribute Details

#days_leftObject

Days left until the limits are refreshed



35
36
37
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 35

def days_left
  @days_left
end

#download_countObject

How many downloads were executed in the last month



38
39
40
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 38

def download_count
  @download_count
end

#download_countsObject

Download counts per user



41
42
43
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 41

def download_counts
  @download_counts
end

#download_limitObject

Total download limit per month



44
45
46
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 44

def download_limit
  @download_limit
end

#hunt_countObject

How many hunts were executed in the last month



47
48
49
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 47

def hunt_count
  @hunt_count
end

#hunt_countsObject

Hunt counts per user



50
51
52
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 50

def hunt_counts
  @hunt_counts
end

#hunt_limitObject

Total hunt limit per month



53
54
55
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 53

def hunt_limit
  @hunt_limit
end

#monitor_countObject

How many monitors were created in the last month



56
57
58
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 56

def monitor_count
  @monitor_count
end

#monitor_limitObject

Total monitor limit per month



59
60
61
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 59

def monitor_limit
  @monitor_limit
end

#refresh_timeObject

Time when the limits are refreshed. ISO 8601 format



62
63
64
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 62

def refresh_time
  @refresh_time
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 65

def self.attribute_map
  {
    :'days_left' => :'days_left',
    :'download_count' => :'download_count',
    :'download_counts' => :'download_counts',
    :'download_limit' => :'download_limit',
    :'hunt_count' => :'hunt_count',
    :'hunt_counts' => :'hunt_counts',
    :'hunt_limit' => :'hunt_limit',
    :'monitor_count' => :'monitor_count',
    :'monitor_limit' => :'monitor_limit',
    :'refresh_time' => :'refresh_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 252

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 86

def self.openapi_types
  {
    :'days_left' => :'Integer',
    :'download_count' => :'Integer',
    :'download_counts' => :'Array<MalqueryUserRequestCount>',
    :'download_limit' => :'Integer',
    :'hunt_count' => :'Integer',
    :'hunt_counts' => :'Array<MalqueryUserRequestCount>',
    :'hunt_limit' => :'Integer',
    :'monitor_count' => :'Integer',
    :'monitor_limit' => :'Integer',
    :'refresh_time' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      days_left == o.days_left &&
      download_count == o.download_count &&
      download_counts == o.download_counts &&
      download_limit == o.download_limit &&
      hunt_count == o.hunt_count &&
      hunt_counts == o.hunt_counts &&
      hunt_limit == o.hunt_limit &&
      monitor_count == o.monitor_count &&
      monitor_limit == o.monitor_limit &&
      refresh_time == o.refresh_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 283

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 259

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


239
240
241
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



245
246
247
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 245

def hash
  [days_left, download_count, download_counts, download_limit, hunt_count, hunt_counts, hunt_limit, monitor_count, monitor_limit, refresh_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  if @days_left.nil?
    invalid_properties.push('invalid value for "days_left", days_left cannot be nil.')
  end

  if @download_count.nil?
    invalid_properties.push('invalid value for "download_count", download_count cannot be nil.')
  end

  if @download_limit.nil?
    invalid_properties.push('invalid value for "download_limit", download_limit cannot be nil.')
  end

  if @hunt_count.nil?
    invalid_properties.push('invalid value for "hunt_count", hunt_count cannot be nil.')
  end

  if @hunt_limit.nil?
    invalid_properties.push('invalid value for "hunt_limit", hunt_limit cannot be nil.')
  end

  if @monitor_count.nil?
    invalid_properties.push('invalid value for "monitor_count", monitor_count cannot be nil.')
  end

  if @monitor_limit.nil?
    invalid_properties.push('invalid value for "monitor_limit", monitor_limit cannot be nil.')
  end

  if @refresh_time.nil?
    invalid_properties.push('invalid value for "refresh_time", refresh_time cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
# File 'lib/crimson-falcon/models/malquery_rate_limits_meta.rb', line 208

def valid?
  return false if @days_left.nil?
  return false if @download_count.nil?
  return false if @download_limit.nil?
  return false if @hunt_count.nil?
  return false if @hunt_limit.nil?
  return false if @monitor_count.nil?
  return false if @monitor_limit.nil?
  return false if @refresh_time.nil?
  true
end