Class: Falcon::MessagesCase

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/messages_case.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MessagesCase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/crimson-falcon/models/messages_case.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::MessagesCase` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::MessagesCase`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aids')
    if (value = attributes[:'aids']).is_a?(Array)
      self.aids = value
    end
  end

  if attributes.key?(:'assigner')
    self.assigner = attributes[:'assigner']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'case_type')
    self.case_type = attributes[:'case_type']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'detections')
    if (value = attributes[:'detections']).is_a?(Array)
      self.detections = value
    end
  end

  if attributes.key?(:'hosts')
    if (value = attributes[:'hosts']).is_a?(Array)
      self.hosts = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'incidents')
    if (value = attributes[:'incidents']).is_a?(Array)
      self.incidents = value
    end
  end

  if attributes.key?(:'ip_addresses')
    if (value = attributes[:'ip_addresses']).is_a?(Array)
      self.ip_addresses = value
    end
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'last_modified_time')
    self.last_modified_time = attributes[:'last_modified_time']
  end

  if attributes.key?(:'malware_submission_id')
    self.malware_submission_id = attributes[:'malware_submission_id']
  end

  if attributes.key?(:'malware_submission_url')
    self.malware_submission_url = attributes[:'malware_submission_url']
  end

  if attributes.key?(:'recon_rule_type')
    self.recon_rule_type = attributes[:'recon_rule_type']
  end

  if attributes.key?(:'rfi_id')
    self.rfi_id = attributes[:'rfi_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#aidsObject

Returns the value of attribute aids.



34
35
36
# File 'lib/crimson-falcon/models/messages_case.rb', line 34

def aids
  @aids
end

#assignerObject

Returns the value of attribute assigner.



36
37
38
# File 'lib/crimson-falcon/models/messages_case.rb', line 36

def assigner
  @assigner
end

#attachmentsObject

Returns the value of attribute attachments.



38
39
40
# File 'lib/crimson-falcon/models/messages_case.rb', line 38

def attachments
  @attachments
end

#bodyObject

Returns the value of attribute body.



40
41
42
# File 'lib/crimson-falcon/models/messages_case.rb', line 40

def body
  @body
end

#case_typeObject

Returns the value of attribute case_type.



42
43
44
# File 'lib/crimson-falcon/models/messages_case.rb', line 42

def case_type
  @case_type
end

#cidObject

Returns the value of attribute cid.



44
45
46
# File 'lib/crimson-falcon/models/messages_case.rb', line 44

def cid
  @cid
end

#created_timeObject

Returns the value of attribute created_time.



46
47
48
# File 'lib/crimson-falcon/models/messages_case.rb', line 46

def created_time
  @created_time
end

#detectionsObject

Returns the value of attribute detections.



48
49
50
# File 'lib/crimson-falcon/models/messages_case.rb', line 48

def detections
  @detections
end

#hostsObject

Returns the value of attribute hosts.



50
51
52
# File 'lib/crimson-falcon/models/messages_case.rb', line 50

def hosts
  @hosts
end

#idObject

Returns the value of attribute id.



52
53
54
# File 'lib/crimson-falcon/models/messages_case.rb', line 52

def id
  @id
end

#incidentsObject

Returns the value of attribute incidents.



54
55
56
# File 'lib/crimson-falcon/models/messages_case.rb', line 54

def incidents
  @incidents
end

#ip_addressesObject

Returns the value of attribute ip_addresses.



56
57
58
# File 'lib/crimson-falcon/models/messages_case.rb', line 56

def ip_addresses
  @ip_addresses
end

#keyObject

Returns the value of attribute key.



58
59
60
# File 'lib/crimson-falcon/models/messages_case.rb', line 58

def key
  @key
end

#last_modified_timeObject

Returns the value of attribute last_modified_time.



60
61
62
# File 'lib/crimson-falcon/models/messages_case.rb', line 60

def last_modified_time
  @last_modified_time
end

#malware_submission_idObject

Returns the value of attribute malware_submission_id.



62
63
64
# File 'lib/crimson-falcon/models/messages_case.rb', line 62

def malware_submission_id
  @malware_submission_id
end

#malware_submission_urlObject

Returns the value of attribute malware_submission_url.



64
65
66
# File 'lib/crimson-falcon/models/messages_case.rb', line 64

def malware_submission_url
  @malware_submission_url
end

#recon_rule_typeObject

Returns the value of attribute recon_rule_type.



66
67
68
# File 'lib/crimson-falcon/models/messages_case.rb', line 66

def recon_rule_type
  @recon_rule_type
end

#rfi_idObject

Returns the value of attribute rfi_id.



68
69
70
# File 'lib/crimson-falcon/models/messages_case.rb', line 68

def rfi_id
  @rfi_id
end

#statusObject

Returns the value of attribute status.



70
71
72
# File 'lib/crimson-falcon/models/messages_case.rb', line 70

def status
  @status
end

#titleObject

Returns the value of attribute title.



72
73
74
# File 'lib/crimson-falcon/models/messages_case.rb', line 72

def title
  @title
end

#typeObject

Returns the value of attribute type.



74
75
76
# File 'lib/crimson-falcon/models/messages_case.rb', line 74

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/crimson-falcon/models/messages_case.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/messages_case.rb', line 77

def self.attribute_map
  {
    :'aids' => :'aids',
    :'assigner' => :'assigner',
    :'attachments' => :'attachments',
    :'body' => :'body',
    :'case_type' => :'case_type',
    :'cid' => :'cid',
    :'created_time' => :'created_time',
    :'detections' => :'detections',
    :'hosts' => :'hosts',
    :'id' => :'id',
    :'incidents' => :'incidents',
    :'ip_addresses' => :'ip_addresses',
    :'key' => :'key',
    :'last_modified_time' => :'last_modified_time',
    :'malware_submission_id' => :'malware_submission_id',
    :'malware_submission_url' => :'malware_submission_url',
    :'recon_rule_type' => :'recon_rule_type',
    :'rfi_id' => :'rfi_id',
    :'status' => :'status',
    :'title' => :'title',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



409
410
411
# File 'lib/crimson-falcon/models/messages_case.rb', line 409

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/crimson-falcon/models/messages_case.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/crimson-falcon/models/messages_case.rb', line 109

def self.openapi_types
  {
    :'aids' => :'Array<String>',
    :'assigner' => :'MessagesAuthor',
    :'attachments' => :'Array<MessagesAttachment>',
    :'body' => :'String',
    :'case_type' => :'String',
    :'cid' => :'String',
    :'created_time' => :'String',
    :'detections' => :'Array<MessagesDetection>',
    :'hosts' => :'Array<String>',
    :'id' => :'String',
    :'incidents' => :'Array<MessagesIncident>',
    :'ip_addresses' => :'Array<String>',
    :'key' => :'String',
    :'last_modified_time' => :'String',
    :'malware_submission_id' => :'String',
    :'malware_submission_url' => :'String',
    :'recon_rule_type' => :'String',
    :'rfi_id' => :'String',
    :'status' => :'String',
    :'title' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/crimson-falcon/models/messages_case.rb', line 368

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aids == o.aids &&
      assigner == o.assigner &&
      attachments == o.attachments &&
      body == o.body &&
      case_type == o.case_type &&
      cid == o.cid &&
      created_time == o.created_time &&
      detections == o.detections &&
      hosts == o.hosts &&
      id == o.id &&
      incidents == o.incidents &&
      ip_addresses == o.ip_addresses &&
      key == o.key &&
      last_modified_time == o.last_modified_time &&
      malware_submission_id == o.malware_submission_id &&
      malware_submission_url == o.malware_submission_url &&
      recon_rule_type == o.recon_rule_type &&
      rfi_id == o.rfi_id &&
      status == o.status &&
      title == o.title &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/crimson-falcon/models/messages_case.rb', line 440

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/crimson-falcon/models/messages_case.rb', line 511

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/crimson-falcon/models/messages_case.rb', line 416

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


396
397
398
# File 'lib/crimson-falcon/models/messages_case.rb', line 396

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



402
403
404
# File 'lib/crimson-falcon/models/messages_case.rb', line 402

def hash
  [aids, assigner, attachments, body, case_type, cid, created_time, detections, hosts, id, incidents, ip_addresses, key, last_modified_time, malware_submission_id, malware_submission_url, recon_rule_type, rfi_id, status, title, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/crimson-falcon/models/messages_case.rb', line 255

def list_invalid_properties
  invalid_properties = Array.new
  if @aids.nil?
    invalid_properties.push('invalid value for "aids", aids cannot be nil.')
  end

  if @assigner.nil?
    invalid_properties.push('invalid value for "assigner", assigner cannot be nil.')
  end

  if @attachments.nil?
    invalid_properties.push('invalid value for "attachments", attachments cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @detections.nil?
    invalid_properties.push('invalid value for "detections", detections cannot be nil.')
  end

  if @hosts.nil?
    invalid_properties.push('invalid value for "hosts", hosts cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @incidents.nil?
    invalid_properties.push('invalid value for "incidents", incidents cannot be nil.')
  end

  if @ip_addresses.nil?
    invalid_properties.push('invalid value for "ip_addresses", ip_addresses cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @last_modified_time.nil?
    invalid_properties.push('invalid value for "last_modified_time", last_modified_time cannot be nil.')
  end

  if @malware_submission_id.nil?
    invalid_properties.push('invalid value for "malware_submission_id", malware_submission_id cannot be nil.')
  end

  if @malware_submission_url.nil?
    invalid_properties.push('invalid value for "malware_submission_url", malware_submission_url cannot be nil.')
  end

  if @recon_rule_type.nil?
    invalid_properties.push('invalid value for "recon_rule_type", recon_rule_type cannot be nil.')
  end

  if @rfi_id.nil?
    invalid_properties.push('invalid value for "rfi_id", rfi_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



487
488
489
# File 'lib/crimson-falcon/models/messages_case.rb', line 487

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/crimson-falcon/models/messages_case.rb', line 493

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



481
482
483
# File 'lib/crimson-falcon/models/messages_case.rb', line 481

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/models/messages_case.rb', line 342

def valid?
  return false if @aids.nil?
  return false if @assigner.nil?
  return false if @attachments.nil?
  return false if @body.nil?
  return false if @cid.nil?
  return false if @created_time.nil?
  return false if @detections.nil?
  return false if @hosts.nil?
  return false if @id.nil?
  return false if @incidents.nil?
  return false if @ip_addresses.nil?
  return false if @key.nil?
  return false if @last_modified_time.nil?
  return false if @malware_submission_id.nil?
  return false if @malware_submission_url.nil?
  return false if @recon_rule_type.nil?
  return false if @rfi_id.nil?
  return false if @status.nil?
  return false if @title.nil?
  return false if @type.nil?
  true
end