Class: Falcon::MlExclusions

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/ml_exclusions.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MlExclusions

Returns a new instance of MlExclusions.



35
36
37
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#create_ml_exclusions_v1(body, opts = {}) ⇒ ExclusionsRespV1

Create the ML exclusions

Parameters:

Returns:



42
43
44
45
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 42

def create_ml_exclusions_v1(body, opts = {})
  data, _status_code, _headers = create_ml_exclusions_v1_with_http_info(body, opts)
  data
end

#create_ml_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(ExclusionsRespV1, Integer, Hash)>

Create the ML exclusions

Parameters:

Returns:

  • (Array<(ExclusionsRespV1, Integer, Hash)>)

    ExclusionsRespV1 data, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 51

def create_ml_exclusions_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.create_ml_exclusions_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.create_ml_exclusions_v1"
  end
  # resource path
  local_var_path = '/policy/entities/ml-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'ExclusionsRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.create_ml_exclusions_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#create_ml_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_ml_exclusions_v1(ids, opts = {}) ⇒ MsaspecQueryResponse

Delete the ML exclusions by id

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    Explains why this exclusions was deleted

Returns:



109
110
111
112
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 109

def delete_ml_exclusions_v1(ids, opts = {})
  data, _status_code, _headers = delete_ml_exclusions_v1_with_http_info(ids, opts)
  data
end

#delete_ml_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Delete the ML exclusions by id

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    Explains why this exclusions was deleted

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 119

def delete_ml_exclusions_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.delete_ml_exclusions_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling MlExclusions.delete_ml_exclusions_v1"
  end
  # resource path
  local_var_path = '/policy/entities/ml-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.delete_ml_exclusions_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#delete_ml_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_aggregates_v2(body, opts = {}) ⇒ nil

Get exclusion aggregates as specified via json in request body.

Parameters:

Returns:

  • (nil)


173
174
175
176
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 173

def exclusions_aggregates_v2(body, opts = {})
  exclusions_aggregates_v2_with_http_info(body, opts)
  nil
end

#exclusions_aggregates_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get exclusion aggregates as specified via json in request body.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 182

def exclusions_aggregates_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_aggregates_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.exclusions_aggregates_v2"
  end
  # resource path
  local_var_path = '/exclusions/aggregates/exclusions/GET/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_aggregates_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_aggregates_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_create_v2(body, opts = {}) ⇒ nil

Create the exclusions, with ancestor fields.

Parameters:

Returns:

  • (nil)


239
240
241
242
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 239

def exclusions_create_v2(body, opts = {})
  exclusions_create_v2_with_http_info(body, opts)
  nil
end

#exclusions_create_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Create the exclusions, with ancestor fields.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 248

def exclusions_create_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_create_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.exclusions_create_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_create_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_create_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_delete_v2(ids, opts = {}) ⇒ nil

Delete the exclusions by id, with ancestor fields.

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    The comment why these exclusions were deleted

Returns:

  • (nil)


306
307
308
309
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 306

def exclusions_delete_v2(ids, opts = {})
  exclusions_delete_v2_with_http_info(ids, opts)
  nil
end

#exclusions_delete_v2_with_http_info(ids, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete the exclusions by id, with ancestor fields.

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :comment (String)

    The comment why these exclusions were deleted

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 316

def exclusions_delete_v2_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_delete_v2 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling MlExclusions.exclusions_delete_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)
  query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_delete_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_delete_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_get_all_v2(opts = {}) ⇒ nil

Get all exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


369
370
371
372
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 369

def exclusions_get_all_v2(opts = {})
  exclusions_get_all_v2_with_http_info(opts)
  nil
end

#exclusions_get_all_v2_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get all exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 377

def exclusions_get_all_v2_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_get_all_v2 ...'
  end
  # resource path
  local_var_path = '/exclusions/entities/all-exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_get_all_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_get_all_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_get_reports_v2(body, opts = {}) ⇒ nil

Create a report of ML exclusions scoped by the given filters

Parameters:

Returns:

  • (nil)


425
426
427
428
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 425

def exclusions_get_reports_v2(body, opts = {})
  exclusions_get_reports_v2_with_http_info(body, opts)
  nil
end

#exclusions_get_reports_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Create a report of ML exclusions scoped by the given filters

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 434

def exclusions_get_reports_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_get_reports_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.exclusions_get_reports_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusions/reports/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_get_reports_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_get_reports_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_get_v2(ids, opts = {}) ⇒ nil

Get the exclusions by id, with ancestor fields.

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


491
492
493
494
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 491

def exclusions_get_v2(ids, opts = {})
  exclusions_get_v2_with_http_info(ids, opts)
  nil
end

#exclusions_get_v2_with_http_info(ids, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get the exclusions by id, with ancestor fields.

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 500

def exclusions_get_v2_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_get_v2 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling MlExclusions.exclusions_get_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_get_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_get_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_perform_action_v2(action_name, body, opts = {}) ⇒ nil

Actions used to manipulate the content of exclusions, with ancestor fields.

Parameters:

  • action_name (String)

    The action to perform.

  • body (MsaspecAction)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


554
555
556
557
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 554

def exclusions_perform_action_v2(action_name, body, opts = {})
  exclusions_perform_action_v2_with_http_info(action_name, body, opts)
  nil
end

#exclusions_perform_action_v2_with_http_info(action_name, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Actions used to manipulate the content of exclusions, with ancestor fields.

Parameters:

  • action_name (String)

    The action to perform.

  • body (MsaspecAction)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 564

def exclusions_perform_action_v2_with_http_info(action_name, body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_perform_action_v2 ...'
  end
  # verify the required parameter 'action_name' is set
  if @api_client.config.client_side_validation && action_name.nil?
    fail ArgumentError, "Missing the required parameter 'action_name' when calling MlExclusions.exclusions_perform_action_v2"
  end
  # verify enum value
  allowable_values = ["add_item", "remove_item", "validate_filepath"]
  if @api_client.config.client_side_validation && !allowable_values.include?(action_name)
    fail ArgumentError, "invalid value for \"action_name\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.exclusions_perform_action_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusion-actions/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'action_name'] = action_name

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_perform_action_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_perform_action_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_search_v2(opts = {}) ⇒ nil

Search for exclusions, with ancestor fields.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-500]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:

  • (nil)


634
635
636
637
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 634

def exclusions_search_v2(opts = {})
  exclusions_search_v2_with_http_info(opts)
  nil
end

#exclusions_search_v2_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Search for exclusions, with ancestor fields.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-500]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 646

def exclusions_search_v2_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_search_v2 ...'
  end
  allowable_values = ["parent_value", "value", "grandparent_value", "applied_globally", "created_on", "created_by", "last_modified", "modified_by", "is_descendant_process"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/exclusions/queries/exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_search_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_search_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#exclusions_update_v2(body, opts = {}) ⇒ nil

Update the exclusions by id, with ancestor fields.

Parameters:

Returns:

  • (nil)


702
703
704
705
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 702

def exclusions_update_v2(body, opts = {})
  exclusions_update_v2_with_http_info(body, opts)
  nil
end

#exclusions_update_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update the exclusions by id, with ancestor fields.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 711

def exclusions_update_v2_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.exclusions_update_v2 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.exclusions_update_v2"
  end
  # resource path
  local_var_path = '/exclusions/entities/exclusions/v2'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.exclusions_update_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#exclusions_update_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_ml_exclusions_v1(ids, opts = {}) ⇒ ExclusionsRespV1

Get a set of ML Exclusions by specifying their IDs

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



768
769
770
771
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 768

def get_ml_exclusions_v1(ids, opts = {})
  data, _status_code, _headers = get_ml_exclusions_v1_with_http_info(ids, opts)
  data
end

#get_ml_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(ExclusionsRespV1, Integer, Hash)>

Get a set of ML Exclusions by specifying their IDs

Parameters:

  • ids (Array<String>)

    The ids of the exclusions to retrieve

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ExclusionsRespV1, Integer, Hash)>)

    ExclusionsRespV1 data, response status code and response headers



777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 777

def get_ml_exclusions_v1_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.get_ml_exclusions_v1 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling MlExclusions.get_ml_exclusions_v1"
  end
  # resource path
  local_var_path = '/policy/entities/ml-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ExclusionsRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.get_ml_exclusions_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#get_ml_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#query_ml_exclusions_v1(opts = {}) ⇒ MsaspecQueryResponse

Search for ML exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-500]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:



833
834
835
836
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 833

def query_ml_exclusions_v1(opts = {})
  data, _status_code, _headers = query_ml_exclusions_v1_with_http_info(opts)
  data
end

#query_ml_exclusions_v1_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Search for ML exclusions.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    The filter expression that should be used to limit the results.

  • :offset (Integer)

    The offset to start retrieving records from

  • :limit (Integer)

    The maximum records to return. [1-500]

  • :sort (String)

    The sort expression that should be used to sort the results.

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 845

def query_ml_exclusions_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.query_ml_exclusions_v1 ...'
  end
  allowable_values = ["applied_globally.asc", "applied_globally.desc", "created_by.asc", "created_by.desc", "created_on.asc", "created_on.desc", "last_modified.asc", "last_modified.desc", "modified_by.asc", "modified_by.desc", "value.asc", "value.desc"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/policy/queries/ml-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.query_ml_exclusions_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#query_ml_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_ml_exclusions_v1(body, opts = {}) ⇒ ExclusionsRespV1

Update the ML exclusions

Parameters:

Returns:



901
902
903
904
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 901

def update_ml_exclusions_v1(body, opts = {})
  data, _status_code, _headers = update_ml_exclusions_v1_with_http_info(body, opts)
  data
end

#update_ml_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(ExclusionsRespV1, Integer, Hash)>

Update the ML exclusions

Parameters:

Returns:

  • (Array<(ExclusionsRespV1, Integer, Hash)>)

    ExclusionsRespV1 data, response status code and response headers



910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
# File 'lib/crimson-falcon/api/ml_exclusions.rb', line 910

def update_ml_exclusions_v1_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MlExclusions.update_ml_exclusions_v1 ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling MlExclusions.update_ml_exclusions_v1"
  end
  # resource path
  local_var_path = '/policy/entities/ml-exclusions/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'ExclusionsRespV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"MlExclusions.update_ml_exclusions_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MlExclusions#update_ml_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end