Class: Falcon::ModelArgument
- Inherits:
-
Object
- Object
- Falcon::ModelArgument
- Defined in:
- lib/crimson-falcon/models/model_argument.rb
Instance Attribute Summary collapse
-
#arg_name ⇒ Object
Returns the value of attribute arg_name.
-
#arg_type ⇒ Object
Returns the value of attribute arg_type.
-
#command_level ⇒ Object
Returns the value of attribute command_level.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#data_type ⇒ Object
Returns the value of attribute data_type.
-
#default_value ⇒ Object
Returns the value of attribute default_value.
-
#description ⇒ Object
Returns the value of attribute description.
-
#encoding ⇒ Object
Returns the value of attribute encoding.
-
#id ⇒ Object
Returns the value of attribute id.
-
#options ⇒ Object
Returns the value of attribute options.
-
#required ⇒ Object
Returns the value of attribute required.
-
#requires_value ⇒ Object
Returns the value of attribute requires_value.
-
#script_id ⇒ Object
Returns the value of attribute script_id.
-
#sequence ⇒ Object
Returns the value of attribute sequence.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelArgument
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelArgument
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelArgument` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelArgument`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'arg_name') self.arg_name = attributes[:'arg_name'] end if attributes.key?(:'arg_type') self.arg_type = attributes[:'arg_type'] end if attributes.key?(:'command_level') self.command_level = attributes[:'command_level'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] end if attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'encoding') self.encoding = attributes[:'encoding'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end end if attributes.key?(:'required') self.required = attributes[:'required'] end if attributes.key?(:'requires_value') self.requires_value = attributes[:'requires_value'] end if attributes.key?(:'script_id') self.script_id = attributes[:'script_id'] end if attributes.key?(:'sequence') self.sequence = attributes[:'sequence'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#arg_name ⇒ Object
Returns the value of attribute arg_name.
34 35 36 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 34 def arg_name @arg_name end |
#arg_type ⇒ Object
Returns the value of attribute arg_type.
36 37 38 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 36 def arg_type @arg_type end |
#command_level ⇒ Object
Returns the value of attribute command_level.
38 39 40 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 38 def command_level @command_level end |
#created_at ⇒ Object
Returns the value of attribute created_at.
40 41 42 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 40 def created_at @created_at end |
#data_type ⇒ Object
Returns the value of attribute data_type.
42 43 44 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 42 def data_type @data_type end |
#default_value ⇒ Object
Returns the value of attribute default_value.
44 45 46 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 44 def default_value @default_value end |
#description ⇒ Object
Returns the value of attribute description.
46 47 48 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 46 def description @description end |
#encoding ⇒ Object
Returns the value of attribute encoding.
48 49 50 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 48 def encoding @encoding end |
#id ⇒ Object
Returns the value of attribute id.
50 51 52 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 50 def id @id end |
#options ⇒ Object
Returns the value of attribute options.
52 53 54 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 52 def @options end |
#required ⇒ Object
Returns the value of attribute required.
54 55 56 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 54 def required @required end |
#requires_value ⇒ Object
Returns the value of attribute requires_value.
56 57 58 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 56 def requires_value @requires_value end |
#script_id ⇒ Object
Returns the value of attribute script_id.
58 59 60 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 58 def script_id @script_id end |
#sequence ⇒ Object
Returns the value of attribute sequence.
60 61 62 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 60 def sequence @sequence end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
62 63 64 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 62 def updated_at @updated_at end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 65 def self.attribute_map { :'arg_name' => :'arg_name', :'arg_type' => :'arg_type', :'command_level' => :'command_level', :'created_at' => :'created_at', :'data_type' => :'data_type', :'default_value' => :'default_value', :'description' => :'description', :'encoding' => :'encoding', :'id' => :'id', :'options' => :'options', :'required' => :'required', :'requires_value' => :'requires_value', :'script_id' => :'script_id', :'sequence' => :'sequence', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 320 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 91 def self.openapi_types { :'arg_name' => :'String', :'arg_type' => :'String', :'command_level' => :'String', :'created_at' => :'Time', :'data_type' => :'String', :'default_value' => :'String', :'description' => :'String', :'encoding' => :'String', :'id' => :'Integer', :'options' => :'Array<String>', :'required' => :'Boolean', :'requires_value' => :'Boolean', :'script_id' => :'Integer', :'sequence' => :'Integer', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && arg_name == o.arg_name && arg_type == o.arg_type && command_level == o.command_level && created_at == o.created_at && data_type == o.data_type && default_value == o.default_value && description == o.description && encoding == o.encoding && id == o.id && == o. && required == o.required && requires_value == o.requires_value && script_id == o.script_id && sequence == o.sequence && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 351 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 313 def hash [arg_name, arg_type, command_level, created_at, data_type, default_value, description, encoding, id, , required, requires_value, script_id, sequence, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 197 def list_invalid_properties invalid_properties = Array.new if @arg_name.nil? invalid_properties.push('invalid value for "arg_name", arg_name cannot be nil.') end if @arg_type.nil? invalid_properties.push('invalid value for "arg_type", arg_type cannot be nil.') end if @command_level.nil? invalid_properties.push('invalid value for "command_level", command_level cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @data_type.nil? invalid_properties.push('invalid value for "data_type", data_type cannot be nil.') end if @default_value.nil? invalid_properties.push('invalid value for "default_value", default_value cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @encoding.nil? invalid_properties.push('invalid value for "encoding", encoding cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @options.nil? invalid_properties.push('invalid value for "options", options cannot be nil.') end if @required.nil? invalid_properties.push('invalid value for "required", required cannot be nil.') end if @requires_value.nil? invalid_properties.push('invalid value for "requires_value", requires_value cannot be nil.') end if @script_id.nil? invalid_properties.push('invalid value for "script_id", script_id cannot be nil.') end if @sequence.nil? invalid_properties.push('invalid value for "sequence", sequence cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
398 399 400 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 398 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 392 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/crimson-falcon/models/model_argument.rb', line 264 def valid? return false if @arg_name.nil? return false if @arg_type.nil? return false if @command_level.nil? return false if @created_at.nil? return false if @data_type.nil? return false if @default_value.nil? return false if @description.nil? return false if @encoding.nil? return false if @id.nil? return false if @options.nil? return false if @required.nil? return false if @requires_value.nil? return false if @script_id.nil? return false if @sequence.nil? return false if @updated_at.nil? true end |