Class: Falcon::ModelUserInputViewModel

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/model_user_input_view_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelUserInputViewModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelUserInputViewModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelUserInputViewModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allowed_inputs')
    if (value = attributes[:'allowed_inputs']).is_a?(Array)
      self.allowed_inputs = value
    end
  end

  if attributes.key?(:'allowed_responders')
    if (value = attributes[:'allowed_responders']).is_a?(Array)
      self.allowed_responders = value
    end
  end

  if attributes.key?(:'completed')
    self.completed = attributes[:'completed']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'input')
    self.input = attributes[:'input']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'responder')
    self.responder = attributes[:'responder']
  end

  if attributes.key?(:'timeout_at')
    self.timeout_at = attributes[:'timeout_at']
  end
end

Instance Attribute Details

#allowed_inputsObject

if not empty, only listed inputs are allowed



35
36
37
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 35

def allowed_inputs
  @allowed_inputs
end

#allowed_respondersObject

if not empty, only listed responders are allowed to provide input



38
39
40
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 38

def allowed_responders
  @allowed_responders
end

#completedObject

whether or not the user input is completed yet



41
42
43
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 41

def completed
  @completed
end

#completed_atObject

time at which the user input was modified



44
45
46
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 44

def completed_at
  @completed_at
end

#created_atObject

time at which the user input was created



47
48
49
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 47

def created_at
  @created_at
end

#idObject

ID of the user input



50
51
52
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 50

def id
  @id
end

#inputObject

input provided by a responder user



53
54
55
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 53

def input
  @input
end

#noteObject

note added to user input at the time an input is provided



56
57
58
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 56

def note
  @note
end

#responderObject

user responding to the user input request



59
60
61
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 59

def responder
  @responder
end

#timeout_atObject

time after which the user input may be expired and no longer actionable



62
63
64
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 62

def timeout_at
  @timeout_at
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 65

def self.attribute_map
  {
    :'allowed_inputs' => :'allowed_inputs',
    :'allowed_responders' => :'allowed_responders',
    :'completed' => :'completed',
    :'completed_at' => :'completed_at',
    :'created_at' => :'created_at',
    :'id' => :'id',
    :'input' => :'input',
    :'note' => :'note',
    :'responder' => :'responder',
    :'timeout_at' => :'timeout_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 262

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 86

def self.openapi_types
  {
    :'allowed_inputs' => :'Array<String>',
    :'allowed_responders' => :'Array<String>',
    :'completed' => :'Boolean',
    :'completed_at' => :'Time',
    :'created_at' => :'Time',
    :'id' => :'String',
    :'input' => :'String',
    :'note' => :'String',
    :'responder' => :'String',
    :'timeout_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_inputs == o.allowed_inputs &&
      allowed_responders == o.allowed_responders &&
      completed == o.completed &&
      completed_at == o.completed_at &&
      created_at == o.created_at &&
      id == o.id &&
      input == o.input &&
      note == o.note &&
      responder == o.responder &&
      timeout_at == o.timeout_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 293

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 269

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 255

def hash
  [allowed_inputs, allowed_responders, completed, completed_at, created_at, id, input, note, responder, timeout_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  if @allowed_inputs.nil?
    invalid_properties.push('invalid value for "allowed_inputs", allowed_inputs cannot be nil.')
  end

  if @allowed_responders.nil?
    invalid_properties.push('invalid value for "allowed_responders", allowed_responders cannot be nil.')
  end

  if @completed.nil?
    invalid_properties.push('invalid value for "completed", completed cannot be nil.')
  end

  if @completed_at.nil?
    invalid_properties.push('invalid value for "completed_at", completed_at cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @input.nil?
    invalid_properties.push('invalid value for "input", input cannot be nil.')
  end

  if @note.nil?
    invalid_properties.push('invalid value for "note", note cannot be nil.')
  end

  if @responder.nil?
    invalid_properties.push('invalid value for "responder", responder cannot be nil.')
  end

  if @timeout_at.nil?
    invalid_properties.push('invalid value for "timeout_at", timeout_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/crimson-falcon/models/model_user_input_view_model.rb', line 216

def valid?
  return false if @allowed_inputs.nil?
  return false if @allowed_responders.nil?
  return false if @completed.nil?
  return false if @completed_at.nil?
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @input.nil?
  return false if @note.nil?
  return false if @responder.nil?
  return false if @timeout_at.nil?
  true
end