Class: Falcon::ModelsAPIDetectionResponse
- Inherits:
-
Object
- Object
- Falcon::ModelsAPIDetectionResponse
- Defined in:
- lib/crimson-falcon/models/models_api_detection_response.rb
Instance Attribute Summary collapse
-
#detection_uuid ⇒ Object
Returns the value of attribute detection_uuid.
-
#file_name ⇒ Object
Returns the value of attribute file_name.
-
#last_detected ⇒ Object
Returns the value of attribute last_detected.
-
#misconfigured_line ⇒ Object
Returns the value of attribute misconfigured_line.
-
#project_name ⇒ Object
Returns the value of attribute project_name.
-
#project_owners ⇒ Object
Returns the value of attribute project_owners.
-
#project_ref ⇒ Object
Returns the value of attribute project_ref.
-
#remediation ⇒ Object
Returns the value of attribute remediation.
-
#resource_name ⇒ Object
Returns the value of attribute resource_name.
-
#resource_type ⇒ Object
Returns the value of attribute resource_type.
-
#rule ⇒ Object
Returns the value of attribute rule.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsAPIDetectionResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsAPIDetectionResponse
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsAPIDetectionResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsAPIDetectionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'detection_uuid') self.detection_uuid = attributes[:'detection_uuid'] end if attributes.key?(:'file_name') self.file_name = attributes[:'file_name'] end if attributes.key?(:'last_detected') self.last_detected = attributes[:'last_detected'] end if attributes.key?(:'misconfigured_line') self.misconfigured_line = attributes[:'misconfigured_line'] end if attributes.key?(:'project_name') self.project_name = attributes[:'project_name'] end if attributes.key?(:'project_owners') if (value = attributes[:'project_owners']).is_a?(Array) self.project_owners = value end end if attributes.key?(:'project_ref') self.project_ref = attributes[:'project_ref'] end if attributes.key?(:'remediation') self.remediation = attributes[:'remediation'] end if attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end end |
Instance Attribute Details
#detection_uuid ⇒ Object
Returns the value of attribute detection_uuid.
34 35 36 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 34 def detection_uuid @detection_uuid end |
#file_name ⇒ Object
Returns the value of attribute file_name.
36 37 38 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 36 def file_name @file_name end |
#last_detected ⇒ Object
Returns the value of attribute last_detected.
38 39 40 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 38 def last_detected @last_detected end |
#misconfigured_line ⇒ Object
Returns the value of attribute misconfigured_line.
40 41 42 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 40 def misconfigured_line @misconfigured_line end |
#project_name ⇒ Object
Returns the value of attribute project_name.
42 43 44 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 42 def project_name @project_name end |
#project_owners ⇒ Object
Returns the value of attribute project_owners.
44 45 46 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 44 def project_owners @project_owners end |
#project_ref ⇒ Object
Returns the value of attribute project_ref.
46 47 48 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 46 def project_ref @project_ref end |
#remediation ⇒ Object
Returns the value of attribute remediation.
48 49 50 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 48 def remediation @remediation end |
#resource_name ⇒ Object
Returns the value of attribute resource_name.
50 51 52 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 50 def resource_name @resource_name end |
#resource_type ⇒ Object
Returns the value of attribute resource_type.
52 53 54 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 52 def resource_type @resource_type end |
#rule ⇒ Object
Returns the value of attribute rule.
54 55 56 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 54 def rule @rule end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 57 def self.attribute_map { :'detection_uuid' => :'detection_uuid', :'file_name' => :'file_name', :'last_detected' => :'last_detected', :'misconfigured_line' => :'misconfigured_line', :'project_name' => :'project_name', :'project_owners' => :'project_owners', :'project_ref' => :'project_ref', :'remediation' => :'remediation', :'resource_name' => :'resource_name', :'resource_type' => :'resource_type', :'rule' => :'rule' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 264 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 79 def self.openapi_types { :'detection_uuid' => :'String', :'file_name' => :'String', :'last_detected' => :'Time', :'misconfigured_line' => :'Integer', :'project_name' => :'String', :'project_owners' => :'Array<String>', :'project_ref' => :'String', :'remediation' => :'Remediation', :'resource_name' => :'String', :'resource_type' => :'String', :'rule' => :'Rule' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && detection_uuid == o.detection_uuid && file_name == o.file_name && last_detected == o.last_detected && misconfigured_line == o.misconfigured_line && project_name == o.project_name && project_owners == o.project_owners && project_ref == o.project_ref && remediation == o.remediation && resource_name == o.resource_name && resource_type == o.resource_type && rule == o.rule end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 295 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 366 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 271 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 257 def hash [detection_uuid, file_name, last_detected, misconfigured_line, project_name, project_owners, project_ref, remediation, resource_name, resource_type, rule].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 165 def list_invalid_properties invalid_properties = Array.new if @detection_uuid.nil? invalid_properties.push('invalid value for "detection_uuid", detection_uuid cannot be nil.') end if @file_name.nil? invalid_properties.push('invalid value for "file_name", file_name cannot be nil.') end if @last_detected.nil? invalid_properties.push('invalid value for "last_detected", last_detected cannot be nil.') end if @misconfigured_line.nil? invalid_properties.push('invalid value for "misconfigured_line", misconfigured_line cannot be nil.') end if @project_name.nil? invalid_properties.push('invalid value for "project_name", project_name cannot be nil.') end if @project_owners.nil? invalid_properties.push('invalid value for "project_owners", project_owners cannot be nil.') end if @project_ref.nil? invalid_properties.push('invalid value for "project_ref", project_ref cannot be nil.') end if @remediation.nil? invalid_properties.push('invalid value for "remediation", remediation cannot be nil.') end if @resource_name.nil? invalid_properties.push('invalid value for "resource_name", resource_name cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @rule.nil? invalid_properties.push('invalid value for "rule", rule cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
342 343 344 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 342 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 336 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/crimson-falcon/models/models_api_detection_response.rb', line 216 def valid? return false if @detection_uuid.nil? return false if @file_name.nil? return false if @last_detected.nil? return false if @misconfigured_line.nil? return false if @project_name.nil? return false if @project_owners.nil? return false if @project_ref.nil? return false if @remediation.nil? return false if @resource_name.nil? return false if @resource_type.nil? return false if @rule.nil? true end |