Class: Falcon::ModelsAPIImageCombinedExport

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/models_api_image_combined_export.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelsAPIImageCombinedExport

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 199

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsAPIImageCombinedExport` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsAPIImageCombinedExport`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ai_related')
    self.ai_related = attributes[:'ai_related']
  end

  if attributes.key?(:'architecture')
    self.architecture = attributes[:'architecture']
  end

  if attributes.key?(:'base_os')
    self.base_os = attributes[:'base_os']
  end

  if attributes.key?(:'business_impact')
    if (value = attributes[:'business_impact']).is_a?(Array)
      self.business_impact = value
    end
  end

  if attributes.key?(:'business_unit')
    if (value = attributes[:'business_unit']).is_a?(Array)
      self.business_unit = value
    end
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_groups_v2')
    if (value = attributes[:'cloud_groups_v2']).is_a?(Array)
      self.cloud_groups_v2 = value
    end
  end

  if attributes.key?(:'cve_exploited_status')
    self.cve_exploited_status = attributes[:'cve_exploited_status']
  end

  if attributes.key?(:'cve_first_seen')
    self.cve_first_seen = attributes[:'cve_first_seen']
  end

  if attributes.key?(:'cve_id')
    self.cve_id = attributes[:'cve_id']
  end

  if attributes.key?(:'cve_publication_date')
    self.cve_publication_date = attributes[:'cve_publication_date']
  end

  if attributes.key?(:'cvss_score')
    self.cvss_score = attributes[:'cvss_score']
  end

  if attributes.key?(:'detection_name')
    self.detection_name = attributes[:'detection_name']
  end

  if attributes.key?(:'detection_severity')
    self.detection_severity = attributes[:'detection_severity']
  end

  if attributes.key?(:'detection_type')
    self.detection_type = attributes[:'detection_type']
  end

  if attributes.key?(:'environment')
    if (value = attributes[:'environment']).is_a?(Array)
      self.environment = value
    end
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'image_build_date')
    self.image_build_date = attributes[:'image_build_date']
  end

  if attributes.key?(:'image_digest')
    self.image_digest = attributes[:'image_digest']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'index_digest')
    self.index_digest = attributes[:'index_digest']
  end

  if attributes.key?(:'is_base_image')
    self.is_base_image = attributes[:'is_base_image']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'package_name_version')
    self.package_name_version = attributes[:'package_name_version']
  end

  if attributes.key?(:'packages_impacted')
    self.packages_impacted = attributes[:'packages_impacted']
  end

  if attributes.key?(:'registry')
    self.registry = attributes[:'registry']
  end

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'started_containers')
    self.started_containers = attributes[:'started_containers']
  end

  if attributes.key?(:'stopped_containers')
    self.stopped_containers = attributes[:'stopped_containers']
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'vulnerability_cps_rating')
    self.vulnerability_cps_rating = attributes[:'vulnerability_cps_rating']
  end

  if attributes.key?(:'vulnerability_description')
    self.vulnerability_description = attributes[:'vulnerability_description']
  end

  if attributes.key?(:'vulnerability_severity')
    self.vulnerability_severity = attributes[:'vulnerability_severity']
  end
end

Instance Attribute Details

Returns the value of attribute ai_related.



34
35
36
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 34

def ai_related
  @ai_related
end

#architectureObject

Returns the value of attribute architecture.



36
37
38
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 36

def architecture
  @architecture
end

#base_osObject

Returns the value of attribute base_os.



38
39
40
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 38

def base_os
  @base_os
end

#business_impactObject

Returns the value of attribute business_impact.



40
41
42
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 40

def business_impact
  @business_impact
end

#business_unitObject

Returns the value of attribute business_unit.



42
43
44
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 42

def business_unit
  @business_unit
end

#cidObject

Returns the value of attribute cid.



44
45
46
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 44

def cid
  @cid
end

#cloud_groups_v2Object

Returns the value of attribute cloud_groups_v2.



46
47
48
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 46

def cloud_groups_v2
  @cloud_groups_v2
end

#cve_exploited_statusObject

Returns the value of attribute cve_exploited_status.



48
49
50
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 48

def cve_exploited_status
  @cve_exploited_status
end

#cve_first_seenObject

Returns the value of attribute cve_first_seen.



50
51
52
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 50

def cve_first_seen
  @cve_first_seen
end

#cve_idObject

Returns the value of attribute cve_id.



52
53
54
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 52

def cve_id
  @cve_id
end

#cve_publication_dateObject

Returns the value of attribute cve_publication_date.



54
55
56
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 54

def cve_publication_date
  @cve_publication_date
end

#cvss_scoreObject

Returns the value of attribute cvss_score.



56
57
58
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 56

def cvss_score
  @cvss_score
end

#detection_nameObject

Returns the value of attribute detection_name.



58
59
60
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 58

def detection_name
  @detection_name
end

#detection_severityObject

Returns the value of attribute detection_severity.



60
61
62
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 60

def detection_severity
  @detection_severity
end

#detection_typeObject

Returns the value of attribute detection_type.



62
63
64
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 62

def detection_type
  @detection_type
end

#environmentObject

Returns the value of attribute environment.



64
65
66
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 64

def environment
  @environment
end

#first_seenObject

Returns the value of attribute first_seen.



66
67
68
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 66

def first_seen
  @first_seen
end

#groupsObject

Returns the value of attribute groups.



68
69
70
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 68

def groups
  @groups
end

#image_build_dateObject

Returns the value of attribute image_build_date.



70
71
72
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 70

def image_build_date
  @image_build_date
end

#image_digestObject

Returns the value of attribute image_digest.



72
73
74
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 72

def image_digest
  @image_digest
end

#image_idObject

Returns the value of attribute image_id.



74
75
76
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 74

def image_id
  @image_id
end

#index_digestObject

Returns the value of attribute index_digest.



76
77
78
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 76

def index_digest
  @index_digest
end

#is_base_imageObject

Returns the value of attribute is_base_image.



78
79
80
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 78

def is_base_image
  @is_base_image
end

#last_seenObject

Returns the value of attribute last_seen.



80
81
82
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 80

def last_seen
  @last_seen
end

#package_name_versionObject

Returns the value of attribute package_name_version.



82
83
84
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 82

def package_name_version
  @package_name_version
end

#packages_impactedObject

Returns the value of attribute packages_impacted.



84
85
86
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 84

def packages_impacted
  @packages_impacted
end

#registryObject

Returns the value of attribute registry.



86
87
88
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 86

def registry
  @registry
end

#repositoryObject

Returns the value of attribute repository.



88
89
90
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 88

def repository
  @repository
end

#sourceObject

Returns the value of attribute source.



90
91
92
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 90

def source
  @source
end

#started_containersObject

Returns the value of attribute started_containers.



92
93
94
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 92

def started_containers
  @started_containers
end

#stopped_containersObject

Returns the value of attribute stopped_containers.



94
95
96
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 94

def stopped_containers
  @stopped_containers
end

#tagObject

Returns the value of attribute tag.



96
97
98
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 96

def tag
  @tag
end

#vulnerability_cps_ratingObject

Returns the value of attribute vulnerability_cps_rating.



98
99
100
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 98

def vulnerability_cps_rating
  @vulnerability_cps_rating
end

#vulnerability_descriptionObject

Returns the value of attribute vulnerability_description.



100
101
102
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 100

def vulnerability_description
  @vulnerability_description
end

#vulnerability_severityObject

Returns the value of attribute vulnerability_severity.



102
103
104
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 102

def vulnerability_severity
  @vulnerability_severity
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



146
147
148
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 146

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 105

def self.attribute_map
  {
    :'ai_related' => :'ai_related',
    :'architecture' => :'architecture',
    :'base_os' => :'base_os',
    :'business_impact' => :'business_impact',
    :'business_unit' => :'business_unit',
    :'cid' => :'cid',
    :'cloud_groups_v2' => :'cloud_groups_v2',
    :'cve_exploited_status' => :'cve_exploited_status',
    :'cve_first_seen' => :'cve_first_seen',
    :'cve_id' => :'cve_id',
    :'cve_publication_date' => :'cve_publication_date',
    :'cvss_score' => :'cvss_score',
    :'detection_name' => :'detection_name',
    :'detection_severity' => :'detection_severity',
    :'detection_type' => :'detection_type',
    :'environment' => :'environment',
    :'first_seen' => :'first_seen',
    :'groups' => :'groups',
    :'image_build_date' => :'image_build_date',
    :'image_digest' => :'image_digest',
    :'image_id' => :'image_id',
    :'index_digest' => :'index_digest',
    :'is_base_image' => :'is_base_image',
    :'last_seen' => :'last_seen',
    :'package_name_version' => :'package_name_version',
    :'packages_impacted' => :'packages_impacted',
    :'registry' => :'registry',
    :'repository' => :'repository',
    :'source' => :'source',
    :'started_containers' => :'started_containers',
    :'stopped_containers' => :'stopped_containers',
    :'tag' => :'tag',
    :'vulnerability_cps_rating' => :'vulnerability_cps_rating',
    :'vulnerability_description' => :'vulnerability_description',
    :'vulnerability_severity' => :'vulnerability_severity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



558
559
560
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 558

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



192
193
194
195
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 192

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 151

def self.openapi_types
  {
    :'ai_related' => :'Boolean',
    :'architecture' => :'String',
    :'base_os' => :'String',
    :'business_impact' => :'Array<String>',
    :'business_unit' => :'Array<String>',
    :'cid' => :'String',
    :'cloud_groups_v2' => :'Array<RbacCloudGroup>',
    :'cve_exploited_status' => :'Integer',
    :'cve_first_seen' => :'String',
    :'cve_id' => :'String',
    :'cve_publication_date' => :'String',
    :'cvss_score' => :'String',
    :'detection_name' => :'String',
    :'detection_severity' => :'String',
    :'detection_type' => :'String',
    :'environment' => :'Array<String>',
    :'first_seen' => :'String',
    :'groups' => :'Array<String>',
    :'image_build_date' => :'String',
    :'image_digest' => :'String',
    :'image_id' => :'String',
    :'index_digest' => :'String',
    :'is_base_image' => :'Boolean',
    :'last_seen' => :'String',
    :'package_name_version' => :'String',
    :'packages_impacted' => :'Integer',
    :'registry' => :'String',
    :'repository' => :'String',
    :'source' => :'String',
    :'started_containers' => :'Integer',
    :'stopped_containers' => :'Integer',
    :'tag' => :'String',
    :'vulnerability_cps_rating' => :'String',
    :'vulnerability_description' => :'String',
    :'vulnerability_severity' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 503

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ai_related == o.ai_related &&
      architecture == o.architecture &&
      base_os == o.base_os &&
      business_impact == o.business_impact &&
      business_unit == o.business_unit &&
      cid == o.cid &&
      cloud_groups_v2 == o.cloud_groups_v2 &&
      cve_exploited_status == o.cve_exploited_status &&
      cve_first_seen == o.cve_first_seen &&
      cve_id == o.cve_id &&
      cve_publication_date == o.cve_publication_date &&
      cvss_score == o.cvss_score &&
      detection_name == o.detection_name &&
      detection_severity == o.detection_severity &&
      detection_type == o.detection_type &&
      environment == o.environment &&
      first_seen == o.first_seen &&
      groups == o.groups &&
      image_build_date == o.image_build_date &&
      image_digest == o.image_digest &&
      image_id == o.image_id &&
      index_digest == o.index_digest &&
      is_base_image == o.is_base_image &&
      last_seen == o.last_seen &&
      package_name_version == o.package_name_version &&
      packages_impacted == o.packages_impacted &&
      registry == o.registry &&
      repository == o.repository &&
      source == o.source &&
      started_containers == o.started_containers &&
      stopped_containers == o.stopped_containers &&
      tag == o.tag &&
      vulnerability_cps_rating == o.vulnerability_cps_rating &&
      vulnerability_description == o.vulnerability_description &&
      vulnerability_severity == o.vulnerability_severity
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 589

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 660

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 565

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


545
546
547
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 545

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



551
552
553
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 551

def hash
  [ai_related, architecture, base_os, business_impact, business_unit, cid, cloud_groups_v2, cve_exploited_status, cve_first_seen, cve_id, cve_publication_date, cvss_score, detection_name, detection_severity, detection_type, environment, first_seen, groups, image_build_date, image_digest, image_id, index_digest, is_base_image, last_seen, package_name_version, packages_impacted, registry, repository, source, started_containers, stopped_containers, tag, vulnerability_cps_rating, vulnerability_description, vulnerability_severity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 365

def list_invalid_properties
  invalid_properties = Array.new
  if @ai_related.nil?
    invalid_properties.push('invalid value for "ai_related", ai_related cannot be nil.')
  end

  if @architecture.nil?
    invalid_properties.push('invalid value for "architecture", architecture cannot be nil.')
  end

  if @base_os.nil?
    invalid_properties.push('invalid value for "base_os", base_os cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @cve_id.nil?
    invalid_properties.push('invalid value for "cve_id", cve_id cannot be nil.')
  end

  if @cvss_score.nil?
    invalid_properties.push('invalid value for "cvss_score", cvss_score cannot be nil.')
  end

  if @detection_name.nil?
    invalid_properties.push('invalid value for "detection_name", detection_name cannot be nil.')
  end

  if @detection_severity.nil?
    invalid_properties.push('invalid value for "detection_severity", detection_severity cannot be nil.')
  end

  if @detection_type.nil?
    invalid_properties.push('invalid value for "detection_type", detection_type cannot be nil.')
  end

  if @first_seen.nil?
    invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.')
  end

  if @image_digest.nil?
    invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @index_digest.nil?
    invalid_properties.push('invalid value for "index_digest", index_digest cannot be nil.')
  end

  if @is_base_image.nil?
    invalid_properties.push('invalid value for "is_base_image", is_base_image cannot be nil.')
  end

  if @last_seen.nil?
    invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.')
  end

  if @packages_impacted.nil?
    invalid_properties.push('invalid value for "packages_impacted", packages_impacted cannot be nil.')
  end

  if @registry.nil?
    invalid_properties.push('invalid value for "registry", registry cannot be nil.')
  end

  if @repository.nil?
    invalid_properties.push('invalid value for "repository", repository cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @started_containers.nil?
    invalid_properties.push('invalid value for "started_containers", started_containers cannot be nil.')
  end

  if @stopped_containers.nil?
    invalid_properties.push('invalid value for "stopped_containers", stopped_containers cannot be nil.')
  end

  if @tag.nil?
    invalid_properties.push('invalid value for "tag", tag cannot be nil.')
  end

  if @vulnerability_cps_rating.nil?
    invalid_properties.push('invalid value for "vulnerability_cps_rating", vulnerability_cps_rating cannot be nil.')
  end

  if @vulnerability_description.nil?
    invalid_properties.push('invalid value for "vulnerability_description", vulnerability_description cannot be nil.')
  end

  if @vulnerability_severity.nil?
    invalid_properties.push('invalid value for "vulnerability_severity", vulnerability_severity cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



636
637
638
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 636

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



642
643
644
645
646
647
648
649
650
651
652
653
654
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 642

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



630
631
632
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 630

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/crimson-falcon/models/models_api_image_combined_export.rb', line 472

def valid?
  return false if @ai_related.nil?
  return false if @architecture.nil?
  return false if @base_os.nil?
  return false if @cid.nil?
  return false if @cve_id.nil?
  return false if @cvss_score.nil?
  return false if @detection_name.nil?
  return false if @detection_severity.nil?
  return false if @detection_type.nil?
  return false if @first_seen.nil?
  return false if @image_digest.nil?
  return false if @image_id.nil?
  return false if @index_digest.nil?
  return false if @is_base_image.nil?
  return false if @last_seen.nil?
  return false if @packages_impacted.nil?
  return false if @registry.nil?
  return false if @repository.nil?
  return false if @source.nil?
  return false if @started_containers.nil?
  return false if @stopped_containers.nil?
  return false if @tag.nil?
  return false if @vulnerability_cps_rating.nil?
  return false if @vulnerability_description.nil?
  return false if @vulnerability_severity.nil?
  true
end