Class: Falcon::ModelsAPIKubernetesIOM
- Inherits:
-
Object
- Object
- Falcon::ModelsAPIKubernetesIOM
- Defined in:
- lib/crimson-falcon/models/models_api_kubernetes_iom.rb
Instance Attribute Summary collapse
-
#admission_review_action ⇒ Object
Returns the value of attribute admission_review_action.
-
#admission_review_id ⇒ Object
Returns the value of attribute admission_review_id.
-
#admission_review_msg ⇒ Object
Returns the value of attribute admission_review_msg.
-
#admission_review_operation ⇒ Object
Returns the value of attribute admission_review_operation.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cis_id ⇒ Object
Returns the value of attribute cis_id.
-
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#containers_impacted_ai_related ⇒ Object
Returns the value of attribute containers_impacted_ai_related.
-
#containers_impacted_count ⇒ Object
Returns the value of attribute containers_impacted_count.
-
#containers_impacted_ids ⇒ Object
Returns the value of attribute containers_impacted_ids.
-
#custom_rego_uuid ⇒ Object
Returns the value of attribute custom_rego_uuid.
-
#description ⇒ Object
Returns the value of attribute description.
-
#detect_timestamp ⇒ Object
Returns the value of attribute detect_timestamp.
-
#detection_id ⇒ Object
Returns the value of attribute detection_id.
-
#detection_name ⇒ Object
Returns the value of attribute detection_name.
-
#detection_type ⇒ Object
Returns the value of attribute detection_type.
-
#image_assessment_matched_cves ⇒ Object
Returns the value of attribute image_assessment_matched_cves.
-
#image_assessment_policy_description ⇒ Object
Returns the value of attribute image_assessment_policy_description.
-
#image_assessment_policy_id ⇒ Object
Returns the value of attribute image_assessment_policy_id.
-
#image_assessment_policy_name ⇒ Object
Returns the value of attribute image_assessment_policy_name.
-
#image_digest ⇒ Object
Returns the value of attribute image_digest.
-
#image_has_been_assessed ⇒ Object
Returns the value of attribute image_has_been_assessed.
-
#image_id ⇒ Object
Returns the value of attribute image_id.
-
#image_registry ⇒ Object
Returns the value of attribute image_registry.
-
#image_repository ⇒ Object
Returns the value of attribute image_repository.
-
#image_tag ⇒ Object
Returns the value of attribute image_tag.
-
#last_seen_timestamp ⇒ Object
Returns the value of attribute last_seen_timestamp.
-
#mitigation_id ⇒ Object
Returns the value of attribute mitigation_id.
-
#mitigation_name ⇒ Object
Returns the value of attribute mitigation_name.
-
#namespace ⇒ Object
Returns the value of attribute namespace.
-
#nist_id ⇒ Object
Returns the value of attribute nist_id.
-
#pod_label ⇒ Object
Returns the value of attribute pod_label.
-
#pods_impacted_count ⇒ Object
Returns the value of attribute pods_impacted_count.
-
#policy_id ⇒ Object
Returns the value of attribute policy_id.
-
#policy_name ⇒ Object
Returns the value of attribute policy_name.
-
#ports ⇒ Object
Returns the value of attribute ports.
-
#prevented ⇒ Object
Returns the value of attribute prevented.
-
#remediation ⇒ Object
Returns the value of attribute remediation.
-
#resource_creation_timestamp ⇒ Object
Returns the value of attribute resource_creation_timestamp.
-
#resource_group_name ⇒ Object
Returns the value of attribute resource_group_name.
-
#resource_id ⇒ Object
Returns the value of attribute resource_id.
-
#resource_name ⇒ Object
Returns the value of attribute resource_name.
-
#resource_type ⇒ Object
Returns the value of attribute resource_type.
-
#sensitive_env_vars ⇒ Object
Returns the value of attribute sensitive_env_vars.
-
#service_type ⇒ Object
Returns the value of attribute service_type.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#tactic_id ⇒ Object
Returns the value of attribute tactic_id.
-
#tactic_name ⇒ Object
Returns the value of attribute tactic_name.
-
#technique_id ⇒ Object
Returns the value of attribute technique_id.
-
#technique_name ⇒ Object
Returns the value of attribute technique_name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsAPIKubernetesIOM
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsAPIKubernetesIOM
Initializes the object
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 263 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsAPIKubernetesIOM` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsAPIKubernetesIOM`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admission_review_action') self.admission_review_action = attributes[:'admission_review_action'] end if attributes.key?(:'admission_review_id') self.admission_review_id = attributes[:'admission_review_id'] end if attributes.key?(:'admission_review_msg') self.admission_review_msg = attributes[:'admission_review_msg'] end if attributes.key?(:'admission_review_operation') self.admission_review_operation = attributes[:'admission_review_operation'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cis_id') if (value = attributes[:'cis_id']).is_a?(Array) self.cis_id = value end end if attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end if attributes.key?(:'containers_impacted_ai_related') self. = attributes[:'containers_impacted_ai_related'] end if attributes.key?(:'containers_impacted_count') self.containers_impacted_count = attributes[:'containers_impacted_count'] end if attributes.key?(:'containers_impacted_ids') if (value = attributes[:'containers_impacted_ids']).is_a?(Array) self.containers_impacted_ids = value end end if attributes.key?(:'custom_rego_uuid') self.custom_rego_uuid = attributes[:'custom_rego_uuid'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'detect_timestamp') self. = attributes[:'detect_timestamp'] end if attributes.key?(:'detection_id') self.detection_id = attributes[:'detection_id'] end if attributes.key?(:'detection_name') self.detection_name = attributes[:'detection_name'] end if attributes.key?(:'detection_type') self.detection_type = attributes[:'detection_type'] end if attributes.key?(:'image_assessment_matched_cves') if (value = attributes[:'image_assessment_matched_cves']).is_a?(Array) self.image_assessment_matched_cves = value end end if attributes.key?(:'image_assessment_policy_description') self.image_assessment_policy_description = attributes[:'image_assessment_policy_description'] end if attributes.key?(:'image_assessment_policy_id') self.image_assessment_policy_id = attributes[:'image_assessment_policy_id'] end if attributes.key?(:'image_assessment_policy_name') self.image_assessment_policy_name = attributes[:'image_assessment_policy_name'] end if attributes.key?(:'image_digest') self.image_digest = attributes[:'image_digest'] end if attributes.key?(:'image_has_been_assessed') self.image_has_been_assessed = attributes[:'image_has_been_assessed'] end if attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] end if attributes.key?(:'image_registry') self.image_registry = attributes[:'image_registry'] end if attributes.key?(:'image_repository') self.image_repository = attributes[:'image_repository'] end if attributes.key?(:'image_tag') self.image_tag = attributes[:'image_tag'] end if attributes.key?(:'last_seen_timestamp') self. = attributes[:'last_seen_timestamp'] end if attributes.key?(:'mitigation_id') self.mitigation_id = attributes[:'mitigation_id'] end if attributes.key?(:'mitigation_name') self.mitigation_name = attributes[:'mitigation_name'] end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'nist_id') self.nist_id = attributes[:'nist_id'] end if attributes.key?(:'pod_label') self.pod_label = attributes[:'pod_label'] end if attributes.key?(:'pods_impacted_count') self.pods_impacted_count = attributes[:'pods_impacted_count'] end if attributes.key?(:'policy_id') self.policy_id = attributes[:'policy_id'] end if attributes.key?(:'policy_name') self.policy_name = attributes[:'policy_name'] end if attributes.key?(:'ports') if (value = attributes[:'ports']).is_a?(Array) self.ports = value end end if attributes.key?(:'prevented') self.prevented = attributes[:'prevented'] end if attributes.key?(:'remediation') self.remediation = attributes[:'remediation'] end if attributes.key?(:'resource_creation_timestamp') self. = attributes[:'resource_creation_timestamp'] end if attributes.key?(:'resource_group_name') self.resource_group_name = attributes[:'resource_group_name'] end if attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] end if attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] end if attributes.key?(:'sensitive_env_vars') if (value = attributes[:'sensitive_env_vars']).is_a?(Array) self.sensitive_env_vars = value end end if attributes.key?(:'service_type') self.service_type = attributes[:'service_type'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'tactic_id') self.tactic_id = attributes[:'tactic_id'] end if attributes.key?(:'tactic_name') self.tactic_name = attributes[:'tactic_name'] end if attributes.key?(:'technique_id') self.technique_id = attributes[:'technique_id'] end if attributes.key?(:'technique_name') self.technique_name = attributes[:'technique_name'] end end |
Instance Attribute Details
#admission_review_action ⇒ Object
Returns the value of attribute admission_review_action.
34 35 36 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 34 def admission_review_action @admission_review_action end |
#admission_review_id ⇒ Object
Returns the value of attribute admission_review_id.
36 37 38 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 36 def admission_review_id @admission_review_id end |
#admission_review_msg ⇒ Object
Returns the value of attribute admission_review_msg.
38 39 40 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 38 def admission_review_msg @admission_review_msg end |
#admission_review_operation ⇒ Object
Returns the value of attribute admission_review_operation.
40 41 42 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 40 def admission_review_operation @admission_review_operation end |
#cid ⇒ Object
Returns the value of attribute cid.
42 43 44 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 42 def cid @cid end |
#cis_id ⇒ Object
Returns the value of attribute cis_id.
44 45 46 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 44 def cis_id @cis_id end |
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
46 47 48 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 46 def cluster_id @cluster_id end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
48 49 50 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 48 def cluster_name @cluster_name end |
#containers_impacted_ai_related ⇒ Object
Returns the value of attribute containers_impacted_ai_related.
50 51 52 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 50 def @containers_impacted_ai_related end |
#containers_impacted_count ⇒ Object
Returns the value of attribute containers_impacted_count.
52 53 54 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 52 def containers_impacted_count @containers_impacted_count end |
#containers_impacted_ids ⇒ Object
Returns the value of attribute containers_impacted_ids.
54 55 56 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 54 def containers_impacted_ids @containers_impacted_ids end |
#custom_rego_uuid ⇒ Object
Returns the value of attribute custom_rego_uuid.
56 57 58 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 56 def custom_rego_uuid @custom_rego_uuid end |
#description ⇒ Object
Returns the value of attribute description.
58 59 60 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 58 def description @description end |
#detect_timestamp ⇒ Object
Returns the value of attribute detect_timestamp.
60 61 62 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 60 def @detect_timestamp end |
#detection_id ⇒ Object
Returns the value of attribute detection_id.
62 63 64 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 62 def detection_id @detection_id end |
#detection_name ⇒ Object
Returns the value of attribute detection_name.
64 65 66 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 64 def detection_name @detection_name end |
#detection_type ⇒ Object
Returns the value of attribute detection_type.
66 67 68 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 66 def detection_type @detection_type end |
#image_assessment_matched_cves ⇒ Object
Returns the value of attribute image_assessment_matched_cves.
68 69 70 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 68 def image_assessment_matched_cves @image_assessment_matched_cves end |
#image_assessment_policy_description ⇒ Object
Returns the value of attribute image_assessment_policy_description.
70 71 72 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 70 def image_assessment_policy_description @image_assessment_policy_description end |
#image_assessment_policy_id ⇒ Object
Returns the value of attribute image_assessment_policy_id.
72 73 74 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 72 def image_assessment_policy_id @image_assessment_policy_id end |
#image_assessment_policy_name ⇒ Object
Returns the value of attribute image_assessment_policy_name.
74 75 76 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 74 def image_assessment_policy_name @image_assessment_policy_name end |
#image_digest ⇒ Object
Returns the value of attribute image_digest.
76 77 78 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 76 def image_digest @image_digest end |
#image_has_been_assessed ⇒ Object
Returns the value of attribute image_has_been_assessed.
78 79 80 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 78 def image_has_been_assessed @image_has_been_assessed end |
#image_id ⇒ Object
Returns the value of attribute image_id.
80 81 82 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 80 def image_id @image_id end |
#image_registry ⇒ Object
Returns the value of attribute image_registry.
82 83 84 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 82 def image_registry @image_registry end |
#image_repository ⇒ Object
Returns the value of attribute image_repository.
84 85 86 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 84 def image_repository @image_repository end |
#image_tag ⇒ Object
Returns the value of attribute image_tag.
86 87 88 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 86 def image_tag @image_tag end |
#last_seen_timestamp ⇒ Object
Returns the value of attribute last_seen_timestamp.
88 89 90 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 88 def @last_seen_timestamp end |
#mitigation_id ⇒ Object
Returns the value of attribute mitigation_id.
90 91 92 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 90 def mitigation_id @mitigation_id end |
#mitigation_name ⇒ Object
Returns the value of attribute mitigation_name.
92 93 94 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 92 def mitigation_name @mitigation_name end |
#namespace ⇒ Object
Returns the value of attribute namespace.
94 95 96 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 94 def namespace @namespace end |
#nist_id ⇒ Object
Returns the value of attribute nist_id.
96 97 98 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 96 def nist_id @nist_id end |
#pod_label ⇒ Object
Returns the value of attribute pod_label.
98 99 100 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 98 def pod_label @pod_label end |
#pods_impacted_count ⇒ Object
Returns the value of attribute pods_impacted_count.
100 101 102 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 100 def pods_impacted_count @pods_impacted_count end |
#policy_id ⇒ Object
Returns the value of attribute policy_id.
102 103 104 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 102 def policy_id @policy_id end |
#policy_name ⇒ Object
Returns the value of attribute policy_name.
104 105 106 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 104 def policy_name @policy_name end |
#ports ⇒ Object
Returns the value of attribute ports.
106 107 108 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 106 def ports @ports end |
#prevented ⇒ Object
Returns the value of attribute prevented.
108 109 110 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 108 def prevented @prevented end |
#remediation ⇒ Object
Returns the value of attribute remediation.
110 111 112 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 110 def remediation @remediation end |
#resource_creation_timestamp ⇒ Object
Returns the value of attribute resource_creation_timestamp.
112 113 114 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 112 def @resource_creation_timestamp end |
#resource_group_name ⇒ Object
Returns the value of attribute resource_group_name.
114 115 116 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 114 def resource_group_name @resource_group_name end |
#resource_id ⇒ Object
Returns the value of attribute resource_id.
116 117 118 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 116 def resource_id @resource_id end |
#resource_name ⇒ Object
Returns the value of attribute resource_name.
118 119 120 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 118 def resource_name @resource_name end |
#resource_type ⇒ Object
Returns the value of attribute resource_type.
120 121 122 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 120 def resource_type @resource_type end |
#sensitive_env_vars ⇒ Object
Returns the value of attribute sensitive_env_vars.
122 123 124 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 122 def sensitive_env_vars @sensitive_env_vars end |
#service_type ⇒ Object
Returns the value of attribute service_type.
124 125 126 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 124 def service_type @service_type end |
#severity ⇒ Object
Returns the value of attribute severity.
126 127 128 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 126 def severity @severity end |
#tactic_id ⇒ Object
Returns the value of attribute tactic_id.
128 129 130 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 128 def tactic_id @tactic_id end |
#tactic_name ⇒ Object
Returns the value of attribute tactic_name.
130 131 132 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 130 def tactic_name @tactic_name end |
#technique_id ⇒ Object
Returns the value of attribute technique_id.
132 133 134 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 132 def technique_id @technique_id end |
#technique_name ⇒ Object
Returns the value of attribute technique_name.
134 135 136 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 134 def technique_name @technique_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
194 195 196 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 194 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 137 def self.attribute_map { :'admission_review_action' => :'admission_review_action', :'admission_review_id' => :'admission_review_id', :'admission_review_msg' => :'admission_review_msg', :'admission_review_operation' => :'admission_review_operation', :'cid' => :'cid', :'cis_id' => :'cis_id', :'cluster_id' => :'cluster_id', :'cluster_name' => :'cluster_name', :'containers_impacted_ai_related' => :'containers_impacted_ai_related', :'containers_impacted_count' => :'containers_impacted_count', :'containers_impacted_ids' => :'containers_impacted_ids', :'custom_rego_uuid' => :'custom_rego_uuid', :'description' => :'description', :'detect_timestamp' => :'detect_timestamp', :'detection_id' => :'detection_id', :'detection_name' => :'detection_name', :'detection_type' => :'detection_type', :'image_assessment_matched_cves' => :'image_assessment_matched_cves', :'image_assessment_policy_description' => :'image_assessment_policy_description', :'image_assessment_policy_id' => :'image_assessment_policy_id', :'image_assessment_policy_name' => :'image_assessment_policy_name', :'image_digest' => :'image_digest', :'image_has_been_assessed' => :'image_has_been_assessed', :'image_id' => :'image_id', :'image_registry' => :'image_registry', :'image_repository' => :'image_repository', :'image_tag' => :'image_tag', :'last_seen_timestamp' => :'last_seen_timestamp', :'mitigation_id' => :'mitigation_id', :'mitigation_name' => :'mitigation_name', :'namespace' => :'namespace', :'nist_id' => :'nist_id', :'pod_label' => :'pod_label', :'pods_impacted_count' => :'pods_impacted_count', :'policy_id' => :'policy_id', :'policy_name' => :'policy_name', :'ports' => :'ports', :'prevented' => :'prevented', :'remediation' => :'remediation', :'resource_creation_timestamp' => :'resource_creation_timestamp', :'resource_group_name' => :'resource_group_name', :'resource_id' => :'resource_id', :'resource_name' => :'resource_name', :'resource_type' => :'resource_type', :'sensitive_env_vars' => :'sensitive_env_vars', :'service_type' => :'service_type', :'severity' => :'severity', :'tactic_id' => :'tactic_id', :'tactic_name' => :'tactic_name', :'technique_id' => :'technique_id', :'technique_name' => :'technique_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
697 698 699 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 697 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
256 257 258 259 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 256 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 199 def self.openapi_types { :'admission_review_action' => :'String', :'admission_review_id' => :'String', :'admission_review_msg' => :'String', :'admission_review_operation' => :'String', :'cid' => :'String', :'cis_id' => :'Array<String>', :'cluster_id' => :'String', :'cluster_name' => :'String', :'containers_impacted_ai_related' => :'Boolean', :'containers_impacted_count' => :'String', :'containers_impacted_ids' => :'Array<String>', :'custom_rego_uuid' => :'String', :'description' => :'String', :'detect_timestamp' => :'String', :'detection_id' => :'String', :'detection_name' => :'String', :'detection_type' => :'String', :'image_assessment_matched_cves' => :'Array<String>', :'image_assessment_policy_description' => :'String', :'image_assessment_policy_id' => :'String', :'image_assessment_policy_name' => :'String', :'image_digest' => :'String', :'image_has_been_assessed' => :'Boolean', :'image_id' => :'String', :'image_registry' => :'String', :'image_repository' => :'String', :'image_tag' => :'String', :'last_seen_timestamp' => :'String', :'mitigation_id' => :'String', :'mitigation_name' => :'String', :'namespace' => :'String', :'nist_id' => :'String', :'pod_label' => :'String', :'pods_impacted_count' => :'String', :'policy_id' => :'String', :'policy_name' => :'String', :'ports' => :'Array<String>', :'prevented' => :'String', :'remediation' => :'String', :'resource_creation_timestamp' => :'String', :'resource_group_name' => :'String', :'resource_id' => :'String', :'resource_name' => :'String', :'resource_type' => :'String', :'sensitive_env_vars' => :'Array<String>', :'service_type' => :'String', :'severity' => :'String', :'tactic_id' => :'String', :'tactic_name' => :'String', :'technique_id' => :'String', :'technique_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 626 def ==(o) return true if self.equal?(o) self.class == o.class && admission_review_action == o.admission_review_action && admission_review_id == o.admission_review_id && admission_review_msg == o.admission_review_msg && admission_review_operation == o.admission_review_operation && cid == o.cid && cis_id == o.cis_id && cluster_id == o.cluster_id && cluster_name == o.cluster_name && == o. && containers_impacted_count == o.containers_impacted_count && containers_impacted_ids == o.containers_impacted_ids && custom_rego_uuid == o.custom_rego_uuid && description == o.description && == o. && detection_id == o.detection_id && detection_name == o.detection_name && detection_type == o.detection_type && image_assessment_matched_cves == o.image_assessment_matched_cves && image_assessment_policy_description == o.image_assessment_policy_description && image_assessment_policy_id == o.image_assessment_policy_id && image_assessment_policy_name == o.image_assessment_policy_name && image_digest == o.image_digest && image_has_been_assessed == o.image_has_been_assessed && image_id == o.image_id && image_registry == o.image_registry && image_repository == o.image_repository && image_tag == o.image_tag && == o. && mitigation_id == o.mitigation_id && mitigation_name == o.mitigation_name && namespace == o.namespace && nist_id == o.nist_id && pod_label == o.pod_label && pods_impacted_count == o.pods_impacted_count && policy_id == o.policy_id && policy_name == o.policy_name && ports == o.ports && prevented == o.prevented && remediation == o.remediation && == o. && resource_group_name == o.resource_group_name && resource_id == o.resource_id && resource_name == o.resource_name && resource_type == o.resource_type && sensitive_env_vars == o.sensitive_env_vars && service_type == o.service_type && severity == o.severity && tactic_id == o.tactic_id && tactic_name == o.tactic_name && technique_id == o.technique_id && technique_name == o.technique_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 728 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
799 800 801 802 803 804 805 806 807 808 809 810 811 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 799 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 704 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
684 685 686 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 684 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
690 691 692 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 690 def hash [admission_review_action, admission_review_id, admission_review_msg, admission_review_operation, cid, cis_id, cluster_id, cluster_name, , containers_impacted_count, containers_impacted_ids, custom_rego_uuid, description, , detection_id, detection_name, detection_type, image_assessment_matched_cves, image_assessment_policy_description, image_assessment_policy_id, image_assessment_policy_name, image_digest, image_has_been_assessed, image_id, image_registry, image_repository, image_tag, , mitigation_id, mitigation_name, namespace, nist_id, pod_label, pods_impacted_count, policy_id, policy_name, ports, prevented, remediation, , resource_group_name, resource_id, resource_name, resource_type, sensitive_env_vars, service_type, severity, tactic_id, tactic_name, technique_id, technique_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 493 def list_invalid_properties invalid_properties = Array.new if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cis_id.nil? invalid_properties.push('invalid value for "cis_id", cis_id cannot be nil.') end if @cluster_id.nil? invalid_properties.push('invalid value for "cluster_id", cluster_id cannot be nil.') end if @cluster_name.nil? invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.') end if @containers_impacted_count.nil? invalid_properties.push('invalid value for "containers_impacted_count", containers_impacted_count cannot be nil.') end if @containers_impacted_ids.nil? invalid_properties.push('invalid value for "containers_impacted_ids", containers_impacted_ids cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @detect_timestamp.nil? invalid_properties.push('invalid value for "detect_timestamp", detect_timestamp cannot be nil.') end if @detection_id.nil? invalid_properties.push('invalid value for "detection_id", detection_id cannot be nil.') end if @detection_name.nil? invalid_properties.push('invalid value for "detection_name", detection_name cannot be nil.') end if @detection_type.nil? invalid_properties.push('invalid value for "detection_type", detection_type cannot be nil.') end if @namespace.nil? invalid_properties.push('invalid value for "namespace", namespace cannot be nil.') end if @prevented.nil? invalid_properties.push('invalid value for "prevented", prevented cannot be nil.') end if @remediation.nil? invalid_properties.push('invalid value for "remediation", remediation cannot be nil.') end if @resource_creation_timestamp.nil? invalid_properties.push('invalid value for "resource_creation_timestamp", resource_creation_timestamp cannot be nil.') end if @resource_id.nil? invalid_properties.push('invalid value for "resource_id", resource_id cannot be nil.') end if @resource_name.nil? invalid_properties.push('invalid value for "resource_name", resource_name cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @sensitive_env_vars.nil? invalid_properties.push('invalid value for "sensitive_env_vars", sensitive_env_vars cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @tactic_id.nil? invalid_properties.push('invalid value for "tactic_id", tactic_id cannot be nil.') end if @tactic_name.nil? invalid_properties.push('invalid value for "tactic_name", tactic_name cannot be nil.') end if @technique_id.nil? invalid_properties.push('invalid value for "technique_id", technique_id cannot be nil.') end if @technique_name.nil? invalid_properties.push('invalid value for "technique_name", technique_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
775 776 777 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 775 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 781 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
769 770 771 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 769 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/crimson-falcon/models/models_api_kubernetes_iom.rb', line 596 def valid? return false if @cid.nil? return false if @cis_id.nil? return false if @cluster_id.nil? return false if @cluster_name.nil? return false if @containers_impacted_count.nil? return false if @containers_impacted_ids.nil? return false if @description.nil? return false if @detect_timestamp.nil? return false if @detection_id.nil? return false if @detection_name.nil? return false if @detection_type.nil? return false if @namespace.nil? return false if @prevented.nil? return false if @remediation.nil? return false if @resource_creation_timestamp.nil? return false if @resource_id.nil? return false if @resource_name.nil? return false if @resource_type.nil? return false if @sensitive_env_vars.nil? return false if @severity.nil? return false if @tactic_id.nil? return false if @tactic_name.nil? return false if @technique_id.nil? return false if @technique_name.nil? true end |