Class: Falcon::ModelsCluster
- Inherits:
-
Object
- Object
- Falcon::ModelsCluster
- Defined in:
- lib/crimson-falcon/models/models_cluster.rb
Instance Attribute Summary collapse
-
#access ⇒ Object
Returns the value of attribute access.
-
#agent_status ⇒ Object
Returns the value of attribute agent_status.
-
#agents ⇒ Object
Returns the value of attribute agents.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
-
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
-
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
-
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
-
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#cluster_security_group ⇒ Object
Returns the value of attribute cluster_security_group.
-
#cluster_status ⇒ Object
Returns the value of attribute cluster_status.
-
#container_count ⇒ Object
Returns the value of attribute container_count.
-
#first_seen ⇒ Object
Returns the value of attribute first_seen.
-
#iar_coverage ⇒ Object
Returns the value of attribute iar_coverage.
-
#kac_agent_active ⇒ Object
Returns the value of attribute kac_agent_active.
-
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
-
#kubernetes_version ⇒ Object
Returns the value of attribute kubernetes_version.
-
#labels_list ⇒ Object
Returns the value of attribute labels_list.
-
#last_seen ⇒ Object
Returns the value of attribute last_seen.
-
#management_status ⇒ Object
Returns the value of attribute management_status.
-
#node_count ⇒ Object
Returns the value of attribute node_count.
-
#pod_count ⇒ Object
Returns the value of attribute pod_count.
-
#security_group ⇒ Object
Returns the value of attribute security_group.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#virtual_network ⇒ Object
Returns the value of attribute virtual_network.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsCluster
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsCluster
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsCluster` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsCluster`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access') self.access = attributes[:'access'] end if attributes.key?(:'agent_status') self.agent_status = attributes[:'agent_status'] end if attributes.key?(:'agents') if (value = attributes[:'agents']).is_a?(Array) self.agents = value end end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_account_id') self.cloud_account_id = attributes[:'cloud_account_id'] end if attributes.key?(:'cloud_name') self.cloud_name = attributes[:'cloud_name'] end if attributes.key?(:'cloud_region') self.cloud_region = attributes[:'cloud_region'] end if attributes.key?(:'cloud_service') self.cloud_service = attributes[:'cloud_service'] end if attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end if attributes.key?(:'cluster_security_group') self.cluster_security_group = attributes[:'cluster_security_group'] end if attributes.key?(:'cluster_status') self.cluster_status = attributes[:'cluster_status'] end if attributes.key?(:'container_count') self.container_count = attributes[:'container_count'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'iar_coverage') self.iar_coverage = attributes[:'iar_coverage'] end if attributes.key?(:'kac_agent_active') self.kac_agent_active = attributes[:'kac_agent_active'] end if attributes.key?(:'kac_agent_id') self.kac_agent_id = attributes[:'kac_agent_id'] end if attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] end if attributes.key?(:'labels_list') if (value = attributes[:'labels_list']).is_a?(Array) self.labels_list = value end end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'management_status') self.management_status = attributes[:'management_status'] end if attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] end if attributes.key?(:'pod_count') self.pod_count = attributes[:'pod_count'] end if attributes.key?(:'security_group') self.security_group = attributes[:'security_group'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Hash) self. = value end end if attributes.key?(:'virtual_network') self.virtual_network = attributes[:'virtual_network'] end end |
Instance Attribute Details
#access ⇒ Object
Returns the value of attribute access.
34 35 36 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 34 def access @access end |
#agent_status ⇒ Object
Returns the value of attribute agent_status.
36 37 38 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 36 def agent_status @agent_status end |
#agents ⇒ Object
Returns the value of attribute agents.
38 39 40 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 38 def agents @agents end |
#cid ⇒ Object
Returns the value of attribute cid.
40 41 42 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 40 def cid @cid end |
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
42 43 44 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 42 def cloud_account_id @cloud_account_id end |
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
44 45 46 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 44 def cloud_name @cloud_name end |
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
46 47 48 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 46 def cloud_region @cloud_region end |
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
48 49 50 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 48 def cloud_service @cloud_service end |
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
50 51 52 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 50 def cluster_id @cluster_id end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
52 53 54 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 52 def cluster_name @cluster_name end |
#cluster_security_group ⇒ Object
Returns the value of attribute cluster_security_group.
54 55 56 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 54 def cluster_security_group @cluster_security_group end |
#cluster_status ⇒ Object
Returns the value of attribute cluster_status.
56 57 58 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 56 def cluster_status @cluster_status end |
#container_count ⇒ Object
Returns the value of attribute container_count.
58 59 60 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 58 def container_count @container_count end |
#first_seen ⇒ Object
Returns the value of attribute first_seen.
60 61 62 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 60 def first_seen @first_seen end |
#iar_coverage ⇒ Object
Returns the value of attribute iar_coverage.
62 63 64 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 62 def iar_coverage @iar_coverage end |
#kac_agent_active ⇒ Object
Returns the value of attribute kac_agent_active.
64 65 66 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 64 def kac_agent_active @kac_agent_active end |
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
66 67 68 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 66 def kac_agent_id @kac_agent_id end |
#kubernetes_version ⇒ Object
Returns the value of attribute kubernetes_version.
68 69 70 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 68 def kubernetes_version @kubernetes_version end |
#labels_list ⇒ Object
Returns the value of attribute labels_list.
70 71 72 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 70 def labels_list @labels_list end |
#last_seen ⇒ Object
Returns the value of attribute last_seen.
72 73 74 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 72 def last_seen @last_seen end |
#management_status ⇒ Object
Returns the value of attribute management_status.
74 75 76 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 74 def management_status @management_status end |
#node_count ⇒ Object
Returns the value of attribute node_count.
76 77 78 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 76 def node_count @node_count end |
#pod_count ⇒ Object
Returns the value of attribute pod_count.
78 79 80 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 78 def pod_count @pod_count end |
#security_group ⇒ Object
Returns the value of attribute security_group.
80 81 82 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 80 def security_group @security_group end |
#tags ⇒ Object
Returns the value of attribute tags.
82 83 84 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 82 def @tags end |
#virtual_network ⇒ Object
Returns the value of attribute virtual_network.
84 85 86 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 84 def virtual_network @virtual_network end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
119 120 121 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 119 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 87 def self.attribute_map { :'access' => :'access', :'agent_status' => :'agent_status', :'agents' => :'agents', :'cid' => :'cid', :'cloud_account_id' => :'cloud_account_id', :'cloud_name' => :'cloud_name', :'cloud_region' => :'cloud_region', :'cloud_service' => :'cloud_service', :'cluster_id' => :'cluster_id', :'cluster_name' => :'cluster_name', :'cluster_security_group' => :'cluster_security_group', :'cluster_status' => :'cluster_status', :'container_count' => :'container_count', :'first_seen' => :'first_seen', :'iar_coverage' => :'iar_coverage', :'kac_agent_active' => :'kac_agent_active', :'kac_agent_id' => :'kac_agent_id', :'kubernetes_version' => :'kubernetes_version', :'labels_list' => :'labels_list', :'last_seen' => :'last_seen', :'management_status' => :'management_status', :'node_count' => :'node_count', :'pod_count' => :'pod_count', :'security_group' => :'security_group', :'tags' => :'tags', :'virtual_network' => :'virtual_network' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
478 479 480 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 478 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
156 157 158 159 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 156 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 124 def self.openapi_types { :'access' => :'String', :'agent_status' => :'String', :'agents' => :'Array<Hash>', :'cid' => :'String', :'cloud_account_id' => :'String', :'cloud_name' => :'String', :'cloud_region' => :'String', :'cloud_service' => :'String', :'cluster_id' => :'String', :'cluster_name' => :'String', :'cluster_security_group' => :'String', :'cluster_status' => :'String', :'container_count' => :'Integer', :'first_seen' => :'String', :'iar_coverage' => :'Boolean', :'kac_agent_active' => :'Boolean', :'kac_agent_id' => :'String', :'kubernetes_version' => :'String', :'labels_list' => :'Array<String>', :'last_seen' => :'String', :'management_status' => :'String', :'node_count' => :'Integer', :'pod_count' => :'Integer', :'security_group' => :'String', :'tags' => :'Hash<String, String>', :'virtual_network' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 432 def ==(o) return true if self.equal?(o) self.class == o.class && access == o.access && agent_status == o.agent_status && agents == o.agents && cid == o.cid && cloud_account_id == o.cloud_account_id && cloud_name == o.cloud_name && cloud_region == o.cloud_region && cloud_service == o.cloud_service && cluster_id == o.cluster_id && cluster_name == o.cluster_name && cluster_security_group == o.cluster_security_group && cluster_status == o.cluster_status && container_count == o.container_count && first_seen == o.first_seen && iar_coverage == o.iar_coverage && kac_agent_active == o.kac_agent_active && kac_agent_id == o.kac_agent_id && kubernetes_version == o.kubernetes_version && labels_list == o.labels_list && last_seen == o.last_seen && management_status == o.management_status && node_count == o.node_count && pod_count == o.pod_count && security_group == o.security_group && == o. && virtual_network == o.virtual_network end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 509 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 580 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 485 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
465 466 467 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 465 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
471 472 473 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 471 def hash [access, agent_status, agents, cid, cloud_account_id, cloud_name, cloud_region, cloud_service, cluster_id, cluster_name, cluster_security_group, cluster_status, container_count, first_seen, iar_coverage, kac_agent_active, kac_agent_id, kubernetes_version, labels_list, last_seen, management_status, node_count, pod_count, security_group, , virtual_network].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 289 def list_invalid_properties invalid_properties = Array.new if @access.nil? invalid_properties.push('invalid value for "access", access cannot be nil.') end if @agent_status.nil? invalid_properties.push('invalid value for "agent_status", agent_status cannot be nil.') end if @agents.nil? invalid_properties.push('invalid value for "agents", agents cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cloud_account_id.nil? invalid_properties.push('invalid value for "cloud_account_id", cloud_account_id cannot be nil.') end if @cloud_name.nil? invalid_properties.push('invalid value for "cloud_name", cloud_name cannot be nil.') end if @cloud_region.nil? invalid_properties.push('invalid value for "cloud_region", cloud_region cannot be nil.') end if @cloud_service.nil? invalid_properties.push('invalid value for "cloud_service", cloud_service cannot be nil.') end if @cluster_id.nil? invalid_properties.push('invalid value for "cluster_id", cluster_id cannot be nil.') end if @cluster_name.nil? invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.') end if @cluster_security_group.nil? invalid_properties.push('invalid value for "cluster_security_group", cluster_security_group cannot be nil.') end if @cluster_status.nil? invalid_properties.push('invalid value for "cluster_status", cluster_status cannot be nil.') end if @container_count.nil? invalid_properties.push('invalid value for "container_count", container_count cannot be nil.') end if @first_seen.nil? invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.') end if @iar_coverage.nil? invalid_properties.push('invalid value for "iar_coverage", iar_coverage cannot be nil.') end if @kac_agent_active.nil? invalid_properties.push('invalid value for "kac_agent_active", kac_agent_active cannot be nil.') end if @kac_agent_id.nil? invalid_properties.push('invalid value for "kac_agent_id", kac_agent_id cannot be nil.') end if @kubernetes_version.nil? invalid_properties.push('invalid value for "kubernetes_version", kubernetes_version cannot be nil.') end if @labels_list.nil? invalid_properties.push('invalid value for "labels_list", labels_list cannot be nil.') end if @last_seen.nil? invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.') end if @management_status.nil? invalid_properties.push('invalid value for "management_status", management_status cannot be nil.') end if @node_count.nil? invalid_properties.push('invalid value for "node_count", node_count cannot be nil.') end if @pod_count.nil? invalid_properties.push('invalid value for "pod_count", pod_count cannot be nil.') end if @security_group.nil? invalid_properties.push('invalid value for "security_group", security_group cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @virtual_network.nil? invalid_properties.push('invalid value for "virtual_network", virtual_network cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
556 557 558 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 556 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 562 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
550 551 552 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 550 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/crimson-falcon/models/models_cluster.rb', line 400 def valid? return false if @access.nil? return false if @agent_status.nil? return false if @agents.nil? return false if @cid.nil? return false if @cloud_account_id.nil? return false if @cloud_name.nil? return false if @cloud_region.nil? return false if @cloud_service.nil? return false if @cluster_id.nil? return false if @cluster_name.nil? return false if @cluster_security_group.nil? return false if @cluster_status.nil? return false if @container_count.nil? return false if @first_seen.nil? return false if @iar_coverage.nil? return false if @kac_agent_active.nil? return false if @kac_agent_id.nil? return false if @kubernetes_version.nil? return false if @labels_list.nil? return false if @last_seen.nil? return false if @management_status.nil? return false if @node_count.nil? return false if @pod_count.nil? return false if @security_group.nil? return false if @tags.nil? return false if @virtual_network.nil? true end |