Class: Falcon::ModelsContainer

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/models_container.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelsContainer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/crimson-falcon/models/models_container.rb', line 263

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsContainer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsContainer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agents')
    if (value = attributes[:'agents']).is_a?(Array)
      self.agents = value
    end
  end

  if attributes.key?(:'ai_related')
    self.ai_related = attributes[:'ai_related']
  end

  if attributes.key?(:'allow_privilege_escalation')
    self.allow_privilege_escalation = attributes[:'allow_privilege_escalation']
  end

  if attributes.key?(:'app_name')
    self.app_name = attributes[:'app_name']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_account_id')
    self. = attributes[:'cloud_account_id']
  end

  if attributes.key?(:'cloud_instance_id')
    self.cloud_instance_id = attributes[:'cloud_instance_id']
  end

  if attributes.key?(:'cloud_name')
    self.cloud_name = attributes[:'cloud_name']
  end

  if attributes.key?(:'cloud_region')
    self.cloud_region = attributes[:'cloud_region']
  end

  if attributes.key?(:'cloud_service')
    self.cloud_service = attributes[:'cloud_service']
  end

  if attributes.key?(:'cluster_id')
    self.cluster_id = attributes[:'cluster_id']
  end

  if attributes.key?(:'cluster_name')
    self.cluster_name = attributes[:'cluster_name']
  end

  if attributes.key?(:'config_labels')
    self.config_labels = attributes[:'config_labels']
  end

  if attributes.key?(:'container_id')
    self.container_id = attributes[:'container_id']
  end

  if attributes.key?(:'container_name')
    self.container_name = attributes[:'container_name']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  end

  if attributes.key?(:'image_application_package_count')
    self.image_application_package_count = attributes[:'image_application_package_count']
  end

  if attributes.key?(:'image_assessed_at')
    self.image_assessed_at = attributes[:'image_assessed_at']
  end

  if attributes.key?(:'image_detection_count')
    self.image_detection_count = attributes[:'image_detection_count']
  end

  if attributes.key?(:'image_digest')
    self.image_digest = attributes[:'image_digest']
  end

  if attributes.key?(:'image_has_been_assessed')
    self.image_has_been_assessed = attributes[:'image_has_been_assessed']
  end

  if attributes.key?(:'image_highest_severity_vulnerability')
    self.image_highest_severity_vulnerability = attributes[:'image_highest_severity_vulnerability']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'image_package_count')
    self.image_package_count = attributes[:'image_package_count']
  end

  if attributes.key?(:'image_registry')
    self.image_registry = attributes[:'image_registry']
  end

  if attributes.key?(:'image_repository')
    self.image_repository = attributes[:'image_repository']
  end

  if attributes.key?(:'image_tag')
    self.image_tag = attributes[:'image_tag']
  end

  if attributes.key?(:'image_vulnerability_count')
    self.image_vulnerability_count = attributes[:'image_vulnerability_count']
  end

  if attributes.key?(:'insecure_mount_source')
    self.insecure_mount_source = attributes[:'insecure_mount_source']
  end

  if attributes.key?(:'insecure_mount_type')
    self.insecure_mount_type = attributes[:'insecure_mount_type']
  end

  if attributes.key?(:'insecure_propagation_mode')
    self.insecure_propagation_mode = attributes[:'insecure_propagation_mode']
  end

  if attributes.key?(:'interactive_mode')
    self.interactive_mode = attributes[:'interactive_mode']
  end

  if attributes.key?(:'ipv4')
    self.ipv4 = attributes[:'ipv4']
  end

  if attributes.key?(:'ipv6')
    self.ipv6 = attributes[:'ipv6']
  end

  if attributes.key?(:'kac_agent_id')
    self.kac_agent_id = attributes[:'kac_agent_id']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  end

  if attributes.key?(:'labels_list')
    if (value = attributes[:'labels_list']).is_a?(Array)
      self.labels_list = value
    end
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'namespace')
    self.namespace = attributes[:'namespace']
  end

  if attributes.key?(:'node_name')
    self.node_name = attributes[:'node_name']
  end

  if attributes.key?(:'node_uid')
    self.node_uid = attributes[:'node_uid']
  end

  if attributes.key?(:'pod_id')
    self.pod_id = attributes[:'pod_id']
  end

  if attributes.key?(:'pod_name')
    self.pod_name = attributes[:'pod_name']
  end

  if attributes.key?(:'ports')
    if (value = attributes[:'ports']).is_a?(Array)
      self.ports = value
    end
  end

  if attributes.key?(:'privileged')
    self.privileged = attributes[:'privileged']
  end

  if attributes.key?(:'root_write_access')
    self.root_write_access = attributes[:'root_write_access']
  end

  if attributes.key?(:'run_as_root_group')
    self.run_as_root_group = attributes[:'run_as_root_group']
  end

  if attributes.key?(:'run_as_root_user')
    self.run_as_root_user = attributes[:'run_as_root_user']
  end

  if attributes.key?(:'running_status')
    self.running_status = attributes[:'running_status']
  end

  if attributes.key?(:'volume_mounts')
    self.volume_mounts = attributes[:'volume_mounts']
  end
end

Instance Attribute Details

#agentsObject

Returns the value of attribute agents.



34
35
36
# File 'lib/crimson-falcon/models/models_container.rb', line 34

def agents
  @agents
end

Returns the value of attribute ai_related.



36
37
38
# File 'lib/crimson-falcon/models/models_container.rb', line 36

def ai_related
  @ai_related
end

#allow_privilege_escalationObject

Returns the value of attribute allow_privilege_escalation.



38
39
40
# File 'lib/crimson-falcon/models/models_container.rb', line 38

def allow_privilege_escalation
  @allow_privilege_escalation
end

#app_nameObject

Returns the value of attribute app_name.



40
41
42
# File 'lib/crimson-falcon/models/models_container.rb', line 40

def app_name
  @app_name
end

#cidObject

Returns the value of attribute cid.



42
43
44
# File 'lib/crimson-falcon/models/models_container.rb', line 42

def cid
  @cid
end

#cloud_account_idObject

Returns the value of attribute cloud_account_id.



44
45
46
# File 'lib/crimson-falcon/models/models_container.rb', line 44

def 
  @cloud_account_id
end

#cloud_instance_idObject

Returns the value of attribute cloud_instance_id.



46
47
48
# File 'lib/crimson-falcon/models/models_container.rb', line 46

def cloud_instance_id
  @cloud_instance_id
end

#cloud_nameObject

Returns the value of attribute cloud_name.



48
49
50
# File 'lib/crimson-falcon/models/models_container.rb', line 48

def cloud_name
  @cloud_name
end

#cloud_regionObject

Returns the value of attribute cloud_region.



50
51
52
# File 'lib/crimson-falcon/models/models_container.rb', line 50

def cloud_region
  @cloud_region
end

#cloud_serviceObject

Returns the value of attribute cloud_service.



52
53
54
# File 'lib/crimson-falcon/models/models_container.rb', line 52

def cloud_service
  @cloud_service
end

#cluster_idObject

Returns the value of attribute cluster_id.



54
55
56
# File 'lib/crimson-falcon/models/models_container.rb', line 54

def cluster_id
  @cluster_id
end

#cluster_nameObject

Returns the value of attribute cluster_name.



56
57
58
# File 'lib/crimson-falcon/models/models_container.rb', line 56

def cluster_name
  @cluster_name
end

#config_labelsObject

Returns the value of attribute config_labels.



58
59
60
# File 'lib/crimson-falcon/models/models_container.rb', line 58

def config_labels
  @config_labels
end

#container_idObject

Returns the value of attribute container_id.



60
61
62
# File 'lib/crimson-falcon/models/models_container.rb', line 60

def container_id
  @container_id
end

#container_nameObject

Returns the value of attribute container_name.



62
63
64
# File 'lib/crimson-falcon/models/models_container.rb', line 62

def container_name
  @container_name
end

#created_atObject

Returns the value of attribute created_at.



64
65
66
# File 'lib/crimson-falcon/models/models_container.rb', line 64

def created_at
  @created_at
end

#first_seenObject

Returns the value of attribute first_seen.



66
67
68
# File 'lib/crimson-falcon/models/models_container.rb', line 66

def first_seen
  @first_seen
end

#image_application_package_countObject

Returns the value of attribute image_application_package_count.



68
69
70
# File 'lib/crimson-falcon/models/models_container.rb', line 68

def image_application_package_count
  @image_application_package_count
end

#image_assessed_atObject

Returns the value of attribute image_assessed_at.



70
71
72
# File 'lib/crimson-falcon/models/models_container.rb', line 70

def image_assessed_at
  @image_assessed_at
end

#image_detection_countObject

Returns the value of attribute image_detection_count.



72
73
74
# File 'lib/crimson-falcon/models/models_container.rb', line 72

def image_detection_count
  @image_detection_count
end

#image_digestObject

Returns the value of attribute image_digest.



74
75
76
# File 'lib/crimson-falcon/models/models_container.rb', line 74

def image_digest
  @image_digest
end

#image_has_been_assessedObject

Returns the value of attribute image_has_been_assessed.



76
77
78
# File 'lib/crimson-falcon/models/models_container.rb', line 76

def image_has_been_assessed
  @image_has_been_assessed
end

#image_highest_severity_vulnerabilityObject

Returns the value of attribute image_highest_severity_vulnerability.



78
79
80
# File 'lib/crimson-falcon/models/models_container.rb', line 78

def image_highest_severity_vulnerability
  @image_highest_severity_vulnerability
end

#image_idObject

Returns the value of attribute image_id.



80
81
82
# File 'lib/crimson-falcon/models/models_container.rb', line 80

def image_id
  @image_id
end

#image_package_countObject

Returns the value of attribute image_package_count.



82
83
84
# File 'lib/crimson-falcon/models/models_container.rb', line 82

def image_package_count
  @image_package_count
end

#image_registryObject

Returns the value of attribute image_registry.



84
85
86
# File 'lib/crimson-falcon/models/models_container.rb', line 84

def image_registry
  @image_registry
end

#image_repositoryObject

Returns the value of attribute image_repository.



86
87
88
# File 'lib/crimson-falcon/models/models_container.rb', line 86

def image_repository
  @image_repository
end

#image_tagObject

Returns the value of attribute image_tag.



88
89
90
# File 'lib/crimson-falcon/models/models_container.rb', line 88

def image_tag
  @image_tag
end

#image_vulnerability_countObject

Returns the value of attribute image_vulnerability_count.



90
91
92
# File 'lib/crimson-falcon/models/models_container.rb', line 90

def image_vulnerability_count
  @image_vulnerability_count
end

#insecure_mount_sourceObject

Returns the value of attribute insecure_mount_source.



92
93
94
# File 'lib/crimson-falcon/models/models_container.rb', line 92

def insecure_mount_source
  @insecure_mount_source
end

#insecure_mount_typeObject

Returns the value of attribute insecure_mount_type.



94
95
96
# File 'lib/crimson-falcon/models/models_container.rb', line 94

def insecure_mount_type
  @insecure_mount_type
end

#insecure_propagation_modeObject

Returns the value of attribute insecure_propagation_mode.



96
97
98
# File 'lib/crimson-falcon/models/models_container.rb', line 96

def insecure_propagation_mode
  @insecure_propagation_mode
end

#interactive_modeObject

Returns the value of attribute interactive_mode.



98
99
100
# File 'lib/crimson-falcon/models/models_container.rb', line 98

def interactive_mode
  @interactive_mode
end

#ipv4Object

Returns the value of attribute ipv4.



100
101
102
# File 'lib/crimson-falcon/models/models_container.rb', line 100

def ipv4
  @ipv4
end

#ipv6Object

Returns the value of attribute ipv6.



102
103
104
# File 'lib/crimson-falcon/models/models_container.rb', line 102

def ipv6
  @ipv6
end

#kac_agent_idObject

Returns the value of attribute kac_agent_id.



104
105
106
# File 'lib/crimson-falcon/models/models_container.rb', line 104

def kac_agent_id
  @kac_agent_id
end

#labelsObject

Returns the value of attribute labels.



106
107
108
# File 'lib/crimson-falcon/models/models_container.rb', line 106

def labels
  @labels
end

#labels_listObject

Returns the value of attribute labels_list.



108
109
110
# File 'lib/crimson-falcon/models/models_container.rb', line 108

def labels_list
  @labels_list
end

#last_seenObject

Returns the value of attribute last_seen.



110
111
112
# File 'lib/crimson-falcon/models/models_container.rb', line 110

def last_seen
  @last_seen
end

#namespaceObject

Returns the value of attribute namespace.



112
113
114
# File 'lib/crimson-falcon/models/models_container.rb', line 112

def namespace
  @namespace
end

#node_nameObject

Returns the value of attribute node_name.



114
115
116
# File 'lib/crimson-falcon/models/models_container.rb', line 114

def node_name
  @node_name
end

#node_uidObject

Returns the value of attribute node_uid.



116
117
118
# File 'lib/crimson-falcon/models/models_container.rb', line 116

def node_uid
  @node_uid
end

#pod_idObject

Returns the value of attribute pod_id.



118
119
120
# File 'lib/crimson-falcon/models/models_container.rb', line 118

def pod_id
  @pod_id
end

#pod_nameObject

Returns the value of attribute pod_name.



120
121
122
# File 'lib/crimson-falcon/models/models_container.rb', line 120

def pod_name
  @pod_name
end

#portsObject

Returns the value of attribute ports.



122
123
124
# File 'lib/crimson-falcon/models/models_container.rb', line 122

def ports
  @ports
end

#privilegedObject

Returns the value of attribute privileged.



124
125
126
# File 'lib/crimson-falcon/models/models_container.rb', line 124

def privileged
  @privileged
end

#root_write_accessObject

Returns the value of attribute root_write_access.



126
127
128
# File 'lib/crimson-falcon/models/models_container.rb', line 126

def root_write_access
  @root_write_access
end

#run_as_root_groupObject

Returns the value of attribute run_as_root_group.



128
129
130
# File 'lib/crimson-falcon/models/models_container.rb', line 128

def run_as_root_group
  @run_as_root_group
end

#run_as_root_userObject

Returns the value of attribute run_as_root_user.



130
131
132
# File 'lib/crimson-falcon/models/models_container.rb', line 130

def run_as_root_user
  @run_as_root_user
end

#running_statusObject

Returns the value of attribute running_status.



132
133
134
# File 'lib/crimson-falcon/models/models_container.rb', line 132

def running_status
  @running_status
end

#volume_mountsObject

Returns the value of attribute volume_mounts.



134
135
136
# File 'lib/crimson-falcon/models/models_container.rb', line 134

def volume_mounts
  @volume_mounts
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



194
195
196
# File 'lib/crimson-falcon/models/models_container.rb', line 194

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/crimson-falcon/models/models_container.rb', line 137

def self.attribute_map
  {
    :'agents' => :'agents',
    :'ai_related' => :'ai_related',
    :'allow_privilege_escalation' => :'allow_privilege_escalation',
    :'app_name' => :'app_name',
    :'cid' => :'cid',
    :'cloud_account_id' => :'cloud_account_id',
    :'cloud_instance_id' => :'cloud_instance_id',
    :'cloud_name' => :'cloud_name',
    :'cloud_region' => :'cloud_region',
    :'cloud_service' => :'cloud_service',
    :'cluster_id' => :'cluster_id',
    :'cluster_name' => :'cluster_name',
    :'config_labels' => :'config_labels',
    :'container_id' => :'container_id',
    :'container_name' => :'container_name',
    :'created_at' => :'created_at',
    :'first_seen' => :'first_seen',
    :'image_application_package_count' => :'image_application_package_count',
    :'image_assessed_at' => :'image_assessed_at',
    :'image_detection_count' => :'image_detection_count',
    :'image_digest' => :'image_digest',
    :'image_has_been_assessed' => :'image_has_been_assessed',
    :'image_highest_severity_vulnerability' => :'image_highest_severity_vulnerability',
    :'image_id' => :'image_id',
    :'image_package_count' => :'image_package_count',
    :'image_registry' => :'image_registry',
    :'image_repository' => :'image_repository',
    :'image_tag' => :'image_tag',
    :'image_vulnerability_count' => :'image_vulnerability_count',
    :'insecure_mount_source' => :'insecure_mount_source',
    :'insecure_mount_type' => :'insecure_mount_type',
    :'insecure_propagation_mode' => :'insecure_propagation_mode',
    :'interactive_mode' => :'interactive_mode',
    :'ipv4' => :'ipv4',
    :'ipv6' => :'ipv6',
    :'kac_agent_id' => :'kac_agent_id',
    :'labels' => :'labels',
    :'labels_list' => :'labels_list',
    :'last_seen' => :'last_seen',
    :'namespace' => :'namespace',
    :'node_name' => :'node_name',
    :'node_uid' => :'node_uid',
    :'pod_id' => :'pod_id',
    :'pod_name' => :'pod_name',
    :'ports' => :'ports',
    :'privileged' => :'privileged',
    :'root_write_access' => :'root_write_access',
    :'run_as_root_group' => :'run_as_root_group',
    :'run_as_root_user' => :'run_as_root_user',
    :'running_status' => :'running_status',
    :'volume_mounts' => :'volume_mounts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



830
831
832
# File 'lib/crimson-falcon/models/models_container.rb', line 830

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



256
257
258
259
# File 'lib/crimson-falcon/models/models_container.rb', line 256

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/crimson-falcon/models/models_container.rb', line 199

def self.openapi_types
  {
    :'agents' => :'Array<Hash>',
    :'ai_related' => :'Boolean',
    :'allow_privilege_escalation' => :'Boolean',
    :'app_name' => :'String',
    :'cid' => :'String',
    :'cloud_account_id' => :'String',
    :'cloud_instance_id' => :'String',
    :'cloud_name' => :'String',
    :'cloud_region' => :'String',
    :'cloud_service' => :'String',
    :'cluster_id' => :'String',
    :'cluster_name' => :'String',
    :'config_labels' => :'String',
    :'container_id' => :'String',
    :'container_name' => :'String',
    :'created_at' => :'String',
    :'first_seen' => :'String',
    :'image_application_package_count' => :'Integer',
    :'image_assessed_at' => :'Integer',
    :'image_detection_count' => :'Integer',
    :'image_digest' => :'String',
    :'image_has_been_assessed' => :'Boolean',
    :'image_highest_severity_vulnerability' => :'String',
    :'image_id' => :'String',
    :'image_package_count' => :'Integer',
    :'image_registry' => :'String',
    :'image_repository' => :'String',
    :'image_tag' => :'String',
    :'image_vulnerability_count' => :'Integer',
    :'insecure_mount_source' => :'String',
    :'insecure_mount_type' => :'String',
    :'insecure_propagation_mode' => :'Boolean',
    :'interactive_mode' => :'Boolean',
    :'ipv4' => :'String',
    :'ipv6' => :'String',
    :'kac_agent_id' => :'String',
    :'labels' => :'Hash<String, String>',
    :'labels_list' => :'Array<String>',
    :'last_seen' => :'String',
    :'namespace' => :'String',
    :'node_name' => :'String',
    :'node_uid' => :'String',
    :'pod_id' => :'String',
    :'pod_name' => :'String',
    :'ports' => :'Array<Hash>',
    :'privileged' => :'Boolean',
    :'root_write_access' => :'Boolean',
    :'run_as_root_group' => :'Boolean',
    :'run_as_root_user' => :'Boolean',
    :'running_status' => :'Boolean',
    :'volume_mounts' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
# File 'lib/crimson-falcon/models/models_container.rb', line 759

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agents == o.agents &&
      ai_related == o.ai_related &&
      allow_privilege_escalation == o.allow_privilege_escalation &&
      app_name == o.app_name &&
      cid == o.cid &&
       == o. &&
      cloud_instance_id == o.cloud_instance_id &&
      cloud_name == o.cloud_name &&
      cloud_region == o.cloud_region &&
      cloud_service == o.cloud_service &&
      cluster_id == o.cluster_id &&
      cluster_name == o.cluster_name &&
      config_labels == o.config_labels &&
      container_id == o.container_id &&
      container_name == o.container_name &&
      created_at == o.created_at &&
      first_seen == o.first_seen &&
      image_application_package_count == o.image_application_package_count &&
      image_assessed_at == o.image_assessed_at &&
      image_detection_count == o.image_detection_count &&
      image_digest == o.image_digest &&
      image_has_been_assessed == o.image_has_been_assessed &&
      image_highest_severity_vulnerability == o.image_highest_severity_vulnerability &&
      image_id == o.image_id &&
      image_package_count == o.image_package_count &&
      image_registry == o.image_registry &&
      image_repository == o.image_repository &&
      image_tag == o.image_tag &&
      image_vulnerability_count == o.image_vulnerability_count &&
      insecure_mount_source == o.insecure_mount_source &&
      insecure_mount_type == o.insecure_mount_type &&
      insecure_propagation_mode == o.insecure_propagation_mode &&
      interactive_mode == o.interactive_mode &&
      ipv4 == o.ipv4 &&
      ipv6 == o.ipv6 &&
      kac_agent_id == o.kac_agent_id &&
      labels == o.labels &&
      labels_list == o.labels_list &&
      last_seen == o.last_seen &&
      namespace == o.namespace &&
      node_name == o.node_name &&
      node_uid == o.node_uid &&
      pod_id == o.pod_id &&
      pod_name == o.pod_name &&
      ports == o.ports &&
      privileged == o.privileged &&
      root_write_access == o.root_write_access &&
      run_as_root_group == o.run_as_root_group &&
      run_as_root_user == o.run_as_root_user &&
      running_status == o.running_status &&
      volume_mounts == o.volume_mounts
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
# File 'lib/crimson-falcon/models/models_container.rb', line 861

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



932
933
934
935
936
937
938
939
940
941
942
943
944
# File 'lib/crimson-falcon/models/models_container.rb', line 932

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
# File 'lib/crimson-falcon/models/models_container.rb', line 837

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


817
818
819
# File 'lib/crimson-falcon/models/models_container.rb', line 817

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



823
824
825
# File 'lib/crimson-falcon/models/models_container.rb', line 823

def hash
  [agents, ai_related, allow_privilege_escalation, app_name, cid, , cloud_instance_id, cloud_name, cloud_region, cloud_service, cluster_id, cluster_name, config_labels, container_id, container_name, created_at, first_seen, image_application_package_count, image_assessed_at, image_detection_count, image_digest, image_has_been_assessed, image_highest_severity_vulnerability, image_id, image_package_count, image_registry, image_repository, image_tag, image_vulnerability_count, insecure_mount_source, insecure_mount_type, insecure_propagation_mode, interactive_mode, ipv4, ipv6, kac_agent_id, labels, labels_list, last_seen, namespace, node_name, node_uid, pod_id, pod_name, ports, privileged, root_write_access, run_as_root_group, run_as_root_user, running_status, volume_mounts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'lib/crimson-falcon/models/models_container.rb', line 491

def list_invalid_properties
  invalid_properties = Array.new
  if @agents.nil?
    invalid_properties.push('invalid value for "agents", agents cannot be nil.')
  end

  if @ai_related.nil?
    invalid_properties.push('invalid value for "ai_related", ai_related cannot be nil.')
  end

  if @allow_privilege_escalation.nil?
    invalid_properties.push('invalid value for "allow_privilege_escalation", allow_privilege_escalation cannot be nil.')
  end

  if @app_name.nil?
    invalid_properties.push('invalid value for "app_name", app_name cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @cloud_account_id.nil?
    invalid_properties.push('invalid value for "cloud_account_id", cloud_account_id cannot be nil.')
  end

  if @cloud_instance_id.nil?
    invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.')
  end

  if @cloud_name.nil?
    invalid_properties.push('invalid value for "cloud_name", cloud_name cannot be nil.')
  end

  if @cloud_region.nil?
    invalid_properties.push('invalid value for "cloud_region", cloud_region cannot be nil.')
  end

  if @cloud_service.nil?
    invalid_properties.push('invalid value for "cloud_service", cloud_service cannot be nil.')
  end

  if @cluster_id.nil?
    invalid_properties.push('invalid value for "cluster_id", cluster_id cannot be nil.')
  end

  if @cluster_name.nil?
    invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.')
  end

  if @config_labels.nil?
    invalid_properties.push('invalid value for "config_labels", config_labels cannot be nil.')
  end

  if @container_id.nil?
    invalid_properties.push('invalid value for "container_id", container_id cannot be nil.')
  end

  if @container_name.nil?
    invalid_properties.push('invalid value for "container_name", container_name cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @first_seen.nil?
    invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.')
  end

  if @image_application_package_count.nil?
    invalid_properties.push('invalid value for "image_application_package_count", image_application_package_count cannot be nil.')
  end

  if @image_assessed_at.nil?
    invalid_properties.push('invalid value for "image_assessed_at", image_assessed_at cannot be nil.')
  end

  if @image_detection_count.nil?
    invalid_properties.push('invalid value for "image_detection_count", image_detection_count cannot be nil.')
  end

  if @image_digest.nil?
    invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.')
  end

  if @image_has_been_assessed.nil?
    invalid_properties.push('invalid value for "image_has_been_assessed", image_has_been_assessed cannot be nil.')
  end

  if @image_highest_severity_vulnerability.nil?
    invalid_properties.push('invalid value for "image_highest_severity_vulnerability", image_highest_severity_vulnerability cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @image_package_count.nil?
    invalid_properties.push('invalid value for "image_package_count", image_package_count cannot be nil.')
  end

  if @image_registry.nil?
    invalid_properties.push('invalid value for "image_registry", image_registry cannot be nil.')
  end

  if @image_repository.nil?
    invalid_properties.push('invalid value for "image_repository", image_repository cannot be nil.')
  end

  if @image_tag.nil?
    invalid_properties.push('invalid value for "image_tag", image_tag cannot be nil.')
  end

  if @image_vulnerability_count.nil?
    invalid_properties.push('invalid value for "image_vulnerability_count", image_vulnerability_count cannot be nil.')
  end

  if @insecure_mount_source.nil?
    invalid_properties.push('invalid value for "insecure_mount_source", insecure_mount_source cannot be nil.')
  end

  if @insecure_mount_type.nil?
    invalid_properties.push('invalid value for "insecure_mount_type", insecure_mount_type cannot be nil.')
  end

  if @insecure_propagation_mode.nil?
    invalid_properties.push('invalid value for "insecure_propagation_mode", insecure_propagation_mode cannot be nil.')
  end

  if @interactive_mode.nil?
    invalid_properties.push('invalid value for "interactive_mode", interactive_mode cannot be nil.')
  end

  if @ipv4.nil?
    invalid_properties.push('invalid value for "ipv4", ipv4 cannot be nil.')
  end

  if @ipv6.nil?
    invalid_properties.push('invalid value for "ipv6", ipv6 cannot be nil.')
  end

  if @kac_agent_id.nil?
    invalid_properties.push('invalid value for "kac_agent_id", kac_agent_id cannot be nil.')
  end

  if @labels.nil?
    invalid_properties.push('invalid value for "labels", labels cannot be nil.')
  end

  if @labels_list.nil?
    invalid_properties.push('invalid value for "labels_list", labels_list cannot be nil.')
  end

  if @last_seen.nil?
    invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.')
  end

  if @namespace.nil?
    invalid_properties.push('invalid value for "namespace", namespace cannot be nil.')
  end

  if @node_name.nil?
    invalid_properties.push('invalid value for "node_name", node_name cannot be nil.')
  end

  if @node_uid.nil?
    invalid_properties.push('invalid value for "node_uid", node_uid cannot be nil.')
  end

  if @pod_id.nil?
    invalid_properties.push('invalid value for "pod_id", pod_id cannot be nil.')
  end

  if @pod_name.nil?
    invalid_properties.push('invalid value for "pod_name", pod_name cannot be nil.')
  end

  if @ports.nil?
    invalid_properties.push('invalid value for "ports", ports cannot be nil.')
  end

  if @privileged.nil?
    invalid_properties.push('invalid value for "privileged", privileged cannot be nil.')
  end

  if @root_write_access.nil?
    invalid_properties.push('invalid value for "root_write_access", root_write_access cannot be nil.')
  end

  if @run_as_root_group.nil?
    invalid_properties.push('invalid value for "run_as_root_group", run_as_root_group cannot be nil.')
  end

  if @run_as_root_user.nil?
    invalid_properties.push('invalid value for "run_as_root_user", run_as_root_user cannot be nil.')
  end

  if @running_status.nil?
    invalid_properties.push('invalid value for "running_status", running_status cannot be nil.')
  end

  if @volume_mounts.nil?
    invalid_properties.push('invalid value for "volume_mounts", volume_mounts cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



908
909
910
# File 'lib/crimson-falcon/models/models_container.rb', line 908

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



914
915
916
917
918
919
920
921
922
923
924
925
926
# File 'lib/crimson-falcon/models/models_container.rb', line 914

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



902
903
904
# File 'lib/crimson-falcon/models/models_container.rb', line 902

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
# File 'lib/crimson-falcon/models/models_container.rb', line 702

def valid?
  return false if @agents.nil?
  return false if @ai_related.nil?
  return false if @allow_privilege_escalation.nil?
  return false if @app_name.nil?
  return false if @cid.nil?
  return false if @cloud_account_id.nil?
  return false if @cloud_instance_id.nil?
  return false if @cloud_name.nil?
  return false if @cloud_region.nil?
  return false if @cloud_service.nil?
  return false if @cluster_id.nil?
  return false if @cluster_name.nil?
  return false if @config_labels.nil?
  return false if @container_id.nil?
  return false if @container_name.nil?
  return false if @created_at.nil?
  return false if @first_seen.nil?
  return false if @image_application_package_count.nil?
  return false if @image_assessed_at.nil?
  return false if @image_detection_count.nil?
  return false if @image_digest.nil?
  return false if @image_has_been_assessed.nil?
  return false if @image_highest_severity_vulnerability.nil?
  return false if @image_id.nil?
  return false if @image_package_count.nil?
  return false if @image_registry.nil?
  return false if @image_repository.nil?
  return false if @image_tag.nil?
  return false if @image_vulnerability_count.nil?
  return false if @insecure_mount_source.nil?
  return false if @insecure_mount_type.nil?
  return false if @insecure_propagation_mode.nil?
  return false if @interactive_mode.nil?
  return false if @ipv4.nil?
  return false if @ipv6.nil?
  return false if @kac_agent_id.nil?
  return false if @labels.nil?
  return false if @labels_list.nil?
  return false if @last_seen.nil?
  return false if @namespace.nil?
  return false if @node_name.nil?
  return false if @node_uid.nil?
  return false if @pod_id.nil?
  return false if @pod_name.nil?
  return false if @ports.nil?
  return false if @privileged.nil?
  return false if @root_write_access.nil?
  return false if @run_as_root_group.nil?
  return false if @run_as_root_user.nil?
  return false if @running_status.nil?
  return false if @volume_mounts.nil?
  true
end