Class: Falcon::ModelsContainerImage

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/models_container_image.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelsContainerImage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/crimson-falcon/models/models_container_image.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsContainerImage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsContainerImage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cluster_info')
    if (value = attributes[:'cluster_info']).is_a?(Array)
      self.cluster_info = value
    end
  end

  if attributes.key?(:'container_count')
    self.container_count = attributes[:'container_count']
  end

  if attributes.key?(:'containers_running_status')
    if (value = attributes[:'containers_running_status']).is_a?(Hash)
      self.containers_running_status = value
    end
  end

  if attributes.key?(:'hosts')
    if (value = attributes[:'hosts']).is_a?(Array)
      self.hosts = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'image_detection_count')
    self.image_detection_count = attributes[:'image_detection_count']
  end

  if attributes.key?(:'image_digest')
    self.image_digest = attributes[:'image_digest']
  end

  if attributes.key?(:'image_has_been_assessed')
    self.image_has_been_assessed = attributes[:'image_has_been_assessed']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'image_name')
    self.image_name = attributes[:'image_name']
  end

  if attributes.key?(:'image_registry')
    self.image_registry = attributes[:'image_registry']
  end

  if attributes.key?(:'image_repository')
    self.image_repository = attributes[:'image_repository']
  end

  if attributes.key?(:'image_tag')
    self.image_tag = attributes[:'image_tag']
  end

  if attributes.key?(:'image_vulnerability_count')
    self.image_vulnerability_count = attributes[:'image_vulnerability_count']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'running_container_count')
    self.running_container_count = attributes[:'running_container_count']
  end
end

Instance Attribute Details

#cidObject

Returns the value of attribute cid.



34
35
36
# File 'lib/crimson-falcon/models/models_container_image.rb', line 34

def cid
  @cid
end

#cluster_infoObject

Returns the value of attribute cluster_info.



36
37
38
# File 'lib/crimson-falcon/models/models_container_image.rb', line 36

def cluster_info
  @cluster_info
end

#container_countObject

Returns the value of attribute container_count.



38
39
40
# File 'lib/crimson-falcon/models/models_container_image.rb', line 38

def container_count
  @container_count
end

#containers_running_statusObject

Returns the value of attribute containers_running_status.



40
41
42
# File 'lib/crimson-falcon/models/models_container_image.rb', line 40

def containers_running_status
  @containers_running_status
end

#hostsObject

Returns the value of attribute hosts.



42
43
44
# File 'lib/crimson-falcon/models/models_container_image.rb', line 42

def hosts
  @hosts
end

#idObject

Returns the value of attribute id.



44
45
46
# File 'lib/crimson-falcon/models/models_container_image.rb', line 44

def id
  @id
end

#image_detection_countObject

Returns the value of attribute image_detection_count.



46
47
48
# File 'lib/crimson-falcon/models/models_container_image.rb', line 46

def image_detection_count
  @image_detection_count
end

#image_digestObject

Returns the value of attribute image_digest.



48
49
50
# File 'lib/crimson-falcon/models/models_container_image.rb', line 48

def image_digest
  @image_digest
end

#image_has_been_assessedObject

Returns the value of attribute image_has_been_assessed.



50
51
52
# File 'lib/crimson-falcon/models/models_container_image.rb', line 50

def image_has_been_assessed
  @image_has_been_assessed
end

#image_idObject

Returns the value of attribute image_id.



52
53
54
# File 'lib/crimson-falcon/models/models_container_image.rb', line 52

def image_id
  @image_id
end

#image_nameObject

Returns the value of attribute image_name.



54
55
56
# File 'lib/crimson-falcon/models/models_container_image.rb', line 54

def image_name
  @image_name
end

#image_registryObject

Returns the value of attribute image_registry.



56
57
58
# File 'lib/crimson-falcon/models/models_container_image.rb', line 56

def image_registry
  @image_registry
end

#image_repositoryObject

Returns the value of attribute image_repository.



58
59
60
# File 'lib/crimson-falcon/models/models_container_image.rb', line 58

def image_repository
  @image_repository
end

#image_tagObject

Returns the value of attribute image_tag.



60
61
62
# File 'lib/crimson-falcon/models/models_container_image.rb', line 60

def image_tag
  @image_tag
end

#image_vulnerability_countObject

Returns the value of attribute image_vulnerability_count.



62
63
64
# File 'lib/crimson-falcon/models/models_container_image.rb', line 62

def image_vulnerability_count
  @image_vulnerability_count
end

#last_seenObject

Returns the value of attribute last_seen.



64
65
66
# File 'lib/crimson-falcon/models/models_container_image.rb', line 64

def last_seen
  @last_seen
end

#running_container_countObject

Returns the value of attribute running_container_count.



66
67
68
# File 'lib/crimson-falcon/models/models_container_image.rb', line 66

def running_container_count
  @running_container_count
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/models_container_image.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/models_container_image.rb', line 69

def self.attribute_map
  {
    :'cid' => :'cid',
    :'cluster_info' => :'cluster_info',
    :'container_count' => :'container_count',
    :'containers_running_status' => :'containers_running_status',
    :'hosts' => :'hosts',
    :'id' => :'id',
    :'image_detection_count' => :'image_detection_count',
    :'image_digest' => :'image_digest',
    :'image_has_been_assessed' => :'image_has_been_assessed',
    :'image_id' => :'image_id',
    :'image_name' => :'image_name',
    :'image_registry' => :'image_registry',
    :'image_repository' => :'image_repository',
    :'image_tag' => :'image_tag',
    :'image_vulnerability_count' => :'image_vulnerability_count',
    :'last_seen' => :'last_seen',
    :'running_container_count' => :'running_container_count'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
# File 'lib/crimson-falcon/models/models_container_image.rb', line 352

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/models_container_image.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/models_container_image.rb', line 97

def self.openapi_types
  {
    :'cid' => :'String',
    :'cluster_info' => :'Array<ModelsClusterInfo>',
    :'container_count' => :'Integer',
    :'containers_running_status' => :'Hash<String, Boolean>',
    :'hosts' => :'Array<String>',
    :'id' => :'String',
    :'image_detection_count' => :'Integer',
    :'image_digest' => :'String',
    :'image_has_been_assessed' => :'Boolean',
    :'image_id' => :'String',
    :'image_name' => :'String',
    :'image_registry' => :'String',
    :'image_repository' => :'String',
    :'image_tag' => :'String',
    :'image_vulnerability_count' => :'Integer',
    :'last_seen' => :'String',
    :'running_container_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/crimson-falcon/models/models_container_image.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cid == o.cid &&
      cluster_info == o.cluster_info &&
      container_count == o.container_count &&
      containers_running_status == o.containers_running_status &&
      hosts == o.hosts &&
      id == o.id &&
      image_detection_count == o.image_detection_count &&
      image_digest == o.image_digest &&
      image_has_been_assessed == o.image_has_been_assessed &&
      image_id == o.image_id &&
      image_name == o.image_name &&
      image_registry == o.image_registry &&
      image_repository == o.image_repository &&
      image_tag == o.image_tag &&
      image_vulnerability_count == o.image_vulnerability_count &&
      last_seen == o.last_seen &&
      running_container_count == o.running_container_count
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/crimson-falcon/models/models_container_image.rb', line 383

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/crimson-falcon/models/models_container_image.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/crimson-falcon/models/models_container_image.rb', line 359

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/crimson-falcon/models/models_container_image.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



345
346
347
# File 'lib/crimson-falcon/models/models_container_image.rb', line 345

def hash
  [cid, cluster_info, container_count, containers_running_status, hosts, id, image_detection_count, image_digest, image_has_been_assessed, image_id, image_name, image_registry, image_repository, image_tag, image_vulnerability_count, last_seen, running_container_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/crimson-falcon/models/models_container_image.rb', line 217

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @cluster_info.nil?
    invalid_properties.push('invalid value for "cluster_info", cluster_info cannot be nil.')
  end

  if @container_count.nil?
    invalid_properties.push('invalid value for "container_count", container_count cannot be nil.')
  end

  if @containers_running_status.nil?
    invalid_properties.push('invalid value for "containers_running_status", containers_running_status cannot be nil.')
  end

  if @hosts.nil?
    invalid_properties.push('invalid value for "hosts", hosts cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @image_detection_count.nil?
    invalid_properties.push('invalid value for "image_detection_count", image_detection_count cannot be nil.')
  end

  if @image_digest.nil?
    invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.')
  end

  if @image_has_been_assessed.nil?
    invalid_properties.push('invalid value for "image_has_been_assessed", image_has_been_assessed cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @image_name.nil?
    invalid_properties.push('invalid value for "image_name", image_name cannot be nil.')
  end

  if @image_registry.nil?
    invalid_properties.push('invalid value for "image_registry", image_registry cannot be nil.')
  end

  if @image_repository.nil?
    invalid_properties.push('invalid value for "image_repository", image_repository cannot be nil.')
  end

  if @image_tag.nil?
    invalid_properties.push('invalid value for "image_tag", image_tag cannot be nil.')
  end

  if @image_vulnerability_count.nil?
    invalid_properties.push('invalid value for "image_vulnerability_count", image_vulnerability_count cannot be nil.')
  end

  if @last_seen.nil?
    invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.')
  end

  if @running_container_count.nil?
    invalid_properties.push('invalid value for "running_container_count", running_container_count cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
# File 'lib/crimson-falcon/models/models_container_image.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/crimson-falcon/models/models_container_image.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



424
425
426
# File 'lib/crimson-falcon/models/models_container_image.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/crimson-falcon/models/models_container_image.rb', line 292

def valid?
  return false if @cid.nil?
  return false if @cluster_info.nil?
  return false if @container_count.nil?
  return false if @containers_running_status.nil?
  return false if @hosts.nil?
  return false if @id.nil?
  return false if @image_detection_count.nil?
  return false if @image_digest.nil?
  return false if @image_has_been_assessed.nil?
  return false if @image_id.nil?
  return false if @image_name.nil?
  return false if @image_registry.nil?
  return false if @image_repository.nil?
  return false if @image_tag.nil?
  return false if @image_vulnerability_count.nil?
  return false if @last_seen.nil?
  return false if @running_container_count.nil?
  true
end