Class: Falcon::ModelsExternalPolicyResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/models_external_policy_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelsExternalPolicyResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsExternalPolicyResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsExternalPolicyResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'deny')
    self.deny = attributes[:'deny']
  end

  if attributes.key?(:'evaluated_at')
    self.evaluated_at = attributes[:'evaluated_at']
  end

  if attributes.key?(:'evaluation_details')
    self.evaluation_details = attributes[:'evaluation_details']
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'policy_group')
    self.policy_group = attributes[:'policy_group']
  end

  if attributes.key?(:'policy_type')
    self.policy_type = attributes[:'policy_type']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



34
35
36
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 34

def action
  @action
end

#conditionsObject

Returns the value of attribute conditions.



36
37
38
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 36

def conditions
  @conditions
end

#denyObject

Returns the value of attribute deny.



38
39
40
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 38

def deny
  @deny
end

#evaluated_atObject

Returns the value of attribute evaluated_at.



40
41
42
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 40

def evaluated_at
  @evaluated_at
end

#evaluation_detailsObject

Returns the value of attribute evaluation_details.



42
43
44
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 42

def evaluation_details
  @evaluation_details
end

#imageObject

Returns the value of attribute image.



44
45
46
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 44

def image
  @image
end

#policyObject

Returns the value of attribute policy.



46
47
48
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 46

def policy
  @policy
end

#policy_groupObject

Returns the value of attribute policy_group.



48
49
50
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 48

def policy_group
  @policy_group
end

#policy_typeObject

Returns the value of attribute policy_type.



50
51
52
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 50

def policy_type
  @policy_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 53

def self.attribute_map
  {
    :'action' => :'action',
    :'conditions' => :'conditions',
    :'deny' => :'deny',
    :'evaluated_at' => :'evaluated_at',
    :'evaluation_details' => :'evaluation_details',
    :'image' => :'image',
    :'policy' => :'policy',
    :'policy_group' => :'policy_group',
    :'policy_type' => :'policy_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 216

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 73

def self.openapi_types
  {
    :'action' => :'String',
    :'conditions' => :'Array<Object>',
    :'deny' => :'Boolean',
    :'evaluated_at' => :'String',
    :'evaluation_details' => :'ModelsAPIPolicyEvaluationDetails',
    :'image' => :'ModelsAPIPolicyImage',
    :'policy' => :'ModelsAPIPolicy',
    :'policy_group' => :'ModelsAPIPolicyGroup',
    :'policy_type' => :'ModelsAPIPolicyConfig'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      conditions == o.conditions &&
      deny == o.deny &&
      evaluated_at == o.evaluated_at &&
      evaluation_details == o.evaluation_details &&
      image == o.image &&
      policy == o.policy &&
      policy_group == o.policy_group &&
      policy_type == o.policy_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 247

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 318

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 209

def hash
  [action, conditions, deny, evaluated_at, evaluation_details, image, policy, policy_group, policy_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 149

def list_invalid_properties
  invalid_properties = Array.new
  if @deny.nil?
    invalid_properties.push('invalid value for "deny", deny cannot be nil.')
  end

  if @evaluated_at.nil?
    invalid_properties.push('invalid value for "evaluated_at", evaluated_at cannot be nil.')
  end

  if @image.nil?
    invalid_properties.push('invalid value for "image", image cannot be nil.')
  end

  if @policy.nil?
    invalid_properties.push('invalid value for "policy", policy cannot be nil.')
  end

  if @policy_type.nil?
    invalid_properties.push('invalid value for "policy_type", policy_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 294

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 288

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
# File 'lib/crimson-falcon/models/models_external_policy_response.rb', line 176

def valid?
  return false if @deny.nil?
  return false if @evaluated_at.nil?
  return false if @image.nil?
  return false if @policy.nil?
  return false if @policy_type.nil?
  true
end