Class: Falcon::ModelsNode
- Inherits:
-
Object
- Object
- Falcon::ModelsNode
- Defined in:
- lib/crimson-falcon/models/models_node.rb
Instance Attribute Summary collapse
-
#agents ⇒ Object
Returns the value of attribute agents.
-
#annotations_list ⇒ Object
Returns the value of attribute annotations_list.
-
#architecture ⇒ Object
Returns the value of attribute architecture.
-
#base_image ⇒ Object
Returns the value of attribute base_image.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
-
#cloud_instance_id ⇒ Object
Returns the value of attribute cloud_instance_id.
-
#cloud_instance_type ⇒ Object
Returns the value of attribute cloud_instance_type.
-
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
-
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
-
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
-
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#container_count ⇒ Object
Returns the value of attribute container_count.
-
#container_runtime_version ⇒ Object
Returns the value of attribute container_runtime_version.
-
#cpu ⇒ Object
Returns the value of attribute cpu.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#external_ip ⇒ Object
Returns the value of attribute external_ip.
-
#first_seen ⇒ Object
Returns the value of attribute first_seen.
-
#ipv4 ⇒ Object
Returns the value of attribute ipv4.
-
#ipv6 ⇒ Object
Returns the value of attribute ipv6.
-
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
-
#kernel_version ⇒ Object
Returns the value of attribute kernel_version.
-
#kubernetes_version ⇒ Object
Returns the value of attribute kubernetes_version.
-
#labels ⇒ Object
Returns the value of attribute labels.
-
#labels_list ⇒ Object
Returns the value of attribute labels_list.
-
#last_seen ⇒ Object
Returns the value of attribute last_seen.
-
#linux_sensor_coverage ⇒ Object
Returns the value of attribute linux_sensor_coverage.
-
#memory ⇒ Object
Returns the value of attribute memory.
-
#node_id ⇒ Object
Returns the value of attribute node_id.
-
#node_name ⇒ Object
Returns the value of attribute node_name.
-
#os ⇒ Object
Returns the value of attribute os.
-
#pod_cidr ⇒ Object
Returns the value of attribute pod_cidr.
-
#pod_count ⇒ Object
Returns the value of attribute pod_count.
-
#provider_id ⇒ Object
Returns the value of attribute provider_id.
-
#resource_status ⇒ Object
Returns the value of attribute resource_status.
-
#storage ⇒ Object
Returns the value of attribute storage.
-
#uid ⇒ Object
Returns the value of attribute uid.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsNode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsNode
Initializes the object
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/crimson-falcon/models/models_node.rb', line 215 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsNode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsNode`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agents') if (value = attributes[:'agents']).is_a?(Array) self.agents = value end end if attributes.key?(:'annotations_list') if (value = attributes[:'annotations_list']).is_a?(Array) self.annotations_list = value end end if attributes.key?(:'architecture') self.architecture = attributes[:'architecture'] end if attributes.key?(:'base_image') self.base_image = attributes[:'base_image'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_account_id') self.cloud_account_id = attributes[:'cloud_account_id'] end if attributes.key?(:'cloud_instance_id') self.cloud_instance_id = attributes[:'cloud_instance_id'] end if attributes.key?(:'cloud_instance_type') self.cloud_instance_type = attributes[:'cloud_instance_type'] end if attributes.key?(:'cloud_name') self.cloud_name = attributes[:'cloud_name'] end if attributes.key?(:'cloud_region') self.cloud_region = attributes[:'cloud_region'] end if attributes.key?(:'cloud_service') self.cloud_service = attributes[:'cloud_service'] end if attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end if attributes.key?(:'container_count') self.container_count = attributes[:'container_count'] end if attributes.key?(:'container_runtime_version') self.container_runtime_version = attributes[:'container_runtime_version'] end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'external_ip') self.external_ip = attributes[:'external_ip'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'ipv4') self.ipv4 = attributes[:'ipv4'] end if attributes.key?(:'ipv6') self.ipv6 = attributes[:'ipv6'] end if attributes.key?(:'kac_agent_id') self.kac_agent_id = attributes[:'kac_agent_id'] end if attributes.key?(:'kernel_version') self.kernel_version = attributes[:'kernel_version'] end if attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Hash) self.labels = value end end if attributes.key?(:'labels_list') if (value = attributes[:'labels_list']).is_a?(Array) self.labels_list = value end end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'linux_sensor_coverage') self.linux_sensor_coverage = attributes[:'linux_sensor_coverage'] end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'node_id') self.node_id = attributes[:'node_id'] end if attributes.key?(:'node_name') self.node_name = attributes[:'node_name'] end if attributes.key?(:'os') self.os = attributes[:'os'] end if attributes.key?(:'pod_cidr') self.pod_cidr = attributes[:'pod_cidr'] end if attributes.key?(:'pod_count') self.pod_count = attributes[:'pod_count'] end if attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] end if attributes.key?(:'resource_status') self.resource_status = attributes[:'resource_status'] end if attributes.key?(:'storage') self.storage = attributes[:'storage'] end if attributes.key?(:'uid') self.uid = attributes[:'uid'] end end |
Instance Attribute Details
#agents ⇒ Object
Returns the value of attribute agents.
34 35 36 |
# File 'lib/crimson-falcon/models/models_node.rb', line 34 def agents @agents end |
#annotations_list ⇒ Object
Returns the value of attribute annotations_list.
36 37 38 |
# File 'lib/crimson-falcon/models/models_node.rb', line 36 def annotations_list @annotations_list end |
#architecture ⇒ Object
Returns the value of attribute architecture.
38 39 40 |
# File 'lib/crimson-falcon/models/models_node.rb', line 38 def architecture @architecture end |
#base_image ⇒ Object
Returns the value of attribute base_image.
40 41 42 |
# File 'lib/crimson-falcon/models/models_node.rb', line 40 def base_image @base_image end |
#cid ⇒ Object
Returns the value of attribute cid.
42 43 44 |
# File 'lib/crimson-falcon/models/models_node.rb', line 42 def cid @cid end |
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
44 45 46 |
# File 'lib/crimson-falcon/models/models_node.rb', line 44 def cloud_account_id @cloud_account_id end |
#cloud_instance_id ⇒ Object
Returns the value of attribute cloud_instance_id.
46 47 48 |
# File 'lib/crimson-falcon/models/models_node.rb', line 46 def cloud_instance_id @cloud_instance_id end |
#cloud_instance_type ⇒ Object
Returns the value of attribute cloud_instance_type.
48 49 50 |
# File 'lib/crimson-falcon/models/models_node.rb', line 48 def cloud_instance_type @cloud_instance_type end |
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
50 51 52 |
# File 'lib/crimson-falcon/models/models_node.rb', line 50 def cloud_name @cloud_name end |
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
52 53 54 |
# File 'lib/crimson-falcon/models/models_node.rb', line 52 def cloud_region @cloud_region end |
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
54 55 56 |
# File 'lib/crimson-falcon/models/models_node.rb', line 54 def cloud_service @cloud_service end |
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
56 57 58 |
# File 'lib/crimson-falcon/models/models_node.rb', line 56 def cluster_id @cluster_id end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
58 59 60 |
# File 'lib/crimson-falcon/models/models_node.rb', line 58 def cluster_name @cluster_name end |
#container_count ⇒ Object
Returns the value of attribute container_count.
60 61 62 |
# File 'lib/crimson-falcon/models/models_node.rb', line 60 def container_count @container_count end |
#container_runtime_version ⇒ Object
Returns the value of attribute container_runtime_version.
62 63 64 |
# File 'lib/crimson-falcon/models/models_node.rb', line 62 def container_runtime_version @container_runtime_version end |
#cpu ⇒ Object
Returns the value of attribute cpu.
64 65 66 |
# File 'lib/crimson-falcon/models/models_node.rb', line 64 def cpu @cpu end |
#created_at ⇒ Object
Returns the value of attribute created_at.
66 67 68 |
# File 'lib/crimson-falcon/models/models_node.rb', line 66 def created_at @created_at end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
68 69 70 |
# File 'lib/crimson-falcon/models/models_node.rb', line 68 def deleted_at @deleted_at end |
#external_ip ⇒ Object
Returns the value of attribute external_ip.
70 71 72 |
# File 'lib/crimson-falcon/models/models_node.rb', line 70 def external_ip @external_ip end |
#first_seen ⇒ Object
Returns the value of attribute first_seen.
72 73 74 |
# File 'lib/crimson-falcon/models/models_node.rb', line 72 def first_seen @first_seen end |
#ipv4 ⇒ Object
Returns the value of attribute ipv4.
74 75 76 |
# File 'lib/crimson-falcon/models/models_node.rb', line 74 def ipv4 @ipv4 end |
#ipv6 ⇒ Object
Returns the value of attribute ipv6.
76 77 78 |
# File 'lib/crimson-falcon/models/models_node.rb', line 76 def ipv6 @ipv6 end |
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
78 79 80 |
# File 'lib/crimson-falcon/models/models_node.rb', line 78 def kac_agent_id @kac_agent_id end |
#kernel_version ⇒ Object
Returns the value of attribute kernel_version.
80 81 82 |
# File 'lib/crimson-falcon/models/models_node.rb', line 80 def kernel_version @kernel_version end |
#kubernetes_version ⇒ Object
Returns the value of attribute kubernetes_version.
82 83 84 |
# File 'lib/crimson-falcon/models/models_node.rb', line 82 def kubernetes_version @kubernetes_version end |
#labels ⇒ Object
Returns the value of attribute labels.
84 85 86 |
# File 'lib/crimson-falcon/models/models_node.rb', line 84 def labels @labels end |
#labels_list ⇒ Object
Returns the value of attribute labels_list.
86 87 88 |
# File 'lib/crimson-falcon/models/models_node.rb', line 86 def labels_list @labels_list end |
#last_seen ⇒ Object
Returns the value of attribute last_seen.
88 89 90 |
# File 'lib/crimson-falcon/models/models_node.rb', line 88 def last_seen @last_seen end |
#linux_sensor_coverage ⇒ Object
Returns the value of attribute linux_sensor_coverage.
90 91 92 |
# File 'lib/crimson-falcon/models/models_node.rb', line 90 def linux_sensor_coverage @linux_sensor_coverage end |
#memory ⇒ Object
Returns the value of attribute memory.
92 93 94 |
# File 'lib/crimson-falcon/models/models_node.rb', line 92 def memory @memory end |
#node_id ⇒ Object
Returns the value of attribute node_id.
94 95 96 |
# File 'lib/crimson-falcon/models/models_node.rb', line 94 def node_id @node_id end |
#node_name ⇒ Object
Returns the value of attribute node_name.
96 97 98 |
# File 'lib/crimson-falcon/models/models_node.rb', line 96 def node_name @node_name end |
#os ⇒ Object
Returns the value of attribute os.
98 99 100 |
# File 'lib/crimson-falcon/models/models_node.rb', line 98 def os @os end |
#pod_cidr ⇒ Object
Returns the value of attribute pod_cidr.
100 101 102 |
# File 'lib/crimson-falcon/models/models_node.rb', line 100 def pod_cidr @pod_cidr end |
#pod_count ⇒ Object
Returns the value of attribute pod_count.
102 103 104 |
# File 'lib/crimson-falcon/models/models_node.rb', line 102 def pod_count @pod_count end |
#provider_id ⇒ Object
Returns the value of attribute provider_id.
104 105 106 |
# File 'lib/crimson-falcon/models/models_node.rb', line 104 def provider_id @provider_id end |
#resource_status ⇒ Object
Returns the value of attribute resource_status.
106 107 108 |
# File 'lib/crimson-falcon/models/models_node.rb', line 106 def resource_status @resource_status end |
#storage ⇒ Object
Returns the value of attribute storage.
108 109 110 |
# File 'lib/crimson-falcon/models/models_node.rb', line 108 def storage @storage end |
#uid ⇒ Object
Returns the value of attribute uid.
110 111 112 |
# File 'lib/crimson-falcon/models/models_node.rb', line 110 def uid @uid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
158 159 160 |
# File 'lib/crimson-falcon/models/models_node.rb', line 158 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/crimson-falcon/models/models_node.rb', line 113 def self.attribute_map { :'agents' => :'agents', :'annotations_list' => :'annotations_list', :'architecture' => :'architecture', :'base_image' => :'base_image', :'cid' => :'cid', :'cloud_account_id' => :'cloud_account_id', :'cloud_instance_id' => :'cloud_instance_id', :'cloud_instance_type' => :'cloud_instance_type', :'cloud_name' => :'cloud_name', :'cloud_region' => :'cloud_region', :'cloud_service' => :'cloud_service', :'cluster_id' => :'cluster_id', :'cluster_name' => :'cluster_name', :'container_count' => :'container_count', :'container_runtime_version' => :'container_runtime_version', :'cpu' => :'cpu', :'created_at' => :'created_at', :'deleted_at' => :'deleted_at', :'external_ip' => :'external_ip', :'first_seen' => :'first_seen', :'ipv4' => :'ipv4', :'ipv6' => :'ipv6', :'kac_agent_id' => :'kac_agent_id', :'kernel_version' => :'kernel_version', :'kubernetes_version' => :'kubernetes_version', :'labels' => :'labels', :'labels_list' => :'labels_list', :'last_seen' => :'last_seen', :'linux_sensor_coverage' => :'linux_sensor_coverage', :'memory' => :'memory', :'node_id' => :'node_id', :'node_name' => :'node_name', :'os' => :'os', :'pod_cidr' => :'pod_cidr', :'pod_count' => :'pod_count', :'provider_id' => :'provider_id', :'resource_status' => :'resource_status', :'storage' => :'storage', :'uid' => :'uid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
657 658 659 |
# File 'lib/crimson-falcon/models/models_node.rb', line 657 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
208 209 210 211 |
# File 'lib/crimson-falcon/models/models_node.rb', line 208 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/crimson-falcon/models/models_node.rb', line 163 def self.openapi_types { :'agents' => :'Array<Hash>', :'annotations_list' => :'Array<String>', :'architecture' => :'String', :'base_image' => :'String', :'cid' => :'String', :'cloud_account_id' => :'String', :'cloud_instance_id' => :'String', :'cloud_instance_type' => :'String', :'cloud_name' => :'String', :'cloud_region' => :'String', :'cloud_service' => :'String', :'cluster_id' => :'String', :'cluster_name' => :'String', :'container_count' => :'Integer', :'container_runtime_version' => :'String', :'cpu' => :'String', :'created_at' => :'String', :'deleted_at' => :'String', :'external_ip' => :'String', :'first_seen' => :'String', :'ipv4' => :'String', :'ipv6' => :'String', :'kac_agent_id' => :'String', :'kernel_version' => :'String', :'kubernetes_version' => :'String', :'labels' => :'Hash<String, String>', :'labels_list' => :'Array<String>', :'last_seen' => :'String', :'linux_sensor_coverage' => :'Boolean', :'memory' => :'String', :'node_id' => :'String', :'node_name' => :'String', :'os' => :'String', :'pod_cidr' => :'String', :'pod_count' => :'Integer', :'provider_id' => :'String', :'resource_status' => :'String', :'storage' => :'String', :'uid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/crimson-falcon/models/models_node.rb', line 598 def ==(o) return true if self.equal?(o) self.class == o.class && agents == o.agents && annotations_list == o.annotations_list && architecture == o.architecture && base_image == o.base_image && cid == o.cid && cloud_account_id == o.cloud_account_id && cloud_instance_id == o.cloud_instance_id && cloud_instance_type == o.cloud_instance_type && cloud_name == o.cloud_name && cloud_region == o.cloud_region && cloud_service == o.cloud_service && cluster_id == o.cluster_id && cluster_name == o.cluster_name && container_count == o.container_count && container_runtime_version == o.container_runtime_version && cpu == o.cpu && created_at == o.created_at && deleted_at == o.deleted_at && external_ip == o.external_ip && first_seen == o.first_seen && ipv4 == o.ipv4 && ipv6 == o.ipv6 && kac_agent_id == o.kac_agent_id && kernel_version == o.kernel_version && kubernetes_version == o.kubernetes_version && labels == o.labels && labels_list == o.labels_list && last_seen == o.last_seen && linux_sensor_coverage == o.linux_sensor_coverage && memory == o.memory && node_id == o.node_id && node_name == o.node_name && os == o.os && pod_cidr == o.pod_cidr && pod_count == o.pod_count && provider_id == o.provider_id && resource_status == o.resource_status && storage == o.storage && uid == o.uid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/crimson-falcon/models/models_node.rb', line 688 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/crimson-falcon/models/models_node.rb', line 759 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 |
# File 'lib/crimson-falcon/models/models_node.rb', line 664 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
644 645 646 |
# File 'lib/crimson-falcon/models/models_node.rb', line 644 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
650 651 652 |
# File 'lib/crimson-falcon/models/models_node.rb', line 650 def hash [agents, annotations_list, architecture, base_image, cid, cloud_account_id, cloud_instance_id, cloud_instance_type, cloud_name, cloud_region, cloud_service, cluster_id, cluster_name, container_count, container_runtime_version, cpu, created_at, deleted_at, external_ip, first_seen, ipv4, ipv6, kac_agent_id, kernel_version, kubernetes_version, labels, labels_list, last_seen, linux_sensor_coverage, memory, node_id, node_name, os, pod_cidr, pod_count, provider_id, resource_status, storage, uid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/crimson-falcon/models/models_node.rb', line 395 def list_invalid_properties invalid_properties = Array.new if @agents.nil? invalid_properties.push('invalid value for "agents", agents cannot be nil.') end if @annotations_list.nil? invalid_properties.push('invalid value for "annotations_list", annotations_list cannot be nil.') end if @architecture.nil? invalid_properties.push('invalid value for "architecture", architecture cannot be nil.') end if @base_image.nil? invalid_properties.push('invalid value for "base_image", base_image cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cloud_account_id.nil? invalid_properties.push('invalid value for "cloud_account_id", cloud_account_id cannot be nil.') end if @cloud_instance_id.nil? invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.') end if @cloud_instance_type.nil? invalid_properties.push('invalid value for "cloud_instance_type", cloud_instance_type cannot be nil.') end if @cloud_name.nil? invalid_properties.push('invalid value for "cloud_name", cloud_name cannot be nil.') end if @cloud_region.nil? invalid_properties.push('invalid value for "cloud_region", cloud_region cannot be nil.') end if @cloud_service.nil? invalid_properties.push('invalid value for "cloud_service", cloud_service cannot be nil.') end if @cluster_id.nil? invalid_properties.push('invalid value for "cluster_id", cluster_id cannot be nil.') end if @cluster_name.nil? invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.') end if @container_count.nil? invalid_properties.push('invalid value for "container_count", container_count cannot be nil.') end if @container_runtime_version.nil? invalid_properties.push('invalid value for "container_runtime_version", container_runtime_version cannot be nil.') end if @cpu.nil? invalid_properties.push('invalid value for "cpu", cpu cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @external_ip.nil? invalid_properties.push('invalid value for "external_ip", external_ip cannot be nil.') end if @first_seen.nil? invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.') end if @ipv4.nil? invalid_properties.push('invalid value for "ipv4", ipv4 cannot be nil.') end if @ipv6.nil? invalid_properties.push('invalid value for "ipv6", ipv6 cannot be nil.') end if @kac_agent_id.nil? invalid_properties.push('invalid value for "kac_agent_id", kac_agent_id cannot be nil.') end if @kernel_version.nil? invalid_properties.push('invalid value for "kernel_version", kernel_version cannot be nil.') end if @kubernetes_version.nil? invalid_properties.push('invalid value for "kubernetes_version", kubernetes_version cannot be nil.') end if @labels.nil? invalid_properties.push('invalid value for "labels", labels cannot be nil.') end if @labels_list.nil? invalid_properties.push('invalid value for "labels_list", labels_list cannot be nil.') end if @last_seen.nil? invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.') end if @linux_sensor_coverage.nil? invalid_properties.push('invalid value for "linux_sensor_coverage", linux_sensor_coverage cannot be nil.') end if @memory.nil? invalid_properties.push('invalid value for "memory", memory cannot be nil.') end if @node_id.nil? invalid_properties.push('invalid value for "node_id", node_id cannot be nil.') end if @node_name.nil? invalid_properties.push('invalid value for "node_name", node_name cannot be nil.') end if @os.nil? invalid_properties.push('invalid value for "os", os cannot be nil.') end if @pod_cidr.nil? invalid_properties.push('invalid value for "pod_cidr", pod_cidr cannot be nil.') end if @pod_count.nil? invalid_properties.push('invalid value for "pod_count", pod_count cannot be nil.') end if @provider_id.nil? invalid_properties.push('invalid value for "provider_id", provider_id cannot be nil.') end if @resource_status.nil? invalid_properties.push('invalid value for "resource_status", resource_status cannot be nil.') end if @storage.nil? invalid_properties.push('invalid value for "storage", storage cannot be nil.') end if @uid.nil? invalid_properties.push('invalid value for "uid", uid cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
735 736 737 |
# File 'lib/crimson-falcon/models/models_node.rb', line 735 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/crimson-falcon/models/models_node.rb', line 741 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
729 730 731 |
# File 'lib/crimson-falcon/models/models_node.rb', line 729 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/crimson-falcon/models/models_node.rb', line 554 def valid? return false if @agents.nil? return false if @annotations_list.nil? return false if @architecture.nil? return false if @base_image.nil? return false if @cid.nil? return false if @cloud_account_id.nil? return false if @cloud_instance_id.nil? return false if @cloud_instance_type.nil? return false if @cloud_name.nil? return false if @cloud_region.nil? return false if @cloud_service.nil? return false if @cluster_id.nil? return false if @cluster_name.nil? return false if @container_count.nil? return false if @container_runtime_version.nil? return false if @cpu.nil? return false if @created_at.nil? return false if @external_ip.nil? return false if @first_seen.nil? return false if @ipv4.nil? return false if @ipv6.nil? return false if @kac_agent_id.nil? return false if @kernel_version.nil? return false if @kubernetes_version.nil? return false if @labels.nil? return false if @labels_list.nil? return false if @last_seen.nil? return false if @linux_sensor_coverage.nil? return false if @memory.nil? return false if @node_id.nil? return false if @node_name.nil? return false if @os.nil? return false if @pod_cidr.nil? return false if @pod_count.nil? return false if @provider_id.nil? return false if @resource_status.nil? return false if @storage.nil? return false if @uid.nil? true end |