Class: Falcon::NetworkScanNetworks

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/network_scan_networks.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NetworkScanNetworks

Returns a new instance of NetworkScanNetworks.



35
36
37
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#aggregate_networks(body, opts = {}) ⇒ MsaAggregatesResponse

Returns "networks" aggregations

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregation specification

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



43
44
45
46
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 43

def aggregate_networks(body, opts = {})
  data, _status_code, _headers = aggregate_networks_with_http_info(body, opts)
  data
end

#aggregate_networks_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>

Returns &quot;networks&quot; aggregations

Parameters:

  • body (Array<MsaAggregateQueryRequest>)

    Aggregation specification

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:

  • (Array<(MsaAggregatesResponse, Integer, Hash)>)

    MsaAggregatesResponse data, response status code and response headers



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 53

def aggregate_networks_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.aggregate_networks ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanNetworks.aggregate_networks"
  end
  # resource path
  local_var_path = '/netscan/aggregates/networks/GET/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'MsaAggregatesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.aggregate_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#aggregate_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_networks(body, opts = {}) ⇒ DomainNetworkEntitiesResponse

Create "networks" using provided specifications

Parameters:

  • body (Array<DomainNetworkCreateRequest>)

    &quot;networks&quot; specifications

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



112
113
114
115
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 112

def create_networks(body, opts = {})
  data, _status_code, _headers = create_networks_with_http_info(body, opts)
  data
end

#create_networks_with_http_info(body, opts = {}) ⇒ Array<(DomainNetworkEntitiesResponse, Integer, Hash)>

Create &quot;networks&quot; using provided specifications

Parameters:

  • body (Array<DomainNetworkCreateRequest>)

    &quot;networks&quot; specifications

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 122

def create_networks_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.create_networks ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanNetworks.create_networks"
  end
  # resource path
  local_var_path = '/netscan/entities/networks/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'DomainNetworkEntitiesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.create_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#create_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_networks(ids, opts = {}) ⇒ MsaspecQueryResponse

Delete "networks" by their IDs

Parameters:

  • ids (Array<String>)

    IDs of &quot;networks&quot; to be deleted (Min: 1, Max: 100)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



181
182
183
184
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 181

def delete_networks(ids, opts = {})
  data, _status_code, _headers = delete_networks_with_http_info(ids, opts)
  data
end

#delete_networks_with_http_info(ids, opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Delete &quot;networks&quot; by their IDs

Parameters:

  • ids (Array<String>)

    IDs of &quot;networks&quot; to be deleted (Min: 1, Max: 100)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 191

def delete_networks_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.delete_networks ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanNetworks.delete_networks"
  end
  # resource path
  local_var_path = '/netscan/entities/networks/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.delete_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#delete_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_networks(ids, opts = {}) ⇒ DomainNetworkEntitiesResponse

Get "networks" by their IDs

Parameters:

  • ids (Array<String>)

    IDs of &quot;networks&quot; to be retrieved (Min: 1, Max: 100)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



246
247
248
249
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 246

def get_networks(ids, opts = {})
  data, _status_code, _headers = get_networks_with_http_info(ids, opts)
  data
end

#get_networks_with_http_info(ids, opts = {}) ⇒ Array<(DomainNetworkEntitiesResponse, Integer, Hash)>

Get &quot;networks&quot; by their IDs

Parameters:

  • ids (Array<String>)

    IDs of &quot;networks&quot; to be retrieved (Min: 1, Max: 100)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 256

def get_networks_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.get_networks ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanNetworks.get_networks"
  end
  # resource path
  local_var_path = '/netscan/entities/networks/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainNetworkEntitiesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.get_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#get_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#query_networks(opts = {}) ⇒ MsaspecQueryResponse

Get "networks IDs" by filter

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

  • :offset (Integer)

    An offset used with the &#x60;limit&#x60; parameter to manage pagination of results. On your first request, don’t provide an &#x60;offset&#x60;. On subsequent requests, add previous &#x60;offset&#x60; with the previous &#x60;limit&#x60; to continue from that place in the results

  • :limit (Integer)

    The number of &quot;networks IDs&quot; to return in this response (Min: 1, Max: 100, Default: 100)

  • :sort (String)

    Sort &quot;networks&quot; by their properties. A single sort field is allowed

  • :filter (String)

    Search for &quot;networks&quot; by providing an FQL filter

Returns:



314
315
316
317
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 314

def query_networks(opts = {})
  data, _status_code, _headers = query_networks_with_http_info(opts)
  data
end

#query_networks_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Get &quot;networks IDs&quot; by filter

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

  • :offset (Integer)

    An offset used with the &#x60;limit&#x60; parameter to manage pagination of results. On your first request, don’t provide an &#x60;offset&#x60;. On subsequent requests, add previous &#x60;offset&#x60; with the previous &#x60;limit&#x60; to continue from that place in the results

  • :limit (Integer)

    The number of &quot;networks IDs&quot; to return in this response (Min: 1, Max: 100, Default: 100)

  • :sort (String)

    Sort &quot;networks&quot; by their properties. A single sort field is allowed

  • :filter (String)

    Search for &quot;networks&quot; by providing an FQL filter

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 327

def query_networks_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.query_networks ...'
  end
  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling NetworkScanNetworks.query_networks, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanNetworks.query_networks, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanNetworks.query_networks, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/netscan/queries/networks/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.query_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#query_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_networks(body, opts = {}) ⇒ DomainNetworkEntitiesResponse

Update "networks" using provided specifications

Parameters:

  • body (Array<DomainNetworkUpdateRequest>)

    &quot;networks&quot; specifications for updating

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



393
394
395
396
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 393

def update_networks(body, opts = {})
  data, _status_code, _headers = update_networks_with_http_info(body, opts)
  data
end

#update_networks_with_http_info(body, opts = {}) ⇒ Array<(DomainNetworkEntitiesResponse, Integer, Hash)>

Update &quot;networks&quot; using provided specifications

Parameters:

  • body (Array<DomainNetworkUpdateRequest>)

    &quot;networks&quot; specifications for updating

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_cs_useruuid (String)

    User UUID

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/crimson-falcon/api/network_scan_networks.rb', line 403

def update_networks_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NetworkScanNetworks.update_networks ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanNetworks.update_networks"
  end
  # resource path
  local_var_path = '/netscan/entities/networks/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
    header_params['Content-Type'] = content_type
  end
  header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'DomainNetworkEntitiesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"NetworkScanNetworks.update_networks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NetworkScanNetworks#update_networks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end