Class: Falcon::NetworkScanScanRuns
- Inherits:
-
Object
- Object
- Falcon::NetworkScanScanRuns
- Defined in:
- lib/crimson-falcon/api/network_scan_scan_runs.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#aggregate_scan_runs(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "scan-runs" aggregations.
-
#aggregate_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "scan-runs" aggregations.
-
#create_scan_runs(body, opts = {}) ⇒ DomainScanRunEntitiesResponse
Create "scan-runs" using provided specifications.
-
#create_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Create "scan-runs" using provided specifications.
-
#get_scan_runs(ids, opts = {}) ⇒ DomainScanRunEntitiesResponse
Get "scan-runs" by their IDs.
-
#get_scan_runs_with_http_info(ids, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Get "scan-runs" by their IDs.
-
#initialize(api_client = ApiClient.default) ⇒ NetworkScanScanRuns
constructor
A new instance of NetworkScanScanRuns.
-
#query_scan_runs(opts = {}) ⇒ MsaspecQueryResponse
Get "scan-runs IDs" by filter.
-
#query_scan_runs_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "scan-runs IDs" by filter.
-
#update_scan_runs(body, opts = {}) ⇒ DomainScanRunEntitiesResponse
Update "scan-runs" using provided specifications.
-
#update_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Update "scan-runs" using provided specifications.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ NetworkScanScanRuns
Returns a new instance of NetworkScanScanRuns.
35 36 37 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 33 def api_client @api_client end |
Instance Method Details
#aggregate_scan_runs(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "scan-runs" aggregations
43 44 45 46 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 43 def aggregate_scan_runs(body, opts = {}) data, _status_code, _headers = aggregate_scan_runs_with_http_info(body, opts) data end |
#aggregate_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "scan-runs" aggregations
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 53 def aggregate_scan_runs_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanRuns.aggregate_scan_runs ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanScanRuns.aggregate_scan_runs" end # resource path local_var_path = '/netscan/aggregates/scan-runs/GET/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'MsaAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanRuns.aggregate_scan_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanRuns#aggregate_scan_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_scan_runs(body, opts = {}) ⇒ DomainScanRunEntitiesResponse
Create "scan-runs" using provided specifications
112 113 114 115 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 112 def create_scan_runs(body, opts = {}) data, _status_code, _headers = create_scan_runs_with_http_info(body, opts) data end |
#create_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Create "scan-runs" using provided specifications
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 122 def create_scan_runs_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanRuns.create_scan_runs ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanScanRuns.create_scan_runs" end # resource path local_var_path = '/netscan/entities/scan-runs/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainScanRunEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanRuns.create_scan_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanRuns#create_scan_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_scan_runs(ids, opts = {}) ⇒ DomainScanRunEntitiesResponse
Get "scan-runs" by their IDs
181 182 183 184 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 181 def get_scan_runs(ids, opts = {}) data, _status_code, _headers = get_scan_runs_with_http_info(ids, opts) data end |
#get_scan_runs_with_http_info(ids, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Get "scan-runs" by their IDs
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 191 def get_scan_runs_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanRuns.get_scan_runs ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanScanRuns.get_scan_runs" end # resource path local_var_path = '/netscan/entities/scan-runs/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainScanRunEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanRuns.get_scan_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanRuns#get_scan_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_scan_runs(opts = {}) ⇒ MsaspecQueryResponse
Get "scan-runs IDs" by filter
249 250 251 252 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 249 def query_scan_runs(opts = {}) data, _status_code, _headers = query_scan_runs_with_http_info(opts) data end |
#query_scan_runs_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "scan-runs IDs" by filter
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 262 def query_scan_runs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanRuns.query_scan_runs ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling NetworkScanScanRuns.query_scan_runs, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanScanRuns.query_scan_runs, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanScanRuns.query_scan_runs, must be greater than or equal to 1.' end # resource path local_var_path = '/netscan/queries/scan-runs/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanRuns.query_scan_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanRuns#query_scan_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_scan_runs(body, opts = {}) ⇒ DomainScanRunEntitiesResponse
Update "scan-runs" using provided specifications
328 329 330 331 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 328 def update_scan_runs(body, opts = {}) data, _status_code, _headers = update_scan_runs_with_http_info(body, opts) data end |
#update_scan_runs_with_http_info(body, opts = {}) ⇒ Array<(DomainScanRunEntitiesResponse, Integer, Hash)>
Update "scan-runs" using provided specifications
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/crimson-falcon/api/network_scan_scan_runs.rb', line 338 def update_scan_runs_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanRuns.update_scan_runs ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanScanRuns.update_scan_runs" end # resource path local_var_path = '/netscan/entities/scan-runs/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainScanRunEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanRuns.update_scan_runs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanRuns#update_scan_runs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |