Class: Falcon::NetworkScanScanners
- Inherits:
-
Object
- Object
- Falcon::NetworkScanScanners
- Defined in:
- lib/crimson-falcon/api/network_scan_scanners.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#aggregate_scanners(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "scanners" aggregations.
-
#aggregate_scanners_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "scanners" aggregations.
-
#get_scanners(ids, opts = {}) ⇒ DomainScannerEntitiesResponse
Get "scanners" by their IDs.
-
#get_scanners_with_http_info(ids, opts = {}) ⇒ Array<(DomainScannerEntitiesResponse, Integer, Hash)>
Get "scanners" by their IDs.
-
#initialize(api_client = ApiClient.default) ⇒ NetworkScanScanners
constructor
A new instance of NetworkScanScanners.
-
#query_scanners(opts = {}) ⇒ MsaspecQueryResponse
Get "scanners IDs" by filter.
-
#query_scanners_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "scanners IDs" by filter.
-
#update_scanners(body, opts = {}) ⇒ DomainScannersUpdateResponse
Update "scanners" using provided specifications.
-
#update_scanners_with_http_info(body, opts = {}) ⇒ Array<(DomainScannersUpdateResponse, Integer, Hash)>
Update "scanners" using provided specifications.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ NetworkScanScanners
Returns a new instance of NetworkScanScanners.
35 36 37 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 33 def api_client @api_client end |
Instance Method Details
#aggregate_scanners(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "scanners" aggregations
43 44 45 46 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 43 def aggregate_scanners(body, opts = {}) data, _status_code, _headers = aggregate_scanners_with_http_info(body, opts) data end |
#aggregate_scanners_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "scanners" aggregations
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 53 def aggregate_scanners_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanners.aggregate_scanners ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanScanners.aggregate_scanners" end # resource path local_var_path = '/netscan/aggregates/scanners/GET/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'MsaAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanners.aggregate_scanners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanners#aggregate_scanners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_scanners(ids, opts = {}) ⇒ DomainScannerEntitiesResponse
Get "scanners" by their IDs
112 113 114 115 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 112 def get_scanners(ids, opts = {}) data, _status_code, _headers = get_scanners_with_http_info(ids, opts) data end |
#get_scanners_with_http_info(ids, opts = {}) ⇒ Array<(DomainScannerEntitiesResponse, Integer, Hash)>
Get "scanners" by their IDs
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 122 def get_scanners_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanners.get_scanners ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanScanners.get_scanners" end # resource path local_var_path = '/netscan/entities/scanners/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainScannerEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanners.get_scanners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanners#get_scanners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_scanners(opts = {}) ⇒ MsaspecQueryResponse
Get "scanners IDs" by filter
180 181 182 183 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 180 def query_scanners(opts = {}) data, _status_code, _headers = query_scanners_with_http_info(opts) data end |
#query_scanners_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "scanners IDs" by filter
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 193 def query_scanners_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanners.query_scanners ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling NetworkScanScanners.query_scanners, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanScanners.query_scanners, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanScanners.query_scanners, must be greater than or equal to 1.' end # resource path local_var_path = '/netscan/queries/scanners/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanners.query_scanners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanners#query_scanners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_scanners(body, opts = {}) ⇒ DomainScannersUpdateResponse
Update "scanners" using provided specifications
259 260 261 262 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 259 def update_scanners(body, opts = {}) data, _status_code, _headers = update_scanners_with_http_info(body, opts) data end |
#update_scanners_with_http_info(body, opts = {}) ⇒ Array<(DomainScannersUpdateResponse, Integer, Hash)>
Update "scanners" using provided specifications
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/crimson-falcon/api/network_scan_scanners.rb', line 269 def update_scanners_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanScanners.update_scanners ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanScanners.update_scanners" end # resource path local_var_path = '/netscan/entities/scanners/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainScannersUpdateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanScanners.update_scanners", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanScanners#update_scanners\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |