Class: Falcon::PreventionPolicyV1
- Inherits:
-
Object
- Object
- Falcon::PreventionPolicyV1
- Defined in:
- lib/crimson-falcon/models/prevention_policy_v1.rb
Overview
A fully formed prevention policy
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cid ⇒ Object
The customer id associated with the policy.
-
#created_by ⇒ Object
The email of the user which created the policy.
-
#created_timestamp ⇒ Object
The time at which the policy was created.
-
#description ⇒ Object
The description of a policy.
-
#enabled ⇒ Object
If a policy is enabled it will be used during the course of policy evaluation.
-
#groups ⇒ Object
The groups that are currently attached to the policy.
-
#id ⇒ Object
The unique id of the policy.
-
#ioa_rule_groups ⇒ Object
The IOA rule groups that are currently attached to the policy.
-
#modified_by ⇒ Object
The email of the user which last modified the policy.
-
#modified_timestamp ⇒ Object
The time at which the policy was last modified.
-
#name ⇒ Object
The human readable name of the policy.
-
#platform_name ⇒ Object
The name of the platform.
-
#prevention_settings ⇒ Object
A category of settings in a prevention policy.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PreventionPolicyV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PreventionPolicyV1
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 147 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::PreventionPolicyV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::PreventionPolicyV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_timestamp') self. = attributes[:'created_timestamp'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ioa_rule_groups') if (value = attributes[:'ioa_rule_groups']).is_a?(Array) self.ioa_rule_groups = value end end if attributes.key?(:'modified_by') self.modified_by = attributes[:'modified_by'] end if attributes.key?(:'modified_timestamp') self. = attributes[:'modified_timestamp'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'prevention_settings') if (value = attributes[:'prevention_settings']).is_a?(Array) self.prevention_settings = value end end end |
Instance Attribute Details
#cid ⇒ Object
The customer id associated with the policy
36 37 38 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 36 def cid @cid end |
#created_by ⇒ Object
The email of the user which created the policy
39 40 41 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 39 def created_by @created_by end |
#created_timestamp ⇒ Object
The time at which the policy was created
42 43 44 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 42 def @created_timestamp end |
#description ⇒ Object
The description of a policy. Use this field to provide a high level summary of what this policy enforces
45 46 47 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 45 def description @description end |
#enabled ⇒ Object
If a policy is enabled it will be used during the course of policy evaluation
48 49 50 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 48 def enabled @enabled end |
#groups ⇒ Object
The groups that are currently attached to the policy
51 52 53 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 51 def groups @groups end |
#id ⇒ Object
The unique id of the policy
54 55 56 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 54 def id @id end |
#ioa_rule_groups ⇒ Object
The IOA rule groups that are currently attached to the policy
57 58 59 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 57 def ioa_rule_groups @ioa_rule_groups end |
#modified_by ⇒ Object
The email of the user which last modified the policy
60 61 62 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 60 def modified_by @modified_by end |
#modified_timestamp ⇒ Object
The time at which the policy was last modified
63 64 65 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 63 def @modified_timestamp end |
#name ⇒ Object
The human readable name of the policy
66 67 68 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 66 def name @name end |
#platform_name ⇒ Object
The name of the platform
69 70 71 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 69 def platform_name @platform_name end |
#prevention_settings ⇒ Object
A category of settings in a prevention policy
72 73 74 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 72 def prevention_settings @prevention_settings end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
116 117 118 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 116 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 97 def self.attribute_map { :'cid' => :'cid', :'created_by' => :'created_by', :'created_timestamp' => :'created_timestamp', :'description' => :'description', :'enabled' => :'enabled', :'groups' => :'groups', :'id' => :'id', :'ioa_rule_groups' => :'ioa_rule_groups', :'modified_by' => :'modified_by', :'modified_timestamp' => :'modified_timestamp', :'name' => :'name', :'platform_name' => :'platform_name', :'prevention_settings' => :'prevention_settings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 344 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
140 141 142 143 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 140 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 121 def self.openapi_types { :'cid' => :'String', :'created_by' => :'String', :'created_timestamp' => :'Time', :'description' => :'String', :'enabled' => :'Boolean', :'groups' => :'Array<HostGroupsHostGroupV1>', :'id' => :'String', :'ioa_rule_groups' => :'Array<IoaRuleGroupsRuleGroupV1>', :'modified_by' => :'String', :'modified_timestamp' => :'Time', :'name' => :'String', :'platform_name' => :'String', :'prevention_settings' => :'Array<PreventionCategoryRespV1>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 311 def ==(o) return true if self.equal?(o) self.class == o.class && cid == o.cid && created_by == o.created_by && == o. && description == o.description && enabled == o.enabled && groups == o.groups && id == o.id && ioa_rule_groups == o.ioa_rule_groups && modified_by == o.modified_by && == o. && name == o.name && platform_name == o.platform_name && prevention_settings == o.prevention_settings end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 375 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 446 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 351 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
331 332 333 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 331 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
337 338 339 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 337 def hash [cid, created_by, , description, enabled, groups, id, ioa_rule_groups, modified_by, , name, platform_name, prevention_settings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 221 def list_invalid_properties invalid_properties = Array.new if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @created_timestamp.nil? invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @groups.nil? invalid_properties.push('invalid value for "groups", groups cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @ioa_rule_groups.nil? invalid_properties.push('invalid value for "ioa_rule_groups", ioa_rule_groups cannot be nil.') end if @modified_by.nil? invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.') end if @modified_timestamp.nil? invalid_properties.push('invalid value for "modified_timestamp", modified_timestamp cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @platform_name.nil? invalid_properties.push('invalid value for "platform_name", platform_name cannot be nil.') end if @prevention_settings.nil? invalid_properties.push('invalid value for "prevention_settings", prevention_settings cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
422 423 424 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 422 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 428 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
416 417 418 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 416 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/crimson-falcon/models/prevention_policy_v1.rb', line 280 def valid? return false if @cid.nil? return false if @created_by.nil? return false if @created_timestamp.nil? return false if @description.nil? return false if @enabled.nil? return false if @groups.nil? return false if @id.nil? return false if @ioa_rule_groups.nil? return false if @modified_by.nil? return false if @modified_timestamp.nil? return false if @name.nil? return false if @platform_name.nil? platform_name_validator = EnumAttributeValidator.new('String', ["Windows", "Mac", "Linux"]) return false unless platform_name_validator.valid?(@platform_name) return false if @prevention_settings.nil? true end |