Class: Falcon::QuickScan
- Inherits:
-
Object
- Object
- Falcon::QuickScan
- Defined in:
- lib/crimson-falcon/api/quick_scan.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_scans(ids, opts = {}) ⇒ MlscannerapiScanV1Response
Check the status of a volume scan.
-
#get_scans_aggregates(body, opts = {}) ⇒ nil
Get scans aggregations as specified via json in request body.
-
#get_scans_aggregates_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get scans aggregations as specified via json in request body.
-
#get_scans_with_http_info(ids, opts = {}) ⇒ Array<(MlscannerapiScanV1Response, Integer, Hash)>
Check the status of a volume scan.
-
#initialize(api_client = ApiClient.default) ⇒ QuickScan
constructor
A new instance of QuickScan.
-
#query_submissions(opts = {}) ⇒ MlscannerapiQueryResponse
Find IDs for submitted scans by providing an FQL filter and paging details.
-
#query_submissions_with_http_info(opts = {}) ⇒ Array<(MlscannerapiQueryResponse, Integer, Hash)>
Find IDs for submitted scans by providing an FQL filter and paging details.
-
#scan_samples(body, opts = {}) ⇒ MlscannerapiQueryResponse
Submit a volume of files for ml scanning.
-
#scan_samples_with_http_info(body, opts = {}) ⇒ Array<(MlscannerapiQueryResponse, Integer, Hash)>
Submit a volume of files for ml scanning.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_scans(ids, opts = {}) ⇒ MlscannerapiScanV1Response
Check the status of a volume scan. Time required for analysis increases with the number of samples in a volume but usually it should take less than 1 minute
42 43 44 45 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 42 def get_scans(ids, opts = {}) data, _status_code, _headers = get_scans_with_http_info(ids, opts) data end |
#get_scans_aggregates(body, opts = {}) ⇒ nil
Get scans aggregations as specified via json in request body.
104 105 106 107 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 104 def get_scans_aggregates(body, opts = {}) get_scans_aggregates_with_http_info(body, opts) nil end |
#get_scans_aggregates_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get scans aggregations as specified via json in request body.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 113 def get_scans_aggregates_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: QuickScan.get_scans_aggregates ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling QuickScan.get_scans_aggregates" end # resource path local_var_path = '/scanner/aggregates/scans/GET/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"QuickScan.get_scans_aggregates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: QuickScan#get_scans_aggregates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_scans_with_http_info(ids, opts = {}) ⇒ Array<(MlscannerapiScanV1Response, Integer, Hash)>
Check the status of a volume scan. Time required for analysis increases with the number of samples in a volume but usually it should take less than 1 minute
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 51 def get_scans_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: QuickScan.get_scans ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling QuickScan.get_scans" end # resource path local_var_path = '/scanner/entities/scans/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :csv) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MlscannerapiScanV1Response' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"QuickScan.get_scans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: QuickScan#get_scans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_submissions(opts = {}) ⇒ MlscannerapiQueryResponse
Find IDs for submitted scans by providing an FQL filter and paging details. Returns a set of volume IDs that match your criteria.
173 174 175 176 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 173 def query_submissions(opts = {}) data, _status_code, _headers = query_submissions_with_http_info(opts) data end |
#query_submissions_with_http_info(opts = {}) ⇒ Array<(MlscannerapiQueryResponse, Integer, Hash)>
Find IDs for submitted scans by providing an FQL filter and paging details. Returns a set of volume IDs that match your criteria.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 185 def query_submissions_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: QuickScan.query_submissions ...' end # resource path local_var_path = '/scanner/queries/scans/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MlscannerapiQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"QuickScan.query_submissions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: QuickScan#query_submissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#scan_samples(body, opts = {}) ⇒ MlscannerapiQueryResponse
Submit a volume of files for ml scanning. Time required for analysis increases with the number of samples in a volume but usually it should take less than 1 minute
237 238 239 240 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 237 def scan_samples(body, opts = {}) data, _status_code, _headers = scan_samples_with_http_info(body, opts) data end |
#scan_samples_with_http_info(body, opts = {}) ⇒ Array<(MlscannerapiQueryResponse, Integer, Hash)>
Submit a volume of files for ml scanning. Time required for analysis increases with the number of samples in a volume but usually it should take less than 1 minute
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/crimson-falcon/api/quick_scan.rb', line 246 def scan_samples_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: QuickScan.scan_samples ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling QuickScan.scan_samples" end # resource path local_var_path = '/scanner/entities/scans/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'MlscannerapiQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"QuickScan.scan_samples", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: QuickScan#scan_samples\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |