Class: Falcon::RegistrationAWSAccountExtV2
- Inherits:
-
Object
- Object
- Falcon::RegistrationAWSAccountExtV2
- Defined in:
- lib/crimson-falcon/models/registration_aws_account_ext_v2.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#behavior_assessment_enabled ⇒ Object
Returns the value of attribute behavior_assessment_enabled.
-
#cloudtrail_region ⇒ Object
Returns the value of attribute cloudtrail_region.
-
#deployment_method ⇒ Object
Returns the value of attribute deployment_method.
-
#dspm_enabled ⇒ Object
Returns the value of attribute dspm_enabled.
-
#dspm_host_account_id ⇒ Object
Returns the value of attribute dspm_host_account_id.
-
#dspm_role ⇒ Object
Returns the value of attribute dspm_role.
-
#falcon_client_id ⇒ Object
Returns the value of attribute falcon_client_id.
-
#iam_role_arn ⇒ Object
Returns the value of attribute iam_role_arn.
-
#is_master ⇒ Object
Returns the value of attribute is_master.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#root_stack_id ⇒ Object
Returns the value of attribute root_stack_id.
-
#sensor_management_enabled ⇒ Object
Returns the value of attribute sensor_management_enabled.
-
#target_ous ⇒ Object
Returns the value of attribute target_ous.
-
#use_existing_cloudtrail ⇒ Object
Returns the value of attribute use_existing_cloudtrail.
-
#vulnerability_scanning_enabled ⇒ Object
Returns the value of attribute vulnerability_scanning_enabled.
-
#vulnerability_scanning_host_account_id ⇒ Object
Returns the value of attribute vulnerability_scanning_host_account_id.
-
#vulnerability_scanning_role ⇒ Object
Returns the value of attribute vulnerability_scanning_role.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegistrationAWSAccountExtV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RegistrationAWSAccountExtV2
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 135 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RegistrationAWSAccountExtV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RegistrationAWSAccountExtV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'behavior_assessment_enabled') self.behavior_assessment_enabled = attributes[:'behavior_assessment_enabled'] end if attributes.key?(:'cloudtrail_region') self.cloudtrail_region = attributes[:'cloudtrail_region'] end if attributes.key?(:'deployment_method') self.deployment_method = attributes[:'deployment_method'] end if attributes.key?(:'dspm_enabled') self.dspm_enabled = attributes[:'dspm_enabled'] end if attributes.key?(:'dspm_host_account_id') self.dspm_host_account_id = attributes[:'dspm_host_account_id'] end if attributes.key?(:'dspm_role') self.dspm_role = attributes[:'dspm_role'] end if attributes.key?(:'falcon_client_id') self.falcon_client_id = attributes[:'falcon_client_id'] end if attributes.key?(:'iam_role_arn') self.iam_role_arn = attributes[:'iam_role_arn'] end if attributes.key?(:'is_master') self.is_master = attributes[:'is_master'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'root_stack_id') self.root_stack_id = attributes[:'root_stack_id'] end if attributes.key?(:'sensor_management_enabled') self.sensor_management_enabled = attributes[:'sensor_management_enabled'] end if attributes.key?(:'target_ous') if (value = attributes[:'target_ous']).is_a?(Array) self.target_ous = value end end if attributes.key?(:'use_existing_cloudtrail') self.use_existing_cloudtrail = attributes[:'use_existing_cloudtrail'] end if attributes.key?(:'vulnerability_scanning_enabled') self.vulnerability_scanning_enabled = attributes[:'vulnerability_scanning_enabled'] end if attributes.key?(:'vulnerability_scanning_host_account_id') self.vulnerability_scanning_host_account_id = attributes[:'vulnerability_scanning_host_account_id'] end if attributes.key?(:'vulnerability_scanning_role') self.vulnerability_scanning_role = attributes[:'vulnerability_scanning_role'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
34 35 36 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 34 def account_id @account_id end |
#account_type ⇒ Object
Returns the value of attribute account_type.
36 37 38 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 36 def account_type @account_type end |
#behavior_assessment_enabled ⇒ Object
Returns the value of attribute behavior_assessment_enabled.
38 39 40 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 38 def behavior_assessment_enabled @behavior_assessment_enabled end |
#cloudtrail_region ⇒ Object
Returns the value of attribute cloudtrail_region.
40 41 42 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 40 def cloudtrail_region @cloudtrail_region end |
#deployment_method ⇒ Object
Returns the value of attribute deployment_method.
42 43 44 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 42 def deployment_method @deployment_method end |
#dspm_enabled ⇒ Object
Returns the value of attribute dspm_enabled.
44 45 46 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 44 def dspm_enabled @dspm_enabled end |
#dspm_host_account_id ⇒ Object
Returns the value of attribute dspm_host_account_id.
46 47 48 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 46 def dspm_host_account_id @dspm_host_account_id end |
#dspm_role ⇒ Object
Returns the value of attribute dspm_role.
48 49 50 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 48 def dspm_role @dspm_role end |
#falcon_client_id ⇒ Object
Returns the value of attribute falcon_client_id.
50 51 52 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 50 def falcon_client_id @falcon_client_id end |
#iam_role_arn ⇒ Object
Returns the value of attribute iam_role_arn.
52 53 54 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 52 def iam_role_arn @iam_role_arn end |
#is_master ⇒ Object
Returns the value of attribute is_master.
54 55 56 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 54 def is_master @is_master end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
56 57 58 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 56 def organization_id @organization_id end |
#root_stack_id ⇒ Object
Returns the value of attribute root_stack_id.
58 59 60 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 58 def root_stack_id @root_stack_id end |
#sensor_management_enabled ⇒ Object
Returns the value of attribute sensor_management_enabled.
60 61 62 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 60 def sensor_management_enabled @sensor_management_enabled end |
#target_ous ⇒ Object
Returns the value of attribute target_ous.
62 63 64 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 62 def target_ous @target_ous end |
#use_existing_cloudtrail ⇒ Object
Returns the value of attribute use_existing_cloudtrail.
64 65 66 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 64 def use_existing_cloudtrail @use_existing_cloudtrail end |
#vulnerability_scanning_enabled ⇒ Object
Returns the value of attribute vulnerability_scanning_enabled.
66 67 68 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 66 def vulnerability_scanning_enabled @vulnerability_scanning_enabled end |
#vulnerability_scanning_host_account_id ⇒ Object
Returns the value of attribute vulnerability_scanning_host_account_id.
68 69 70 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 68 def vulnerability_scanning_host_account_id @vulnerability_scanning_host_account_id end |
#vulnerability_scanning_role ⇒ Object
Returns the value of attribute vulnerability_scanning_role.
70 71 72 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 70 def vulnerability_scanning_role @vulnerability_scanning_role end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 73 def self.attribute_map { :'account_id' => :'account_id', :'account_type' => :'account_type', :'behavior_assessment_enabled' => :'behavior_assessment_enabled', :'cloudtrail_region' => :'cloudtrail_region', :'deployment_method' => :'deployment_method', :'dspm_enabled' => :'dspm_enabled', :'dspm_host_account_id' => :'dspm_host_account_id', :'dspm_role' => :'dspm_role', :'falcon_client_id' => :'falcon_client_id', :'iam_role_arn' => :'iam_role_arn', :'is_master' => :'is_master', :'organization_id' => :'organization_id', :'root_stack_id' => :'root_stack_id', :'sensor_management_enabled' => :'sensor_management_enabled', :'target_ous' => :'target_ous', :'use_existing_cloudtrail' => :'use_existing_cloudtrail', :'vulnerability_scanning_enabled' => :'vulnerability_scanning_enabled', :'vulnerability_scanning_host_account_id' => :'vulnerability_scanning_host_account_id', :'vulnerability_scanning_role' => :'vulnerability_scanning_role' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 301 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 128 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 103 def self.openapi_types { :'account_id' => :'String', :'account_type' => :'String', :'behavior_assessment_enabled' => :'Boolean', :'cloudtrail_region' => :'String', :'deployment_method' => :'String', :'dspm_enabled' => :'Boolean', :'dspm_host_account_id' => :'String', :'dspm_role' => :'String', :'falcon_client_id' => :'String', :'iam_role_arn' => :'String', :'is_master' => :'Boolean', :'organization_id' => :'String', :'root_stack_id' => :'String', :'sensor_management_enabled' => :'Boolean', :'target_ous' => :'Array<String>', :'use_existing_cloudtrail' => :'Boolean', :'vulnerability_scanning_enabled' => :'Boolean', :'vulnerability_scanning_host_account_id' => :'String', :'vulnerability_scanning_role' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && account_type == o.account_type && behavior_assessment_enabled == o.behavior_assessment_enabled && cloudtrail_region == o.cloudtrail_region && deployment_method == o.deployment_method && dspm_enabled == o.dspm_enabled && dspm_host_account_id == o.dspm_host_account_id && dspm_role == o.dspm_role && falcon_client_id == o.falcon_client_id && iam_role_arn == o.iam_role_arn && is_master == o.is_master && organization_id == o.organization_id && root_stack_id == o.root_stack_id && sensor_management_enabled == o.sensor_management_enabled && target_ous == o.target_ous && use_existing_cloudtrail == o.use_existing_cloudtrail && vulnerability_scanning_enabled == o.vulnerability_scanning_enabled && vulnerability_scanning_host_account_id == o.vulnerability_scanning_host_account_id && vulnerability_scanning_role == o.vulnerability_scanning_role end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 332 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 403 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 308 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 294 def hash [account_id, account_type, behavior_assessment_enabled, cloudtrail_region, deployment_method, dspm_enabled, dspm_host_account_id, dspm_role, falcon_client_id, iam_role_arn, is_master, organization_id, root_stack_id, sensor_management_enabled, target_ous, use_existing_cloudtrail, vulnerability_scanning_enabled, vulnerability_scanning_host_account_id, vulnerability_scanning_role].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 229 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @cloudtrail_region.nil? invalid_properties.push('invalid value for "cloudtrail_region", cloudtrail_region cannot be nil.') end if @iam_role_arn.nil? invalid_properties.push('invalid value for "iam_role_arn", iam_role_arn cannot be nil.') end if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
379 380 381 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 379 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 385 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 373 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
252 253 254 255 256 257 258 |
# File 'lib/crimson-falcon/models/registration_aws_account_ext_v2.rb', line 252 def valid? return false if @account_id.nil? return false if @cloudtrail_region.nil? return false if @iam_role_arn.nil? return false if @organization_id.nil? true end |