Class: Falcon::RegistrationAWSAccountPatch

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/registration_aws_account_patch.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RegistrationAWSAccountPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RegistrationAWSAccountPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RegistrationAWSAccountPatch`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'behavior_assessment_enabled')
    self.behavior_assessment_enabled = attributes[:'behavior_assessment_enabled']
  end

  if attributes.key?(:'cloudtrail_region')
    self.cloudtrail_region = attributes[:'cloudtrail_region']
  end

  if attributes.key?(:'deployment_method')
    self.deployment_method = attributes[:'deployment_method']
  end

  if attributes.key?(:'dspm_enabled')
    self.dspm_enabled = attributes[:'dspm_enabled']
  end

  if attributes.key?(:'dspm_role')
    self.dspm_role = attributes[:'dspm_role']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'falcon_client_id')
    self.falcon_client_id = attributes[:'falcon_client_id']
  end

  if attributes.key?(:'iam_role_arn')
    self.iam_role_arn = attributes[:'iam_role_arn']
  end

  if attributes.key?(:'remediation_region')
    self.remediation_region = attributes[:'remediation_region']
  end

  if attributes.key?(:'remediation_tou_accepted')
    self.remediation_tou_accepted = attributes[:'remediation_tou_accepted']
  end

  if attributes.key?(:'root_stack_id')
    self.root_stack_id = attributes[:'root_stack_id']
  end

  if attributes.key?(:'sensor_management_enabled')
    self.sensor_management_enabled = attributes[:'sensor_management_enabled']
  end

  if attributes.key?(:'target_ous')
    if (value = attributes[:'target_ous']).is_a?(Array)
      self.target_ous = value
    end
  end

  if attributes.key?(:'vulnerability_scanning_enabled')
    self.vulnerability_scanning_enabled = attributes[:'vulnerability_scanning_enabled']
  end

  if attributes.key?(:'vulnerability_scanning_role')
    self.vulnerability_scanning_role = attributes[:'vulnerability_scanning_role']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



34
35
36
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 34

def 
  @account_id
end

#behavior_assessment_enabledObject

Returns the value of attribute behavior_assessment_enabled.



36
37
38
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 36

def behavior_assessment_enabled
  @behavior_assessment_enabled
end

#cloudtrail_regionObject

Returns the value of attribute cloudtrail_region.



38
39
40
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 38

def cloudtrail_region
  @cloudtrail_region
end

#deployment_methodObject

Returns the value of attribute deployment_method.



40
41
42
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 40

def deployment_method
  @deployment_method
end

#dspm_enabledObject

Returns the value of attribute dspm_enabled.



42
43
44
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 42

def dspm_enabled
  @dspm_enabled
end

#dspm_roleObject

Returns the value of attribute dspm_role.



44
45
46
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 44

def dspm_role
  @dspm_role
end

#environmentObject

Returns the value of attribute environment.



46
47
48
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 46

def environment
  @environment
end

#falcon_client_idObject

Returns the value of attribute falcon_client_id.



48
49
50
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 48

def falcon_client_id
  @falcon_client_id
end

#iam_role_arnObject

Returns the value of attribute iam_role_arn.



50
51
52
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 50

def iam_role_arn
  @iam_role_arn
end

#remediation_regionObject

Returns the value of attribute remediation_region.



52
53
54
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 52

def remediation_region
  @remediation_region
end

#remediation_tou_acceptedObject

Returns the value of attribute remediation_tou_accepted.



54
55
56
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 54

def remediation_tou_accepted
  @remediation_tou_accepted
end

#root_stack_idObject

Returns the value of attribute root_stack_id.



56
57
58
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 56

def root_stack_id
  @root_stack_id
end

#sensor_management_enabledObject

Returns the value of attribute sensor_management_enabled.



58
59
60
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 58

def sensor_management_enabled
  @sensor_management_enabled
end

#target_ousObject

Returns the value of attribute target_ous.



60
61
62
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 60

def target_ous
  @target_ous
end

#vulnerability_scanning_enabledObject

Returns the value of attribute vulnerability_scanning_enabled.



62
63
64
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 62

def vulnerability_scanning_enabled
  @vulnerability_scanning_enabled
end

#vulnerability_scanning_roleObject

Returns the value of attribute vulnerability_scanning_role.



64
65
66
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 64

def vulnerability_scanning_role
  @vulnerability_scanning_role
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 67

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'behavior_assessment_enabled' => :'behavior_assessment_enabled',
    :'cloudtrail_region' => :'cloudtrail_region',
    :'deployment_method' => :'deployment_method',
    :'dspm_enabled' => :'dspm_enabled',
    :'dspm_role' => :'dspm_role',
    :'environment' => :'environment',
    :'falcon_client_id' => :'falcon_client_id',
    :'iam_role_arn' => :'iam_role_arn',
    :'remediation_region' => :'remediation_region',
    :'remediation_tou_accepted' => :'remediation_tou_accepted',
    :'root_stack_id' => :'root_stack_id',
    :'sensor_management_enabled' => :'sensor_management_enabled',
    :'target_ous' => :'target_ous',
    :'vulnerability_scanning_enabled' => :'vulnerability_scanning_enabled',
    :'vulnerability_scanning_role' => :'vulnerability_scanning_role'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 284

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 94

def self.openapi_types
  {
    :'account_id' => :'String',
    :'behavior_assessment_enabled' => :'Boolean',
    :'cloudtrail_region' => :'String',
    :'deployment_method' => :'String',
    :'dspm_enabled' => :'Boolean',
    :'dspm_role' => :'String',
    :'environment' => :'String',
    :'falcon_client_id' => :'String',
    :'iam_role_arn' => :'String',
    :'remediation_region' => :'String',
    :'remediation_tou_accepted' => :'Time',
    :'root_stack_id' => :'String',
    :'sensor_management_enabled' => :'Boolean',
    :'target_ous' => :'Array<String>',
    :'vulnerability_scanning_enabled' => :'Boolean',
    :'vulnerability_scanning_role' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      behavior_assessment_enabled == o.behavior_assessment_enabled &&
      cloudtrail_region == o.cloudtrail_region &&
      deployment_method == o.deployment_method &&
      dspm_enabled == o.dspm_enabled &&
      dspm_role == o.dspm_role &&
      environment == o.environment &&
      falcon_client_id == o.falcon_client_id &&
      iam_role_arn == o.iam_role_arn &&
      remediation_region == o.remediation_region &&
      remediation_tou_accepted == o.remediation_tou_accepted &&
      root_stack_id == o.root_stack_id &&
      sensor_management_enabled == o.sensor_management_enabled &&
      target_ous == o.target_ous &&
      vulnerability_scanning_enabled == o.vulnerability_scanning_enabled &&
      vulnerability_scanning_role == o.vulnerability_scanning_role
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 315

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 386

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 291

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 277

def hash
  [, behavior_assessment_enabled, cloudtrail_region, deployment_method, dspm_enabled, dspm_role, environment, falcon_client_id, iam_role_arn, remediation_region, remediation_tou_accepted, root_stack_id, sensor_management_enabled, target_ous, vulnerability_scanning_enabled, vulnerability_scanning_role].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @behavior_assessment_enabled.nil?
    invalid_properties.push('invalid value for "behavior_assessment_enabled", behavior_assessment_enabled cannot be nil.')
  end

  if @dspm_enabled.nil?
    invalid_properties.push('invalid value for "dspm_enabled", dspm_enabled cannot be nil.')
  end

  if @iam_role_arn.nil?
    invalid_properties.push('invalid value for "iam_role_arn", iam_role_arn cannot be nil.')
  end

  if @sensor_management_enabled.nil?
    invalid_properties.push('invalid value for "sensor_management_enabled", sensor_management_enabled cannot be nil.')
  end

  if @vulnerability_scanning_enabled.nil?
    invalid_properties.push('invalid value for "vulnerability_scanning_enabled", vulnerability_scanning_enabled cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 362

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



356
357
358
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 356

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
# File 'lib/crimson-falcon/models/registration_aws_account_patch.rb', line 236

def valid?
  return false if @account_id.nil?
  return false if @behavior_assessment_enabled.nil?
  return false if @dspm_enabled.nil?
  return false if @iam_role_arn.nil?
  return false if @sensor_management_enabled.nil?
  return false if @vulnerability_scanning_enabled.nil?
  true
end