Class: Falcon::RegistrationAzureAccountV1Ext

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/registration_azure_account_v1_ext.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RegistrationAzureAccountV1Ext

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 193

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RegistrationAzureAccountV1Ext` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RegistrationAzureAccountV1Ext`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  end

  if attributes.key?(:'azure_permissions_status')
    if (value = attributes[:'azure_permissions_status']).is_a?(Array)
      self.azure_permissions_status = value
    end
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'cloud_scopes')
    if (value = attributes[:'cloud_scopes']).is_a?(Array)
      self.cloud_scopes = value
    end
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'credentials_end_date')
    self.credentials_end_date = attributes[:'credentials_end_date']
  end

  if attributes.key?(:'credentials_type')
    self.credentials_type = attributes[:'credentials_type']
  end

  if attributes.key?(:'default_subscription_id')
    self.default_subscription_id = attributes[:'default_subscription_id']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'ioa_status')
    self.ioa_status = attributes[:'ioa_status']
  end

  if attributes.key?(:'iom_status')
    self.iom_status = attributes[:'iom_status']
  end

  if attributes.key?(:'is_cspm_lite')
    self.is_cspm_lite = attributes[:'is_cspm_lite']
  end

  if attributes.key?(:'parent_management_group_id')
    self.parent_management_group_id = attributes[:'parent_management_group_id']
  end

  if attributes.key?(:'parent_management_group_name')
    self.parent_management_group_name = attributes[:'parent_management_group_name']
  end

  if attributes.key?(:'primary_domain')
    self.primary_domain = attributes[:'primary_domain']
  end

  if attributes.key?(:'public_certificate')
    self.public_certificate = attributes[:'public_certificate']
  end

  if attributes.key?(:'public_certificate_raw')
    self.public_certificate_raw = attributes[:'public_certificate_raw']
  end

  if attributes.key?(:'role_assignments')
    if (value = attributes[:'role_assignments']).is_a?(Array)
      self.role_assignments = value
    end
  end

  if attributes.key?(:'show_modal')
    self.show_modal = attributes[:'show_modal']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'subscription_name')
    self.subscription_name = attributes[:'subscription_name']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'tenant_name')
    self.tenant_name = attributes[:'tenant_name']
  end

  if attributes.key?(:'years_valid')
    self.years_valid = attributes[:'years_valid']
  end

  if attributes.key?(:'obj_id')
    self.obj_id = attributes[:'obj_id']
  end
end

Instance Attribute Details

#account_typeObject

Returns the value of attribute account_type.



42
43
44
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 42

def 
  @account_type
end

#azure_permissions_statusObject

Permissions status returned via API.



45
46
47
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 45

def azure_permissions_status
  @azure_permissions_status
end

#cidObject

Returns the value of attribute cid.



47
48
49
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 47

def cid
  @cid
end

#client_idObject

Returns the value of attribute client_id.



49
50
51
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 49

def client_id
  @client_id
end

#cloud_scopesObject

Returns the value of attribute cloud_scopes.



51
52
53
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 51

def cloud_scopes
  @cloud_scopes
end

#conditionsObject

Returns the value of attribute conditions.



53
54
55
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 53

def conditions
  @conditions
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 34

def created_at
  @created_at
end

#credentials_end_dateObject

Returns the value of attribute credentials_end_date.



55
56
57
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 55

def credentials_end_date
  @credentials_end_date
end

#credentials_typeObject

Returns the value of attribute credentials_type.



57
58
59
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 57

def credentials_type
  @credentials_type
end

#default_subscription_idObject

Default Azure Subscription ID to provision shared IOA infrastructure.



60
61
62
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 60

def default_subscription_id
  @default_subscription_id
end

#deleted_atObject

Returns the value of attribute deleted_at.



36
37
38
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 36

def deleted_at
  @deleted_at
end

#environmentObject

Returns the value of attribute environment.



62
63
64
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 62

def environment
  @environment
end

#idObject

Returns the value of attribute id.



38
39
40
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 38

def id
  @id
end

#ioa_statusObject

Returns the value of attribute ioa_status.



64
65
66
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 64

def ioa_status
  @ioa_status
end

#iom_statusObject

Returns the value of attribute iom_status.



66
67
68
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 66

def iom_status
  @iom_status
end

#is_cspm_liteObject

Is CSPM Lite enabled.



69
70
71
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 69

def is_cspm_lite
  @is_cspm_lite
end

#obj_idObject

Returns the value of attribute obj_id.



104
105
106
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 104

def obj_id
  @obj_id
end

#parent_management_group_idObject

Returns the value of attribute parent_management_group_id.



71
72
73
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 71

def parent_management_group_id
  @parent_management_group_id
end

#parent_management_group_nameObject

Returns the value of attribute parent_management_group_name.



73
74
75
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 73

def parent_management_group_name
  @parent_management_group_name
end

#primary_domainObject

Azure Tenant Primary Domain.



76
77
78
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 76

def primary_domain
  @primary_domain
end

#public_certificateObject

Returns the value of attribute public_certificate.



78
79
80
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 78

def public_certificate
  @public_certificate
end

#public_certificate_rawObject

Returns the value of attribute public_certificate_raw.



80
81
82
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 80

def public_certificate_raw
  @public_certificate_raw
end

#role_assignmentsObject

Returns the value of attribute role_assignments.



82
83
84
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 82

def role_assignments
  @role_assignments
end

#show_modalObject

Whether to show modal on the UI instructing existing D4C Azure customer to reregister subscriptions for CSPM.



85
86
87
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 85

def show_modal
  @show_modal
end

#statusObject

Account registration status.



88
89
90
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 88

def status
  @status
end

#subscription_idObject

Azure Subscription ID.



91
92
93
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 91

def subscription_id
  @subscription_id
end

#subscription_nameObject

Azure Subscription Name.



94
95
96
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 94

def subscription_name
  @subscription_name
end

#tenant_idObject

Azure Tenant ID to use.



97
98
99
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 97

def tenant_id
  @tenant_id
end

#tenant_nameObject

Azure Tenant Name.



100
101
102
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 100

def tenant_name
  @tenant_name
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 40

def updated_at
  @updated_at
end

#years_validObject

Returns the value of attribute years_valid.



102
103
104
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 102

def years_valid
  @years_valid
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



144
145
146
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 144

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 107

def self.attribute_map
  {
    :'created_at' => :'CreatedAt',
    :'deleted_at' => :'DeletedAt',
    :'id' => :'ID',
    :'updated_at' => :'UpdatedAt',
    :'account_type' => :'account_type',
    :'azure_permissions_status' => :'azure_permissions_status',
    :'cid' => :'cid',
    :'client_id' => :'client_id',
    :'cloud_scopes' => :'cloud_scopes',
    :'conditions' => :'conditions',
    :'credentials_end_date' => :'credentials_end_date',
    :'credentials_type' => :'credentials_type',
    :'default_subscription_id' => :'default_subscription_id',
    :'environment' => :'environment',
    :'ioa_status' => :'ioa_status',
    :'iom_status' => :'iom_status',
    :'is_cspm_lite' => :'is_cspm_lite',
    :'parent_management_group_id' => :'parent_management_group_id',
    :'parent_management_group_name' => :'parent_management_group_name',
    :'primary_domain' => :'primary_domain',
    :'public_certificate' => :'public_certificate',
    :'public_certificate_raw' => :'public_certificate_raw',
    :'role_assignments' => :'role_assignments',
    :'show_modal' => :'show_modal',
    :'status' => :'status',
    :'subscription_id' => :'subscription_id',
    :'subscription_name' => :'subscription_name',
    :'tenant_id' => :'tenant_id',
    :'tenant_name' => :'tenant_name',
    :'years_valid' => :'years_valid',
    :'obj_id' => :'obj_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



450
451
452
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 450

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 186

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 149

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'id' => :'Integer',
    :'updated_at' => :'Time',
    :'account_type' => :'String',
    :'azure_permissions_status' => :'Array<DomainPermission>',
    :'cid' => :'String',
    :'client_id' => :'String',
    :'cloud_scopes' => :'Array<DomainCloudScope>',
    :'conditions' => :'Array<StatemgmtCondition>',
    :'credentials_end_date' => :'Time',
    :'credentials_type' => :'String',
    :'default_subscription_id' => :'String',
    :'environment' => :'String',
    :'ioa_status' => :'String',
    :'iom_status' => :'String',
    :'is_cspm_lite' => :'Boolean',
    :'parent_management_group_id' => :'String',
    :'parent_management_group_name' => :'String',
    :'primary_domain' => :'String',
    :'public_certificate' => :'String',
    :'public_certificate_raw' => :'String',
    :'role_assignments' => :'Array<AzureDBRoleAssignment>',
    :'show_modal' => :'Boolean',
    :'status' => :'String',
    :'subscription_id' => :'String',
    :'subscription_name' => :'String',
    :'tenant_id' => :'String',
    :'tenant_name' => :'String',
    :'years_valid' => :'Integer',
    :'obj_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 399

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      id == o.id &&
      updated_at == o.updated_at &&
       == o. &&
      azure_permissions_status == o.azure_permissions_status &&
      cid == o.cid &&
      client_id == o.client_id &&
      cloud_scopes == o.cloud_scopes &&
      conditions == o.conditions &&
      credentials_end_date == o.credentials_end_date &&
      credentials_type == o.credentials_type &&
      default_subscription_id == o.default_subscription_id &&
      environment == o.environment &&
      ioa_status == o.ioa_status &&
      iom_status == o.iom_status &&
      is_cspm_lite == o.is_cspm_lite &&
      parent_management_group_id == o.parent_management_group_id &&
      parent_management_group_name == o.parent_management_group_name &&
      primary_domain == o.primary_domain &&
      public_certificate == o.public_certificate &&
      public_certificate_raw == o.public_certificate_raw &&
      role_assignments == o.role_assignments &&
      show_modal == o.show_modal &&
      status == o.status &&
      subscription_id == o.subscription_id &&
      subscription_name == o.subscription_name &&
      tenant_id == o.tenant_id &&
      tenant_name == o.tenant_name &&
      years_valid == o.years_valid &&
      obj_id == o.obj_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 481

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



552
553
554
555
556
557
558
559
560
561
562
563
564
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 552

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 457

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


437
438
439
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 437

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



443
444
445
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 443

def hash
  [created_at, deleted_at, id, updated_at, , azure_permissions_status, cid, client_id, cloud_scopes, conditions, credentials_end_date, credentials_type, default_subscription_id, environment, ioa_status, iom_status, is_cspm_lite, parent_management_group_id, parent_management_group_name, primary_domain, public_certificate, public_certificate_raw, role_assignments, show_modal, status, subscription_id, subscription_name, tenant_id, tenant_name, years_valid, obj_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 341

def list_invalid_properties
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @deleted_at.nil?
    invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @azure_permissions_status.nil?
    invalid_properties.push('invalid value for "azure_permissions_status", azure_permissions_status cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @ioa_status.nil?
    invalid_properties.push('invalid value for "ioa_status", ioa_status cannot be nil.')
  end

  if @iom_status.nil?
    invalid_properties.push('invalid value for "iom_status", iom_status cannot be nil.')
  end

  if @show_modal.nil?
    invalid_properties.push('invalid value for "show_modal", show_modal cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



528
529
530
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 528

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 534

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



522
523
524
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 522

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/crimson-falcon/models/registration_azure_account_v1_ext.rb', line 384

def valid?
  return false if @created_at.nil?
  return false if @deleted_at.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  return false if @azure_permissions_status.nil?
  return false if @cid.nil?
  return false if @ioa_status.nil?
  return false if @iom_status.nil?
  return false if @show_modal.nil?
  true
end