Class: Falcon::RegistrationGCPAccountReqObjV2
- Inherits:
-
Object
- Object
- Falcon::RegistrationGCPAccountReqObjV2
- Defined in:
- lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb
Instance Attribute Summary collapse
-
#client_email ⇒ Object
Returns the value of attribute client_email.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#parent_type ⇒ Object
Returns the value of attribute parent_type.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#private_key_id ⇒ Object
Returns the value of attribute private_key_id.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#service_account_conditions ⇒ Object
Returns the value of attribute service_account_conditions.
-
#service_account_id ⇒ Object
Returns the value of attribute service_account_id.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegistrationGCPAccountReqObjV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RegistrationGCPAccountReqObjV2
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RegistrationGCPAccountReqObjV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RegistrationGCPAccountReqObjV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_email') self.client_email = attributes[:'client_email'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'parent_type') self.parent_type = attributes[:'parent_type'] end if attributes.key?(:'private_key') self.private_key = attributes[:'private_key'] end if attributes.key?(:'private_key_id') self.private_key_id = attributes[:'private_key_id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'service_account_conditions') if (value = attributes[:'service_account_conditions']).is_a?(Array) self.service_account_conditions = value end end if attributes.key?(:'service_account_id') self.service_account_id = attributes[:'service_account_id'] end end |
Instance Attribute Details
#client_email ⇒ Object
Returns the value of attribute client_email.
34 35 36 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 34 def client_email @client_email end |
#client_id ⇒ Object
Returns the value of attribute client_id.
36 37 38 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 36 def client_id @client_id end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
38 39 40 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 38 def parent_id @parent_id end |
#parent_type ⇒ Object
Returns the value of attribute parent_type.
40 41 42 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 40 def parent_type @parent_type end |
#private_key ⇒ Object
Returns the value of attribute private_key.
42 43 44 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 42 def private_key @private_key end |
#private_key_id ⇒ Object
Returns the value of attribute private_key_id.
44 45 46 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 44 def private_key_id @private_key_id end |
#project_id ⇒ Object
Returns the value of attribute project_id.
46 47 48 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 46 def project_id @project_id end |
#service_account_conditions ⇒ Object
Returns the value of attribute service_account_conditions.
48 49 50 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 48 def service_account_conditions @service_account_conditions end |
#service_account_id ⇒ Object
Returns the value of attribute service_account_id.
50 51 52 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 50 def service_account_id @service_account_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 53 def self.attribute_map { :'client_email' => :'client_email', :'client_id' => :'client_id', :'parent_id' => :'parent_id', :'parent_type' => :'parent_type', :'private_key' => :'private_key', :'private_key_id' => :'private_key_id', :'project_id' => :'project_id', :'service_account_conditions' => :'service_account_conditions', :'service_account_id' => :'service_account_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 196 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 73 def self.openapi_types { :'client_email' => :'String', :'client_id' => :'String', :'parent_id' => :'String', :'parent_type' => :'String', :'private_key' => :'String', :'private_key_id' => :'String', :'project_id' => :'String', :'service_account_conditions' => :'Array<StatemgmtCondition>', :'service_account_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && client_email == o.client_email && client_id == o.client_id && parent_id == o.parent_id && parent_type == o.parent_type && private_key == o.private_key && private_key_id == o.private_key_id && project_id == o.project_id && service_account_conditions == o.service_account_conditions && service_account_id == o.service_account_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 227 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 298 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 189 def hash [client_email, client_id, parent_id, parent_type, private_key, private_key_id, project_id, service_account_conditions, service_account_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 149 def list_invalid_properties invalid_properties = Array.new if @parent_id.nil? invalid_properties.push('invalid value for "parent_id", parent_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
274 275 276 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 274 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 268 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 |
# File 'lib/crimson-falcon/models/registration_gcp_account_req_obj_v2.rb', line 160 def valid? return false if @parent_id.nil? true end |