Class: Falcon::RegistrationIOMEventV2
- Inherits:
-
Object
- Object
- Falcon::RegistrationIOMEventV2
- Defined in:
- lib/crimson-falcon/models/registration_iom_event_v2.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_name ⇒ Object
Returns the value of attribute account_name.
-
#agent_id ⇒ Object
Returns the value of attribute agent_id.
-
#azure_tenant_id ⇒ Object
Returns the value of attribute azure_tenant_id.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_groups_v2 ⇒ Object
Returns the value of attribute cloud_groups_v2.
-
#cloud_labels ⇒ Object
Returns the value of attribute cloud_labels.
-
#cloud_provider ⇒ Object
Returns the value of attribute cloud_provider.
-
#cloud_scopes ⇒ Object
Returns the value of attribute cloud_scopes.
-
#custom_policy_id ⇒ Object
Returns the value of attribute custom_policy_id.
-
#finding ⇒ Object
Returns the value of attribute finding.
-
#findings ⇒ Object
Returns the value of attribute findings.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_managed ⇒ Object
Returns the value of attribute is_managed.
-
#policy_id ⇒ Object
Returns the value of attribute policy_id.
-
#policy_statement ⇒ Object
Returns the value of attribute policy_statement.
-
#policy_type ⇒ Object
Returns the value of attribute policy_type.
-
#region ⇒ Object
Returns the value of attribute region.
-
#report_date_time ⇒ Object
Returns the value of attribute report_date_time.
-
#resource_attributes ⇒ Object
Returns the value of attribute resource_attributes.
-
#resource_create_time ⇒ Object
Returns the value of attribute resource_create_time.
-
#resource_id ⇒ Object
Returns the value of attribute resource_id.
-
#resource_id_type ⇒ Object
Returns the value of attribute resource_id_type.
-
#resource_url ⇒ Object
Returns the value of attribute resource_url.
-
#resource_uuid ⇒ Object
Returns the value of attribute resource_uuid.
-
#scan_id ⇒ Object
Returns the value of attribute scan_id.
-
#scan_time ⇒ Object
Returns the value of attribute scan_time.
-
#service ⇒ Object
Returns the value of attribute service.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#vm_id ⇒ Object
Returns the value of attribute vm_id.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegistrationIOMEventV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RegistrationIOMEventV2
Initializes the object
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 191 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RegistrationIOMEventV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RegistrationIOMEventV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] end if attributes.key?(:'azure_tenant_id') self.azure_tenant_id = attributes[:'azure_tenant_id'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_groups_v2') if (value = attributes[:'cloud_groups_v2']).is_a?(Array) self.cloud_groups_v2 = value end end if attributes.key?(:'cloud_labels') if (value = attributes[:'cloud_labels']).is_a?(Array) self.cloud_labels = value end end if attributes.key?(:'cloud_provider') self.cloud_provider = attributes[:'cloud_provider'] end if attributes.key?(:'cloud_scopes') if (value = attributes[:'cloud_scopes']).is_a?(Array) self.cloud_scopes = value end end if attributes.key?(:'custom_policy_id') self.custom_policy_id = attributes[:'custom_policy_id'] end if attributes.key?(:'finding') self.finding = attributes[:'finding'] end if attributes.key?(:'findings') if (value = attributes[:'findings']).is_a?(Array) self.findings = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'is_managed') self.is_managed = attributes[:'is_managed'] end if attributes.key?(:'policy_id') self.policy_id = attributes[:'policy_id'] end if attributes.key?(:'policy_statement') self.policy_statement = attributes[:'policy_statement'] end if attributes.key?(:'policy_type') self.policy_type = attributes[:'policy_type'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'report_date_time') self.report_date_time = attributes[:'report_date_time'] end if attributes.key?(:'resource_attributes') self.resource_attributes = attributes[:'resource_attributes'] end if attributes.key?(:'resource_create_time') self.resource_create_time = attributes[:'resource_create_time'] end if attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] end if attributes.key?(:'resource_id_type') self.resource_id_type = attributes[:'resource_id_type'] end if attributes.key?(:'resource_url') self.resource_url = attributes[:'resource_url'] end if attributes.key?(:'resource_uuid') self.resource_uuid = attributes[:'resource_uuid'] end if attributes.key?(:'scan_id') self.scan_id = attributes[:'scan_id'] end if attributes.key?(:'scan_time') self.scan_time = attributes[:'scan_time'] end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Hash) self. = value end end if attributes.key?(:'vm_id') self.vm_id = attributes[:'vm_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
34 35 36 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 34 def account_id @account_id end |
#account_name ⇒ Object
Returns the value of attribute account_name.
36 37 38 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 36 def account_name @account_name end |
#agent_id ⇒ Object
Returns the value of attribute agent_id.
38 39 40 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 38 def agent_id @agent_id end |
#azure_tenant_id ⇒ Object
Returns the value of attribute azure_tenant_id.
40 41 42 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 40 def azure_tenant_id @azure_tenant_id end |
#cid ⇒ Object
Returns the value of attribute cid.
42 43 44 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 42 def cid @cid end |
#cloud_groups_v2 ⇒ Object
Returns the value of attribute cloud_groups_v2.
44 45 46 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 44 def cloud_groups_v2 @cloud_groups_v2 end |
#cloud_labels ⇒ Object
Returns the value of attribute cloud_labels.
46 47 48 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 46 def cloud_labels @cloud_labels end |
#cloud_provider ⇒ Object
Returns the value of attribute cloud_provider.
48 49 50 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 48 def cloud_provider @cloud_provider end |
#cloud_scopes ⇒ Object
Returns the value of attribute cloud_scopes.
50 51 52 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 50 def cloud_scopes @cloud_scopes end |
#custom_policy_id ⇒ Object
Returns the value of attribute custom_policy_id.
52 53 54 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 52 def custom_policy_id @custom_policy_id end |
#finding ⇒ Object
Returns the value of attribute finding.
54 55 56 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 54 def finding @finding end |
#findings ⇒ Object
Returns the value of attribute findings.
56 57 58 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 56 def findings @findings end |
#groups ⇒ Object
Returns the value of attribute groups.
58 59 60 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 58 def groups @groups end |
#id ⇒ Object
Returns the value of attribute id.
60 61 62 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 60 def id @id end |
#is_managed ⇒ Object
Returns the value of attribute is_managed.
62 63 64 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 62 def is_managed @is_managed end |
#policy_id ⇒ Object
Returns the value of attribute policy_id.
64 65 66 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 64 def policy_id @policy_id end |
#policy_statement ⇒ Object
Returns the value of attribute policy_statement.
66 67 68 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 66 def policy_statement @policy_statement end |
#policy_type ⇒ Object
Returns the value of attribute policy_type.
68 69 70 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 68 def policy_type @policy_type end |
#region ⇒ Object
Returns the value of attribute region.
70 71 72 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 70 def region @region end |
#report_date_time ⇒ Object
Returns the value of attribute report_date_time.
72 73 74 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 72 def report_date_time @report_date_time end |
#resource_attributes ⇒ Object
Returns the value of attribute resource_attributes.
74 75 76 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 74 def resource_attributes @resource_attributes end |
#resource_create_time ⇒ Object
Returns the value of attribute resource_create_time.
76 77 78 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 76 def resource_create_time @resource_create_time end |
#resource_id ⇒ Object
Returns the value of attribute resource_id.
78 79 80 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 78 def resource_id @resource_id end |
#resource_id_type ⇒ Object
Returns the value of attribute resource_id_type.
80 81 82 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 80 def resource_id_type @resource_id_type end |
#resource_url ⇒ Object
Returns the value of attribute resource_url.
82 83 84 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 82 def resource_url @resource_url end |
#resource_uuid ⇒ Object
Returns the value of attribute resource_uuid.
84 85 86 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 84 def resource_uuid @resource_uuid end |
#scan_id ⇒ Object
Returns the value of attribute scan_id.
86 87 88 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 86 def scan_id @scan_id end |
#scan_time ⇒ Object
Returns the value of attribute scan_time.
88 89 90 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 88 def scan_time @scan_time end |
#service ⇒ Object
Returns the value of attribute service.
90 91 92 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 90 def service @service end |
#severity ⇒ Object
Returns the value of attribute severity.
92 93 94 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 92 def severity @severity end |
#status ⇒ Object
Returns the value of attribute status.
94 95 96 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 94 def status @status end |
#tags ⇒ Object
Returns the value of attribute tags.
96 97 98 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 96 def @tags end |
#vm_id ⇒ Object
Returns the value of attribute vm_id.
98 99 100 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 98 def vm_id @vm_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
140 141 142 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 140 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 101 def self.attribute_map { :'account_id' => :'account_id', :'account_name' => :'account_name', :'agent_id' => :'agent_id', :'azure_tenant_id' => :'azure_tenant_id', :'cid' => :'cid', :'cloud_groups_v2' => :'cloud_groups_v2', :'cloud_labels' => :'cloud_labels', :'cloud_provider' => :'cloud_provider', :'cloud_scopes' => :'cloud_scopes', :'custom_policy_id' => :'custom_policy_id', :'finding' => :'finding', :'findings' => :'findings', :'groups' => :'groups', :'id' => :'id', :'is_managed' => :'is_managed', :'policy_id' => :'policy_id', :'policy_statement' => :'policy_statement', :'policy_type' => :'policy_type', :'region' => :'region', :'report_date_time' => :'report_date_time', :'resource_attributes' => :'resource_attributes', :'resource_create_time' => :'resource_create_time', :'resource_id' => :'resource_id', :'resource_id_type' => :'resource_id_type', :'resource_url' => :'resource_url', :'resource_uuid' => :'resource_uuid', :'scan_id' => :'scan_id', :'scan_time' => :'scan_time', :'service' => :'service', :'severity' => :'severity', :'status' => :'status', :'tags' => :'tags', :'vm_id' => :'vm_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
522 523 524 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 522 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
184 185 186 187 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 184 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 145 def self.openapi_types { :'account_id' => :'String', :'account_name' => :'String', :'agent_id' => :'String', :'azure_tenant_id' => :'String', :'cid' => :'String', :'cloud_groups_v2' => :'Array<DomainCloudGroup>', :'cloud_labels' => :'Array<ClassificationLabel>', :'cloud_provider' => :'String', :'cloud_scopes' => :'Array<DomainCloudScope>', :'custom_policy_id' => :'Integer', :'finding' => :'Object', :'findings' => :'Array<Object>', :'groups' => :'Array<String>', :'id' => :'String', :'is_managed' => :'Boolean', :'policy_id' => :'Integer', :'policy_statement' => :'String', :'policy_type' => :'String', :'region' => :'String', :'report_date_time' => :'Time', :'resource_attributes' => :'Object', :'resource_create_time' => :'Time', :'resource_id' => :'String', :'resource_id_type' => :'String', :'resource_url' => :'String', :'resource_uuid' => :'String', :'scan_id' => :'String', :'scan_time' => :'Time', :'service' => :'String', :'severity' => :'String', :'status' => :'String', :'tags' => :'Hash<String, String>', :'vm_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 469 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && account_name == o.account_name && agent_id == o.agent_id && azure_tenant_id == o.azure_tenant_id && cid == o.cid && cloud_groups_v2 == o.cloud_groups_v2 && cloud_labels == o.cloud_labels && cloud_provider == o.cloud_provider && cloud_scopes == o.cloud_scopes && custom_policy_id == o.custom_policy_id && finding == o.finding && findings == o.findings && groups == o.groups && id == o.id && is_managed == o.is_managed && policy_id == o.policy_id && policy_statement == o.policy_statement && policy_type == o.policy_type && region == o.region && report_date_time == o.report_date_time && resource_attributes == o.resource_attributes && resource_create_time == o.resource_create_time && resource_id == o.resource_id && resource_id_type == o.resource_id_type && resource_url == o.resource_url && resource_uuid == o.resource_uuid && scan_id == o.scan_id && scan_time == o.scan_time && service == o.service && severity == o.severity && status == o.status && == o. && vm_id == o.vm_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 553 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
624 625 626 627 628 629 630 631 632 633 634 635 636 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 624 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 529 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
509 510 511 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 509 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
515 516 517 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 515 def hash [account_id, account_name, agent_id, azure_tenant_id, cid, cloud_groups_v2, cloud_labels, cloud_provider, cloud_scopes, custom_policy_id, finding, findings, groups, id, is_managed, policy_id, policy_statement, policy_type, region, report_date_time, resource_attributes, resource_create_time, resource_id, resource_id_type, resource_url, resource_uuid, scan_id, scan_time, service, severity, status, , vm_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 351 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @account_name.nil? invalid_properties.push('invalid value for "account_name", account_name cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cloud_provider.nil? invalid_properties.push('invalid value for "cloud_provider", cloud_provider cannot be nil.') end if @finding.nil? invalid_properties.push('invalid value for "finding", finding cannot be nil.') end if @findings.nil? invalid_properties.push('invalid value for "findings", findings cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @policy_statement.nil? invalid_properties.push('invalid value for "policy_statement", policy_statement cannot be nil.') end if @region.nil? invalid_properties.push('invalid value for "region", region cannot be nil.') end if @report_date_time.nil? invalid_properties.push('invalid value for "report_date_time", report_date_time cannot be nil.') end if @resource_attributes.nil? invalid_properties.push('invalid value for "resource_attributes", resource_attributes cannot be nil.') end if @resource_create_time.nil? invalid_properties.push('invalid value for "resource_create_time", resource_create_time cannot be nil.') end if @resource_id.nil? invalid_properties.push('invalid value for "resource_id", resource_id cannot be nil.') end if @resource_id_type.nil? invalid_properties.push('invalid value for "resource_id_type", resource_id_type cannot be nil.') end if @resource_url.nil? invalid_properties.push('invalid value for "resource_url", resource_url cannot be nil.') end if @resource_uuid.nil? invalid_properties.push('invalid value for "resource_uuid", resource_uuid cannot be nil.') end if @scan_time.nil? invalid_properties.push('invalid value for "scan_time", scan_time cannot be nil.') end if @service.nil? invalid_properties.push('invalid value for "service", service cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
600 601 602 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 600 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 606 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
594 595 596 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 594 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/crimson-falcon/models/registration_iom_event_v2.rb', line 442 def valid? return false if @account_id.nil? return false if @account_name.nil? return false if @cid.nil? return false if @cloud_provider.nil? return false if @finding.nil? return false if @findings.nil? return false if @id.nil? return false if @policy_statement.nil? return false if @region.nil? return false if @report_date_time.nil? return false if @resource_attributes.nil? return false if @resource_create_time.nil? return false if @resource_id.nil? return false if @resource_id_type.nil? return false if @resource_url.nil? return false if @resource_uuid.nil? return false if @scan_time.nil? return false if @service.nil? return false if @severity.nil? return false if @status.nil? return false if @tags.nil? true end |