Class: Falcon::ReleasesReleaseResponseV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/releases_release_response_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReleasesReleaseResponseV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ReleasesReleaseResponseV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ReleasesReleaseResponseV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'annotation')
    self.annotation = attributes[:'annotation']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'deployed_timestamp')
    self.deployed_timestamp = attributes[:'deployed_timestamp']
  end

  if attributes.key?(:'deployment_start_timestamp')
    self.deployment_start_timestamp = attributes[:'deployment_start_timestamp']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_modified_by')
    self.last_modified_by = attributes[:'last_modified_by']
  end

  if attributes.key?(:'last_modified_timestamp')
    self.last_modified_timestamp = attributes[:'last_modified_timestamp']
  end

  if attributes.key?(:'release_contents')
    if (value = attributes[:'release_contents']).is_a?(Array)
      self.release_contents = value
    end
  end

  if attributes.key?(:'release_notes_ticket')
    self.release_notes_ticket = attributes[:'release_notes_ticket']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#annotationObject

Returns the value of attribute annotation.



34
35
36
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 34

def annotation
  @annotation
end

#created_byObject

Returns the value of attribute created_by.



36
37
38
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 36

def created_by
  @created_by
end

#created_timestampObject

Returns the value of attribute created_timestamp.



38
39
40
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 38

def created_timestamp
  @created_timestamp
end

#deployed_timestampObject

Returns the value of attribute deployed_timestamp.



40
41
42
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 40

def deployed_timestamp
  @deployed_timestamp
end

#deployment_start_timestampObject

Returns the value of attribute deployment_start_timestamp.



42
43
44
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 42

def deployment_start_timestamp
  @deployment_start_timestamp
end

#idObject

Returns the value of attribute id.



44
45
46
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 44

def id
  @id
end

#last_modified_byObject

Returns the value of attribute last_modified_by.



46
47
48
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 46

def last_modified_by
  @last_modified_by
end

#last_modified_timestampObject

Returns the value of attribute last_modified_timestamp.



48
49
50
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 48

def last_modified_timestamp
  @last_modified_timestamp
end

#release_contentsObject

Returns the value of attribute release_contents.



50
51
52
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 50

def release_contents
  @release_contents
end

#release_notes_ticketObject

Returns the value of attribute release_notes_ticket.



52
53
54
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 52

def release_notes_ticket
  @release_notes_ticket
end

#statusObject

Returns the value of attribute status.



54
55
56
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 54

def status
  @status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 57

def self.attribute_map
  {
    :'annotation' => :'annotation',
    :'created_by' => :'created_by',
    :'created_timestamp' => :'created_timestamp',
    :'deployed_timestamp' => :'deployed_timestamp',
    :'deployment_start_timestamp' => :'deployment_start_timestamp',
    :'id' => :'id',
    :'last_modified_by' => :'last_modified_by',
    :'last_modified_timestamp' => :'last_modified_timestamp',
    :'release_contents' => :'release_contents',
    :'release_notes_ticket' => :'release_notes_ticket',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 79

def self.openapi_types
  {
    :'annotation' => :'String',
    :'created_by' => :'String',
    :'created_timestamp' => :'Time',
    :'deployed_timestamp' => :'Time',
    :'deployment_start_timestamp' => :'Time',
    :'id' => :'String',
    :'last_modified_by' => :'String',
    :'last_modified_timestamp' => :'Time',
    :'release_contents' => :'Array<ReleasecontentsReleaseContentResponseV1>',
    :'release_notes_ticket' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      annotation == o.annotation &&
      created_by == o.created_by &&
      created_timestamp == o.created_timestamp &&
      deployed_timestamp == o.deployed_timestamp &&
      deployment_start_timestamp == o.deployment_start_timestamp &&
      id == o.id &&
      last_modified_by == o.last_modified_by &&
      last_modified_timestamp == o.last_modified_timestamp &&
      release_contents == o.release_contents &&
      release_notes_ticket == o.release_notes_ticket &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 265

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 336

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 227

def hash
  [annotation, created_by, created_timestamp, deployed_timestamp, deployment_start_timestamp, id, last_modified_by, last_modified_timestamp, release_contents, release_notes_ticket, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_modified_timestamp.nil?
    invalid_properties.push('invalid value for "last_modified_timestamp", last_modified_timestamp cannot be nil.')
  end

  if @release_contents.nil?
    invalid_properties.push('invalid value for "release_contents", release_contents cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 312

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



306
307
308
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 306

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
# File 'lib/crimson-falcon/models/releases_release_response_v1.rb', line 192

def valid?
  return false if @created_timestamp.nil?
  return false if @id.nil?
  return false if @last_modified_timestamp.nil?
  return false if @release_contents.nil?
  return false if @status.nil?
  true
end