Class: Falcon::ReportExecutions
- Inherits:
-
Object
- Object
- Falcon::ReportExecutions
- Defined in:
- lib/crimson-falcon/api/report_executions.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ReportExecutions
constructor
A new instance of ReportExecutions.
-
#report_executions_download_get(ids, opts = {}) ⇒ Object
Get report entity download.
-
#report_executions_download_get_with_http_info(ids, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get report entity download.
-
#report_executions_get(ids, opts = {}) ⇒ DomainReportExecutionsResponseV1
Retrieve report details for the provided report IDs.
-
#report_executions_get_with_http_info(ids, opts = {}) ⇒ Array<(DomainReportExecutionsResponseV1, Integer, Hash)>
Retrieve report details for the provided report IDs.
-
#report_executions_query(opts = {}) ⇒ MsaQueryResponse
Find all report execution IDs matching the query with filter.
-
#report_executions_query_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Find all report execution IDs matching the query with filter.
-
#report_executions_retry(body, opts = {}) ⇒ DomainReportExecutionsResponseV1
This endpoint will be used to retry report executions.
-
#report_executions_retry_with_http_info(body, opts = {}) ⇒ Array<(DomainReportExecutionsResponseV1, Integer, Hash)>
This endpoint will be used to retry report executions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ReportExecutions
Returns a new instance of ReportExecutions.
35 36 37 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 33 def api_client @api_client end |
Instance Method Details
#report_executions_download_get(ids, opts = {}) ⇒ Object
Get report entity download. Returns either a JSON object or a CSV string.
42 43 44 45 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 42 def report_executions_download_get(ids, opts = {}) data, _status_code, _headers = report_executions_download_get_with_http_info(ids, opts) data end |
#report_executions_download_get_with_http_info(ids, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get report entity download. Returns either a JSON object or a CSV string.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 51 def report_executions_download_get_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportExecutions.report_executions_download_get ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling ReportExecutions.report_executions_download_get" end # resource path local_var_path = '/reports/entities/report-executions-download/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = ids # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*', 'application/json', 'text/csv']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ReportExecutions.report_executions_download_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportExecutions#report_executions_download_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#report_executions_get(ids, opts = {}) ⇒ DomainReportExecutionsResponseV1
Retrieve report details for the provided report IDs.
104 105 106 107 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 104 def report_executions_get(ids, opts = {}) data, _status_code, _headers = report_executions_get_with_http_info(ids, opts) data end |
#report_executions_get_with_http_info(ids, opts = {}) ⇒ Array<(DomainReportExecutionsResponseV1, Integer, Hash)>
Retrieve report details for the provided report IDs.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 113 def report_executions_get_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportExecutions.report_executions_get ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling ReportExecutions.report_executions_get" end # resource path local_var_path = '/reports/entities/report-executions/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainReportExecutionsResponseV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ReportExecutions.report_executions_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportExecutions#report_executions_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#report_executions_query(opts = {}) ⇒ MsaQueryResponse
Find all report execution IDs matching the query with filter
170 171 172 173 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 170 def report_executions_query(opts = {}) data, _status_code, _headers = report_executions_query_with_http_info(opts) data end |
#report_executions_query_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Find all report execution IDs matching the query with filter
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 183 def report_executions_query_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportExecutions.report_executions_query ...' end # resource path local_var_path = '/reports/queries/report-executions/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ReportExecutions.report_executions_query", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportExecutions#report_executions_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#report_executions_retry(body, opts = {}) ⇒ DomainReportExecutionsResponseV1
This endpoint will be used to retry report executions
236 237 238 239 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 236 def report_executions_retry(body, opts = {}) data, _status_code, _headers = report_executions_retry_with_http_info(body, opts) data end |
#report_executions_retry_with_http_info(body, opts = {}) ⇒ Array<(DomainReportExecutionsResponseV1, Integer, Hash)>
This endpoint will be used to retry report executions
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/crimson-falcon/api/report_executions.rb', line 245 def report_executions_retry_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReportExecutions.report_executions_retry ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ReportExecutions.report_executions_retry" end # resource path local_var_path = '/reports/entities/report-executions-retry/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainReportExecutionsResponseV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ReportExecutions.report_executions_retry", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReportExecutions#report_executions_retry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |