Class: Falcon::ResourcesCloudContext

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/resources_cloud_context.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResourcesCloudContext

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ResourcesCloudContext` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ResourcesCloudContext`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_name')
    self. = attributes[:'account_name']
  end

  if attributes.key?(:'allows_public_access')
    self.allows_public_access = attributes[:'allows_public_access']
  end

  if attributes.key?(:'asset_graph')
    self.asset_graph = attributes[:'asset_graph']
  end

  if attributes.key?(:'cloud_risks')
    self.cloud_risks = attributes[:'cloud_risks']
  end

  if attributes.key?(:'cspm_license')
    self.cspm_license = attributes[:'cspm_license']
  end

  if attributes.key?(:'data_classifications')
    self.data_classifications = attributes[:'data_classifications']
  end

  if attributes.key?(:'detections')
    self.detections = attributes[:'detections']
  end

  if attributes.key?(:'has_falcon_sensor')
    self.has_falcon_sensor = attributes[:'has_falcon_sensor']
  end

  if attributes.key?(:'has_tags')
    self.has_tags = attributes[:'has_tags']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'insights')
    self.insights = attributes[:'insights']
  end

  if attributes.key?(:'instance_id')
    self.instance_id = attributes[:'instance_id']
  end

  if attributes.key?(:'instance_state')
    self.instance_state = attributes[:'instance_state']
  end

  if attributes.key?(:'legacy_resource_id')
    self.legacy_resource_id = attributes[:'legacy_resource_id']
  end

  if attributes.key?(:'legacy_type_id')
    self.legacy_type_id = attributes[:'legacy_type_id']
  end

  if attributes.key?(:'legacy_uuid')
    self.legacy_uuid = attributes[:'legacy_uuid']
  end

  if attributes.key?(:'managed_by')
    self.managed_by = attributes[:'managed_by']
  end

  if attributes.key?(:'open_cloud_risks')
    self.open_cloud_risks = attributes[:'open_cloud_risks']
  end

  if attributes.key?(:'publicly_exposed')
    self.publicly_exposed = attributes[:'publicly_exposed']
  end

  if attributes.key?(:'scan_type')
    self.scan_type = attributes[:'scan_type']
  end
end

Instance Attribute Details

#account_nameObject

Returns the value of attribute account_name.



34
35
36
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 34

def 
  @account_name
end

#allows_public_accessObject

Returns the value of attribute allows_public_access.



36
37
38
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 36

def allows_public_access
  @allows_public_access
end

#asset_graphObject

Returns the value of attribute asset_graph.



38
39
40
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 38

def asset_graph
  @asset_graph
end

#cloud_risksObject

Returns the value of attribute cloud_risks.



40
41
42
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 40

def cloud_risks
  @cloud_risks
end

#cspm_licenseObject

Returns the value of attribute cspm_license.



42
43
44
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 42

def cspm_license
  @cspm_license
end

#data_classificationsObject

Returns the value of attribute data_classifications.



44
45
46
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 44

def data_classifications
  @data_classifications
end

#detectionsObject

Returns the value of attribute detections.



46
47
48
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 46

def detections
  @detections
end

#has_falcon_sensorObject

Returns the value of attribute has_falcon_sensor.



48
49
50
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 48

def has_falcon_sensor
  @has_falcon_sensor
end

#has_tagsObject

Returns the value of attribute has_tags.



50
51
52
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 50

def has_tags
  @has_tags
end

#hostObject

Returns the value of attribute host.



52
53
54
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 52

def host
  @host
end

#insightsObject

Returns the value of attribute insights.



54
55
56
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 54

def insights
  @insights
end

#instance_idObject

Returns the value of attribute instance_id.



56
57
58
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 56

def instance_id
  @instance_id
end

#instance_stateObject

Returns the value of attribute instance_state.



58
59
60
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 58

def instance_state
  @instance_state
end

#legacy_resource_idObject

Returns the value of attribute legacy_resource_id.



60
61
62
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 60

def legacy_resource_id
  @legacy_resource_id
end

#legacy_type_idObject

Returns the value of attribute legacy_type_id.



62
63
64
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 62

def legacy_type_id
  @legacy_type_id
end

#legacy_uuidObject

Returns the value of attribute legacy_uuid.



64
65
66
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 64

def legacy_uuid
  @legacy_uuid
end

#managed_byObject

Returns the value of attribute managed_by.



66
67
68
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 66

def managed_by
  @managed_by
end

#open_cloud_risksObject

Returns the value of attribute open_cloud_risks.



68
69
70
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 68

def open_cloud_risks
  @open_cloud_risks
end

#publicly_exposedObject

Returns the value of attribute publicly_exposed.



70
71
72
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 70

def publicly_exposed
  @publicly_exposed
end

#scan_typeObject

Returns the value of attribute scan_type.



72
73
74
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 72

def scan_type
  @scan_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 75

def self.attribute_map
  {
    :'account_name' => :'account_name',
    :'allows_public_access' => :'allows_public_access',
    :'asset_graph' => :'asset_graph',
    :'cloud_risks' => :'cloud_risks',
    :'cspm_license' => :'cspm_license',
    :'data_classifications' => :'data_classifications',
    :'detections' => :'detections',
    :'has_falcon_sensor' => :'has_falcon_sensor',
    :'has_tags' => :'has_tags',
    :'host' => :'host',
    :'insights' => :'insights',
    :'instance_id' => :'instance_id',
    :'instance_state' => :'instance_state',
    :'legacy_resource_id' => :'legacy_resource_id',
    :'legacy_type_id' => :'legacy_type_id',
    :'legacy_uuid' => :'legacy_uuid',
    :'managed_by' => :'managed_by',
    :'open_cloud_risks' => :'open_cloud_risks',
    :'publicly_exposed' => :'publicly_exposed',
    :'scan_type' => :'scan_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 288

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 106

def self.openapi_types
  {
    :'account_name' => :'String',
    :'allows_public_access' => :'Boolean',
    :'asset_graph' => :'ResourcesAssetGraph',
    :'cloud_risks' => :'ResourcesCloudRisks',
    :'cspm_license' => :'String',
    :'data_classifications' => :'DataclassificationsResponse',
    :'detections' => :'ResourcesDetections',
    :'has_falcon_sensor' => :'Boolean',
    :'has_tags' => :'Boolean',
    :'host' => :'ResourcesHost',
    :'insights' => :'InsightsInsight',
    :'instance_id' => :'String',
    :'instance_state' => :'String',
    :'legacy_resource_id' => :'String',
    :'legacy_type_id' => :'Integer',
    :'legacy_uuid' => :'String',
    :'managed_by' => :'String',
    :'open_cloud_risks' => :'Integer',
    :'publicly_exposed' => :'Boolean',
    :'scan_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      allows_public_access == o.allows_public_access &&
      asset_graph == o.asset_graph &&
      cloud_risks == o.cloud_risks &&
      cspm_license == o.cspm_license &&
      data_classifications == o.data_classifications &&
      detections == o.detections &&
      has_falcon_sensor == o.has_falcon_sensor &&
      has_tags == o.has_tags &&
      host == o.host &&
      insights == o.insights &&
      instance_id == o.instance_id &&
      instance_state == o.instance_state &&
      legacy_resource_id == o.legacy_resource_id &&
      legacy_type_id == o.legacy_type_id &&
      legacy_uuid == o.legacy_uuid &&
      managed_by == o.managed_by &&
      open_cloud_risks == o.open_cloud_risks &&
      publicly_exposed == o.publicly_exposed &&
      scan_type == o.scan_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 319

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 390

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 295

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 281

def hash
  [, allows_public_access, asset_graph, cloud_risks, cspm_license, data_classifications, detections, has_falcon_sensor, has_tags, host, insights, instance_id, instance_state, legacy_resource_id, legacy_type_id, legacy_uuid, managed_by, open_cloud_risks, publicly_exposed, scan_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 235

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 366

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 372

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



360
361
362
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 360

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
# File 'lib/crimson-falcon/models/resources_cloud_context.rb', line 242

def valid?
  true
end