Class: Falcon::ResourcesDetections
- Inherits:
-
Object
- Object
- Falcon::ResourcesDetections
- Defined in:
- lib/crimson-falcon/models/resources_detections.rb
Instance Attribute Summary collapse
-
#compliant ⇒ Object
Returns the value of attribute compliant.
-
#highest_severity ⇒ Object
Returns the value of attribute highest_severity.
-
#ioa_counts ⇒ Object
Returns the value of attribute ioa_counts.
-
#ioa_counts_by_severity ⇒ Object
Returns the value of attribute ioa_counts_by_severity.
-
#iom_counts ⇒ Object
Returns the value of attribute iom_counts.
-
#iom_counts_by_severity ⇒ Object
Returns the value of attribute iom_counts_by_severity.
-
#non_compliant ⇒ Object
Returns the value of attribute non_compliant.
-
#resource_url ⇒ Object
Returns the value of attribute resource_url.
-
#severities ⇒ Object
Returns the value of attribute severities.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourcesDetections
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ResourcesDetections
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ResourcesDetections` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ResourcesDetections`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'compliant') self.compliant = attributes[:'compliant'] end if attributes.key?(:'highest_severity') self.highest_severity = attributes[:'highest_severity'] end if attributes.key?(:'ioa_counts') self.ioa_counts = attributes[:'ioa_counts'] end if attributes.key?(:'ioa_counts_by_severity') self.ioa_counts_by_severity = attributes[:'ioa_counts_by_severity'] end if attributes.key?(:'iom_counts') self.iom_counts = attributes[:'iom_counts'] end if attributes.key?(:'iom_counts_by_severity') self.iom_counts_by_severity = attributes[:'iom_counts_by_severity'] end if attributes.key?(:'non_compliant') self.non_compliant = attributes[:'non_compliant'] end if attributes.key?(:'resource_url') self.resource_url = attributes[:'resource_url'] end if attributes.key?(:'severities') if (value = attributes[:'severities']).is_a?(Array) self.severities = value end end end |
Instance Attribute Details
#compliant ⇒ Object
Returns the value of attribute compliant.
34 35 36 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 34 def compliant @compliant end |
#highest_severity ⇒ Object
Returns the value of attribute highest_severity.
36 37 38 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 36 def highest_severity @highest_severity end |
#ioa_counts ⇒ Object
Returns the value of attribute ioa_counts.
38 39 40 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 38 def ioa_counts @ioa_counts end |
#ioa_counts_by_severity ⇒ Object
Returns the value of attribute ioa_counts_by_severity.
40 41 42 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 40 def ioa_counts_by_severity @ioa_counts_by_severity end |
#iom_counts ⇒ Object
Returns the value of attribute iom_counts.
42 43 44 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 42 def iom_counts @iom_counts end |
#iom_counts_by_severity ⇒ Object
Returns the value of attribute iom_counts_by_severity.
44 45 46 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 44 def iom_counts_by_severity @iom_counts_by_severity end |
#non_compliant ⇒ Object
Returns the value of attribute non_compliant.
46 47 48 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 46 def non_compliant @non_compliant end |
#resource_url ⇒ Object
Returns the value of attribute resource_url.
48 49 50 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 48 def resource_url @resource_url end |
#severities ⇒ Object
Returns the value of attribute severities.
50 51 52 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 50 def severities @severities end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 53 def self.attribute_map { :'compliant' => :'compliant', :'highest_severity' => :'highest_severity', :'ioa_counts' => :'ioa_counts', :'ioa_counts_by_severity' => :'ioa_counts_by_severity', :'iom_counts' => :'iom_counts', :'iom_counts_by_severity' => :'iom_counts_by_severity', :'non_compliant' => :'non_compliant', :'resource_url' => :'resource_url', :'severities' => :'severities' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 206 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 73 def self.openapi_types { :'compliant' => :'ResourcesCompliance', :'highest_severity' => :'String', :'ioa_counts' => :'Integer', :'ioa_counts_by_severity' => :'ResourcesDetectionCount', :'iom_counts' => :'Integer', :'iom_counts_by_severity' => :'ResourcesDetectionCount', :'non_compliant' => :'ResourcesCompliance', :'resource_url' => :'String', :'severities' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && compliant == o.compliant && highest_severity == o.highest_severity && ioa_counts == o.ioa_counts && ioa_counts_by_severity == o.ioa_counts_by_severity && iom_counts == o.iom_counts && iom_counts_by_severity == o.iom_counts_by_severity && non_compliant == o.non_compliant && resource_url == o.resource_url && severities == o.severities end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 237 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 308 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 213 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 199 def hash [compliant, highest_severity, ioa_counts, ioa_counts_by_severity, iom_counts, iom_counts_by_severity, non_compliant, resource_url, severities].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 149 def list_invalid_properties invalid_properties = Array.new if @ioa_counts.nil? invalid_properties.push('invalid value for "ioa_counts", ioa_counts cannot be nil.') end if @iom_counts.nil? invalid_properties.push('invalid value for "iom_counts", iom_counts cannot be nil.') end if @resource_url.nil? invalid_properties.push('invalid value for "resource_url", resource_url cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
284 285 286 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 284 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 278 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 |
# File 'lib/crimson-falcon/models/resources_detections.rb', line 168 def valid? return false if @ioa_counts.nil? return false if @iom_counts.nil? return false if @resource_url.nil? true end |