Class: Falcon::ResourcesHost

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/resources_host.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResourcesHost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/crimson-falcon/models/resources_host.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ResourcesHost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ResourcesHost`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aid')
    self.aid = attributes[:'aid']
  end

  if attributes.key?(:'apps')
    if (value = attributes[:'apps']).is_a?(Array)
      self.apps = value
    end
  end

  if attributes.key?(:'cve_ids')
    if (value = attributes[:'cve_ids']).is_a?(Array)
      self.cve_ids = value
    end
  end

  if attributes.key?(:'exprt_ratings')
    if (value = attributes[:'exprt_ratings']).is_a?(Array)
      self.exprt_ratings = value
    end
  end

  if attributes.key?(:'managed_by')
    self.managed_by = attributes[:'managed_by']
  end

  if attributes.key?(:'os_build')
    self.os_build = attributes[:'os_build']
  end

  if attributes.key?(:'os_version')
    self.os_version = attributes[:'os_version']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'platform_os_name')
    self.platform_os_name = attributes[:'platform_os_name']
  end

  if attributes.key?(:'platform_os_version')
    self.platform_os_version = attributes[:'platform_os_version']
  end

  if attributes.key?(:'recommendations')
    if (value = attributes[:'recommendations']).is_a?(Array)
      self.recommendations = value
    end
  end

  if attributes.key?(:'sensor_priority')
    self.sensor_priority = attributes[:'sensor_priority']
  end

  if attributes.key?(:'snapshot_detections')
    if (value = attributes[:'snapshot_detections']).is_a?(Array)
      self.snapshot_detections = value
    end
  end

  if attributes.key?(:'ssm_managed')
    self.ssm_managed = attributes[:'ssm_managed']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'vulnerabilities')
    if (value = attributes[:'vulnerabilities']).is_a?(Array)
      self.vulnerabilities = value
    end
  end

  if attributes.key?(:'vulnerabilities_count')
    self.vulnerabilities_count = attributes[:'vulnerabilities_count']
  end
end

Instance Attribute Details

#aidObject

Returns the value of attribute aid.



34
35
36
# File 'lib/crimson-falcon/models/resources_host.rb', line 34

def aid
  @aid
end

#appsObject

Returns the value of attribute apps.



36
37
38
# File 'lib/crimson-falcon/models/resources_host.rb', line 36

def apps
  @apps
end

#cve_idsObject

Returns the value of attribute cve_ids.



38
39
40
# File 'lib/crimson-falcon/models/resources_host.rb', line 38

def cve_ids
  @cve_ids
end

#exprt_ratingsObject

Returns the value of attribute exprt_ratings.



40
41
42
# File 'lib/crimson-falcon/models/resources_host.rb', line 40

def exprt_ratings
  @exprt_ratings
end

#managed_byObject

Returns the value of attribute managed_by.



42
43
44
# File 'lib/crimson-falcon/models/resources_host.rb', line 42

def managed_by
  @managed_by
end

#os_buildObject

Returns the value of attribute os_build.



44
45
46
# File 'lib/crimson-falcon/models/resources_host.rb', line 44

def os_build
  @os_build
end

#os_versionObject

Returns the value of attribute os_version.



46
47
48
# File 'lib/crimson-falcon/models/resources_host.rb', line 46

def os_version
  @os_version
end

#platform_nameObject

Returns the value of attribute platform_name.



48
49
50
# File 'lib/crimson-falcon/models/resources_host.rb', line 48

def platform_name
  @platform_name
end

#platform_os_nameObject

Returns the value of attribute platform_os_name.



50
51
52
# File 'lib/crimson-falcon/models/resources_host.rb', line 50

def platform_os_name
  @platform_os_name
end

#platform_os_versionObject

Returns the value of attribute platform_os_version.



52
53
54
# File 'lib/crimson-falcon/models/resources_host.rb', line 52

def platform_os_version
  @platform_os_version
end

#recommendationsObject

Returns the value of attribute recommendations.



54
55
56
# File 'lib/crimson-falcon/models/resources_host.rb', line 54

def recommendations
  @recommendations
end

#sensor_priorityObject

Returns the value of attribute sensor_priority.



56
57
58
# File 'lib/crimson-falcon/models/resources_host.rb', line 56

def sensor_priority
  @sensor_priority
end

#snapshot_detectionsObject

Returns the value of attribute snapshot_detections.



58
59
60
# File 'lib/crimson-falcon/models/resources_host.rb', line 58

def snapshot_detections
  @snapshot_detections
end

#ssm_managedObject

Returns the value of attribute ssm_managed.



60
61
62
# File 'lib/crimson-falcon/models/resources_host.rb', line 60

def ssm_managed
  @ssm_managed
end

#stateObject

Returns the value of attribute state.



62
63
64
# File 'lib/crimson-falcon/models/resources_host.rb', line 62

def state
  @state
end

#vulnerabilitiesObject

Returns the value of attribute vulnerabilities.



64
65
66
# File 'lib/crimson-falcon/models/resources_host.rb', line 64

def vulnerabilities
  @vulnerabilities
end

#vulnerabilities_countObject

Returns the value of attribute vulnerabilities_count.



66
67
68
# File 'lib/crimson-falcon/models/resources_host.rb', line 66

def vulnerabilities_count
  @vulnerabilities_count
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/crimson-falcon/models/resources_host.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/resources_host.rb', line 69

def self.attribute_map
  {
    :'aid' => :'aid',
    :'apps' => :'apps',
    :'cve_ids' => :'cve_ids',
    :'exprt_ratings' => :'exprt_ratings',
    :'managed_by' => :'managed_by',
    :'os_build' => :'os_build',
    :'os_version' => :'os_version',
    :'platform_name' => :'platform_name',
    :'platform_os_name' => :'platform_os_name',
    :'platform_os_version' => :'platform_os_version',
    :'recommendations' => :'recommendations',
    :'sensor_priority' => :'sensor_priority',
    :'snapshot_detections' => :'snapshot_detections',
    :'ssm_managed' => :'ssm_managed',
    :'state' => :'state',
    :'vulnerabilities' => :'vulnerabilities',
    :'vulnerabilities_count' => :'vulnerabilities_count'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
# File 'lib/crimson-falcon/models/resources_host.rb', line 273

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/crimson-falcon/models/resources_host.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/crimson-falcon/models/resources_host.rb', line 97

def self.openapi_types
  {
    :'aid' => :'String',
    :'apps' => :'Array<String>',
    :'cve_ids' => :'Array<String>',
    :'exprt_ratings' => :'Array<String>',
    :'managed_by' => :'String',
    :'os_build' => :'String',
    :'os_version' => :'String',
    :'platform_name' => :'String',
    :'platform_os_name' => :'String',
    :'platform_os_version' => :'String',
    :'recommendations' => :'Array<String>',
    :'sensor_priority' => :'String',
    :'snapshot_detections' => :'Array<String>',
    :'ssm_managed' => :'Boolean',
    :'state' => :'String',
    :'vulnerabilities' => :'Array<ResourcesVulnerability>',
    :'vulnerabilities_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/crimson-falcon/models/resources_host.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aid == o.aid &&
      apps == o.apps &&
      cve_ids == o.cve_ids &&
      exprt_ratings == o.exprt_ratings &&
      managed_by == o.managed_by &&
      os_build == o.os_build &&
      os_version == o.os_version &&
      platform_name == o.platform_name &&
      platform_os_name == o.platform_os_name &&
      platform_os_version == o.platform_os_version &&
      recommendations == o.recommendations &&
      sensor_priority == o.sensor_priority &&
      snapshot_detections == o.snapshot_detections &&
      ssm_managed == o.ssm_managed &&
      state == o.state &&
      vulnerabilities == o.vulnerabilities &&
      vulnerabilities_count == o.vulnerabilities_count
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/crimson-falcon/models/resources_host.rb', line 304

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/crimson-falcon/models/resources_host.rb', line 375

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/crimson-falcon/models/resources_host.rb', line 280

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/crimson-falcon/models/resources_host.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/crimson-falcon/models/resources_host.rb', line 266

def hash
  [aid, apps, cve_ids, exprt_ratings, managed_by, os_build, os_version, platform_name, platform_os_name, platform_os_version, recommendations, sensor_priority, snapshot_detections, ssm_managed, state, vulnerabilities, vulnerabilities_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
# File 'lib/crimson-falcon/models/resources_host.rb', line 223

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
# File 'lib/crimson-falcon/models/resources_host.rb', line 351

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/crimson-falcon/models/resources_host.rb', line 357

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



345
346
347
# File 'lib/crimson-falcon/models/resources_host.rb', line 345

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
# File 'lib/crimson-falcon/models/resources_host.rb', line 230

def valid?
  true
end