Class: Falcon::RestAWSAccountPatchExtV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RestAWSAccountPatchExtV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 179

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::RestAWSAccountPatchExtV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::RestAWSAccountPatchExtV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'cloudtrail_region')
    self.cloudtrail_region = attributes[:'cloudtrail_region']
  end

  if attributes.key?(:'csp_events')
    self.csp_events = attributes[:'csp_events']
  end

  if attributes.key?(:'disable_products')
    if (value = attributes[:'disable_products']).is_a?(Array)
      self.disable_products = value
    end
  end

  if attributes.key?(:'dspm_custom_vpc_configuration')
    if (value = attributes[:'dspm_custom_vpc_configuration']).is_a?(Hash)
      self.dspm_custom_vpc_configuration = value
    end
  end

  if attributes.key?(:'dspm_host_account_id')
    self. = attributes[:'dspm_host_account_id']
  end

  if attributes.key?(:'dspm_network_configuration_type')
    self.dspm_network_configuration_type = attributes[:'dspm_network_configuration_type']
  end

  if attributes.key?(:'dspm_regions')
    if (value = attributes[:'dspm_regions']).is_a?(Array)
      self.dspm_regions = value
    end
  end

  if attributes.key?(:'dspm_role')
    self.dspm_role = attributes[:'dspm_role']
  end

  if attributes.key?(:'dspm_service_permissions_override')
    if (value = attributes[:'dspm_service_permissions_override']).is_a?(Array)
      self.dspm_service_permissions_override = value
    end
  end

  if attributes.key?(:'falcon_client_id')
    self.falcon_client_id = attributes[:'falcon_client_id']
  end

  if attributes.key?(:'ioa_regions')
    if (value = attributes[:'ioa_regions']).is_a?(Array)
      self.ioa_regions = value
    end
  end

  if attributes.key?(:'log_ingestion_method')
    self.log_ingestion_method = attributes[:'log_ingestion_method']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'products')
    if (value = attributes[:'products']).is_a?(Array)
      self.products = value
    end
  end

  if attributes.key?(:'reader_role_arn')
    self.reader_role_arn = attributes[:'reader_role_arn']
  end

  if attributes.key?(:'remediation_region')
    self.remediation_region = attributes[:'remediation_region']
  end

  if attributes.key?(:'remediation_tou_accepted')
    self.remediation_tou_accepted = attributes[:'remediation_tou_accepted']
  end

  if attributes.key?(:'resource_name_prefix')
    self.resource_name_prefix = attributes[:'resource_name_prefix']
  end

  if attributes.key?(:'resource_name_suffix')
    self.resource_name_suffix = attributes[:'resource_name_suffix']
  end

  if attributes.key?(:'s3_log_ingestion_bucket_name')
    self.s3_log_ingestion_bucket_name = attributes[:'s3_log_ingestion_bucket_name']
  end

  if attributes.key?(:'s3_log_ingestion_bucket_prefix')
    self.s3_log_ingestion_bucket_prefix = attributes[:'s3_log_ingestion_bucket_prefix']
  end

  if attributes.key?(:'s3_log_ingestion_kms_key_arn')
    self.s3_log_ingestion_kms_key_arn = attributes[:'s3_log_ingestion_kms_key_arn']
  end

  if attributes.key?(:'s3_log_ingestion_sns_topic_arn')
    self.s3_log_ingestion_sns_topic_arn = attributes[:'s3_log_ingestion_sns_topic_arn']
  end

  if attributes.key?(:'use_existing_cloudtrail')
    self.use_existing_cloudtrail = attributes[:'use_existing_cloudtrail']
  end

  if attributes.key?(:'vulnerability_scanning_custom_vpc_configuration')
    if (value = attributes[:'vulnerability_scanning_custom_vpc_configuration']).is_a?(Hash)
      self.vulnerability_scanning_custom_vpc_configuration = value
    end
  end

  if attributes.key?(:'vulnerability_scanning_host_account_id')
    self. = attributes[:'vulnerability_scanning_host_account_id']
  end

  if attributes.key?(:'vulnerability_scanning_network_configuration_type')
    self.vulnerability_scanning_network_configuration_type = attributes[:'vulnerability_scanning_network_configuration_type']
  end

  if attributes.key?(:'vulnerability_scanning_regions')
    if (value = attributes[:'vulnerability_scanning_regions']).is_a?(Array)
      self.vulnerability_scanning_regions = value
    end
  end

  if attributes.key?(:'vulnerability_scanning_role')
    self.vulnerability_scanning_role = attributes[:'vulnerability_scanning_role']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



34
35
36
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 34

def 
  @account_id
end

#cloudtrail_regionObject

Returns the value of attribute cloudtrail_region.



36
37
38
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 36

def cloudtrail_region
  @cloudtrail_region
end

#csp_eventsObject

Returns the value of attribute csp_events.



38
39
40
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 38

def csp_events
  @csp_events
end

#disable_productsObject

Returns the value of attribute disable_products.



40
41
42
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 40

def disable_products
  @disable_products
end

#dspm_custom_vpc_configurationObject

Returns the value of attribute dspm_custom_vpc_configuration.



42
43
44
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 42

def dspm_custom_vpc_configuration
  @dspm_custom_vpc_configuration
end

#dspm_host_account_idObject

Returns the value of attribute dspm_host_account_id.



44
45
46
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 44

def 
  @dspm_host_account_id
end

#dspm_network_configuration_typeObject

Returns the value of attribute dspm_network_configuration_type.



46
47
48
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 46

def dspm_network_configuration_type
  @dspm_network_configuration_type
end

#dspm_regionsObject

Returns the value of attribute dspm_regions.



48
49
50
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 48

def dspm_regions
  @dspm_regions
end

#dspm_roleObject

Returns the value of attribute dspm_role.



50
51
52
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 50

def dspm_role
  @dspm_role
end

#dspm_service_permissions_overrideObject

Returns the value of attribute dspm_service_permissions_override.



52
53
54
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 52

def dspm_service_permissions_override
  @dspm_service_permissions_override
end

#falcon_client_idObject

Returns the value of attribute falcon_client_id.



54
55
56
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 54

def falcon_client_id
  @falcon_client_id
end

#ioa_regionsObject

Returns the value of attribute ioa_regions.



56
57
58
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 56

def ioa_regions
  @ioa_regions
end

#log_ingestion_methodObject

Returns the value of attribute log_ingestion_method.



58
59
60
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 58

def log_ingestion_method
  @log_ingestion_method
end

#organization_idObject

Returns the value of attribute organization_id.



60
61
62
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 60

def organization_id
  @organization_id
end

#productsObject

Returns the value of attribute products.



62
63
64
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 62

def products
  @products
end

#reader_role_arnObject

Returns the value of attribute reader_role_arn.



64
65
66
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 64

def reader_role_arn
  @reader_role_arn
end

#remediation_regionObject

Returns the value of attribute remediation_region.



66
67
68
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 66

def remediation_region
  @remediation_region
end

#remediation_tou_acceptedObject

Returns the value of attribute remediation_tou_accepted.



68
69
70
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 68

def remediation_tou_accepted
  @remediation_tou_accepted
end

#resource_name_prefixObject

Returns the value of attribute resource_name_prefix.



70
71
72
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 70

def resource_name_prefix
  @resource_name_prefix
end

#resource_name_suffixObject

Returns the value of attribute resource_name_suffix.



72
73
74
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 72

def resource_name_suffix
  @resource_name_suffix
end

#s3_log_ingestion_bucket_nameObject

Returns the value of attribute s3_log_ingestion_bucket_name.



74
75
76
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 74

def s3_log_ingestion_bucket_name
  @s3_log_ingestion_bucket_name
end

#s3_log_ingestion_bucket_prefixObject

Returns the value of attribute s3_log_ingestion_bucket_prefix.



76
77
78
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 76

def s3_log_ingestion_bucket_prefix
  @s3_log_ingestion_bucket_prefix
end

#s3_log_ingestion_kms_key_arnObject

Returns the value of attribute s3_log_ingestion_kms_key_arn.



78
79
80
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 78

def s3_log_ingestion_kms_key_arn
  @s3_log_ingestion_kms_key_arn
end

#s3_log_ingestion_sns_topic_arnObject

Returns the value of attribute s3_log_ingestion_sns_topic_arn.



80
81
82
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 80

def s3_log_ingestion_sns_topic_arn
  @s3_log_ingestion_sns_topic_arn
end

#use_existing_cloudtrailObject

Returns the value of attribute use_existing_cloudtrail.



82
83
84
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 82

def use_existing_cloudtrail
  @use_existing_cloudtrail
end

#vulnerability_scanning_custom_vpc_configurationObject

Returns the value of attribute vulnerability_scanning_custom_vpc_configuration.



84
85
86
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 84

def vulnerability_scanning_custom_vpc_configuration
  @vulnerability_scanning_custom_vpc_configuration
end

#vulnerability_scanning_host_account_idObject

Returns the value of attribute vulnerability_scanning_host_account_id.



86
87
88
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 86

def 
  @vulnerability_scanning_host_account_id
end

#vulnerability_scanning_network_configuration_typeObject

Returns the value of attribute vulnerability_scanning_network_configuration_type.



88
89
90
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 88

def vulnerability_scanning_network_configuration_type
  @vulnerability_scanning_network_configuration_type
end

#vulnerability_scanning_regionsObject

Returns the value of attribute vulnerability_scanning_regions.



90
91
92
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 90

def vulnerability_scanning_regions
  @vulnerability_scanning_regions
end

#vulnerability_scanning_roleObject

Returns the value of attribute vulnerability_scanning_role.



92
93
94
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 92

def vulnerability_scanning_role
  @vulnerability_scanning_role
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 131

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 95

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'cloudtrail_region' => :'cloudtrail_region',
    :'csp_events' => :'csp_events',
    :'disable_products' => :'disable_products',
    :'dspm_custom_vpc_configuration' => :'dspm_custom_vpc_configuration',
    :'dspm_host_account_id' => :'dspm_host_account_id',
    :'dspm_network_configuration_type' => :'dspm_network_configuration_type',
    :'dspm_regions' => :'dspm_regions',
    :'dspm_role' => :'dspm_role',
    :'dspm_service_permissions_override' => :'dspm_service_permissions_override',
    :'falcon_client_id' => :'falcon_client_id',
    :'ioa_regions' => :'ioa_regions',
    :'log_ingestion_method' => :'log_ingestion_method',
    :'organization_id' => :'organization_id',
    :'products' => :'products',
    :'reader_role_arn' => :'reader_role_arn',
    :'remediation_region' => :'remediation_region',
    :'remediation_tou_accepted' => :'remediation_tou_accepted',
    :'resource_name_prefix' => :'resource_name_prefix',
    :'resource_name_suffix' => :'resource_name_suffix',
    :'s3_log_ingestion_bucket_name' => :'s3_log_ingestion_bucket_name',
    :'s3_log_ingestion_bucket_prefix' => :'s3_log_ingestion_bucket_prefix',
    :'s3_log_ingestion_kms_key_arn' => :'s3_log_ingestion_kms_key_arn',
    :'s3_log_ingestion_sns_topic_arn' => :'s3_log_ingestion_sns_topic_arn',
    :'use_existing_cloudtrail' => :'use_existing_cloudtrail',
    :'vulnerability_scanning_custom_vpc_configuration' => :'vulnerability_scanning_custom_vpc_configuration',
    :'vulnerability_scanning_host_account_id' => :'vulnerability_scanning_host_account_id',
    :'vulnerability_scanning_network_configuration_type' => :'vulnerability_scanning_network_configuration_type',
    :'vulnerability_scanning_regions' => :'vulnerability_scanning_regions',
    :'vulnerability_scanning_role' => :'vulnerability_scanning_role'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



399
400
401
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 399

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



172
173
174
175
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 172

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 136

def self.openapi_types
  {
    :'account_id' => :'String',
    :'cloudtrail_region' => :'String',
    :'csp_events' => :'Boolean',
    :'disable_products' => :'Array<RestAccountProductRequestExtV1>',
    :'dspm_custom_vpc_configuration' => :'Hash<String, DomainAWSRegionalVPCConfiguration>',
    :'dspm_host_account_id' => :'String',
    :'dspm_network_configuration_type' => :'String',
    :'dspm_regions' => :'Array<String>',
    :'dspm_role' => :'String',
    :'dspm_service_permissions_override' => :'Array<String>',
    :'falcon_client_id' => :'String',
    :'ioa_regions' => :'Array<String>',
    :'log_ingestion_method' => :'String',
    :'organization_id' => :'String',
    :'products' => :'Array<RestAccountProductRequestExtV1>',
    :'reader_role_arn' => :'String',
    :'remediation_region' => :'String',
    :'remediation_tou_accepted' => :'Time',
    :'resource_name_prefix' => :'String',
    :'resource_name_suffix' => :'String',
    :'s3_log_ingestion_bucket_name' => :'String',
    :'s3_log_ingestion_bucket_prefix' => :'String',
    :'s3_log_ingestion_kms_key_arn' => :'String',
    :'s3_log_ingestion_sns_topic_arn' => :'String',
    :'use_existing_cloudtrail' => :'Boolean',
    :'vulnerability_scanning_custom_vpc_configuration' => :'Hash<String, DomainAWSRegionalVPCConfiguration>',
    :'vulnerability_scanning_host_account_id' => :'String',
    :'vulnerability_scanning_network_configuration_type' => :'String',
    :'vulnerability_scanning_regions' => :'Array<String>',
    :'vulnerability_scanning_role' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 349

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      cloudtrail_region == o.cloudtrail_region &&
      csp_events == o.csp_events &&
      disable_products == o.disable_products &&
      dspm_custom_vpc_configuration == o.dspm_custom_vpc_configuration &&
       == o. &&
      dspm_network_configuration_type == o.dspm_network_configuration_type &&
      dspm_regions == o.dspm_regions &&
      dspm_role == o.dspm_role &&
      dspm_service_permissions_override == o.dspm_service_permissions_override &&
      falcon_client_id == o.falcon_client_id &&
      ioa_regions == o.ioa_regions &&
      log_ingestion_method == o.log_ingestion_method &&
      organization_id == o.organization_id &&
      products == o.products &&
      reader_role_arn == o.reader_role_arn &&
      remediation_region == o.remediation_region &&
      remediation_tou_accepted == o.remediation_tou_accepted &&
      resource_name_prefix == o.resource_name_prefix &&
      resource_name_suffix == o.resource_name_suffix &&
      s3_log_ingestion_bucket_name == o.s3_log_ingestion_bucket_name &&
      s3_log_ingestion_bucket_prefix == o.s3_log_ingestion_bucket_prefix &&
      s3_log_ingestion_kms_key_arn == o.s3_log_ingestion_kms_key_arn &&
      s3_log_ingestion_sns_topic_arn == o.s3_log_ingestion_sns_topic_arn &&
      use_existing_cloudtrail == o.use_existing_cloudtrail &&
      vulnerability_scanning_custom_vpc_configuration == o.vulnerability_scanning_custom_vpc_configuration &&
       == o. &&
      vulnerability_scanning_network_configuration_type == o.vulnerability_scanning_network_configuration_type &&
      vulnerability_scanning_regions == o.vulnerability_scanning_regions &&
      vulnerability_scanning_role == o.vulnerability_scanning_role
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 430

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 501

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 406

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


386
387
388
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 386

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



392
393
394
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 392

def hash
  [, cloudtrail_region, csp_events, disable_products, dspm_custom_vpc_configuration, , dspm_network_configuration_type, dspm_regions, dspm_role, dspm_service_permissions_override, falcon_client_id, ioa_regions, log_ingestion_method, organization_id, products, reader_role_arn, remediation_region, remediation_tou_accepted, resource_name_prefix, resource_name_suffix, s3_log_ingestion_bucket_name, s3_log_ingestion_bucket_prefix, s3_log_ingestion_kms_key_arn, s3_log_ingestion_sns_topic_arn, use_existing_cloudtrail, vulnerability_scanning_custom_vpc_configuration, , vulnerability_scanning_network_configuration_type, vulnerability_scanning_regions, vulnerability_scanning_role].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



331
332
333
334
335
336
337
338
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 331

def list_invalid_properties
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



477
478
479
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 477

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 483

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



471
472
473
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 471

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



342
343
344
345
# File 'lib/crimson-falcon/models/rest_aws_account_patch_ext_v1.rb', line 342

def valid?
  return false if @account_id.nil?
  true
end