Class: Falcon::RuntimeDetections

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/runtime_detections.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RuntimeDetections

Returns a new instance of RuntimeDetections.



36
37
38
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 36

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



34
35
36
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 34

def api_client
  @api_client
end

Instance Method Details

#get_runtime_detections_combined_v2(opts = {}) ⇒ RuntimedetectionsDetectionsEntityResponse

Maximum offset = 10000 - limit

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Filter Container Runtime Detections using a query in Falcon Query Language (FQL). Supported filter fields: - `agent_type` - `aid` - `cid` - `cloud_name` - `cloud` - `cluster_name` - `computer_name` - `container_id` - `detect_timestamp` - `host_id` - `host_type` - `image_id` - `name` - `namespace` - `pod_name` - `severity`

  • :sort (String)

    The fields to sort the records on.

  • :limit (Integer)

    The upper-bound on the number of records to retrieve. (default to 100)

  • :offset (Integer)

    The offset from where to begin.

Returns:



46
47
48
49
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 46

def get_runtime_detections_combined_v2(opts = {})
  data, _status_code, _headers = get_runtime_detections_combined_v2_with_http_info(opts)
  data
end

#get_runtime_detections_combined_v2_with_http_info(opts = {}) ⇒ Array<(RuntimedetectionsDetectionsEntityResponse, Integer, Hash)>

Maximum offset &#x3D; 10000 - limit

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Filter Container Runtime Detections using a query in Falcon Query Language (FQL). Supported filter fields: - &#x60;agent_type&#x60; - &#x60;aid&#x60; - &#x60;cid&#x60; - &#x60;cloud_name&#x60; - &#x60;cloud&#x60; - &#x60;cluster_name&#x60; - &#x60;computer_name&#x60; - &#x60;container_id&#x60; - &#x60;detect_timestamp&#x60; - &#x60;host_id&#x60; - &#x60;host_type&#x60; - &#x60;image_id&#x60; - &#x60;name&#x60; - &#x60;namespace&#x60; - &#x60;pod_name&#x60; - &#x60;severity&#x60;

  • :sort (String)

    The fields to sort the records on.

  • :limit (Integer)

    The upper-bound on the number of records to retrieve. (default to 100)

  • :offset (Integer)

    The offset from where to begin.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 58

def get_runtime_detections_combined_v2_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RuntimeDetections.get_runtime_detections_combined_v2 ...'
  end
  # resource path
  local_var_path = '/container-security/combined/runtime-detections/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RuntimedetectionsDetectionsEntityResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"RuntimeDetections.get_runtime_detections_combined_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RuntimeDetections#get_runtime_detections_combined_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end