Class: Falcon::SadomainCreateRuleRequestV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SadomainCreateRuleRequestV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SadomainCreateRuleRequestV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SadomainCreateRuleRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'breach_monitor_only')
    self.breach_monitor_only = attributes[:'breach_monitor_only']
  end

  if attributes.key?(:'breach_monitoring_enabled')
    self.breach_monitoring_enabled = attributes[:'breach_monitoring_enabled']
  end

  if attributes.key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.key?(:'lookback_period')
    self.lookback_period = attributes[:'lookback_period']
  end

  if attributes.key?(:'match_on_tsq_result_types')
    if (value = attributes[:'match_on_tsq_result_types']).is_a?(Array)
      self.match_on_tsq_result_types = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'originating_template_id')
    self.originating_template_id = attributes[:'originating_template_id']
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'substring_matching_enabled')
    self.substring_matching_enabled = attributes[:'substring_matching_enabled']
  end

  if attributes.key?(:'topic')
    self.topic = attributes[:'topic']
  end
end

Instance Attribute Details

#breach_monitor_onlyObject

Monitor only for exposed data. Must be accompanied by breach_monitoring_enabled:true.



35
36
37
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 35

def breach_monitor_only
  @breach_monitor_only
end

#breach_monitoring_enabledObject

Whether to monitor for exposed data. Available only for ‘Company Domains` and `Email addresses` rule topics.



38
39
40
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 38

def breach_monitoring_enabled
  @breach_monitoring_enabled
end

#filterObject

The FQL filter to be used for searching



41
42
43
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 41

def filter
  @filter
end

#lookback_periodObject

The duration for which the rule will look back in the past at the first run. Time unit: nanoseconds. Possible values: [‘604800000000000 (7 days)`, `2592000000000000 (1 month)`, `15552000000000000 (6 months)`, `31536000000000000 (1 year)`]



44
45
46
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 44

def lookback_period
  @lookback_period
end

#match_on_tsq_result_typesObject

Which result types to monitor for. Can be set to only monitor domains or subdomains, as well as both. Only available for the ‘Typosquatting` rule topic. Possible values: [`basedomains`, `subdomains`]



47
48
49
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 47

def match_on_tsq_result_types
  @match_on_tsq_result_types
end

#nameObject

The name of a given rule



50
51
52
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 50

def name
  @name
end

#originating_template_idObject

This is for internal use only. It tells the id of the template if the rule was generated based on one.



53
54
55
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 53

def originating_template_id
  @originating_template_id
end

#permissionsObject

The permissions for a given rule which specifies the rule’s access by other users. Possible values: [‘public (All Recon users)`, `private (Recon admins)`]



56
57
58
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 56

def permissions
  @permissions
end

#priorityObject

The priority for a given rule. Possible values: [‘none`, `low`, `medium`, `high`, `critical`]



59
60
61
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 59

def priority
  @priority
end

#substring_matching_enabledObject

Whether to monitor for substring matches. Only available for the ‘Typosquatting` rule topic.



62
63
64
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 62

def substring_matching_enabled
  @substring_matching_enabled
end

#topicObject

The topic of a given rule. Possible values: [‘SA_BRAND_PRODUCT (Brands and products)`, `SA_VIP (High-profile-employees)`, `SA_THIRD_PARTY (Supply chain vendors)`, `SA_IP (IP addresses)`, `SA_CVE (Vulnerabilities (CVEs))`, `SA_BIN (Bank identification numbers (BINs))`, `SA_DOMAIN (Company domains)`, `SA_EMAIL (Email addresses)`, `SA_ALIAS (Company names)`, `SA_AUTHOR (Authors)`, `SA_CUSTOM (Custom)`, `SA_TYPOSQUATTING (Typosquatting)`]



65
66
67
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 65

def topic
  @topic
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 68

def self.attribute_map
  {
    :'breach_monitor_only' => :'breach_monitor_only',
    :'breach_monitoring_enabled' => :'breach_monitoring_enabled',
    :'filter' => :'filter',
    :'lookback_period' => :'lookback_period',
    :'match_on_tsq_result_types' => :'match_on_tsq_result_types',
    :'name' => :'name',
    :'originating_template_id' => :'originating_template_id',
    :'permissions' => :'permissions',
    :'priority' => :'priority',
    :'substring_matching_enabled' => :'substring_matching_enabled',
    :'topic' => :'topic'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 270

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 90

def self.openapi_types
  {
    :'breach_monitor_only' => :'Boolean',
    :'breach_monitoring_enabled' => :'Boolean',
    :'filter' => :'String',
    :'lookback_period' => :'Integer',
    :'match_on_tsq_result_types' => :'Array<String>',
    :'name' => :'String',
    :'originating_template_id' => :'String',
    :'permissions' => :'String',
    :'priority' => :'String',
    :'substring_matching_enabled' => :'Boolean',
    :'topic' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      breach_monitor_only == o.breach_monitor_only &&
      breach_monitoring_enabled == o.breach_monitoring_enabled &&
      filter == o.filter &&
      lookback_period == o.lookback_period &&
      match_on_tsq_result_types == o.match_on_tsq_result_types &&
      name == o.name &&
      originating_template_id == o.originating_template_id &&
      permissions == o.permissions &&
      priority == o.priority &&
      substring_matching_enabled == o.substring_matching_enabled &&
      topic == o.topic
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 301

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 372

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 277

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 263

def hash
  [breach_monitor_only, breach_monitoring_enabled, filter, lookback_period, match_on_tsq_result_types, name, originating_template_id, permissions, priority, substring_matching_enabled, topic].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 176

def list_invalid_properties
  invalid_properties = Array.new
  if @breach_monitor_only.nil?
    invalid_properties.push('invalid value for "breach_monitor_only", breach_monitor_only cannot be nil.')
  end

  if @breach_monitoring_enabled.nil?
    invalid_properties.push('invalid value for "breach_monitoring_enabled", breach_monitoring_enabled cannot be nil.')
  end

  if @filter.nil?
    invalid_properties.push('invalid value for "filter", filter cannot be nil.')
  end

  if @match_on_tsq_result_types.nil?
    invalid_properties.push('invalid value for "match_on_tsq_result_types", match_on_tsq_result_types cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @originating_template_id.nil?
    invalid_properties.push('invalid value for "originating_template_id", originating_template_id cannot be nil.')
  end

  if @permissions.nil?
    invalid_properties.push('invalid value for "permissions", permissions cannot be nil.')
  end

  if @priority.nil?
    invalid_properties.push('invalid value for "priority", priority cannot be nil.')
  end

  if @substring_matching_enabled.nil?
    invalid_properties.push('invalid value for "substring_matching_enabled", substring_matching_enabled cannot be nil.')
  end

  if @topic.nil?
    invalid_properties.push('invalid value for "topic", topic cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 348

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



342
343
344
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 342

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/crimson-falcon/models/sadomain_create_rule_request_v1.rb', line 223

def valid?
  return false if @breach_monitor_only.nil?
  return false if @breach_monitoring_enabled.nil?
  return false if @filter.nil?
  return false if @match_on_tsq_result_types.nil?
  return false if @name.nil?
  return false if @originating_template_id.nil?
  return false if @permissions.nil?
  return false if @priority.nil?
  return false if @substring_matching_enabled.nil?
  return false if @topic.nil?
  true
end