Class: Falcon::SadomainNotificationLog

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/sadomain_notification_log.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SadomainNotificationLog

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SadomainNotificationLog` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SadomainNotificationLog`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_date')
    self.created_date = attributes[:'created_date']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  end

  if attributes.key?(:'user_email')
    self.user_email = attributes[:'user_email']
  end

  if attributes.key?(:'user_uuid')
    self.user_uuid = attributes[:'user_uuid']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



34
35
36
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 34

def action
  @action
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 36

def cid
  @cid
end

#created_dateObject

Returns the value of attribute created_date.



38
39
40
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 38

def created_date
  @created_date
end

#detailsObject

Returns the value of attribute details.



40
41
42
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 40

def details
  @details
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 42

def id
  @id
end

#messageObject

Returns the value of attribute message.



44
45
46
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 44

def message
  @message
end

#notification_idObject

Returns the value of attribute notification_id.



46
47
48
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 46

def notification_id
  @notification_id
end

#user_emailObject

Returns the value of attribute user_email.



48
49
50
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 48

def user_email
  @user_email
end

#user_uuidObject

Returns the value of attribute user_uuid.



50
51
52
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 50

def user_uuid
  @user_uuid
end

#usernameObject

Returns the value of attribute username.



52
53
54
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 52

def username
  @username
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 71

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 55

def self.attribute_map
  {
    :'action' => :'action',
    :'cid' => :'cid',
    :'created_date' => :'created_date',
    :'details' => :'details',
    :'id' => :'id',
    :'message' => :'message',
    :'notification_id' => :'notification_id',
    :'user_email' => :'user_email',
    :'user_uuid' => :'user_uuid',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 248

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 76

def self.openapi_types
  {
    :'action' => :'String',
    :'cid' => :'String',
    :'created_date' => :'Time',
    :'details' => :'String',
    :'id' => :'String',
    :'message' => :'String',
    :'notification_id' => :'String',
    :'user_email' => :'String',
    :'user_uuid' => :'String',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      cid == o.cid &&
      created_date == o.created_date &&
      details == o.details &&
      id == o.id &&
      message == o.message &&
      notification_id == o.notification_id &&
      user_email == o.user_email &&
      user_uuid == o.user_uuid &&
      username == o.username
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 279

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 350

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 255

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 241

def hash
  [action, cid, created_date, details, id, message, notification_id, user_email, user_uuid, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 155

def list_invalid_properties
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_date.nil?
    invalid_properties.push('invalid value for "created_date", created_date cannot be nil.')
  end

  if @details.nil?
    invalid_properties.push('invalid value for "details", details cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @user_email.nil?
    invalid_properties.push('invalid value for "user_email", user_email cannot be nil.')
  end

  if @user_uuid.nil?
    invalid_properties.push('invalid value for "user_uuid", user_uuid cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 326

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



320
321
322
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 320

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/crimson-falcon/models/sadomain_notification_log.rb', line 202

def valid?
  return false if @action.nil?
  return false if @cid.nil?
  return false if @created_date.nil?
  return false if @details.nil?
  return false if @id.nil?
  return false if @message.nil?
  return false if @notification_id.nil?
  return false if @user_email.nil?
  return false if @user_uuid.nil?
  return false if @username.nil?
  true
end