Class: Falcon::SecurityCheckWithComplianceGetSecurityChecks

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SecurityCheckWithComplianceGetSecurityChecks

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 158

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SecurityCheckWithComplianceGetSecurityChecks` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SecurityCheckWithComplianceGetSecurityChecks`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'affected')
    self.affected = attributes[:'affected']
  end

  if attributes.key?(:'base_check_id')
    self.base_check_id = attributes[:'base_check_id']
  end

  if attributes.key?(:'check_tags')
    if (value = attributes[:'check_tags']).is_a?(Array)
      self.check_tags = value
    end
  end

  if attributes.key?(:'compliance_data')
    if (value = attributes[:'compliance_data']).is_a?(Array)
      self.compliance_data = value
    end
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'dismiss_expiration_date')
    self.dismiss_expiration_date = attributes[:'dismiss_expiration_date']
  end

  if attributes.key?(:'dismiss_reason')
    self.dismiss_reason = attributes[:'dismiss_reason']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'impact')
    self.impact = attributes[:'impact']
  end

  if attributes.key?(:'integration_alias')
    self.integration_alias = attributes[:'integration_alias']
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'is_global')
    self.is_global = attributes[:'is_global']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'remediation_plan')
    self.remediation_plan = attributes[:'remediation_plan']
  end

  if attributes.key?(:'saas_name')
    self.saas_name = attributes[:'saas_name']
  end

  if attributes.key?(:'security_check_type')
    self.security_check_type = attributes[:'security_check_type']
  end

  if attributes.key?(:'security_domain')
    self.security_domain = attributes[:'security_domain']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_last_changed_date')
    self.status_last_changed_date = attributes[:'status_last_changed_date']
  end

  if attributes.key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  end

  if attributes.key?(:'user_who_dismissed')
    self.user_who_dismissed = attributes[:'user_who_dismissed']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



34
35
36
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 34

def 
  @account_id
end

#affectedObject

Returns the value of attribute affected.



36
37
38
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 36

def affected
  @affected
end

#base_check_idObject

Returns the value of attribute base_check_id.



38
39
40
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 38

def base_check_id
  @base_check_id
end

#check_tagsObject

Returns the value of attribute check_tags.



40
41
42
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 40

def check_tags
  @check_tags
end

#compliance_dataObject

Returns the value of attribute compliance_data.



42
43
44
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 42

def compliance_data
  @compliance_data
end

#created_byObject

Returns the value of attribute created_by.



44
45
46
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 44

def created_by
  @created_by
end

#creation_dateObject

Returns the value of attribute creation_date.



46
47
48
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 46

def creation_date
  @creation_date
end

#detailsObject

Returns the value of attribute details.



48
49
50
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 48

def details
  @details
end

#dismiss_expiration_dateObject

Returns the value of attribute dismiss_expiration_date.



50
51
52
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 50

def dismiss_expiration_date
  @dismiss_expiration_date
end

#dismiss_reasonObject

Returns the value of attribute dismiss_reason.



52
53
54
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 52

def dismiss_reason
  @dismiss_reason
end

#idObject

Returns the value of attribute id.



54
55
56
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 54

def id
  @id
end

#impactObject

Returns the value of attribute impact.



56
57
58
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 56

def impact
  @impact
end

#integration_aliasObject

Returns the value of attribute integration_alias.



58
59
60
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 58

def integration_alias
  @integration_alias
end

#integration_idObject

Returns the value of attribute integration_id.



60
61
62
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 60

def integration_id
  @integration_id
end

#is_globalObject

Returns the value of attribute is_global.



62
63
64
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 62

def is_global
  @is_global
end

#nameObject

Returns the value of attribute name.



64
65
66
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 64

def name
  @name
end

#remediation_planObject

Returns the value of attribute remediation_plan.



66
67
68
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 66

def remediation_plan
  @remediation_plan
end

#saas_nameObject

Returns the value of attribute saas_name.



68
69
70
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 68

def saas_name
  @saas_name
end

#security_check_typeObject

Returns the value of attribute security_check_type.



70
71
72
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 70

def security_check_type
  @security_check_type
end

#security_domainObject

Returns the value of attribute security_domain.



72
73
74
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 72

def security_domain
  @security_domain
end

#statusObject

Returns the value of attribute status.



74
75
76
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 74

def status
  @status
end

#status_last_changed_dateObject

Returns the value of attribute status_last_changed_date.



76
77
78
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 76

def status_last_changed_date
  @status_last_changed_date
end

#status_reasonObject

Returns the value of attribute status_reason.



78
79
80
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 78

def status_reason
  @status_reason
end

#user_who_dismissedObject

Returns the value of attribute user_who_dismissed.



80
81
82
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 80

def user_who_dismissed
  @user_who_dismissed
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



113
114
115
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 113

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 83

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'affected' => :'affected',
    :'base_check_id' => :'base_check_id',
    :'check_tags' => :'check_tags',
    :'compliance_data' => :'compliance_data',
    :'created_by' => :'created_by',
    :'creation_date' => :'creation_date',
    :'details' => :'details',
    :'dismiss_expiration_date' => :'dismiss_expiration_date',
    :'dismiss_reason' => :'dismiss_reason',
    :'id' => :'id',
    :'impact' => :'impact',
    :'integration_alias' => :'integration_alias',
    :'integration_id' => :'integration_id',
    :'is_global' => :'is_global',
    :'name' => :'name',
    :'remediation_plan' => :'remediation_plan',
    :'saas_name' => :'saas_name',
    :'security_check_type' => :'security_check_type',
    :'security_domain' => :'security_domain',
    :'status' => :'status',
    :'status_last_changed_date' => :'status_last_changed_date',
    :'status_reason' => :'status_reason',
    :'user_who_dismissed' => :'user_who_dismissed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



679
680
681
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 679

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



148
149
150
151
152
153
154
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 148

def self.openapi_nullable
  Set.new([
    :'dismiss_expiration_date',
    :'integration_alias',
    :'status_last_changed_date',
  ])
end

.openapi_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 118

def self.openapi_types
  {
    :'account_id' => :'String',
    :'affected' => :'Integer',
    :'base_check_id' => :'String',
    :'check_tags' => :'Array<Hash<String, String>>',
    :'compliance_data' => :'Array<Hash<String, String>>',
    :'created_by' => :'String',
    :'creation_date' => :'Time',
    :'details' => :'String',
    :'dismiss_expiration_date' => :'Time',
    :'dismiss_reason' => :'String',
    :'id' => :'String',
    :'impact' => :'String',
    :'integration_alias' => :'String',
    :'integration_id' => :'String',
    :'is_global' => :'Boolean',
    :'name' => :'String',
    :'remediation_plan' => :'String',
    :'saas_name' => :'String',
    :'security_check_type' => :'String',
    :'security_domain' => :'String',
    :'status' => :'String',
    :'status_last_changed_date' => :'Time',
    :'status_reason' => :'String',
    :'user_who_dismissed' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 635

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      affected == o.affected &&
      base_check_id == o.base_check_id &&
      check_tags == o.check_tags &&
      compliance_data == o.compliance_data &&
      created_by == o.created_by &&
      creation_date == o.creation_date &&
      details == o.details &&
      dismiss_expiration_date == o.dismiss_expiration_date &&
      dismiss_reason == o.dismiss_reason &&
      id == o.id &&
      impact == o.impact &&
      integration_alias == o.integration_alias &&
      integration_id == o.integration_id &&
      is_global == o.is_global &&
      name == o.name &&
      remediation_plan == o.remediation_plan &&
      saas_name == o.saas_name &&
      security_check_type == o.security_check_type &&
      security_domain == o.security_domain &&
      status == o.status &&
      status_last_changed_date == o.status_last_changed_date &&
      status_reason == o.status_reason &&
      user_who_dismissed == o.user_who_dismissed
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 710

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 781

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 686

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


666
667
668
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 666

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



672
673
674
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 672

def hash
  [, affected, base_check_id, check_tags, compliance_data, created_by, creation_date, details, dismiss_expiration_date, dismiss_reason, id, impact, integration_alias, integration_id, is_global, name, remediation_plan, saas_name, security_check_type, security_domain, status, status_last_changed_date, status_reason, user_who_dismissed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 274

def list_invalid_properties
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @affected.nil?
    invalid_properties.push('invalid value for "affected", affected cannot be nil.')
  end

  if @base_check_id.nil?
    invalid_properties.push('invalid value for "base_check_id", base_check_id cannot be nil.')
  end

  if @check_tags.nil?
    invalid_properties.push('invalid value for "check_tags", check_tags cannot be nil.')
  end

  if @compliance_data.nil?
    invalid_properties.push('invalid value for "compliance_data", compliance_data cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_by.to_s.length < 1
    invalid_properties.push('invalid value for "created_by", the character length must be great than or equal to 1.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @details.nil?
    invalid_properties.push('invalid value for "details", details cannot be nil.')
  end

  if @details.to_s.length < 1
    invalid_properties.push('invalid value for "details", the character length must be great than or equal to 1.')
  end

  if @dismiss_reason.nil?
    invalid_properties.push('invalid value for "dismiss_reason", dismiss_reason cannot be nil.')
  end

  if @dismiss_reason.to_s.length < 1
    invalid_properties.push('invalid value for "dismiss_reason", the character length must be great than or equal to 1.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @impact.nil?
    invalid_properties.push('invalid value for "impact", impact cannot be nil.')
  end

  if @impact.to_s.length < 1
    invalid_properties.push('invalid value for "impact", the character length must be great than or equal to 1.')
  end

  if @integration_alias.to_s.length < 1
    invalid_properties.push('invalid value for "integration_alias", the character length must be great than or equal to 1.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @is_global.nil?
    invalid_properties.push('invalid value for "is_global", is_global cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @remediation_plan.nil?
    invalid_properties.push('invalid value for "remediation_plan", remediation_plan cannot be nil.')
  end

  if @remediation_plan.to_s.length < 1
    invalid_properties.push('invalid value for "remediation_plan", the character length must be great than or equal to 1.')
  end

  if @saas_name.nil?
    invalid_properties.push('invalid value for "saas_name", saas_name cannot be nil.')
  end

  if @saas_name.to_s.length < 1
    invalid_properties.push('invalid value for "saas_name", the character length must be great than or equal to 1.')
  end

  if @security_check_type.nil?
    invalid_properties.push('invalid value for "security_check_type", security_check_type cannot be nil.')
  end

  if @security_check_type.to_s.length < 1
    invalid_properties.push('invalid value for "security_check_type", the character length must be great than or equal to 1.')
  end

  if @security_domain.nil?
    invalid_properties.push('invalid value for "security_domain", security_domain cannot be nil.')
  end

  if @security_domain.to_s.length < 1
    invalid_properties.push('invalid value for "security_domain", the character length must be great than or equal to 1.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @status.to_s.length < 1
    invalid_properties.push('invalid value for "status", the character length must be great than or equal to 1.')
  end

  if @status_reason.nil?
    invalid_properties.push('invalid value for "status_reason", status_reason cannot be nil.')
  end

  if @status_reason.to_s.length < 1
    invalid_properties.push('invalid value for "status_reason", the character length must be great than or equal to 1.')
  end

  if @user_who_dismissed.nil?
    invalid_properties.push('invalid value for "user_who_dismissed", user_who_dismissed cannot be nil.')
  end

  if @user_who_dismissed.to_s.length < 1
    invalid_properties.push('invalid value for "user_who_dismissed", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



757
758
759
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 757

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



763
764
765
766
767
768
769
770
771
772
773
774
775
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 763

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



751
752
753
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 751

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/crimson-falcon/models/security_check_with_compliance_get_security_checks.rb', line 417

def valid?
  return false if @account_id.nil?
  return false if @affected.nil?
  return false if @base_check_id.nil?
  return false if @check_tags.nil?
  return false if @compliance_data.nil?
  return false if @created_by.nil?
  return false if @created_by.to_s.length < 1
  return false if @creation_date.nil?
  return false if @details.nil?
  return false if @details.to_s.length < 1
  return false if @dismiss_reason.nil?
  return false if @dismiss_reason.to_s.length < 1
  return false if @id.nil?
  return false if @impact.nil?
  return false if @impact.to_s.length < 1
  return false if @integration_alias.to_s.length < 1
  return false if @integration_id.nil?
  return false if @is_global.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @remediation_plan.nil?
  return false if @remediation_plan.to_s.length < 1
  return false if @saas_name.nil?
  return false if @saas_name.to_s.length < 1
  return false if @security_check_type.nil?
  return false if @security_check_type.to_s.length < 1
  return false if @security_domain.nil?
  return false if @security_domain.to_s.length < 1
  return false if @status.nil?
  return false if @status.to_s.length < 1
  return false if @status_reason.nil?
  return false if @status_reason.to_s.length < 1
  return false if @user_who_dismissed.nil?
  return false if @user_who_dismissed.to_s.length < 1
  true
end