Class: Falcon::SensorDownload

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/sensor_download.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SensorDownload

Returns a new instance of SensorDownload.



35
36
37
# File 'lib/crimson-falcon/api/sensor_download.rb', line 35

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



33
34
35
# File 'lib/crimson-falcon/api/sensor_download.rb', line 33

def api_client
  @api_client
end

Instance Method Details

#download_sensor_installer_by_id(id, opts = {}) ⇒ File

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


42
43
44
45
# File 'lib/crimson-falcon/api/sensor_download.rb', line 42

def download_sensor_installer_by_id(id, opts = {})
  data, _status_code, _headers = download_sensor_installer_by_id_with_http_info(id, opts)
  data
end

#download_sensor_installer_by_id_v2(id, opts = {}) ⇒ File

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


104
105
106
107
# File 'lib/crimson-falcon/api/sensor_download.rb', line 104

def download_sensor_installer_by_id_v2(id, opts = {})
  data, _status_code, _headers = download_sensor_installer_by_id_v2_with_http_info(id, opts)
  data
end

#download_sensor_installer_by_id_v2_with_http_info(id, opts = {}) ⇒ Array<(File, Integer, Hash)>

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/crimson-falcon/api/sensor_download.rb', line 113

def download_sensor_installer_by_id_v2_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.download_sensor_installer_by_id_v2 ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SensorDownload.download_sensor_installer_by_id_v2"
  end
  # resource path
  local_var_path = '/sensors/entities/download-installer/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/octet-stream'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.download_sensor_installer_by_id_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#download_sensor_installer_by_id_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_sensor_installer_by_id_v3(id, opts = {}) ⇒ File

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (File)


166
167
168
169
# File 'lib/crimson-falcon/api/sensor_download.rb', line 166

def download_sensor_installer_by_id_v3(id, opts = {})
  data, _status_code, _headers = download_sensor_installer_by_id_v3_with_http_info(id, opts)
  data
end

#download_sensor_installer_by_id_v3_with_http_info(id, opts = {}) ⇒ Array<(File, Integer, Hash)>

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/crimson-falcon/api/sensor_download.rb', line 175

def download_sensor_installer_by_id_v3_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.download_sensor_installer_by_id_v3 ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SensorDownload.download_sensor_installer_by_id_v3"
  end
  # resource path
  local_var_path = '/sensors/entities/download-installer/v3'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/octet-stream'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.download_sensor_installer_by_id_v3",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#download_sensor_installer_by_id_v3\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_sensor_installer_by_id_with_http_info(id, opts = {}) ⇒ Array<(File, Integer, Hash)>

Download sensor installer by SHA256 ID

Parameters:

  • id (String)

    SHA256 of the installer to download

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/crimson-falcon/api/sensor_download.rb', line 51

def download_sensor_installer_by_id_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.download_sensor_installer_by_id ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SensorDownload.download_sensor_installer_by_id"
  end
  # resource path
  local_var_path = '/sensors/entities/download-installer/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/octet-stream'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.download_sensor_installer_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#download_sensor_installer_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_combined_sensor_installers_by_query(opts = {}) ⇒ DomainSensorInstallersV1

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



231
232
233
234
# File 'lib/crimson-falcon/api/sensor_download.rb', line 231

def get_combined_sensor_installers_by_query(opts = {})
  data, _status_code, _headers = get_combined_sensor_installers_by_query_with_http_info(opts)
  data
end

#get_combined_sensor_installers_by_query_v2(opts = {}) ⇒ DomainSensorInstallersV2

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



298
299
300
301
# File 'lib/crimson-falcon/api/sensor_download.rb', line 298

def get_combined_sensor_installers_by_query_v2(opts = {})
  data, _status_code, _headers = get_combined_sensor_installers_by_query_v2_with_http_info(opts)
  data
end

#get_combined_sensor_installers_by_query_v2_with_http_info(opts = {}) ⇒ Array<(DomainSensorInstallersV2, Integer, Hash)>

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(DomainSensorInstallersV2, Integer, Hash)>)

    DomainSensorInstallersV2 data, response status code and response headers



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/crimson-falcon/api/sensor_download.rb', line 310

def get_combined_sensor_installers_by_query_v2_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_combined_sensor_installers_by_query_v2 ...'
  end
  # resource path
  local_var_path = '/sensors/combined/installers/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV2'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_combined_sensor_installers_by_query_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_combined_sensor_installers_by_query_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_combined_sensor_installers_by_query_v3(opts = {}) ⇒ DomainSensorInstallersV3

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include:\n\n&lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results.\n\nCommon filter options include:\n&lt;ul&gt;&lt;li&gt;platform:\&quot;windows\&quot;&lt;/li&gt;&lt;li&gt;version:&gt;\&quot;5.2\&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



365
366
367
368
# File 'lib/crimson-falcon/api/sensor_download.rb', line 365

def get_combined_sensor_installers_by_query_v3(opts = {})
  data, _status_code, _headers = get_combined_sensor_installers_by_query_v3_with_http_info(opts)
  data
end

#get_combined_sensor_installers_by_query_v3_with_http_info(opts = {}) ⇒ Array<(DomainSensorInstallersV3, Integer, Hash)>

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include:\n\n&lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results.\n\nCommon filter options include:\n&lt;ul&gt;&lt;li&gt;platform:\&quot;windows\&quot;&lt;/li&gt;&lt;li&gt;version:&gt;\&quot;5.2\&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(DomainSensorInstallersV3, Integer, Hash)>)

    DomainSensorInstallersV3 data, response status code and response headers



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/crimson-falcon/api/sensor_download.rb', line 377

def get_combined_sensor_installers_by_query_v3_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_combined_sensor_installers_by_query_v3 ...'
  end
  # resource path
  local_var_path = '/sensors/combined/installers/v3'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV3'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_combined_sensor_installers_by_query_v3",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_combined_sensor_installers_by_query_v3\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_combined_sensor_installers_by_query_with_http_info(opts = {}) ⇒ Array<(DomainSensorInstallersV1, Integer, Hash)>

Get sensor installer details by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(DomainSensorInstallersV1, Integer, Hash)>)

    DomainSensorInstallersV1 data, response status code and response headers



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/crimson-falcon/api/sensor_download.rb', line 243

def get_combined_sensor_installers_by_query_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_combined_sensor_installers_by_query ...'
  end
  # resource path
  local_var_path = '/sensors/combined/installers/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_combined_sensor_installers_by_query",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_combined_sensor_installers_by_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_by_query(opts = {}) ⇒ MsaspecQueryResponse

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



432
433
434
435
# File 'lib/crimson-falcon/api/sensor_download.rb', line 432

def get_sensor_installers_by_query(opts = {})
  data, _status_code, _headers = get_sensor_installers_by_query_with_http_info(opts)
  data
end

#get_sensor_installers_by_query_v2(opts = {}) ⇒ MsaspecQueryResponse

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



499
500
501
502
# File 'lib/crimson-falcon/api/sensor_download.rb', line 499

def get_sensor_installers_by_query_v2(opts = {})
  data, _status_code, _headers = get_sensor_installers_by_query_v2_with_http_info(opts)
  data
end

#get_sensor_installers_by_query_v2_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
# File 'lib/crimson-falcon/api/sensor_download.rb', line 511

def get_sensor_installers_by_query_v2_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_by_query_v2 ...'
  end
  # resource path
  local_var_path = '/sensors/queries/installers/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_by_query_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_by_query_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_by_query_v3(opts = {}) ⇒ MsaspecQueryResponse

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include:\n\n&lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results.\n\nCommon filter options include:\n&lt;ul&gt;&lt;li&gt;platform:\&quot;windows\&quot;&lt;/li&gt;&lt;li&gt;version:&gt;\&quot;5.2\&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:



566
567
568
569
# File 'lib/crimson-falcon/api/sensor_download.rb', line 566

def get_sensor_installers_by_query_v3(opts = {})
  data, _status_code, _headers = get_sensor_installers_by_query_v3_with_http_info(opts)
  data
end

#get_sensor_installers_by_query_v3_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include:\n\n&lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results.\n\nCommon filter options include:\n&lt;ul&gt;&lt;li&gt;platform:\&quot;windows\&quot;&lt;/li&gt;&lt;li&gt;version:&gt;\&quot;5.2\&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
# File 'lib/crimson-falcon/api/sensor_download.rb', line 578

def get_sensor_installers_by_query_v3_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_by_query_v3 ...'
  end
  # resource path
  local_var_path = '/sensors/queries/installers/v3'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_by_query_v3",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_by_query_v3\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_by_query_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Get sensor installer IDs by provided query

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :offset (Integer)

    The first item to return, where 0 is the latest item. Use with the limit parameter to manage pagination of results.

  • :limit (Integer)

    The number of items to return in this response (default: 100, max: 500). Use with the offset parameter to manage pagination of results.

  • :sort (String)

    Sort items using their properties. Common sort options include: &lt;ul&gt;&lt;li&gt;version|asc&lt;/li&gt;&lt;li&gt;release_date|desc&lt;/li&gt;&lt;/ul&gt;

  • :filter (String)

    Filter items using a query in Falcon Query Language (FQL). An asterisk wildcard * includes all results. Common filter options include: &lt;ul&gt;&lt;li&gt;platform:&quot;windows&quot;&lt;/li&gt;&lt;li&gt;version:&gt;&quot;5.2&quot;&lt;/li&gt;&lt;/ul&gt;

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/crimson-falcon/api/sensor_download.rb', line 444

def get_sensor_installers_by_query_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_by_query ...'
  end
  # resource path
  local_var_path = '/sensors/queries/installers/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_by_query",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_by_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_ccidby_query(opts = {}) ⇒ MsaspecQueryResponse

Get CCID to use with sensor installers

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



629
630
631
632
# File 'lib/crimson-falcon/api/sensor_download.rb', line 629

def get_sensor_installers_ccidby_query(opts = {})
  data, _status_code, _headers = get_sensor_installers_ccidby_query_with_http_info(opts)
  data
end

#get_sensor_installers_ccidby_query_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>

Get CCID to use with sensor installers

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MsaspecQueryResponse, Integer, Hash)>)

    MsaspecQueryResponse data, response status code and response headers



637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
# File 'lib/crimson-falcon/api/sensor_download.rb', line 637

def get_sensor_installers_ccidby_query_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_ccidby_query ...'
  end
  # resource path
  local_var_path = '/sensors/queries/installers/ccid/v1'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MsaspecQueryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_ccidby_query",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_ccidby_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_entities(ids, opts = {}) ⇒ DomainSensorInstallersV1

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



685
686
687
688
# File 'lib/crimson-falcon/api/sensor_download.rb', line 685

def get_sensor_installers_entities(ids, opts = {})
  data, _status_code, _headers = get_sensor_installers_entities_with_http_info(ids, opts)
  data
end

#get_sensor_installers_entities_v2(ids, opts = {}) ⇒ DomainSensorInstallersV2

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



747
748
749
750
# File 'lib/crimson-falcon/api/sensor_download.rb', line 747

def get_sensor_installers_entities_v2(ids, opts = {})
  data, _status_code, _headers = get_sensor_installers_entities_v2_with_http_info(ids, opts)
  data
end

#get_sensor_installers_entities_v2_with_http_info(ids, opts = {}) ⇒ Array<(DomainSensorInstallersV2, Integer, Hash)>

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DomainSensorInstallersV2, Integer, Hash)>)

    DomainSensorInstallersV2 data, response status code and response headers



756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
# File 'lib/crimson-falcon/api/sensor_download.rb', line 756

def get_sensor_installers_entities_v2_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_entities_v2 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling SensorDownload.get_sensor_installers_entities_v2"
  end
  # resource path
  local_var_path = '/sensors/entities/installers/v2'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV2'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_entities_v2",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_entities_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_entities_v3(ids, opts = {}) ⇒ DomainSensorInstallersV3

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



809
810
811
812
# File 'lib/crimson-falcon/api/sensor_download.rb', line 809

def get_sensor_installers_entities_v3(ids, opts = {})
  data, _status_code, _headers = get_sensor_installers_entities_v3_with_http_info(ids, opts)
  data
end

#get_sensor_installers_entities_v3_with_http_info(ids, opts = {}) ⇒ Array<(DomainSensorInstallersV3, Integer, Hash)>

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DomainSensorInstallersV3, Integer, Hash)>)

    DomainSensorInstallersV3 data, response status code and response headers



818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
# File 'lib/crimson-falcon/api/sensor_download.rb', line 818

def get_sensor_installers_entities_v3_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_entities_v3 ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling SensorDownload.get_sensor_installers_entities_v3"
  end
  # resource path
  local_var_path = '/sensors/entities/installers/v3'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV3'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_entities_v3",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_entities_v3\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_sensor_installers_entities_with_http_info(ids, opts = {}) ⇒ Array<(DomainSensorInstallersV1, Integer, Hash)>

Get sensor installer details by provided SHA256 IDs

Parameters:

  • ids (Array<String>)

    The IDs of the installers

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DomainSensorInstallersV1, Integer, Hash)>)

    DomainSensorInstallersV1 data, response status code and response headers



694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
# File 'lib/crimson-falcon/api/sensor_download.rb', line 694

def get_sensor_installers_entities_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SensorDownload.get_sensor_installers_entities ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling SensorDownload.get_sensor_installers_entities"
  end
  # resource path
  local_var_path = '/sensors/entities/installers/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = @api_client.build_collection_param(ids, :multi)

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DomainSensorInstallersV1'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"SensorDownload.get_sensor_installers_entities",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SensorDownload#get_sensor_installers_entities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end