Class: Falcon::SensorUsageApi
- Inherits:
-
Object
- Object
- Falcon::SensorUsageApi
- Defined in:
- lib/crimson-falcon/api/sensor_usage_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_sensor_usage_hourly(opts = {}) ⇒ ApiHourlyAverageResponse
Fetches hourly average.
-
#get_sensor_usage_hourly_with_http_info(opts = {}) ⇒ Array<(ApiHourlyAverageResponse, Integer, Hash)>
Fetches hourly average.
-
#initialize(api_client = ApiClient.default) ⇒ SensorUsageApi
constructor
A new instance of SensorUsageApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SensorUsageApi
Returns a new instance of SensorUsageApi.
35 36 37 |
# File 'lib/crimson-falcon/api/sensor_usage_api.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/sensor_usage_api.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_sensor_usage_hourly(opts = {}) ⇒ ApiHourlyAverageResponse
Fetches hourly average. Each data point represents the average of how many unique AIDs were seen per hour for the previous 28 days.
42 43 44 45 |
# File 'lib/crimson-falcon/api/sensor_usage_api.rb', line 42 def get_sensor_usage_hourly(opts = {}) data, _status_code, _headers = get_sensor_usage_hourly_with_http_info(opts) data end |
#get_sensor_usage_hourly_with_http_info(opts = {}) ⇒ Array<(ApiHourlyAverageResponse, Integer, Hash)>
Fetches hourly average. Each data point represents the average of how many unique AIDs were seen per hour for the previous 28 days.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/crimson-falcon/api/sensor_usage_api.rb', line 51 def get_sensor_usage_hourly_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SensorUsageApi.get_sensor_usage_hourly ...' end # resource path local_var_path = '/billing-dashboards-usage/aggregates/hourly-average/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApiHourlyAverageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"SensorUsageApi.get_sensor_usage_hourly", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SensorUsageApi#get_sensor_usage_hourly\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |