Class: Falcon::ServerlessVulnerabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/api/serverless_vulnerabilities.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ServerlessVulnerabilities

Returns a new instance of ServerlessVulnerabilities.



36
37
38
# File 'lib/crimson-falcon/api/serverless_vulnerabilities.rb', line 36

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



34
35
36
# File 'lib/crimson-falcon/api/serverless_vulnerabilities.rb', line 34

def api_client
  @api_client
end

Instance Method Details

#get_combined_vulnerabilities_sarif(opts = {}) ⇒ VulnerabilitiesVulnerabilityEntitySARIFResponse

Retrieve all lambda vulnerabilities that match the given query and return in the SARIF format

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Filter lambda vulnerabilities using a query in Falcon Query Language (FQL).Supported filters: application_name,application_name_version,cid,cloud_account_id,cloud_account_name,cloud_provider,cve_id,cvss_base_score,exprt_rating,first_seen_timestamp,function_name,function_resource_id,is_supported,is_valid_asset_id,layer,region,runtime,severity,timestamp,type

  • :limit (Integer)

    The upper-bound on the number of records to retrieve.

  • :offset (Integer)

    The offset from where to begin.

  • :sort (String)

    The fields to sort the records on. Supported columns: [application_name application_name_version cid cloud_account_id cloud_account_name cloud_provider cve_id cvss_base_score exprt_rating first_seen_timestamp function_resource_id is_supported layer region runtime severity timestamp type]

Returns:



46
47
48
49
# File 'lib/crimson-falcon/api/serverless_vulnerabilities.rb', line 46

def get_combined_vulnerabilities_sarif(opts = {})
  data, _status_code, _headers = get_combined_vulnerabilities_sarif_with_http_info(opts)
  data
end

#get_combined_vulnerabilities_sarif_with_http_info(opts = {}) ⇒ Array<(VulnerabilitiesVulnerabilityEntitySARIFResponse, Integer, Hash)>

Retrieve all lambda vulnerabilities that match the given query and return in the SARIF format

Parameters:

  • (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Filter lambda vulnerabilities using a query in Falcon Query Language (FQL).Supported filters: application_name,application_name_version,cid,cloud_account_id,cloud_account_name,cloud_provider,cve_id,cvss_base_score,exprt_rating,first_seen_timestamp,function_name,function_resource_id,is_supported,is_valid_asset_id,layer,region,runtime,severity,timestamp,type

  • :limit (Integer)

    The upper-bound on the number of records to retrieve.

  • :offset (Integer)

    The offset from where to begin.

  • :sort (String)

    The fields to sort the records on. Supported columns: [application_name application_name_version cid cloud_account_id cloud_account_name cloud_provider cve_id cvss_base_score exprt_rating first_seen_timestamp function_resource_id is_supported layer region runtime severity timestamp type]

Returns:

  • VulnerabilitiesVulnerabilityEntitySARIFResponse data, response status code and response headers



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/api/serverless_vulnerabilities.rb', line 58

def get_combined_vulnerabilities_sarif_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ServerlessVulnerabilities.get_combined_vulnerabilities_sarif ...'
  end
  # resource path
  local_var_path = '/lambdas/combined/vulnerabilities/sarif/v1'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'VulnerabilitiesVulnerabilityEntitySARIFResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"ServerlessVulnerabilities.get_combined_vulnerabilities_sarif",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ServerlessVulnerabilities#get_combined_vulnerabilities_sarif\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end