Class: Falcon::SuppressionrulesCreateSuppressionRuleRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SuppressionrulesCreateSuppressionRuleRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SuppressionrulesCreateSuppressionRuleRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SuppressionrulesCreateSuppressionRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'rule_selection_filter')
    self.rule_selection_filter = attributes[:'rule_selection_filter']
  end

  if attributes.key?(:'rule_selection_type')
    self.rule_selection_type = attributes[:'rule_selection_type']
  end

  if attributes.key?(:'scope_asset_filter')
    self.scope_asset_filter = attributes[:'scope_asset_filter']
  end

  if attributes.key?(:'scope_type')
    self.scope_type = attributes[:'scope_type']
  end

  if attributes.key?(:'subdomain')
    self.subdomain = attributes[:'subdomain']
  end

  if attributes.key?(:'suppression_comment')
    self.suppression_comment = attributes[:'suppression_comment']
  end

  if attributes.key?(:'suppression_expiration_date')
    self.suppression_expiration_date = attributes[:'suppression_expiration_date']
  end

  if attributes.key?(:'suppression_reason')
    self.suppression_reason = attributes[:'suppression_reason']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



34
35
36
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 34

def description
  @description
end

#domainObject

Returns the value of attribute domain.



36
37
38
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 36

def domain
  @domain
end

#nameObject

Returns the value of attribute name.



38
39
40
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 38

def name
  @name
end

#rule_selection_filterObject

Returns the value of attribute rule_selection_filter.



40
41
42
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 40

def rule_selection_filter
  @rule_selection_filter
end

#rule_selection_typeObject

Returns the value of attribute rule_selection_type.



42
43
44
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 42

def rule_selection_type
  @rule_selection_type
end

#scope_asset_filterObject

Returns the value of attribute scope_asset_filter.



44
45
46
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 44

def scope_asset_filter
  @scope_asset_filter
end

#scope_typeObject

Returns the value of attribute scope_type.



46
47
48
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 46

def scope_type
  @scope_type
end

#subdomainObject

Returns the value of attribute subdomain.



48
49
50
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 48

def subdomain
  @subdomain
end

#suppression_commentObject

Returns the value of attribute suppression_comment.



50
51
52
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 50

def suppression_comment
  @suppression_comment
end

#suppression_expiration_dateObject

Returns the value of attribute suppression_expiration_date.



52
53
54
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 52

def suppression_expiration_date
  @suppression_expiration_date
end

#suppression_reasonObject

Returns the value of attribute suppression_reason.



54
55
56
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 54

def suppression_reason
  @suppression_reason
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 57

def self.attribute_map
  {
    :'description' => :'description',
    :'domain' => :'domain',
    :'name' => :'name',
    :'rule_selection_filter' => :'rule_selection_filter',
    :'rule_selection_type' => :'rule_selection_type',
    :'scope_asset_filter' => :'scope_asset_filter',
    :'scope_type' => :'scope_type',
    :'subdomain' => :'subdomain',
    :'suppression_comment' => :'suppression_comment',
    :'suppression_expiration_date' => :'suppression_expiration_date',
    :'suppression_reason' => :'suppression_reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 237

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 79

def self.openapi_types
  {
    :'description' => :'String',
    :'domain' => :'String',
    :'name' => :'String',
    :'rule_selection_filter' => :'SuppressionrulesRuleSelectionFilter',
    :'rule_selection_type' => :'String',
    :'scope_asset_filter' => :'SuppressionrulesScopeAssetFilter',
    :'scope_type' => :'String',
    :'subdomain' => :'String',
    :'suppression_comment' => :'String',
    :'suppression_expiration_date' => :'String',
    :'suppression_reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      domain == o.domain &&
      name == o.name &&
      rule_selection_filter == o.rule_selection_filter &&
      rule_selection_type == o.rule_selection_type &&
      scope_asset_filter == o.scope_asset_filter &&
      scope_type == o.scope_type &&
      subdomain == o.subdomain &&
      suppression_comment == o.suppression_comment &&
      suppression_expiration_date == o.suppression_expiration_date &&
      suppression_reason == o.suppression_reason
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 268

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 339

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 244

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 230

def hash
  [description, domain, name, rule_selection_filter, rule_selection_type, scope_asset_filter, scope_type, subdomain, suppression_comment, suppression_expiration_date, suppression_reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 163

def list_invalid_properties
  invalid_properties = Array.new
  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @rule_selection_type.nil?
    invalid_properties.push('invalid value for "rule_selection_type", rule_selection_type cannot be nil.')
  end

  if @scope_type.nil?
    invalid_properties.push('invalid value for "scope_type", scope_type cannot be nil.')
  end

  if @subdomain.nil?
    invalid_properties.push('invalid value for "subdomain", subdomain cannot be nil.')
  end

  if @suppression_reason.nil?
    invalid_properties.push('invalid value for "suppression_reason", suppression_reason cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 315

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



309
310
311
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 309

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
# File 'lib/crimson-falcon/models/suppressionrules_create_suppression_rule_request.rb', line 194

def valid?
  return false if @domain.nil?
  return false if @name.nil?
  return false if @rule_selection_type.nil?
  return false if @scope_type.nil?
  return false if @subdomain.nil?
  return false if @suppression_reason.nil?
  true
end