Class: Falcon::SuppressionrulesRuleSelectionFilter

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SuppressionrulesRuleSelectionFilter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SuppressionrulesRuleSelectionFilter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SuppressionrulesRuleSelectionFilter`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rule_ids')
    if (value = attributes[:'rule_ids']).is_a?(Array)
      self.rule_ids = value
    end
  end

  if attributes.key?(:'rule_names')
    if (value = attributes[:'rule_names']).is_a?(Array)
      self.rule_names = value
    end
  end

  if attributes.key?(:'rule_origins')
    if (value = attributes[:'rule_origins']).is_a?(Array)
      self.rule_origins = value
    end
  end

  if attributes.key?(:'rule_providers')
    if (value = attributes[:'rule_providers']).is_a?(Array)
      self.rule_providers = value
    end
  end

  if attributes.key?(:'rule_resource_type_names')
    if (value = attributes[:'rule_resource_type_names']).is_a?(Array)
      self.rule_resource_type_names = value
    end
  end

  if attributes.key?(:'rule_risk_factors')
    if (value = attributes[:'rule_risk_factors']).is_a?(Array)
      self.rule_risk_factors = value
    end
  end

  if attributes.key?(:'rule_services')
    if (value = attributes[:'rule_services']).is_a?(Array)
      self.rule_services = value
    end
  end

  if attributes.key?(:'rule_severities')
    if (value = attributes[:'rule_severities']).is_a?(Array)
      self.rule_severities = value
    end
  end
end

Instance Attribute Details

#rule_idsObject

Returns the value of attribute rule_ids.



34
35
36
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 34

def rule_ids
  @rule_ids
end

#rule_namesObject

Returns the value of attribute rule_names.



36
37
38
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 36

def rule_names
  @rule_names
end

#rule_originsObject

Returns the value of attribute rule_origins.



38
39
40
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 38

def rule_origins
  @rule_origins
end

#rule_providersObject

Returns the value of attribute rule_providers.



40
41
42
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 40

def rule_providers
  @rule_providers
end

#rule_resource_type_namesObject

Returns the value of attribute rule_resource_type_names.



42
43
44
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 42

def rule_resource_type_names
  @rule_resource_type_names
end

#rule_risk_factorsObject

Returns the value of attribute rule_risk_factors.



44
45
46
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 44

def rule_risk_factors
  @rule_risk_factors
end

#rule_servicesObject

Returns the value of attribute rule_services.



46
47
48
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 46

def rule_services
  @rule_services
end

#rule_severitiesObject

Returns the value of attribute rule_severities.



48
49
50
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 48

def rule_severities
  @rule_severities
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 51

def self.attribute_map
  {
    :'rule_ids' => :'rule_ids',
    :'rule_names' => :'rule_names',
    :'rule_origins' => :'rule_origins',
    :'rule_providers' => :'rule_providers',
    :'rule_resource_type_names' => :'rule_resource_type_names',
    :'rule_risk_factors' => :'rule_risk_factors',
    :'rule_services' => :'rule_services',
    :'rule_severities' => :'rule_severities'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 196

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 70

def self.openapi_types
  {
    :'rule_ids' => :'Array<String>',
    :'rule_names' => :'Array<String>',
    :'rule_origins' => :'Array<String>',
    :'rule_providers' => :'Array<String>',
    :'rule_resource_type_names' => :'Array<String>',
    :'rule_risk_factors' => :'Array<String>',
    :'rule_services' => :'Array<String>',
    :'rule_severities' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rule_ids == o.rule_ids &&
      rule_names == o.rule_names &&
      rule_origins == o.rule_origins &&
      rule_providers == o.rule_providers &&
      rule_resource_type_names == o.rule_resource_type_names &&
      rule_risk_factors == o.rule_risk_factors &&
      rule_services == o.rule_services &&
      rule_severities == o.rule_severities
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 227

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 298

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 203

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 189

def hash
  [rule_ids, rule_names, rule_origins, rule_providers, rule_resource_type_names, rule_risk_factors, rule_services, rule_severities].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 155

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 274

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 268

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
# File 'lib/crimson-falcon/models/suppressionrules_rule_selection_filter.rb', line 162

def valid?
  true
end