Class: Falcon::SvExclusionsSVExclusionV1

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SvExclusionsSVExclusionV1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::SvExclusionsSVExclusionV1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::SvExclusionsSVExclusionV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applied_globally')
    self.applied_globally = attributes[:'applied_globally']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_descendant_process')
    self.is_descendant_process = attributes[:'is_descendant_process']
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end

  if attributes.key?(:'regexp_value')
    self.regexp_value = attributes[:'regexp_value']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'value_hash')
    self.value_hash = attributes[:'value_hash']
  end
end

Instance Attribute Details

#applied_globallyObject

Returns the value of attribute applied_globally.



34
35
36
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 34

def applied_globally
  @applied_globally
end

#created_byObject

Returns the value of attribute created_by.



36
37
38
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 36

def created_by
  @created_by
end

#created_onObject

Returns the value of attribute created_on.



38
39
40
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 38

def created_on
  @created_on
end

#groupsObject

Returns the value of attribute groups.



40
41
42
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 40

def groups
  @groups
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 42

def id
  @id
end

#is_descendant_processObject

Returns the value of attribute is_descendant_process.



44
45
46
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 44

def is_descendant_process
  @is_descendant_process
end

#last_modifiedObject

Returns the value of attribute last_modified.



46
47
48
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 46

def last_modified
  @last_modified
end

#modified_byObject

Returns the value of attribute modified_by.



48
49
50
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 48

def modified_by
  @modified_by
end

#regexp_valueObject

Returns the value of attribute regexp_value.



50
51
52
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 50

def regexp_value
  @regexp_value
end

#valueObject

Returns the value of attribute value.



52
53
54
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 52

def value
  @value
end

#value_hashObject

Returns the value of attribute value_hash.



54
55
56
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 54

def value_hash
  @value_hash
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 57

def self.attribute_map
  {
    :'applied_globally' => :'applied_globally',
    :'created_by' => :'created_by',
    :'created_on' => :'created_on',
    :'groups' => :'groups',
    :'id' => :'id',
    :'is_descendant_process' => :'is_descendant_process',
    :'last_modified' => :'last_modified',
    :'modified_by' => :'modified_by',
    :'regexp_value' => :'regexp_value',
    :'value' => :'value',
    :'value_hash' => :'value_hash'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 259

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 79

def self.openapi_types
  {
    :'applied_globally' => :'Boolean',
    :'created_by' => :'String',
    :'created_on' => :'Time',
    :'groups' => :'Array<HostGroupsHostGroupV1>',
    :'id' => :'String',
    :'is_descendant_process' => :'Boolean',
    :'last_modified' => :'Time',
    :'modified_by' => :'String',
    :'regexp_value' => :'String',
    :'value' => :'String',
    :'value_hash' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applied_globally == o.applied_globally &&
      created_by == o.created_by &&
      created_on == o.created_on &&
      groups == o.groups &&
      id == o.id &&
      is_descendant_process == o.is_descendant_process &&
      last_modified == o.last_modified &&
      modified_by == o.modified_by &&
      regexp_value == o.regexp_value &&
      value == o.value &&
      value_hash == o.value_hash
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 290

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 266

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 252

def hash
  [applied_globally, created_by, created_on, groups, id, is_descendant_process, last_modified, modified_by, regexp_value, value, value_hash].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @applied_globally.nil?
    invalid_properties.push('invalid value for "applied_globally", applied_globally cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  if @groups.nil?
    invalid_properties.push('invalid value for "groups", groups cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_modified.nil?
    invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.')
  end

  if @modified_by.nil?
    invalid_properties.push('invalid value for "modified_by", modified_by cannot be nil.')
  end

  if @regexp_value.nil?
    invalid_properties.push('invalid value for "regexp_value", regexp_value cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @value_hash.nil?
    invalid_properties.push('invalid value for "value_hash", value_hash cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 337

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



331
332
333
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 331

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/crimson-falcon/models/sv_exclusions_sv_exclusion_v1.rb', line 212

def valid?
  return false if @applied_globally.nil?
  return false if @created_by.nil?
  return false if @created_on.nil?
  return false if @groups.nil?
  return false if @id.nil?
  return false if @last_modified.nil?
  return false if @modified_by.nil?
  return false if @regexp_value.nil?
  return false if @value.nil?
  return false if @value_hash.nil?
  true
end