Class: Falcon::TypesCrowdStrikeCloudSecurityMetadata

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TypesCrowdStrikeCloudSecurityMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::TypesCrowdStrikeCloudSecurityMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::TypesCrowdStrikeCloudSecurityMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'cloud_provider')
    self.cloud_provider = attributes[:'cloud_provider']
  end

  if attributes.key?(:'iom_id')
    self.iom_id = attributes[:'iom_id']
  end

  if attributes.key?(:'policy_id')
    self.policy_id = attributes[:'policy_id']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'resource_type')
    self.resource_type = attributes[:'resource_type']
  end
end

Instance Attribute Details

#base_urlObject

Returns the value of attribute base_url.



34
35
36
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 34

def base_url
  @base_url
end

#client_idObject

Returns the value of attribute client_id.



36
37
38
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 36

def client_id
  @client_id
end

#cloud_providerObject

Returns the value of attribute cloud_provider.



38
39
40
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 38

def cloud_provider
  @cloud_provider
end

#iom_idObject

Returns the value of attribute iom_id.



40
41
42
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 40

def iom_id
  @iom_id
end

#policy_idObject

Returns the value of attribute policy_id.



42
43
44
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 42

def policy_id
  @policy_id
end

#resource_idObject

Returns the value of attribute resource_id.



44
45
46
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 44

def resource_id
  @resource_id
end

#resource_typeObject

Returns the value of attribute resource_type.



46
47
48
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 46

def resource_type
  @resource_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 62

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 49

def self.attribute_map
  {
    :'base_url' => :'baseUrl',
    :'client_id' => :'clientId',
    :'cloud_provider' => :'cloudProvider',
    :'iom_id' => :'iomID',
    :'policy_id' => :'policyId',
    :'resource_id' => :'resourceId',
    :'resource_type' => :'resourceType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 171

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 67

def self.openapi_types
  {
    :'base_url' => :'String',
    :'client_id' => :'String',
    :'cloud_provider' => :'String',
    :'iom_id' => :'String',
    :'policy_id' => :'Integer',
    :'resource_id' => :'String',
    :'resource_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      base_url == o.base_url &&
      client_id == o.client_id &&
      cloud_provider == o.cloud_provider &&
      iom_id == o.iom_id &&
      policy_id == o.policy_id &&
      resource_id == o.resource_id &&
      resource_type == o.resource_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 202

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 273

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 164

def hash
  [base_url, client_id, cloud_provider, iom_id, policy_id, resource_id, resource_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 131

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 249

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



243
244
245
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 243

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
# File 'lib/crimson-falcon/models/types_crowd_strike_cloud_security_metadata.rb', line 138

def valid?
  true
end