Class: Falcon::TypesExecutorNode

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/types_executor_node.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TypesExecutorNode

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::TypesExecutorNode` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::TypesExecutorNode`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'additional_header')
    self.additional_header = attributes[:'additional_header']
  end

  if attributes.key?(:'current_aws_arn')
    self.current_aws_arn = attributes[:'current_aws_arn']
  end

  if attributes.key?(:'dashboard_url')
    self.dashboard_url = attributes[:'dashboard_url']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'last_health_check')
    self.last_health_check = attributes[:'last_health_check']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'node_type')
    self.node_type = attributes[:'node_type']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'pod_settings')
    self.pod_settings = attributes[:'pod_settings']
  end

  if attributes.key?(:'proxy_address')
    self.proxy_address = attributes[:'proxy_address']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'use_jobs')
    self.use_jobs = attributes[:'use_jobs']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#additional_headerObject

Returns the value of attribute additional_header.



34
35
36
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 34

def additional_header
  @additional_header
end

#current_aws_arnObject

Returns the value of attribute current_aws_arn.



36
37
38
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 36

def current_aws_arn
  @current_aws_arn
end

#dashboard_urlObject

Returns the value of attribute dashboard_url.



38
39
40
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 38

def dashboard_url
  @dashboard_url
end

#idObject

Returns the value of attribute id.



40
41
42
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 40

def id
  @id
end

#last_health_checkObject

Returns the value of attribute last_health_check.



42
43
44
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 42

def last_health_check
  @last_health_check
end

#nameObject

Returns the value of attribute name.



44
45
46
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 44

def name
  @name
end

#node_typeObject

Returns the value of attribute node_type.



46
47
48
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 46

def node_type
  @node_type
end

#passwordObject

Returns the value of attribute password.



48
49
50
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 48

def password
  @password
end

#pod_settingsObject

Returns the value of attribute pod_settings.



50
51
52
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 50

def pod_settings
  @pod_settings
end

#proxy_addressObject

Returns the value of attribute proxy_address.



52
53
54
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 52

def proxy_address
  @proxy_address
end

#statusObject

Returns the value of attribute status.



54
55
56
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 54

def status
  @status
end

#typeObject

Returns the value of attribute type.



56
57
58
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 56

def type
  @type
end

#use_jobsObject

Returns the value of attribute use_jobs.



58
59
60
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 58

def use_jobs
  @use_jobs
end

#usernameObject

Returns the value of attribute username.



60
61
62
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 60

def username
  @username
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 63

def self.attribute_map
  {
    :'additional_header' => :'additional_header',
    :'current_aws_arn' => :'current_aws_arn',
    :'dashboard_url' => :'dashboard_url',
    :'id' => :'id',
    :'last_health_check' => :'last_health_check',
    :'name' => :'name',
    :'node_type' => :'node_type',
    :'password' => :'password',
    :'pod_settings' => :'pod_settings',
    :'proxy_address' => :'proxy_address',
    :'status' => :'status',
    :'type' => :'type',
    :'use_jobs' => :'useJobs',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 88

def self.openapi_types
  {
    :'additional_header' => :'String',
    :'current_aws_arn' => :'String',
    :'dashboard_url' => :'String',
    :'id' => :'String',
    :'last_health_check' => :'Integer',
    :'name' => :'String',
    :'node_type' => :'String',
    :'password' => :'String',
    :'pod_settings' => :'TypesK8SPodSettings',
    :'proxy_address' => :'String',
    :'status' => :'TypesExecutorNodeStatus',
    :'type' => :'String',
    :'use_jobs' => :'Boolean',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 200

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      additional_header == o.additional_header &&
      current_aws_arn == o.current_aws_arn &&
      dashboard_url == o.dashboard_url &&
      id == o.id &&
      last_health_check == o.last_health_check &&
      name == o.name &&
      node_type == o.node_type &&
      password == o.password &&
      pod_settings == o.pod_settings &&
      proxy_address == o.proxy_address &&
      status == o.status &&
      type == o.type &&
      use_jobs == o.use_jobs &&
      username == o.username
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 265

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 336

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 227

def hash
  [additional_header, current_aws_arn, dashboard_url, id, last_health_check, name, node_type, password, pod_settings, proxy_address, status, type, use_jobs, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 187

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 312

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



306
307
308
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 306

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
# File 'lib/crimson-falcon/models/types_executor_node.rb', line 194

def valid?
  true
end