Class: Falcon::TypesGetServicesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/types_get_services_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TypesGetServicesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::TypesGetServicesRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::TypesGetServicesRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cids')
    if (value = attributes[:'cids']).is_a?(Array)
      self.cids = value
    end
  end

  if attributes.key?(:'deployment_tuple_filters')
    if (value = attributes[:'deployment_tuple_filters']).is_a?(Array)
      self.deployment_tuple_filters = value
    end
  end

  if attributes.key?(:'nesting_level')
    self.nesting_level = attributes[:'nesting_level']
  end

  if attributes.key?(:'only_count')
    self.only_count = attributes[:'only_count']
  end

  if attributes.key?(:'optional_time')
    self.optional_time = attributes[:'optional_time']
  end

  if attributes.key?(:'pagination')
    self.pagination = attributes[:'pagination']
  end

  if attributes.key?(:'persistent_signatures')
    if (value = attributes[:'persistent_signatures']).is_a?(Array)
      self.persistent_signatures = value
    end
  end

  if attributes.key?(:'ql_filters')
    self.ql_filters = attributes[:'ql_filters']
  end

  if attributes.key?(:'related_entities')
    if (value = attributes[:'related_entities']).is_a?(Array)
      self.related_entities = value
    end
  end

  if attributes.key?(:'revision_id')
    self.revision_id = attributes[:'revision_id']
  end

  if attributes.key?(:'roles_signature')
    self.roles_signature = attributes[:'roles_signature']
  end
end

Instance Attribute Details

#cidsObject

Returns the value of attribute cids.



34
35
36
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 34

def cids
  @cids
end

#deployment_tuple_filtersObject

Returns the value of attribute deployment_tuple_filters.



36
37
38
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 36

def deployment_tuple_filters
  @deployment_tuple_filters
end

#nesting_levelObject

Returns the value of attribute nesting_level.



38
39
40
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 38

def nesting_level
  @nesting_level
end

#only_countObject

Returns the value of attribute only_count.



40
41
42
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 40

def only_count
  @only_count
end

#optional_timeObject

Returns the value of attribute optional_time.



42
43
44
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 42

def optional_time
  @optional_time
end

#paginationObject

Returns the value of attribute pagination.



44
45
46
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 44

def pagination
  @pagination
end

#persistent_signaturesObject

Returns the value of attribute persistent_signatures.



46
47
48
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 46

def persistent_signatures
  @persistent_signatures
end

#ql_filtersObject

Returns the value of attribute ql_filters.



48
49
50
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 48

def ql_filters
  @ql_filters
end

Returns the value of attribute related_entities.



50
51
52
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 50

def related_entities
  @related_entities
end

#revision_idObject

Returns the value of attribute revision_id.



52
53
54
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 52

def revision_id
  @revision_id
end

#roles_signatureObject

Returns the value of attribute roles_signature.



54
55
56
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 54

def roles_signature
  @roles_signature
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 57

def self.attribute_map
  {
    :'cids' => :'cids',
    :'deployment_tuple_filters' => :'deploymentTupleFilters',
    :'nesting_level' => :'nestingLevel',
    :'only_count' => :'onlyCount',
    :'optional_time' => :'optionalTime',
    :'pagination' => :'pagination',
    :'persistent_signatures' => :'persistentSignatures',
    :'ql_filters' => :'qlFilters',
    :'related_entities' => :'relatedEntities',
    :'revision_id' => :'revisionId',
    :'roles_signature' => :'rolesSignature'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 215

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 79

def self.openapi_types
  {
    :'cids' => :'Array<String>',
    :'deployment_tuple_filters' => :'Array<TypesDeploymentUnitsTupleFilters>',
    :'nesting_level' => :'Integer',
    :'only_count' => :'Boolean',
    :'optional_time' => :'Integer',
    :'pagination' => :'TypesPagination',
    :'persistent_signatures' => :'Array<String>',
    :'ql_filters' => :'String',
    :'related_entities' => :'Array<TypesGetServicesRelatedEntity>',
    :'revision_id' => :'Integer',
    :'roles_signature' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cids == o.cids &&
      deployment_tuple_filters == o.deployment_tuple_filters &&
      nesting_level == o.nesting_level &&
      only_count == o.only_count &&
      optional_time == o.optional_time &&
      pagination == o.pagination &&
      persistent_signatures == o.persistent_signatures &&
      ql_filters == o.ql_filters &&
      related_entities == o.related_entities &&
      revision_id == o.revision_id &&
      roles_signature == o.roles_signature
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 246

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 317

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 222

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 208

def hash
  [cids, deployment_tuple_filters, nesting_level, only_count, optional_time, pagination, persistent_signatures, ql_filters, related_entities, revision_id, roles_signature].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 293

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



287
288
289
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 287

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
# File 'lib/crimson-falcon/models/types_get_services_request.rb', line 178

def valid?
  true
end