Class: Falcon::V2ClusterV2

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/v2_cluster_v2.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V2ClusterV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::V2ClusterV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::V2ClusterV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access')
    self.access = attributes[:'access']
  end

  if attributes.key?(:'agent_coverage')
    self.agent_coverage = attributes[:'agent_coverage']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'cloud_provider_info')
    self.cloud_provider_info = attributes[:'cloud_provider_info']
  end

  if attributes.key?(:'cloud_resource_id')
    self.cloud_resource_id = attributes[:'cloud_resource_id']
  end

  if attributes.key?(:'cluster_id')
    self.cluster_id = attributes[:'cluster_id']
  end

  if attributes.key?(:'cluster_name')
    self.cluster_name = attributes[:'cluster_name']
  end

  if attributes.key?(:'cluster_status')
    self.cluster_status = attributes[:'cluster_status']
  end

  if attributes.key?(:'kubernetes_version')
    self.kubernetes_version = attributes[:'kubernetes_version']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Hash)
      self.labels = value
    end
  end

  if attributes.key?(:'management_status')
    self.management_status = attributes[:'management_status']
  end

  if attributes.key?(:'resource_counts')
    if (value = attributes[:'resource_counts']).is_a?(Hash)
      self.resource_counts = value
    end
  end

  if attributes.key?(:'security_group')
    self.security_group = attributes[:'security_group']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'timestamps')
    self.timestamps = attributes[:'timestamps']
  end

  if attributes.key?(:'virtual_network')
    self.virtual_network = attributes[:'virtual_network']
  end
end

Instance Attribute Details

#accessObject

Returns the value of attribute access.



34
35
36
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 34

def access
  @access
end

#agent_coverageObject

Returns the value of attribute agent_coverage.



36
37
38
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 36

def agent_coverage
  @agent_coverage
end

#cidObject

Returns the value of attribute cid.



38
39
40
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 38

def cid
  @cid
end

#cloud_provider_infoObject

Returns the value of attribute cloud_provider_info.



40
41
42
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 40

def cloud_provider_info
  @cloud_provider_info
end

#cloud_resource_idObject

Returns the value of attribute cloud_resource_id.



42
43
44
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 42

def cloud_resource_id
  @cloud_resource_id
end

#cluster_idObject

Returns the value of attribute cluster_id.



44
45
46
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 44

def cluster_id
  @cluster_id
end

#cluster_nameObject

Returns the value of attribute cluster_name.



46
47
48
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 46

def cluster_name
  @cluster_name
end

#cluster_statusObject

Returns the value of attribute cluster_status.



48
49
50
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 48

def cluster_status
  @cluster_status
end

#kubernetes_versionObject

Returns the value of attribute kubernetes_version.



50
51
52
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 50

def kubernetes_version
  @kubernetes_version
end

#labelsObject

Returns the value of attribute labels.



52
53
54
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 52

def labels
  @labels
end

#management_statusObject

Returns the value of attribute management_status.



54
55
56
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 54

def management_status
  @management_status
end

#resource_countsObject

Returns the value of attribute resource_counts.



56
57
58
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 56

def resource_counts
  @resource_counts
end

#security_groupObject

Returns the value of attribute security_group.



58
59
60
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 58

def security_group
  @security_group
end

#tagsObject

Returns the value of attribute tags.



60
61
62
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 60

def tags
  @tags
end

#timestampsObject

Returns the value of attribute timestamps.



62
63
64
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 62

def timestamps
  @timestamps
end

#virtual_networkObject

Returns the value of attribute virtual_network.



64
65
66
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 64

def virtual_network
  @virtual_network
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 67

def self.attribute_map
  {
    :'access' => :'access',
    :'agent_coverage' => :'agent_coverage',
    :'cid' => :'cid',
    :'cloud_provider_info' => :'cloud_provider_info',
    :'cloud_resource_id' => :'cloud_resource_id',
    :'cluster_id' => :'cluster_id',
    :'cluster_name' => :'cluster_name',
    :'cluster_status' => :'cluster_status',
    :'kubernetes_version' => :'kubernetes_version',
    :'labels' => :'labels',
    :'management_status' => :'management_status',
    :'resource_counts' => :'resource_counts',
    :'security_group' => :'security_group',
    :'tags' => :'tags',
    :'timestamps' => :'timestamps',
    :'virtual_network' => :'virtual_network'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 268

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 94

def self.openapi_types
  {
    :'access' => :'String',
    :'agent_coverage' => :'V2AgentCoverage',
    :'cid' => :'String',
    :'cloud_provider_info' => :'V2CloudProviderInfo',
    :'cloud_resource_id' => :'String',
    :'cluster_id' => :'String',
    :'cluster_name' => :'String',
    :'cluster_status' => :'String',
    :'kubernetes_version' => :'String',
    :'labels' => :'Hash<String, String>',
    :'management_status' => :'String',
    :'resource_counts' => :'Hash<String, Integer>',
    :'security_group' => :'String',
    :'tags' => :'Hash<String, String>',
    :'timestamps' => :'V2TimestampFields',
    :'virtual_network' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access == o.access &&
      agent_coverage == o.agent_coverage &&
      cid == o.cid &&
      cloud_provider_info == o.cloud_provider_info &&
      cloud_resource_id == o.cloud_resource_id &&
      cluster_id == o.cluster_id &&
      cluster_name == o.cluster_name &&
      cluster_status == o.cluster_status &&
      kubernetes_version == o.kubernetes_version &&
      labels == o.labels &&
      management_status == o.management_status &&
      resource_counts == o.resource_counts &&
      security_group == o.security_group &&
      tags == o.tags &&
      timestamps == o.timestamps &&
      virtual_network == o.virtual_network
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 299

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 370

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 255

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



261
262
263
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 261

def hash
  [access, agent_coverage, cid, cloud_provider_info, cloud_resource_id, cluster_id, cluster_name, cluster_status, kubernetes_version, labels, management_status, resource_counts, security_group, tags, timestamps, virtual_network].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 209

def list_invalid_properties
  invalid_properties = Array.new
  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @timestamps.nil?
    invalid_properties.push('invalid value for "timestamps", timestamps cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 346

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



340
341
342
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 340

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
# File 'lib/crimson-falcon/models/v2_cluster_v2.rb', line 224

def valid?
  return false if @cid.nil?
  return false if @timestamps.nil?
  true
end