Class: Falcon::VulncheckExploitTimeline

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/vulncheck_exploit_timeline.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VulncheckExploitTimeline

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::VulncheckExploitTimeline` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::VulncheckExploitTimeline`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cisa_kev_date_added')
    self.cisa_kev_date_added = attributes[:'cisa_kev_date_added']
  end

  if attributes.key?(:'cisa_kev_date_due')
    self.cisa_kev_date_due = attributes[:'cisa_kev_date_due']
  end

  if attributes.key?(:'first_exploit_poc_or_higher')
    self.first_exploit_poc_or_higher = attributes[:'first_exploit_poc_or_higher']
  end

  if attributes.key?(:'first_exploit_published')
    self.first_exploit_published = attributes[:'first_exploit_published']
  end

  if attributes.key?(:'first_exploit_weaponized_or_higher')
    self.first_exploit_weaponized_or_higher = attributes[:'first_exploit_weaponized_or_higher']
  end

  if attributes.key?(:'first_reported_botnet')
    self.first_reported_botnet = attributes[:'first_reported_botnet']
  end

  if attributes.key?(:'first_reported_ransomware')
    self.first_reported_ransomware = attributes[:'first_reported_ransomware']
  end

  if attributes.key?(:'first_reported_threat_actor')
    self.first_reported_threat_actor = attributes[:'first_reported_threat_actor']
  end

  if attributes.key?(:'most_recent_exploit_published')
    self.most_recent_exploit_published = attributes[:'most_recent_exploit_published']
  end

  if attributes.key?(:'most_recent_reported_botnet')
    self.most_recent_reported_botnet = attributes[:'most_recent_reported_botnet']
  end

  if attributes.key?(:'most_recent_reported_ransomware')
    self.most_recent_reported_ransomware = attributes[:'most_recent_reported_ransomware']
  end

  if attributes.key?(:'most_recent_reported_threat_actor')
    self.most_recent_reported_threat_actor = attributes[:'most_recent_reported_threat_actor']
  end

  if attributes.key?(:'nvd_published')
    self.nvd_published = attributes[:'nvd_published']
  end
end

Instance Attribute Details

#cisa_kev_date_addedObject

Returns the value of attribute cisa_kev_date_added.



34
35
36
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 34

def cisa_kev_date_added
  @cisa_kev_date_added
end

#cisa_kev_date_dueObject

Returns the value of attribute cisa_kev_date_due.



36
37
38
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 36

def cisa_kev_date_due
  @cisa_kev_date_due
end

#first_exploit_poc_or_higherObject

Returns the value of attribute first_exploit_poc_or_higher.



38
39
40
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 38

def first_exploit_poc_or_higher
  @first_exploit_poc_or_higher
end

#first_exploit_publishedObject

Returns the value of attribute first_exploit_published.



40
41
42
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 40

def first_exploit_published
  @first_exploit_published
end

#first_exploit_weaponized_or_higherObject

Returns the value of attribute first_exploit_weaponized_or_higher.



42
43
44
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 42

def first_exploit_weaponized_or_higher
  @first_exploit_weaponized_or_higher
end

#first_reported_botnetObject

Returns the value of attribute first_reported_botnet.



44
45
46
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 44

def first_reported_botnet
  @first_reported_botnet
end

#first_reported_ransomwareObject

Returns the value of attribute first_reported_ransomware.



46
47
48
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 46

def first_reported_ransomware
  @first_reported_ransomware
end

#first_reported_threat_actorObject

Returns the value of attribute first_reported_threat_actor.



48
49
50
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 48

def first_reported_threat_actor
  @first_reported_threat_actor
end

#most_recent_exploit_publishedObject

Returns the value of attribute most_recent_exploit_published.



50
51
52
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 50

def most_recent_exploit_published
  @most_recent_exploit_published
end

#most_recent_reported_botnetObject

Returns the value of attribute most_recent_reported_botnet.



52
53
54
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 52

def most_recent_reported_botnet
  @most_recent_reported_botnet
end

#most_recent_reported_ransomwareObject

Returns the value of attribute most_recent_reported_ransomware.



54
55
56
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 54

def most_recent_reported_ransomware
  @most_recent_reported_ransomware
end

#most_recent_reported_threat_actorObject

Returns the value of attribute most_recent_reported_threat_actor.



56
57
58
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 56

def most_recent_reported_threat_actor
  @most_recent_reported_threat_actor
end

#nvd_publishedObject

Returns the value of attribute nvd_published.



58
59
60
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 58

def nvd_published
  @nvd_published
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 61

def self.attribute_map
  {
    :'cisa_kev_date_added' => :'cisa_kev_date_added',
    :'cisa_kev_date_due' => :'cisa_kev_date_due',
    :'first_exploit_poc_or_higher' => :'first_exploit_poc_or_higher',
    :'first_exploit_published' => :'first_exploit_published',
    :'first_exploit_weaponized_or_higher' => :'first_exploit_weaponized_or_higher',
    :'first_reported_botnet' => :'first_reported_botnet',
    :'first_reported_ransomware' => :'first_reported_ransomware',
    :'first_reported_threat_actor' => :'first_reported_threat_actor',
    :'most_recent_exploit_published' => :'most_recent_exploit_published',
    :'most_recent_reported_botnet' => :'most_recent_reported_botnet',
    :'most_recent_reported_ransomware' => :'most_recent_reported_ransomware',
    :'most_recent_reported_threat_actor' => :'most_recent_reported_threat_actor',
    :'nvd_published' => :'nvd_published'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 225

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 85

def self.openapi_types
  {
    :'cisa_kev_date_added' => :'String',
    :'cisa_kev_date_due' => :'String',
    :'first_exploit_poc_or_higher' => :'String',
    :'first_exploit_published' => :'String',
    :'first_exploit_weaponized_or_higher' => :'String',
    :'first_reported_botnet' => :'String',
    :'first_reported_ransomware' => :'String',
    :'first_reported_threat_actor' => :'String',
    :'most_recent_exploit_published' => :'String',
    :'most_recent_reported_botnet' => :'String',
    :'most_recent_reported_ransomware' => :'String',
    :'most_recent_reported_threat_actor' => :'String',
    :'nvd_published' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cisa_kev_date_added == o.cisa_kev_date_added &&
      cisa_kev_date_due == o.cisa_kev_date_due &&
      first_exploit_poc_or_higher == o.first_exploit_poc_or_higher &&
      first_exploit_published == o.first_exploit_published &&
      first_exploit_weaponized_or_higher == o.first_exploit_weaponized_or_higher &&
      first_reported_botnet == o.first_reported_botnet &&
      first_reported_ransomware == o.first_reported_ransomware &&
      first_reported_threat_actor == o.first_reported_threat_actor &&
      most_recent_exploit_published == o.most_recent_exploit_published &&
      most_recent_reported_botnet == o.most_recent_reported_botnet &&
      most_recent_reported_ransomware == o.most_recent_reported_ransomware &&
      most_recent_reported_threat_actor == o.most_recent_reported_threat_actor &&
      nvd_published == o.nvd_published
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 256

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 327

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 232

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 218

def hash
  [cisa_kev_date_added, cisa_kev_date_due, first_exploit_poc_or_higher, first_exploit_published, first_exploit_weaponized_or_higher, first_reported_botnet, first_reported_ransomware, first_reported_threat_actor, most_recent_exploit_published, most_recent_reported_botnet, most_recent_reported_ransomware, most_recent_reported_threat_actor, nvd_published].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 303

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



297
298
299
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 297

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
# File 'lib/crimson-falcon/models/vulncheck_exploit_timeline.rb', line 186

def valid?
  true
end