Class: Falcon::VulnerabilitymetadataapiFalconVulnMetadata

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VulnerabilitymetadataapiFalconVulnMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::VulnerabilitymetadataapiFalconVulnMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::VulnerabilitymetadataapiFalconVulnMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'actors')
    if (value = attributes[:'actors']).is_a?(Array)
      self.actors = value
    end
  end

  if attributes.key?(:'additional_info')
    self.additional_info = attributes[:'additional_info']
  end

  if attributes.key?(:'cisa_kev_info')
    self.cisa_kev_info = attributes[:'cisa_kev_info']
  end

  if attributes.key?(:'created_content_id')
    self.created_content_id = attributes[:'created_content_id']
  end

  if attributes.key?(:'cs_exploit')
    self.cs_exploit = attributes[:'cs_exploit']
  end

  if attributes.key?(:'exprt_rating')
    self.exprt_rating = attributes[:'exprt_rating']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'source_type')
    self.source_type = attributes[:'source_type']
  end

  if attributes.key?(:'spotlight_published_date')
    self.spotlight_published_date = attributes[:'spotlight_published_date']
  end

  if attributes.key?(:'supported_platforms')
    if (value = attributes[:'supported_platforms']).is_a?(Array)
      self.supported_platforms = value
    end
  end

  if attributes.key?(:'types')
    if (value = attributes[:'types']).is_a?(Array)
      self.types = value
    end
  end

  if attributes.key?(:'updated_content_id')
    self.updated_content_id = attributes[:'updated_content_id']
  end
end

Instance Attribute Details

#actorsObject

Returns the value of attribute actors.



34
35
36
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 34

def actors
  @actors
end

#additional_infoObject

Returns the value of attribute additional_info.



36
37
38
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 36

def additional_info
  @additional_info
end

#cisa_kev_infoObject

Returns the value of attribute cisa_kev_info.



38
39
40
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 38

def cisa_kev_info
  @cisa_kev_info
end

#created_content_idObject

Returns the value of attribute created_content_id.



40
41
42
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 40

def created_content_id
  @created_content_id
end

#cs_exploitObject

Returns the value of attribute cs_exploit.



42
43
44
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 42

def cs_exploit
  @cs_exploit
end

#exprt_ratingObject

Returns the value of attribute exprt_rating.



44
45
46
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 44

def exprt_rating
  @exprt_rating
end

#sourceObject

Returns the value of attribute source.



46
47
48
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 46

def source
  @source
end

#source_typeObject

Returns the value of attribute source_type.



48
49
50
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 48

def source_type
  @source_type
end

#spotlight_published_dateObject

Returns the value of attribute spotlight_published_date.



50
51
52
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 50

def spotlight_published_date
  @spotlight_published_date
end

#supported_platformsObject

Returns the value of attribute supported_platforms.



52
53
54
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 52

def supported_platforms
  @supported_platforms
end

#typesObject

Returns the value of attribute types.



54
55
56
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 54

def types
  @types
end

#updated_content_idObject

Returns the value of attribute updated_content_id.



56
57
58
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 56

def updated_content_id
  @updated_content_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 59

def self.attribute_map
  {
    :'actors' => :'actors',
    :'additional_info' => :'additional_info',
    :'cisa_kev_info' => :'cisa_kev_info',
    :'created_content_id' => :'created_content_id',
    :'cs_exploit' => :'cs_exploit',
    :'exprt_rating' => :'exprt_rating',
    :'source' => :'source',
    :'source_type' => :'source_type',
    :'spotlight_published_date' => :'spotlight_published_date',
    :'supported_platforms' => :'supported_platforms',
    :'types' => :'types',
    :'updated_content_id' => :'updated_content_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 282

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 82

def self.openapi_types
  {
    :'actors' => :'Array<String>',
    :'additional_info' => :'String',
    :'cisa_kev_info' => :'VulnerabilitymetadataapiCISAKnownExploitedVulnerabilitiesInfo',
    :'created_content_id' => :'String',
    :'cs_exploit' => :'VulnerabilitymetadataapiCSExploit',
    :'exprt_rating' => :'VulnerabilitymetadataapiExPRTRating',
    :'source' => :'String',
    :'source_type' => :'String',
    :'spotlight_published_date' => :'String',
    :'supported_platforms' => :'Array<VulnerabilitymetadataapiSupportedPlatform>',
    :'types' => :'Array<String>',
    :'updated_content_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      actors == o.actors &&
      additional_info == o.additional_info &&
      cisa_kev_info == o.cisa_kev_info &&
      created_content_id == o.created_content_id &&
      cs_exploit == o.cs_exploit &&
      exprt_rating == o.exprt_rating &&
      source == o.source &&
      source_type == o.source_type &&
      spotlight_published_date == o.spotlight_published_date &&
      supported_platforms == o.supported_platforms &&
      types == o.types &&
      updated_content_id == o.updated_content_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 313

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 384

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 289

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 275

def hash
  [actors, additional_info, cisa_kev_info, created_content_id, cs_exploit, exprt_rating, source, source_type, spotlight_published_date, supported_platforms, types, updated_content_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 177

def list_invalid_properties
  invalid_properties = Array.new
  if @actors.nil?
    invalid_properties.push('invalid value for "actors", actors cannot be nil.')
  end

  if @additional_info.nil?
    invalid_properties.push('invalid value for "additional_info", additional_info cannot be nil.')
  end

  if @cisa_kev_info.nil?
    invalid_properties.push('invalid value for "cisa_kev_info", cisa_kev_info cannot be nil.')
  end

  if @created_content_id.nil?
    invalid_properties.push('invalid value for "created_content_id", created_content_id cannot be nil.')
  end

  if @cs_exploit.nil?
    invalid_properties.push('invalid value for "cs_exploit", cs_exploit cannot be nil.')
  end

  if @exprt_rating.nil?
    invalid_properties.push('invalid value for "exprt_rating", exprt_rating cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @source_type.nil?
    invalid_properties.push('invalid value for "source_type", source_type cannot be nil.')
  end

  if @spotlight_published_date.nil?
    invalid_properties.push('invalid value for "spotlight_published_date", spotlight_published_date cannot be nil.')
  end

  if @supported_platforms.nil?
    invalid_properties.push('invalid value for "supported_platforms", supported_platforms cannot be nil.')
  end

  if @types.nil?
    invalid_properties.push('invalid value for "types", types cannot be nil.')
  end

  if @updated_content_id.nil?
    invalid_properties.push('invalid value for "updated_content_id", updated_content_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 360

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 354

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_falcon_vuln_metadata.rb', line 232

def valid?
  return false if @actors.nil?
  return false if @additional_info.nil?
  return false if @cisa_kev_info.nil?
  return false if @created_content_id.nil?
  return false if @cs_exploit.nil?
  return false if @exprt_rating.nil?
  return false if @source.nil?
  return false if @source_type.nil?
  return false if @spotlight_published_date.nil?
  return false if @supported_platforms.nil?
  return false if @types.nil?
  return false if @updated_content_id.nil?
  true
end