Class: Falcon::VulnerabilitymetadataapiRule

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VulnerabilitymetadataapiRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::VulnerabilitymetadataapiRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::VulnerabilitymetadataapiRule`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'audit_procedure')
    self.audit_procedure = attributes[:'audit_procedure']
  end

  if attributes.key?(:'authority')
    self.authority = attributes[:'authority']
  end

  if attributes.key?(:'benchmark')
    self.benchmark = attributes[:'benchmark']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'cce')
    self.cce = attributes[:'cce']
  end

  if attributes.key?(:'controls')
    if (value = attributes[:'controls']).is_a?(Array)
      self.controls = value
    end
  end

  if attributes.key?(:'cs_id')
    self.cs_id = attributes[:'cs_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'impact_statement')
    self.impact_statement = attributes[:'impact_statement']
  end

  if attributes.key?(:'mitre_attack_tactics')
    if (value = attributes[:'mitre_attack_tactics']).is_a?(Array)
      self.mitre_attack_tactics = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'rationale_statement')
    self.rationale_statement = attributes[:'rationale_statement']
  end

  if attributes.key?(:'requirement_id')
    self.requirement_id = attributes[:'requirement_id']
  end

  if attributes.key?(:'resource_metadata')
    self. = attributes[:'resource_metadata']
  end

  if attributes.key?(:'resource_type')
    if (value = attributes[:'resource_type']).is_a?(Array)
      self.resource_type = value
    end
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'subdomain')
    self.subdomain = attributes[:'subdomain']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#audit_procedureObject

Returns the value of attribute audit_procedure.



34
35
36
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 34

def audit_procedure
  @audit_procedure
end

#authorityObject

Returns the value of attribute authority.



36
37
38
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 36

def authority
  @authority
end

#benchmarkObject

Returns the value of attribute benchmark.



38
39
40
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 38

def benchmark
  @benchmark
end

#categoryObject

Returns the value of attribute category.



40
41
42
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 40

def category
  @category
end

#cceObject

Returns the value of attribute cce.



42
43
44
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 42

def cce
  @cce
end

#controlsObject

Returns the value of attribute controls.



44
45
46
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 44

def controls
  @controls
end

#cs_idObject

Returns the value of attribute cs_id.



46
47
48
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 46

def cs_id
  @cs_id
end

#descriptionObject

Returns the value of attribute description.



48
49
50
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 48

def description
  @description
end

#domainObject

Returns the value of attribute domain.



50
51
52
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 50

def domain
  @domain
end

#idObject

Returns the value of attribute id.



52
53
54
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 52

def id
  @id
end

#impact_statementObject

Returns the value of attribute impact_statement.



54
55
56
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 54

def impact_statement
  @impact_statement
end

#mitre_attack_tacticsObject

Returns the value of attribute mitre_attack_tactics.



56
57
58
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 56

def mitre_attack_tactics
  @mitre_attack_tactics
end

#nameObject

Returns the value of attribute name.



58
59
60
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 58

def name
  @name
end

#platform_nameObject

Returns the value of attribute platform_name.



60
61
62
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 60

def platform_name
  @platform_name
end

#rationale_statementObject

Returns the value of attribute rationale_statement.



62
63
64
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 62

def rationale_statement
  @rationale_statement
end

#requirement_idObject

Returns the value of attribute requirement_id.



64
65
66
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 64

def requirement_id
  @requirement_id
end

#resource_metadataObject

Returns the value of attribute resource_metadata.



66
67
68
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 66

def 
  @resource_metadata
end

#resource_typeObject

Returns the value of attribute resource_type.



68
69
70
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 68

def resource_type
  @resource_type
end

#revisionObject

Returns the value of attribute revision.



70
71
72
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 70

def revision
  @revision
end

#severityObject

Returns the value of attribute severity.



72
73
74
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 72

def severity
  @severity
end

#subdomainObject

Returns the value of attribute subdomain.



74
75
76
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 74

def subdomain
  @subdomain
end

#typeObject

Returns the value of attribute type.



76
77
78
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 76

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 107

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 79

def self.attribute_map
  {
    :'audit_procedure' => :'audit_procedure',
    :'authority' => :'authority',
    :'benchmark' => :'benchmark',
    :'category' => :'category',
    :'cce' => :'cce',
    :'controls' => :'controls',
    :'cs_id' => :'cs_id',
    :'description' => :'description',
    :'domain' => :'domain',
    :'id' => :'id',
    :'impact_statement' => :'impact_statement',
    :'mitre_attack_tactics' => :'mitre_attack_tactics',
    :'name' => :'name',
    :'platform_name' => :'platform_name',
    :'rationale_statement' => :'rationale_statement',
    :'requirement_id' => :'requirement_id',
    :'resource_metadata' => :'resource_metadata',
    :'resource_type' => :'resource_type',
    :'revision' => :'revision',
    :'severity' => :'severity',
    :'subdomain' => :'subdomain',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



422
423
424
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 422

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 112

def self.openapi_types
  {
    :'audit_procedure' => :'String',
    :'authority' => :'String',
    :'benchmark' => :'VulnerabilitymetadataapiRuleBenchmark',
    :'category' => :'String',
    :'cce' => :'String',
    :'controls' => :'Array<VulnerabilitymetadataapiRuleControl>',
    :'cs_id' => :'String',
    :'description' => :'String',
    :'domain' => :'String',
    :'id' => :'String',
    :'impact_statement' => :'String',
    :'mitre_attack_tactics' => :'Array<VulnerabilitymetadataapiRuleMitreAttackTactics>',
    :'name' => :'String',
    :'platform_name' => :'String',
    :'rationale_statement' => :'String',
    :'requirement_id' => :'String',
    :'resource_metadata' => :'String',
    :'resource_type' => :'Array<VulnerabilitymetadataapiRuleResourceType>',
    :'revision' => :'String',
    :'severity' => :'String',
    :'subdomain' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 380

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      audit_procedure == o.audit_procedure &&
      authority == o.authority &&
      benchmark == o.benchmark &&
      category == o.category &&
      cce == o.cce &&
      controls == o.controls &&
      cs_id == o.cs_id &&
      description == o.description &&
      domain == o.domain &&
      id == o.id &&
      impact_statement == o.impact_statement &&
      mitre_attack_tactics == o.mitre_attack_tactics &&
      name == o.name &&
      platform_name == o.platform_name &&
      rationale_statement == o.rationale_statement &&
      requirement_id == o.requirement_id &&
       == o. &&
      resource_type == o.resource_type &&
      revision == o.revision &&
      severity == o.severity &&
      subdomain == o.subdomain &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 453

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 524

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 429

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


409
410
411
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 409

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



415
416
417
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 415

def hash
  [audit_procedure, authority, benchmark, category, cce, controls, cs_id, description, domain, id, impact_statement, mitre_attack_tactics, name, platform_name, rationale_statement, requirement_id, , resource_type, revision, severity, subdomain, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 257

def list_invalid_properties
  invalid_properties = Array.new
  if @audit_procedure.nil?
    invalid_properties.push('invalid value for "audit_procedure", audit_procedure cannot be nil.')
  end

  if @authority.nil?
    invalid_properties.push('invalid value for "authority", authority cannot be nil.')
  end

  if @benchmark.nil?
    invalid_properties.push('invalid value for "benchmark", benchmark cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @cce.nil?
    invalid_properties.push('invalid value for "cce", cce cannot be nil.')
  end

  if @controls.nil?
    invalid_properties.push('invalid value for "controls", controls cannot be nil.')
  end

  if @cs_id.nil?
    invalid_properties.push('invalid value for "cs_id", cs_id cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @impact_statement.nil?
    invalid_properties.push('invalid value for "impact_statement", impact_statement cannot be nil.')
  end

  if @mitre_attack_tactics.nil?
    invalid_properties.push('invalid value for "mitre_attack_tactics", mitre_attack_tactics cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @platform_name.nil?
    invalid_properties.push('invalid value for "platform_name", platform_name cannot be nil.')
  end

  if @rationale_statement.nil?
    invalid_properties.push('invalid value for "rationale_statement", rationale_statement cannot be nil.')
  end

  if @requirement_id.nil?
    invalid_properties.push('invalid value for "requirement_id", requirement_id cannot be nil.')
  end

  if @resource_metadata.nil?
    invalid_properties.push('invalid value for "resource_metadata", resource_metadata cannot be nil.')
  end

  if @resource_type.nil?
    invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.')
  end

  if @revision.nil?
    invalid_properties.push('invalid value for "revision", revision cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @subdomain.nil?
    invalid_properties.push('invalid value for "subdomain", subdomain cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



500
501
502
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 500

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 506

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



494
495
496
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 494

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_rule.rb', line 352

def valid?
  return false if @audit_procedure.nil?
  return false if @authority.nil?
  return false if @benchmark.nil?
  return false if @category.nil?
  return false if @cce.nil?
  return false if @controls.nil?
  return false if @cs_id.nil?
  return false if @description.nil?
  return false if @domain.nil?
  return false if @id.nil?
  return false if @impact_statement.nil?
  return false if @mitre_attack_tactics.nil?
  return false if @name.nil?
  return false if @platform_name.nil?
  return false if @rationale_statement.nil?
  return false if @requirement_id.nil?
  return false if @resource_metadata.nil?
  return false if @resource_type.nil?
  return false if @revision.nil?
  return false if @severity.nil?
  return false if @subdomain.nil?
  return false if @type.nil?
  true
end