Class: Falcon::VulnerabilitymetadataapiTenableVulnMetadata
- Inherits:
-
Object
- Object
- Falcon::VulnerabilitymetadataapiTenableVulnMetadata
- Defined in:
- lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb
Instance Attribute Summary collapse
-
#cpe ⇒ Object
Returns the value of attribute cpe.
-
#exploit_ease ⇒ Object
Returns the value of attribute exploit_ease.
-
#family ⇒ Object
Returns the value of attribute family.
-
#plugin_id ⇒ Object
Returns the value of attribute plugin_id.
-
#plugin_name ⇒ Object
Returns the value of attribute plugin_name.
-
#port ⇒ Object
Returns the value of attribute port.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#solution ⇒ Object
Returns the value of attribute solution.
-
#synopsis ⇒ Object
Returns the value of attribute synopsis.
-
#type ⇒ Object
Returns the value of attribute type.
-
#vpr ⇒ Object
Returns the value of attribute vpr.
-
#vpr_severity ⇒ Object
Returns the value of attribute vpr_severity.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VulnerabilitymetadataapiTenableVulnMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VulnerabilitymetadataapiTenableVulnMetadata
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::VulnerabilitymetadataapiTenableVulnMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::VulnerabilitymetadataapiTenableVulnMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cpe') if (value = attributes[:'cpe']).is_a?(Array) self.cpe = value end end if attributes.key?(:'exploit_ease') self.exploit_ease = attributes[:'exploit_ease'] end if attributes.key?(:'family') self.family = attributes[:'family'] end if attributes.key?(:'plugin_id') self.plugin_id = attributes[:'plugin_id'] end if attributes.key?(:'plugin_name') self.plugin_name = attributes[:'plugin_name'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'solution') self.solution = attributes[:'solution'] end if attributes.key?(:'synopsis') self.synopsis = attributes[:'synopsis'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'vpr') self.vpr = attributes[:'vpr'] end if attributes.key?(:'vpr_severity') self.vpr_severity = attributes[:'vpr_severity'] end end |
Instance Attribute Details
#cpe ⇒ Object
Returns the value of attribute cpe.
34 35 36 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 34 def cpe @cpe end |
#exploit_ease ⇒ Object
Returns the value of attribute exploit_ease.
36 37 38 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 36 def exploit_ease @exploit_ease end |
#family ⇒ Object
Returns the value of attribute family.
38 39 40 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 38 def family @family end |
#plugin_id ⇒ Object
Returns the value of attribute plugin_id.
40 41 42 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 40 def plugin_id @plugin_id end |
#plugin_name ⇒ Object
Returns the value of attribute plugin_name.
42 43 44 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 42 def plugin_name @plugin_name end |
#port ⇒ Object
Returns the value of attribute port.
44 45 46 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 44 def port @port end |
#severity ⇒ Object
Returns the value of attribute severity.
46 47 48 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 46 def severity @severity end |
#solution ⇒ Object
Returns the value of attribute solution.
48 49 50 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 48 def solution @solution end |
#synopsis ⇒ Object
Returns the value of attribute synopsis.
50 51 52 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 50 def synopsis @synopsis end |
#type ⇒ Object
Returns the value of attribute type.
52 53 54 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 52 def type @type end |
#vpr ⇒ Object
Returns the value of attribute vpr.
54 55 56 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 54 def vpr @vpr end |
#vpr_severity ⇒ Object
Returns the value of attribute vpr_severity.
56 57 58 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 56 def vpr_severity @vpr_severity end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 59 def self.attribute_map { :'cpe' => :'cpe', :'exploit_ease' => :'exploit_ease', :'family' => :'family', :'plugin_id' => :'plugin_id', :'plugin_name' => :'plugin_name', :'port' => :'port', :'severity' => :'severity', :'solution' => :'solution', :'synopsis' => :'synopsis', :'type' => :'type', :'vpr' => :'vpr', :'vpr_severity' => :'vpr_severity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 253 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 82 def self.openapi_types { :'cpe' => :'Array<String>', :'exploit_ease' => :'String', :'family' => :'String', :'plugin_id' => :'String', :'plugin_name' => :'String', :'port' => :'Integer', :'severity' => :'String', :'solution' => :'String', :'synopsis' => :'String', :'type' => :'String', :'vpr' => :'Float', :'vpr_severity' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && cpe == o.cpe && exploit_ease == o.exploit_ease && family == o.family && plugin_id == o.plugin_id && plugin_name == o.plugin_name && port == o.port && severity == o.severity && solution == o.solution && synopsis == o.synopsis && type == o.type && vpr == o.vpr && vpr_severity == o.vpr_severity end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 284 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 355 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 260 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 246 def hash [cpe, exploit_ease, family, plugin_id, plugin_name, port, severity, solution, synopsis, type, vpr, vpr_severity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 173 def list_invalid_properties invalid_properties = Array.new if @cpe.nil? invalid_properties.push('invalid value for "cpe", cpe cannot be nil.') end if @family.nil? invalid_properties.push('invalid value for "family", family cannot be nil.') end if @plugin_id.nil? invalid_properties.push('invalid value for "plugin_id", plugin_id cannot be nil.') end if @plugin_name.nil? invalid_properties.push('invalid value for "plugin_name", plugin_name cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @vpr.nil? invalid_properties.push('invalid value for "vpr", vpr cannot be nil.') end if @vpr_severity.nil? invalid_properties.push('invalid value for "vpr_severity", vpr_severity cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_tenable_vuln_metadata.rb', line 208 def valid? return false if @cpe.nil? return false if @family.nil? return false if @plugin_id.nil? return false if @plugin_name.nil? return false if @severity.nil? return false if @vpr.nil? return false if @vpr_severity.nil? true end |