Class: Falcon::VulnerabilitymetadataapiVulnerabilityProviderMetadata

Inherits:
Object
  • Object
show all
Defined in:
lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VulnerabilitymetadataapiVulnerabilityProviderMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::VulnerabilitymetadataapiVulnerabilityProviderMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::VulnerabilitymetadataapiVulnerabilityProviderMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_alias')
    self._alias = attributes[:'_alias']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'created_timestamp')
    self.created_timestamp = attributes[:'created_timestamp']
  end

  if attributes.key?(:'cve_ids')
    if (value = attributes[:'cve_ids']).is_a?(Array)
      self.cve_ids = value
    end
  end

  if attributes.key?(:'cwe_ids')
    if (value = attributes[:'cwe_ids']).is_a?(Array)
      self.cwe_ids = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'impact')
    self.impact = attributes[:'impact']
  end

  if attributes.key?(:'is_evaluation_supported')
    self.is_evaluation_supported = attributes[:'is_evaluation_supported']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'provider_metadata')
    self. = attributes[:'provider_metadata']
  end

  if attributes.key?(:'references')
    if (value = attributes[:'references']).is_a?(Array)
      self.references = value
    end
  end

  if attributes.key?(:'risk_metadata')
    self. = attributes[:'risk_metadata']
  end

  if attributes.key?(:'source_created_timestamp')
    self.source_created_timestamp = attributes[:'source_created_timestamp']
  end

  if attributes.key?(:'source_updated_timestamp')
    self.source_updated_timestamp = attributes[:'source_updated_timestamp']
  end

  if attributes.key?(:'supported_finding_providers')
    if (value = attributes[:'supported_finding_providers']).is_a?(Array)
      self.supported_finding_providers = value
    end
  end

  if attributes.key?(:'supported_finding_providers_full_name')
    if (value = attributes[:'supported_finding_providers_full_name']).is_a?(Array)
      self.supported_finding_providers_full_name = value
    end
  end

  if attributes.key?(:'updated_timestamp')
    self.updated_timestamp = attributes[:'updated_timestamp']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#_aliasObject

Returns the value of attribute _alias.



34
35
36
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 34

def _alias
  @_alias
end

#cidObject

Returns the value of attribute cid.



36
37
38
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 36

def cid
  @cid
end

#created_timestampObject

Returns the value of attribute created_timestamp.



38
39
40
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 38

def created_timestamp
  @created_timestamp
end

#cve_idsObject

Returns the value of attribute cve_ids.



40
41
42
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 40

def cve_ids
  @cve_ids
end

#cwe_idsObject

Returns the value of attribute cwe_ids.



42
43
44
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 42

def cwe_ids
  @cwe_ids
end

#descriptionObject

Returns the value of attribute description.



44
45
46
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 44

def description
  @description
end

#idObject

Returns the value of attribute id.



46
47
48
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 46

def id
  @id
end

#impactObject

Returns the value of attribute impact.



48
49
50
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 48

def impact
  @impact
end

#is_evaluation_supportedObject

Returns the value of attribute is_evaluation_supported.



50
51
52
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 50

def is_evaluation_supported
  @is_evaluation_supported
end

#providerObject

Returns the value of attribute provider.



52
53
54
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 52

def provider
  @provider
end

#provider_metadataObject

Returns the value of attribute provider_metadata.



54
55
56
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 54

def 
  @provider_metadata
end

#referencesObject

Returns the value of attribute references.



56
57
58
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 56

def references
  @references
end

#risk_metadataObject

Returns the value of attribute risk_metadata.



58
59
60
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 58

def 
  @risk_metadata
end

#source_created_timestampObject

Returns the value of attribute source_created_timestamp.



60
61
62
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 60

def source_created_timestamp
  @source_created_timestamp
end

#source_updated_timestampObject

Returns the value of attribute source_updated_timestamp.



62
63
64
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 62

def source_updated_timestamp
  @source_updated_timestamp
end

#supported_finding_providersObject

Returns the value of attribute supported_finding_providers.



64
65
66
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 64

def supported_finding_providers
  @supported_finding_providers
end

#supported_finding_providers_full_nameObject

Returns the value of attribute supported_finding_providers_full_name.



66
67
68
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 66

def supported_finding_providers_full_name
  @supported_finding_providers_full_name
end

#updated_timestampObject

Returns the value of attribute updated_timestamp.



68
69
70
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 68

def updated_timestamp
  @updated_timestamp
end

#versionObject

Returns the value of attribute version.



70
71
72
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 70

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 73

def self.attribute_map
  {
    :'_alias' => :'alias',
    :'cid' => :'cid',
    :'created_timestamp' => :'created_timestamp',
    :'cve_ids' => :'cve_ids',
    :'cwe_ids' => :'cwe_ids',
    :'description' => :'description',
    :'id' => :'id',
    :'impact' => :'impact',
    :'is_evaluation_supported' => :'is_evaluation_supported',
    :'provider' => :'provider',
    :'provider_metadata' => :'provider_metadata',
    :'references' => :'references',
    :'risk_metadata' => :'risk_metadata',
    :'source_created_timestamp' => :'source_created_timestamp',
    :'source_updated_timestamp' => :'source_updated_timestamp',
    :'supported_finding_providers' => :'supported_finding_providers',
    :'supported_finding_providers_full_name' => :'supported_finding_providers_full_name',
    :'updated_timestamp' => :'updated_timestamp',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 369

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 103

def self.openapi_types
  {
    :'_alias' => :'String',
    :'cid' => :'String',
    :'created_timestamp' => :'Time',
    :'cve_ids' => :'Array<String>',
    :'cwe_ids' => :'Array<String>',
    :'description' => :'String',
    :'id' => :'String',
    :'impact' => :'VulnerabilitymetadataapiImpact',
    :'is_evaluation_supported' => :'Boolean',
    :'provider' => :'String',
    :'provider_metadata' => :'VulnerabilitymetadataapiProviderMetadata',
    :'references' => :'Array<VulnerabilitymetadataapiReference>',
    :'risk_metadata' => :'VulnerabilitymetadataapiRiskMetadata',
    :'source_created_timestamp' => :'Time',
    :'source_updated_timestamp' => :'Time',
    :'supported_finding_providers' => :'Array<String>',
    :'supported_finding_providers_full_name' => :'Array<String>',
    :'updated_timestamp' => :'Time',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 330

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _alias == o._alias &&
      cid == o.cid &&
      created_timestamp == o.created_timestamp &&
      cve_ids == o.cve_ids &&
      cwe_ids == o.cwe_ids &&
      description == o.description &&
      id == o.id &&
      impact == o.impact &&
      is_evaluation_supported == o.is_evaluation_supported &&
      provider == o.provider &&
       == o. &&
      references == o.references &&
       == o. &&
      source_created_timestamp == o.source_created_timestamp &&
      source_updated_timestamp == o.source_updated_timestamp &&
      supported_finding_providers == o.supported_finding_providers &&
      supported_finding_providers_full_name == o.supported_finding_providers_full_name &&
      updated_timestamp == o.updated_timestamp &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 400

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Falcon.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 471

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 376

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


356
357
358
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 356

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



362
363
364
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 362

def hash
  [_alias, cid, created_timestamp, cve_ids, cwe_ids, description, id, impact, is_evaluation_supported, provider, , references, , source_created_timestamp, source_updated_timestamp, supported_finding_providers, supported_finding_providers_full_name, updated_timestamp, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 237

def list_invalid_properties
  invalid_properties = Array.new
  if @_alias.nil?
    invalid_properties.push('invalid value for "_alias", _alias cannot be nil.')
  end

  if @cid.nil?
    invalid_properties.push('invalid value for "cid", cid cannot be nil.')
  end

  if @created_timestamp.nil?
    invalid_properties.push('invalid value for "created_timestamp", created_timestamp cannot be nil.')
  end

  if @cve_ids.nil?
    invalid_properties.push('invalid value for "cve_ids", cve_ids cannot be nil.')
  end

  if @cwe_ids.nil?
    invalid_properties.push('invalid value for "cwe_ids", cwe_ids cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @impact.nil?
    invalid_properties.push('invalid value for "impact", impact cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @provider_metadata.nil?
    invalid_properties.push('invalid value for "provider_metadata", provider_metadata cannot be nil.')
  end

  if @references.nil?
    invalid_properties.push('invalid value for "references", references cannot be nil.')
  end

  if @risk_metadata.nil?
    invalid_properties.push('invalid value for "risk_metadata", risk_metadata cannot be nil.')
  end

  if @source_created_timestamp.nil?
    invalid_properties.push('invalid value for "source_created_timestamp", source_created_timestamp cannot be nil.')
  end

  if @source_updated_timestamp.nil?
    invalid_properties.push('invalid value for "source_updated_timestamp", source_updated_timestamp cannot be nil.')
  end

  if @updated_timestamp.nil?
    invalid_properties.push('invalid value for "updated_timestamp", updated_timestamp cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



447
448
449
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 447

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 453

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



441
442
443
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 441

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/crimson-falcon/models/vulnerabilitymetadataapi_vulnerability_provider_metadata.rb', line 308

def valid?
  return false if @_alias.nil?
  return false if @cid.nil?
  return false if @created_timestamp.nil?
  return false if @cve_ids.nil?
  return false if @cwe_ids.nil?
  return false if @description.nil?
  return false if @id.nil?
  return false if @impact.nil?
  return false if @provider.nil?
  return false if @provider_metadata.nil?
  return false if @references.nil?
  return false if @risk_metadata.nil?
  return false if @source_created_timestamp.nil?
  return false if @source_updated_timestamp.nil?
  return false if @updated_timestamp.nil?
  return false if @version.nil?
  true
end