Class: Falcon::ZeroTrustAssessment
- Inherits:
-
Object
- Object
- Falcon::ZeroTrustAssessment
- Defined in:
- lib/crimson-falcon/api/zero_trust_assessment.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_assessment_v1(ids, opts = {}) ⇒ DomainAssessmentsResponse
Get Zero Trust Assessment data for one or more hosts by providing agent IDs (AID) and a customer ID (CID).
-
#get_assessment_v1_with_http_info(ids, opts = {}) ⇒ Array<(DomainAssessmentsResponse, Integer, Hash)>
Get Zero Trust Assessment data for one or more hosts by providing agent IDs (AID) and a customer ID (CID).
-
#get_assessments_by_score_v1(filter, opts = {}) ⇒ DomainAssessmentsByScoreResponse
Get Zero Trust Assessment data for one or more hosts by providing a customer ID (CID) and a range of scores.
-
#get_assessments_by_score_v1_with_http_info(filter, opts = {}) ⇒ Array<(DomainAssessmentsByScoreResponse, Integer, Hash)>
Get Zero Trust Assessment data for one or more hosts by providing a customer ID (CID) and a range of scores.
-
#get_audit_v1(opts = {}) ⇒ DomainAuditResponse
Get the Zero Trust Assessment audit report for one customer ID (CID).
-
#get_audit_v1_with_http_info(opts = {}) ⇒ Array<(DomainAuditResponse, Integer, Hash)>
Get the Zero Trust Assessment audit report for one customer ID (CID).
-
#initialize(api_client = ApiClient.default) ⇒ ZeroTrustAssessment
constructor
A new instance of ZeroTrustAssessment.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ZeroTrustAssessment
Returns a new instance of ZeroTrustAssessment.
35 36 37 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_assessment_v1(ids, opts = {}) ⇒ DomainAssessmentsResponse
Get Zero Trust Assessment data for one or more hosts by providing agent IDs (AID) and a customer ID (CID).
42 43 44 45 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 42 def get_assessment_v1(ids, opts = {}) data, _status_code, _headers = get_assessment_v1_with_http_info(ids, opts) data end |
#get_assessment_v1_with_http_info(ids, opts = {}) ⇒ Array<(DomainAssessmentsResponse, Integer, Hash)>
Get Zero Trust Assessment data for one or more hosts by providing agent IDs (AID) and a customer ID (CID).
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 51 def get_assessment_v1_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZeroTrustAssessment.get_assessment_v1 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling ZeroTrustAssessment.get_assessment_v1" end # resource path local_var_path = '/zero-trust-assessment/entities/assessments/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainAssessmentsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ZeroTrustAssessment.get_assessment_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZeroTrustAssessment#get_assessment_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_assessments_by_score_v1(filter, opts = {}) ⇒ DomainAssessmentsByScoreResponse
Get Zero Trust Assessment data for one or more hosts by providing a customer ID (CID) and a range of scores.
107 108 109 110 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 107 def get_assessments_by_score_v1(filter, opts = {}) data, _status_code, _headers = get_assessments_by_score_v1_with_http_info(filter, opts) data end |
#get_assessments_by_score_v1_with_http_info(filter, opts = {}) ⇒ Array<(DomainAssessmentsByScoreResponse, Integer, Hash)>
Get Zero Trust Assessment data for one or more hosts by providing a customer ID (CID) and a range of scores.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 119 def get_assessments_by_score_v1_with_http_info(filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZeroTrustAssessment.get_assessments_by_score_v1 ...' end # verify the required parameter 'filter' is set if @api_client.config.client_side_validation && filter.nil? fail ArgumentError, "Missing the required parameter 'filter' when calling ZeroTrustAssessment.get_assessments_by_score_v1" end # resource path local_var_path = '/zero-trust-assessment/queries/assessments/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = filter query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainAssessmentsByScoreResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ZeroTrustAssessment.get_assessments_by_score_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZeroTrustAssessment#get_assessments_by_score_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_v1(opts = {}) ⇒ DomainAuditResponse
Get the Zero Trust Assessment audit report for one customer ID (CID).
174 175 176 177 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 174 def get_audit_v1(opts = {}) data, _status_code, _headers = get_audit_v1_with_http_info(opts) data end |
#get_audit_v1_with_http_info(opts = {}) ⇒ Array<(DomainAuditResponse, Integer, Hash)>
Get the Zero Trust Assessment audit report for one customer ID (CID).
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/crimson-falcon/api/zero_trust_assessment.rb', line 182 def get_audit_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ZeroTrustAssessment.get_audit_v1 ...' end # resource path local_var_path = '/zero-trust-assessment/entities/audit/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainAuditResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ZeroTrustAssessment.get_audit_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ZeroTrustAssessment#get_audit_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |