Class: Falcon::Alerts
- Inherits:
-
Object
- Object
- Falcon::Alerts
- Defined in:
- lib/crimson-falcon/api/alerts.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_queries_alerts_v1(opts = {}) ⇒ DetectsapiAlertQueryResponse
Deprecated: please use version v2 of this endpoint.
-
#get_queries_alerts_v1_with_http_info(opts = {}) ⇒ Array<(DetectsapiAlertQueryResponse, Integer, Hash)>
Deprecated: please use version v2 of this endpoint.
-
#get_queries_alerts_v2(opts = {}) ⇒ DetectsapiAlertQueryResponse
Retrieves all Alerts ids that match a given query.
-
#get_queries_alerts_v2_with_http_info(opts = {}) ⇒ Array<(DetectsapiAlertQueryResponse, Integer, Hash)>
Retrieves all Alerts ids that match a given query.
-
#initialize(api_client = ApiClient.default) ⇒ Alerts
constructor
A new instance of Alerts.
-
#patch_entities_alerts_v2(body, opts = {}) ⇒ DetectsapiResponseFields
Deprecated: Please use version v3 of this endpoint.
-
#patch_entities_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiResponseFields, Integer, Hash)>
Deprecated: Please use version v3 of this endpoint.
-
#patch_entities_alerts_v3(body, opts = {}) ⇒ DetectsapiResponseFields
Perform actions on Alerts identified by composite ID(s) in request.
-
#patch_entities_alerts_v3_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiResponseFields, Integer, Hash)>
Perform actions on Alerts identified by composite ID(s) in request.
-
#post_aggregates_alerts_v1(body, opts = {}) ⇒ DetectsapiAggregatesResponse
Deprecated: Please use version v2 of this endpoint.
-
#post_aggregates_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiAggregatesResponse, Integer, Hash)>
Deprecated: Please use version v2 of this endpoint.
-
#post_aggregates_alerts_v2(body, opts = {}) ⇒ DetectsapiAggregatesResponse
Retrieves aggregate values for Alerts across all CIDs.
-
#post_aggregates_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiAggregatesResponse, Integer, Hash)>
Retrieves aggregate values for Alerts across all CIDs.
-
#post_combined_alerts_v1(body, opts = {}) ⇒ DetectsapiPostCombinedAlertsV1ResponseSwagger
Retrieves all Alerts that match a particular FQL filter.
-
#post_combined_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostCombinedAlertsV1ResponseSwagger, Integer, Hash)>
Retrieves all Alerts that match a particular FQL filter.
-
#post_entities_alerts_v1(body, opts = {}) ⇒ DetectsapiPostEntitiesAlertsV1ResponseSwagger
Deprecated: please use version v2 of this endpoint.
-
#post_entities_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostEntitiesAlertsV1ResponseSwagger, Integer, Hash)>
Deprecated: please use version v2 of this endpoint.
-
#post_entities_alerts_v2(body, opts = {}) ⇒ DetectsapiPostEntitiesAlertsV2ResponseSwagger
Retrieves all Alerts given their composite ids.
-
#post_entities_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostEntitiesAlertsV2ResponseSwagger, Integer, Hash)>
Retrieves all Alerts given their composite ids.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/alerts.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_queries_alerts_v1(opts = {}) ⇒ DetectsapiAlertQueryResponse
Deprecated: please use version v2 of this endpoint. Retrieves all Alerts ids that match a given query.
46 47 48 49 |
# File 'lib/crimson-falcon/api/alerts.rb', line 46 def get_queries_alerts_v1(opts = {}) data, _status_code, _headers = get_queries_alerts_v1_with_http_info(opts) data end |
#get_queries_alerts_v1_with_http_info(opts = {}) ⇒ Array<(DetectsapiAlertQueryResponse, Integer, Hash)>
Deprecated: please use version v2 of this endpoint. Retrieves all Alerts ids that match a given query.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/crimson-falcon/api/alerts.rb', line 59 def get_queries_alerts_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.get_queries_alerts_v1 ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Alerts.get_queries_alerts_v1, must be smaller than or equal to 10000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Alerts.get_queries_alerts_v1, must be greater than or equal to 0.' end # resource path local_var_path = '/alerts/queries/alerts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DetectsapiAlertQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.get_queries_alerts_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#get_queries_alerts_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_queries_alerts_v2(opts = {}) ⇒ DetectsapiAlertQueryResponse
Retrieves all Alerts ids that match a given query.
125 126 127 128 |
# File 'lib/crimson-falcon/api/alerts.rb', line 125 def get_queries_alerts_v2(opts = {}) data, _status_code, _headers = get_queries_alerts_v2_with_http_info(opts) data end |
#get_queries_alerts_v2_with_http_info(opts = {}) ⇒ Array<(DetectsapiAlertQueryResponse, Integer, Hash)>
Retrieves all Alerts ids that match a given query.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/crimson-falcon/api/alerts.rb', line 139 def get_queries_alerts_v2_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.get_queries_alerts_v2 ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 10000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Alerts.get_queries_alerts_v2, must be smaller than or equal to 10000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling Alerts.get_queries_alerts_v2, must be greater than or equal to 0.' end # resource path local_var_path = '/alerts/queries/alerts/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'include_hidden'] = opts[:'include_hidden'] if !opts[:'include_hidden'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DetectsapiAlertQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.get_queries_alerts_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#get_queries_alerts_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_entities_alerts_v2(body, opts = {}) ⇒ DetectsapiResponseFields
Deprecated: Please use version v3 of this endpoint. Perform actions on Alerts identified by composite ID(s) in request. Each action has a name and a description which describes what the action does. If a request adds and removes tag in a single request, the order of processing would be to remove tags before adding new ones in.
201 202 203 204 |
# File 'lib/crimson-falcon/api/alerts.rb', line 201 def patch_entities_alerts_v2(body, opts = {}) data, _status_code, _headers = patch_entities_alerts_v2_with_http_info(body, opts) data end |
#patch_entities_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiResponseFields, Integer, Hash)>
Deprecated: Please use version v3 of this endpoint. Perform actions on Alerts identified by composite ID(s) in request. Each action has a name and a description which describes what the action does. If a request adds and removes tag in a single request, the order of processing would be to remove tags before adding new ones in.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/crimson-falcon/api/alerts.rb', line 210 def patch_entities_alerts_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.patch_entities_alerts_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.patch_entities_alerts_v2" end # resource path local_var_path = '/alerts/entities/alerts/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiResponseFields' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.patch_entities_alerts_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#patch_entities_alerts_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_entities_alerts_v3(body, opts = {}) ⇒ DetectsapiResponseFields
Perform actions on Alerts identified by composite ID(s) in request. Each action has a name and a description which describes what the action does. If a request adds and removes tag in a single request, the order of processing would be to remove tags before adding new ones in.
268 269 270 271 |
# File 'lib/crimson-falcon/api/alerts.rb', line 268 def patch_entities_alerts_v3(body, opts = {}) data, _status_code, _headers = patch_entities_alerts_v3_with_http_info(body, opts) data end |
#patch_entities_alerts_v3_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiResponseFields, Integer, Hash)>
Perform actions on Alerts identified by composite ID(s) in request. Each action has a name and a description which describes what the action does. If a request adds and removes tag in a single request, the order of processing would be to remove tags before adding new ones in.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/crimson-falcon/api/alerts.rb', line 278 def patch_entities_alerts_v3_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.patch_entities_alerts_v3 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.patch_entities_alerts_v3" end # resource path local_var_path = '/alerts/entities/alerts/v3' # query parameters query_params = opts[:query_params] || {} query_params[:'include_hidden'] = opts[:'include_hidden'] if !opts[:'include_hidden'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiResponseFields' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.patch_entities_alerts_v3", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#patch_entities_alerts_v3\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_aggregates_alerts_v1(body, opts = {}) ⇒ DetectsapiAggregatesResponse
Deprecated: Please use version v2 of this endpoint. Retrieves aggregate values for Alerts across all CIDs.
336 337 338 339 |
# File 'lib/crimson-falcon/api/alerts.rb', line 336 def post_aggregates_alerts_v1(body, opts = {}) data, _status_code, _headers = post_aggregates_alerts_v1_with_http_info(body, opts) data end |
#post_aggregates_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiAggregatesResponse, Integer, Hash)>
Deprecated: Please use version v2 of this endpoint. Retrieves aggregate values for Alerts across all CIDs.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/crimson-falcon/api/alerts.rb', line 345 def post_aggregates_alerts_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.post_aggregates_alerts_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.post_aggregates_alerts_v1" end # resource path local_var_path = '/alerts/aggregates/alerts/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.post_aggregates_alerts_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#post_aggregates_alerts_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_aggregates_alerts_v2(body, opts = {}) ⇒ DetectsapiAggregatesResponse
Retrieves aggregate values for Alerts across all CIDs.
403 404 405 406 |
# File 'lib/crimson-falcon/api/alerts.rb', line 403 def post_aggregates_alerts_v2(body, opts = {}) data, _status_code, _headers = post_aggregates_alerts_v2_with_http_info(body, opts) data end |
#post_aggregates_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiAggregatesResponse, Integer, Hash)>
Retrieves aggregate values for Alerts across all CIDs.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/crimson-falcon/api/alerts.rb', line 413 def post_aggregates_alerts_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.post_aggregates_alerts_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.post_aggregates_alerts_v2" end # resource path local_var_path = '/alerts/aggregates/alerts/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'include_hidden'] = opts[:'include_hidden'] if !opts[:'include_hidden'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.post_aggregates_alerts_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#post_aggregates_alerts_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_combined_alerts_v1(body, opts = {}) ⇒ DetectsapiPostCombinedAlertsV1ResponseSwagger
Retrieves all Alerts that match a particular FQL filter. This API is intended for retrieval of large amounts of Alerts(>10k) using a pagination based on a ‘after` token. If you need to use `offset` pagination, consider using GET /alerts/queries/alerts/* and POST /alerts/entities/alerts/* APIs.
471 472 473 474 |
# File 'lib/crimson-falcon/api/alerts.rb', line 471 def post_combined_alerts_v1(body, opts = {}) data, _status_code, _headers = post_combined_alerts_v1_with_http_info(body, opts) data end |
#post_combined_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostCombinedAlertsV1ResponseSwagger, Integer, Hash)>
Retrieves all Alerts that match a particular FQL filter. This API is intended for retrieval of large amounts of Alerts(>10k) using a pagination based on a `after` token. If you need to use `offset` pagination, consider using GET /alerts/queries/alerts/* and POST /alerts/entities/alerts/* APIs.
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/crimson-falcon/api/alerts.rb', line 480 def post_combined_alerts_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.post_combined_alerts_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.post_combined_alerts_v1" end # resource path local_var_path = '/alerts/combined/alerts/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiPostCombinedAlertsV1ResponseSwagger' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.post_combined_alerts_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#post_combined_alerts_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_entities_alerts_v1(body, opts = {}) ⇒ DetectsapiPostEntitiesAlertsV1ResponseSwagger
Deprecated: please use version v2 of this endpoint. Retrieves all Alerts given their ids.
537 538 539 540 |
# File 'lib/crimson-falcon/api/alerts.rb', line 537 def post_entities_alerts_v1(body, opts = {}) data, _status_code, _headers = post_entities_alerts_v1_with_http_info(body, opts) data end |
#post_entities_alerts_v1_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostEntitiesAlertsV1ResponseSwagger, Integer, Hash)>
Deprecated: please use version v2 of this endpoint. Retrieves all Alerts given their ids.
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/crimson-falcon/api/alerts.rb', line 546 def post_entities_alerts_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.post_entities_alerts_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.post_entities_alerts_v1" end # resource path local_var_path = '/alerts/entities/alerts/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiPostEntitiesAlertsV1ResponseSwagger' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.post_entities_alerts_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#post_entities_alerts_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_entities_alerts_v2(body, opts = {}) ⇒ DetectsapiPostEntitiesAlertsV2ResponseSwagger
Retrieves all Alerts given their composite ids.
604 605 606 607 |
# File 'lib/crimson-falcon/api/alerts.rb', line 604 def post_entities_alerts_v2(body, opts = {}) data, _status_code, _headers = post_entities_alerts_v2_with_http_info(body, opts) data end |
#post_entities_alerts_v2_with_http_info(body, opts = {}) ⇒ Array<(DetectsapiPostEntitiesAlertsV2ResponseSwagger, Integer, Hash)>
Retrieves all Alerts given their composite ids.
614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'lib/crimson-falcon/api/alerts.rb', line 614 def post_entities_alerts_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Alerts.post_entities_alerts_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling Alerts.post_entities_alerts_v2" end # resource path local_var_path = '/alerts/entities/alerts/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'include_hidden'] = opts[:'include_hidden'] if !opts[:'include_hidden'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DetectsapiPostEntitiesAlertsV2ResponseSwagger' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"Alerts.post_entities_alerts_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Alerts#post_entities_alerts_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |