Class: Falcon::ApiNotificationExposedDataRecordV1
- Inherits:
-
Object
- Object
- Falcon::ApiNotificationExposedDataRecordV1
- Defined in:
- lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb
Instance Attribute Summary collapse
-
#author ⇒ Object
The individual or group who exposed the data.
-
#author_id ⇒ Object
The ID of the author within Recon.
-
#bot ⇒ Object
Returns the value of attribute bot.
-
#cid ⇒ Object
The customer ID.
-
#company ⇒ Object
The company of the user.
-
#created_date ⇒ Object
The date when this entity was created in Recon.
-
#credential_status ⇒ Object
The status set after deduplication.
-
#credentials_domain ⇒ Object
The domain where the credentials are valid.
-
#credentials_ip ⇒ Object
The IP where the credentials are valid.
-
#credentials_url ⇒ Object
The URL where the credentials are valid.
-
#display_name ⇒ Object
The nickname of the user on the impacted site.
-
#domain ⇒ Object
The domain of the email linked to the impacted site.
-
#email ⇒ Object
The email linked to the impacted site.
-
#event_date ⇒ Object
The approximate date when the event occurred.
-
#exposure_date ⇒ Object
The date when the exposed data was posted online.
-
#file ⇒ Object
Returns the value of attribute file.
-
#financial ⇒ Object
Returns the value of attribute financial.
-
#full_name ⇒ Object
The full name of the user on the impacted site.
-
#hash_type ⇒ Object
The algorithm used to hash the password.
-
#id ⇒ Object
The ID of this entity.
-
#job_position ⇒ Object
The users job at the company.
-
#location ⇒ Object
Returns the value of attribute location.
-
#login_id ⇒ Object
Returns the value of attribute login_id.
-
#malware_family ⇒ Object
Information of the bot malware family.
-
#notification_group_id ⇒ Object
The thread group ID of the parent notification associated with this entity.
-
#notification_id ⇒ Object
The ID of the parent notification associated with this entity.
-
#password ⇒ Object
The password used for login.
-
#password_hash ⇒ Object
The password hash.
-
#password_salt ⇒ Object
The password salt.
-
#phone_number ⇒ Object
The phone number of the user on the impacted site.
-
#raw_intel_id ⇒ Object
Returns the value of attribute raw_intel_id.
-
#rule ⇒ Object
Returns the value of attribute rule.
-
#site ⇒ Object
The source where this entity was found.
-
#site_id ⇒ Object
The ID of the site within Recon.
-
#social ⇒ Object
Returns the value of attribute social.
-
#source_category ⇒ Object
The category of the source where this entity was found.
-
#user_id ⇒ Object
The ID of the user on the impacted site.
-
#user_ip ⇒ Object
The IP of the user on the impacted site.
-
#user_uuid ⇒ Object
Returns the value of attribute user_uuid.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiNotificationExposedDataRecordV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApiNotificationExposedDataRecordV1
Initializes the object
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 245 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApiNotificationExposedDataRecordV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApiNotificationExposedDataRecordV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'author') self. = attributes[:'author'] end if attributes.key?(:'author_id') self. = attributes[:'author_id'] end if attributes.key?(:'bot') self.bot = attributes[:'bot'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'created_date') self.created_date = attributes[:'created_date'] end if attributes.key?(:'credential_status') self.credential_status = attributes[:'credential_status'] end if attributes.key?(:'credentials_domain') self.credentials_domain = attributes[:'credentials_domain'] end if attributes.key?(:'credentials_ip') self.credentials_ip = attributes[:'credentials_ip'] end if attributes.key?(:'credentials_url') self.credentials_url = attributes[:'credentials_url'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'event_date') self.event_date = attributes[:'event_date'] end if attributes.key?(:'exposure_date') self.exposure_date = attributes[:'exposure_date'] end if attributes.key?(:'file') self.file = attributes[:'file'] end if attributes.key?(:'financial') self.financial = attributes[:'financial'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'hash_type') self.hash_type = attributes[:'hash_type'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'job_position') self.job_position = attributes[:'job_position'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'login_id') self.login_id = attributes[:'login_id'] end if attributes.key?(:'malware_family') self.malware_family = attributes[:'malware_family'] end if attributes.key?(:'notification_group_id') self.notification_group_id = attributes[:'notification_group_id'] end if attributes.key?(:'notification_id') self.notification_id = attributes[:'notification_id'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'password_hash') self.password_hash = attributes[:'password_hash'] end if attributes.key?(:'password_salt') self.password_salt = attributes[:'password_salt'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'raw_intel_id') self.raw_intel_id = attributes[:'raw_intel_id'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'site') self.site = attributes[:'site'] end if attributes.key?(:'site_id') self.site_id = attributes[:'site_id'] end if attributes.key?(:'social') self. = attributes[:'social'] end if attributes.key?(:'source_category') self.source_category = attributes[:'source_category'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'user_ip') self.user_ip = attributes[:'user_ip'] end if attributes.key?(:'user_uuid') self.user_uuid = attributes[:'user_uuid'] end end |
Instance Attribute Details
#author ⇒ Object
The individual or group who exposed the data
35 36 37 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 35 def @author end |
#author_id ⇒ Object
The ID of the author within Recon
38 39 40 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 38 def @author_id end |
#bot ⇒ Object
Returns the value of attribute bot.
40 41 42 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 40 def bot @bot end |
#cid ⇒ Object
The customer ID
43 44 45 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 43 def cid @cid end |
#company ⇒ Object
The company of the user
46 47 48 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 46 def company @company end |
#created_date ⇒ Object
The date when this entity was created in Recon
49 50 51 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 49 def created_date @created_date end |
#credential_status ⇒ Object
The status set after deduplication. Possible values: ‘newly_detected’, ‘previously_reported’, ‘other’
52 53 54 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 52 def credential_status @credential_status end |
#credentials_domain ⇒ Object
The domain where the credentials are valid
55 56 57 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 55 def credentials_domain @credentials_domain end |
#credentials_ip ⇒ Object
The IP where the credentials are valid
58 59 60 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 58 def credentials_ip @credentials_ip end |
#credentials_url ⇒ Object
The URL where the credentials are valid
61 62 63 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 61 def credentials_url @credentials_url end |
#display_name ⇒ Object
The nickname of the user on the impacted site
64 65 66 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 64 def display_name @display_name end |
#domain ⇒ Object
The domain of the email linked to the impacted site
67 68 69 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 67 def domain @domain end |
#email ⇒ Object
The email linked to the impacted site
70 71 72 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 70 def email @email end |
#event_date ⇒ Object
The approximate date when the event occurred
73 74 75 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 73 def event_date @event_date end |
#exposure_date ⇒ Object
The date when the exposed data was posted online
76 77 78 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 76 def exposure_date @exposure_date end |
#file ⇒ Object
Returns the value of attribute file.
78 79 80 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 78 def file @file end |
#financial ⇒ Object
Returns the value of attribute financial.
80 81 82 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 80 def financial @financial end |
#full_name ⇒ Object
The full name of the user on the impacted site
83 84 85 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 83 def full_name @full_name end |
#hash_type ⇒ Object
The algorithm used to hash the password
86 87 88 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 86 def hash_type @hash_type end |
#id ⇒ Object
The ID of this entity
89 90 91 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 89 def id @id end |
#job_position ⇒ Object
The users job at the company
92 93 94 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 92 def job_position @job_position end |
#location ⇒ Object
Returns the value of attribute location.
94 95 96 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 94 def location @location end |
#login_id ⇒ Object
Returns the value of attribute login_id.
96 97 98 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 96 def login_id @login_id end |
#malware_family ⇒ Object
Information of the bot malware family
99 100 101 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 99 def malware_family @malware_family end |
#notification_group_id ⇒ Object
The thread group ID of the parent notification associated with this entity
102 103 104 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 102 def notification_group_id @notification_group_id end |
#notification_id ⇒ Object
The ID of the parent notification associated with this entity
105 106 107 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 105 def notification_id @notification_id end |
#password ⇒ Object
The password used for login
108 109 110 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 108 def password @password end |
#password_hash ⇒ Object
The password hash
111 112 113 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 111 def password_hash @password_hash end |
#password_salt ⇒ Object
The password salt
114 115 116 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 114 def password_salt @password_salt end |
#phone_number ⇒ Object
The phone number of the user on the impacted site
117 118 119 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 117 def phone_number @phone_number end |
#raw_intel_id ⇒ Object
Returns the value of attribute raw_intel_id.
119 120 121 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 119 def raw_intel_id @raw_intel_id end |
#rule ⇒ Object
Returns the value of attribute rule.
121 122 123 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 121 def rule @rule end |
#site ⇒ Object
The source where this entity was found
124 125 126 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 124 def site @site end |
#site_id ⇒ Object
The ID of the site within Recon
127 128 129 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 127 def site_id @site_id end |
#social ⇒ Object
Returns the value of attribute social.
129 130 131 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 129 def @social end |
#source_category ⇒ Object
The category of the source where this entity was found
132 133 134 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 132 def source_category @source_category end |
#user_id ⇒ Object
The ID of the user on the impacted site
135 136 137 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 135 def user_id @user_id end |
#user_ip ⇒ Object
The IP of the user on the impacted site
138 139 140 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 138 def user_ip @user_ip end |
#user_uuid ⇒ Object
Returns the value of attribute user_uuid.
140 141 142 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 140 def user_uuid @user_uuid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
188 189 190 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 188 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 143 def self.attribute_map { :'author' => :'author', :'author_id' => :'author_id', :'bot' => :'bot', :'cid' => :'cid', :'company' => :'company', :'created_date' => :'created_date', :'credential_status' => :'credential_status', :'credentials_domain' => :'credentials_domain', :'credentials_ip' => :'credentials_ip', :'credentials_url' => :'credentials_url', :'display_name' => :'display_name', :'domain' => :'domain', :'email' => :'email', :'event_date' => :'event_date', :'exposure_date' => :'exposure_date', :'file' => :'file', :'financial' => :'financial', :'full_name' => :'full_name', :'hash_type' => :'hash_type', :'id' => :'id', :'job_position' => :'job_position', :'location' => :'location', :'login_id' => :'login_id', :'malware_family' => :'malware_family', :'notification_group_id' => :'notification_group_id', :'notification_id' => :'notification_id', :'password' => :'password', :'password_hash' => :'password_hash', :'password_salt' => :'password_salt', :'phone_number' => :'phone_number', :'raw_intel_id' => :'raw_intel_id', :'rule' => :'rule', :'site' => :'site', :'site_id' => :'site_id', :'social' => :'social', :'source_category' => :'source_category', :'user_id' => :'user_id', :'user_ip' => :'user_ip', :'user_uuid' => :'user_uuid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
549 550 551 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 549 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
238 239 240 241 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 238 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 193 def self.openapi_types { :'author' => :'String', :'author_id' => :'String', :'bot' => :'ApiExposedDataRecordBotV1', :'cid' => :'String', :'company' => :'String', :'created_date' => :'Time', :'credential_status' => :'String', :'credentials_domain' => :'String', :'credentials_ip' => :'String', :'credentials_url' => :'String', :'display_name' => :'String', :'domain' => :'String', :'email' => :'String', :'event_date' => :'String', :'exposure_date' => :'Time', :'file' => :'ApiExposedDataFileDetailsV1', :'financial' => :'ApiExposedDataRecordFinancialV1', :'full_name' => :'String', :'hash_type' => :'String', :'id' => :'String', :'job_position' => :'String', :'location' => :'ApiExposedDataRecordLocationV1', :'login_id' => :'String', :'malware_family' => :'String', :'notification_group_id' => :'String', :'notification_id' => :'String', :'password' => :'String', :'password_hash' => :'String', :'password_salt' => :'String', :'phone_number' => :'String', :'raw_intel_id' => :'String', :'rule' => :'ApiRuleDetailsV1', :'site' => :'String', :'site_id' => :'String', :'social' => :'ApiExposedDataRecordSocialV1', :'source_category' => :'String', :'user_id' => :'String', :'user_ip' => :'String', :'user_uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 490 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && == o. && bot == o.bot && cid == o.cid && company == o.company && created_date == o.created_date && credential_status == o.credential_status && credentials_domain == o.credentials_domain && credentials_ip == o.credentials_ip && credentials_url == o.credentials_url && display_name == o.display_name && domain == o.domain && email == o.email && event_date == o.event_date && exposure_date == o.exposure_date && file == o.file && financial == o.financial && full_name == o.full_name && hash_type == o.hash_type && id == o.id && job_position == o.job_position && location == o.location && login_id == o.login_id && malware_family == o.malware_family && notification_group_id == o.notification_group_id && notification_id == o.notification_id && password == o.password && password_hash == o.password_hash && password_salt == o.password_salt && phone_number == o.phone_number && raw_intel_id == o.raw_intel_id && rule == o.rule && site == o.site && site_id == o.site_id && == o. && source_category == o.source_category && user_id == o.user_id && user_ip == o.user_ip && user_uuid == o.user_uuid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 580 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 651 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 556 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
536 537 538 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 536 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
542 543 544 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 542 def hash [, , bot, cid, company, created_date, credential_status, credentials_domain, credentials_ip, credentials_url, display_name, domain, email, event_date, exposure_date, file, financial, full_name, hash_type, id, job_position, location, login_id, malware_family, notification_group_id, notification_id, password, password_hash, password_salt, phone_number, raw_intel_id, rule, site, site_id, , source_category, user_id, user_ip, user_uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 417 def list_invalid_properties invalid_properties = Array.new if @author.nil? invalid_properties.push('invalid value for "author", author cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @created_date.nil? invalid_properties.push('invalid value for "created_date", created_date cannot be nil.') end if @event_date.nil? invalid_properties.push('invalid value for "event_date", event_date cannot be nil.') end if @exposure_date.nil? invalid_properties.push('invalid value for "exposure_date", exposure_date cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @notification_id.nil? invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.') end if @raw_intel_id.nil? invalid_properties.push('invalid value for "raw_intel_id", raw_intel_id cannot be nil.') end if @rule.nil? invalid_properties.push('invalid value for "rule", rule cannot be nil.') end if @site.nil? invalid_properties.push('invalid value for "site", site cannot be nil.') end if @source_category.nil? invalid_properties.push('invalid value for "source_category", source_category cannot be nil.') end if @user_uuid.nil? invalid_properties.push('invalid value for "user_uuid", user_uuid cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
627 628 629 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 627 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 633 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
621 622 623 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 621 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/crimson-falcon/models/api_notification_exposed_data_record_v1.rb', line 472 def valid? return false if @author.nil? return false if @cid.nil? return false if @created_date.nil? return false if @event_date.nil? return false if @exposure_date.nil? return false if @id.nil? return false if @notification_id.nil? return false if @raw_intel_id.nil? return false if @rule.nil? return false if @site.nil? return false if @source_category.nil? return false if @user_uuid.nil? true end |