Class: Falcon::ApimodelsSuppressionRule
- Inherits:
-
Object
- Object
- Falcon::ApimodelsSuppressionRule
- Defined in:
- lib/crimson-falcon/models/apimodels_suppression_rule.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#deleted_by ⇒ Object
Returns the value of attribute deleted_by.
-
#description ⇒ Object
Returns the value of attribute description.
-
#disabled ⇒ Object
Returns the value of attribute disabled.
-
#domain ⇒ Object
Returns the value of attribute domain.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#rule_ids ⇒ Object
Returns the value of attribute rule_ids.
-
#rule_selection_count ⇒ Object
Returns the value of attribute rule_selection_count.
-
#rule_selection_filter ⇒ Object
Returns the value of attribute rule_selection_filter.
-
#rule_selection_type ⇒ Object
Returns the value of attribute rule_selection_type.
-
#scope_asset_filter ⇒ Object
Returns the value of attribute scope_asset_filter.
-
#scope_type ⇒ Object
Returns the value of attribute scope_type.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#suppression_comment ⇒ Object
Returns the value of attribute suppression_comment.
-
#suppression_expiration_date ⇒ Object
Returns the value of attribute suppression_expiration_date.
-
#suppression_reason ⇒ Object
Returns the value of attribute suppression_reason.
-
#update_reason ⇒ Object
Returns the value of attribute update_reason.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#updated_by ⇒ Object
Returns the value of attribute updated_by.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApimodelsSuppressionRule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApimodelsSuppressionRule
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 147 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ApimodelsSuppressionRule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ApimodelsSuppressionRule`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'deleted_by') self.deleted_by = attributes[:'deleted_by'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'rule_ids') if (value = attributes[:'rule_ids']).is_a?(Array) self.rule_ids = value end end if attributes.key?(:'rule_selection_count') self.rule_selection_count = attributes[:'rule_selection_count'] end if attributes.key?(:'rule_selection_filter') self.rule_selection_filter = attributes[:'rule_selection_filter'] end if attributes.key?(:'rule_selection_type') self.rule_selection_type = attributes[:'rule_selection_type'] end if attributes.key?(:'scope_asset_filter') self.scope_asset_filter = attributes[:'scope_asset_filter'] end if attributes.key?(:'scope_type') self.scope_type = attributes[:'scope_type'] end if attributes.key?(:'subdomain') self.subdomain = attributes[:'subdomain'] end if attributes.key?(:'suppression_comment') self.suppression_comment = attributes[:'suppression_comment'] end if attributes.key?(:'suppression_expiration_date') self.suppression_expiration_date = attributes[:'suppression_expiration_date'] end if attributes.key?(:'suppression_reason') self.suppression_reason = attributes[:'suppression_reason'] end if attributes.key?(:'update_reason') self.update_reason = attributes[:'update_reason'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 34 def created_at @created_at end |
#created_by ⇒ Object
Returns the value of attribute created_by.
36 37 38 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 36 def created_by @created_by end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
38 39 40 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 38 def deleted_at @deleted_at end |
#deleted_by ⇒ Object
Returns the value of attribute deleted_by.
40 41 42 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 40 def deleted_by @deleted_by end |
#description ⇒ Object
Returns the value of attribute description.
42 43 44 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 42 def description @description end |
#disabled ⇒ Object
Returns the value of attribute disabled.
44 45 46 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 44 def disabled @disabled end |
#domain ⇒ Object
Returns the value of attribute domain.
46 47 48 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 46 def domain @domain end |
#id ⇒ Object
Returns the value of attribute id.
48 49 50 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 48 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
50 51 52 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 50 def name @name end |
#rule_ids ⇒ Object
Returns the value of attribute rule_ids.
52 53 54 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 52 def rule_ids @rule_ids end |
#rule_selection_count ⇒ Object
Returns the value of attribute rule_selection_count.
54 55 56 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 54 def rule_selection_count @rule_selection_count end |
#rule_selection_filter ⇒ Object
Returns the value of attribute rule_selection_filter.
56 57 58 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 56 def rule_selection_filter @rule_selection_filter end |
#rule_selection_type ⇒ Object
Returns the value of attribute rule_selection_type.
58 59 60 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 58 def rule_selection_type @rule_selection_type end |
#scope_asset_filter ⇒ Object
Returns the value of attribute scope_asset_filter.
60 61 62 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 60 def scope_asset_filter @scope_asset_filter end |
#scope_type ⇒ Object
Returns the value of attribute scope_type.
62 63 64 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 62 def scope_type @scope_type end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
64 65 66 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 64 def subdomain @subdomain end |
#suppression_comment ⇒ Object
Returns the value of attribute suppression_comment.
66 67 68 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 66 def suppression_comment @suppression_comment end |
#suppression_expiration_date ⇒ Object
Returns the value of attribute suppression_expiration_date.
68 69 70 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 68 def suppression_expiration_date @suppression_expiration_date end |
#suppression_reason ⇒ Object
Returns the value of attribute suppression_reason.
70 71 72 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 70 def suppression_reason @suppression_reason end |
#update_reason ⇒ Object
Returns the value of attribute update_reason.
72 73 74 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 72 def update_reason @update_reason end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
74 75 76 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 74 def updated_at @updated_at end |
#updated_by ⇒ Object
Returns the value of attribute updated_by.
76 77 78 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 76 def updated_by @updated_by end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
107 108 109 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 107 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 79 def self.attribute_map { :'created_at' => :'created_at', :'created_by' => :'created_by', :'deleted_at' => :'deleted_at', :'deleted_by' => :'deleted_by', :'description' => :'description', :'disabled' => :'disabled', :'domain' => :'domain', :'id' => :'id', :'name' => :'name', :'rule_ids' => :'rule_ids', :'rule_selection_count' => :'rule_selection_count', :'rule_selection_filter' => :'rule_selection_filter', :'rule_selection_type' => :'rule_selection_type', :'scope_asset_filter' => :'scope_asset_filter', :'scope_type' => :'scope_type', :'subdomain' => :'subdomain', :'suppression_comment' => :'suppression_comment', :'suppression_expiration_date' => :'suppression_expiration_date', :'suppression_reason' => :'suppression_reason', :'update_reason' => :'update_reason', :'updated_at' => :'updated_at', :'updated_by' => :'updated_by' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
363 364 365 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 363 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
140 141 142 143 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 140 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 112 def self.openapi_types { :'created_at' => :'Time', :'created_by' => :'String', :'deleted_at' => :'Time', :'deleted_by' => :'String', :'description' => :'String', :'disabled' => :'Boolean', :'domain' => :'String', :'id' => :'String', :'name' => :'String', :'rule_ids' => :'Array<String>', :'rule_selection_count' => :'Integer', :'rule_selection_filter' => :'ApimodelsRuleSelectionFilter', :'rule_selection_type' => :'String', :'scope_asset_filter' => :'ApimodelsAssetFilter', :'scope_type' => :'String', :'subdomain' => :'String', :'suppression_comment' => :'String', :'suppression_expiration_date' => :'String', :'suppression_reason' => :'String', :'update_reason' => :'String', :'updated_at' => :'Time', :'updated_by' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 321 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && created_by == o.created_by && deleted_at == o.deleted_at && deleted_by == o.deleted_by && description == o.description && disabled == o.disabled && domain == o.domain && id == o.id && name == o.name && rule_ids == o.rule_ids && rule_selection_count == o.rule_selection_count && rule_selection_filter == o.rule_selection_filter && rule_selection_type == o.rule_selection_type && scope_asset_filter == o.scope_asset_filter && scope_type == o.scope_type && subdomain == o.subdomain && suppression_comment == o.suppression_comment && suppression_expiration_date == o.suppression_expiration_date && suppression_reason == o.suppression_reason && update_reason == o.update_reason && updated_at == o.updated_at && updated_by == o.updated_by end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 394 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 465 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 370 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
350 351 352 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 350 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
356 357 358 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 356 def hash [created_at, created_by, deleted_at, deleted_by, description, disabled, domain, id, name, rule_ids, rule_selection_count, rule_selection_filter, rule_selection_type, scope_asset_filter, scope_type, subdomain, suppression_comment, suppression_expiration_date, suppression_reason, update_reason, updated_at, updated_by].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 253 def list_invalid_properties invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @disabled.nil? invalid_properties.push('invalid value for "disabled", disabled cannot be nil.') end if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rule_selection_count.nil? invalid_properties.push('invalid value for "rule_selection_count", rule_selection_count cannot be nil.') end if @rule_selection_type.nil? invalid_properties.push('invalid value for "rule_selection_type", rule_selection_type cannot be nil.') end if @scope_type.nil? invalid_properties.push('invalid value for "scope_type", scope_type cannot be nil.') end if @subdomain.nil? invalid_properties.push('invalid value for "subdomain", subdomain cannot be nil.') end if @suppression_reason.nil? invalid_properties.push('invalid value for "suppression_reason", suppression_reason cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
441 442 443 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 441 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 447 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
435 436 437 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 435 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/crimson-falcon/models/apimodels_suppression_rule.rb', line 304 def valid? return false if @created_at.nil? return false if @created_by.nil? return false if @disabled.nil? return false if @domain.nil? return false if @id.nil? return false if @name.nil? return false if @rule_selection_count.nil? return false if @rule_selection_type.nil? return false if @scope_type.nil? return false if @subdomain.nil? return false if @suppression_reason.nil? true end |