Class: Falcon::CaoHunting
- Inherits:
-
Object
- Object
- Falcon::CaoHunting
- Defined in:
- lib/crimson-falcon/api/cao_hunting.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#aggregate_hunting_guides(body, opts = {}) ⇒ CaohuntingapiHuntingGuideAggregatesResponse
Aggregate Hunting Guides.
-
#aggregate_hunting_guides_with_http_info(body, opts = {}) ⇒ Array<(CaohuntingapiHuntingGuideAggregatesResponse, Integer, Hash)>
Aggregate Hunting Guides.
-
#aggregate_intelligence_queries(body, opts = {}) ⇒ CaohuntingapiIntelligenceQueryAggregatesResponse
Aggregate intelligence queries.
-
#aggregate_intelligence_queries_with_http_info(body, opts = {}) ⇒ Array<(CaohuntingapiIntelligenceQueryAggregatesResponse, Integer, Hash)>
Aggregate intelligence queries.
-
#get_archive_export(language, opts = {}) ⇒ Array<Integer>
Creates an Archive Export.
-
#get_archive_export_with_http_info(language, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
Creates an Archive Export.
-
#get_hunting_guides(ids, opts = {}) ⇒ CaohuntingapiHuntingGuideEntityResponse
Retrieves a list of Hunting Guides.
-
#get_hunting_guides_with_http_info(ids, opts = {}) ⇒ Array<(CaohuntingapiHuntingGuideEntityResponse, Integer, Hash)>
Retrieves a list of Hunting Guides.
-
#get_intelligence_queries(ids, opts = {}) ⇒ CaohuntingapiIntelligenceQueryEntityResponse
Retrieves the details of a list of Intelligence queries IDs.
-
#get_intelligence_queries_with_http_info(ids, opts = {}) ⇒ Array<(CaohuntingapiIntelligenceQueryEntityResponse, Integer, Hash)>
Retrieves the details of a list of Intelligence queries IDs.
-
#initialize(api_client = ApiClient.default) ⇒ CaoHunting
constructor
A new instance of CaoHunting.
-
#search_hunting_guides(opts = {}) ⇒ MsaspecQueryResponse
Search for Hunting Guides that match the provided conditions.
-
#search_hunting_guides_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for Hunting Guides that match the provided conditions.
-
#search_intelligence_queries(opts = {}) ⇒ MsaspecQueryResponse
Search for a list of intelligence queries IDs that match the provided conditions.
-
#search_intelligence_queries_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for a list of intelligence queries IDs that match the provided conditions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CaoHunting
Returns a new instance of CaoHunting.
35 36 37 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 33 def api_client @api_client end |
Instance Method Details
#aggregate_hunting_guides(body, opts = {}) ⇒ CaohuntingapiHuntingGuideAggregatesResponse
Aggregate Hunting Guides
42 43 44 45 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 42 def aggregate_hunting_guides(body, opts = {}) data, _status_code, _headers = aggregate_hunting_guides_with_http_info(body, opts) data end |
#aggregate_hunting_guides_with_http_info(body, opts = {}) ⇒ Array<(CaohuntingapiHuntingGuideAggregatesResponse, Integer, Hash)>
Aggregate Hunting Guides
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 51 def aggregate_hunting_guides_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.aggregate_hunting_guides ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CaoHunting.aggregate_hunting_guides" end # resource path local_var_path = '/hunting/aggregates/hunting-guides/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'CaohuntingapiHuntingGuideAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.aggregate_hunting_guides", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#aggregate_hunting_guides\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#aggregate_intelligence_queries(body, opts = {}) ⇒ CaohuntingapiIntelligenceQueryAggregatesResponse
Aggregate intelligence queries
108 109 110 111 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 108 def aggregate_intelligence_queries(body, opts = {}) data, _status_code, _headers = aggregate_intelligence_queries_with_http_info(body, opts) data end |
#aggregate_intelligence_queries_with_http_info(body, opts = {}) ⇒ Array<(CaohuntingapiIntelligenceQueryAggregatesResponse, Integer, Hash)>
Aggregate intelligence queries
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 117 def aggregate_intelligence_queries_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.aggregate_intelligence_queries ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CaoHunting.aggregate_intelligence_queries" end # resource path local_var_path = '/hunting/aggregates/intelligence-queries/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'CaohuntingapiIntelligenceQueryAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.aggregate_intelligence_queries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#aggregate_intelligence_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_archive_export(language, opts = {}) ⇒ Array<Integer>
Creates an Archive Export
176 177 178 179 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 176 def get_archive_export(language, opts = {}) data, _status_code, _headers = get_archive_export_with_http_info(language, opts) data end |
#get_archive_export_with_http_info(language, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
Creates an Archive Export
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 187 def get_archive_export_with_http_info(language, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.get_archive_export ...' end # verify the required parameter 'language' is set if @api_client.config.client_side_validation && language.nil? fail ArgumentError, "Missing the required parameter 'language' when calling CaoHunting.get_archive_export" end # resource path local_var_path = '/hunting/entities/archive-exports/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'language'] = language query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'archive_type'] = opts[:'archive_type'] if !opts[:'archive_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream', 'application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Integer>' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.get_archive_export", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#get_archive_export\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_hunting_guides(ids, opts = {}) ⇒ CaohuntingapiHuntingGuideEntityResponse
Retrieves a list of Hunting Guides
242 243 244 245 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 242 def get_hunting_guides(ids, opts = {}) data, _status_code, _headers = get_hunting_guides_with_http_info(ids, opts) data end |
#get_hunting_guides_with_http_info(ids, opts = {}) ⇒ Array<(CaohuntingapiHuntingGuideEntityResponse, Integer, Hash)>
Retrieves a list of Hunting Guides
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 251 def get_hunting_guides_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.get_hunting_guides ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling CaoHunting.get_hunting_guides" end # resource path local_var_path = '/hunting/entities/hunting-guides/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CaohuntingapiHuntingGuideEntityResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.get_hunting_guides", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#get_hunting_guides\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_intelligence_queries(ids, opts = {}) ⇒ CaohuntingapiIntelligenceQueryEntityResponse
Retrieves the details of a list of Intelligence queries IDs
305 306 307 308 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 305 def get_intelligence_queries(ids, opts = {}) data, _status_code, _headers = get_intelligence_queries_with_http_info(ids, opts) data end |
#get_intelligence_queries_with_http_info(ids, opts = {}) ⇒ Array<(CaohuntingapiIntelligenceQueryEntityResponse, Integer, Hash)>
Retrieves the details of a list of Intelligence queries IDs
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 315 def get_intelligence_queries_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.get_intelligence_queries ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling CaoHunting.get_intelligence_queries" end # resource path local_var_path = '/hunting/entities/intelligence-queries/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) query_params[:'include_translated_content'] = @api_client.build_collection_param(opts[:'include_translated_content'], :multi) if !opts[:'include_translated_content'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CaohuntingapiIntelligenceQueryEntityResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.get_intelligence_queries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#get_intelligence_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#search_hunting_guides(opts = {}) ⇒ MsaspecQueryResponse
Search for Hunting Guides that match the provided conditions
373 374 375 376 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 373 def search_hunting_guides(opts = {}) data, _status_code, _headers = search_hunting_guides_with_http_info(opts) data end |
#search_hunting_guides_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for Hunting Guides that match the provided conditions
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 386 def search_hunting_guides_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.search_hunting_guides ...' end # resource path local_var_path = '/hunting/queries/hunting-guides/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.search_hunting_guides", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#search_hunting_guides\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#search_intelligence_queries(opts = {}) ⇒ MsaspecQueryResponse
Search for a list of intelligence queries IDs that match the provided conditions
443 444 445 446 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 443 def search_intelligence_queries(opts = {}) data, _status_code, _headers = search_intelligence_queries_with_http_info(opts) data end |
#search_intelligence_queries_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for a list of intelligence queries IDs that match the provided conditions
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/crimson-falcon/api/cao_hunting.rb', line 456 def search_intelligence_queries_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CaoHunting.search_intelligence_queries ...' end # resource path local_var_path = '/hunting/queries/intelligence-queries/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CaoHunting.search_intelligence_queries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CaoHunting#search_intelligence_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |