Class: Falcon::ChangesChange
- Inherits:
-
Object
- Object
- Falcon::ChangesChange
- Defined in:
- lib/crimson-falcon/models/changes_change.rb
Instance Attribute Summary collapse
-
#action_timestamp ⇒ Object
Returns the value of attribute action_timestamp.
-
#action_type ⇒ Object
Possible values: UNKNOWN, CREATE, WRITE, DELETE, SET, RENAME.
-
#aid ⇒ Object
Returns the value of attribute aid.
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#command_line ⇒ Object
Returns the value of attribute command_line.
-
#diff ⇒ Object
Returns the value of attribute diff.
-
#entity_path ⇒ Object
Returns the value of attribute entity_path.
-
#entity_path_new ⇒ Object
Returns the value of attribute entity_path_new.
-
#entity_type ⇒ Object
Possible values: UNKNOWN, FILE, DIR, REGKEY, REGVAL.
-
#file_size ⇒ Object
Returns the value of attribute file_size.
-
#grandparent_process_image_file_name ⇒ Object
Returns the value of attribute grandparent_process_image_file_name.
-
#host ⇒ Object
Returns the value of attribute host.
-
#id ⇒ Object
Returns the value of attribute id.
-
#ingestion_timestamp ⇒ Object
Returns the value of attribute ingestion_timestamp.
-
#is_from_different_mount_namespace ⇒ Object
Returns the value of attribute is_from_different_mount_namespace.
-
#is_suppressed ⇒ Object
Returns the value of attribute is_suppressed.
-
#oci_container_id ⇒ Object
Returns the value of attribute oci_container_id.
-
#parent_process_image_file_name ⇒ Object
Returns the value of attribute parent_process_image_file_name.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#permissions_lin ⇒ Object
Returns the value of attribute permissions_lin.
-
#permissions_mac ⇒ Object
Returns the value of attribute permissions_mac.
-
#platform_name ⇒ Object
Returns the value of attribute platform_name.
-
#policy ⇒ Object
Returns the value of attribute policy.
-
#prevalence ⇒ Object
Returns the value of attribute prevalence.
-
#process_id ⇒ Object
Returns the value of attribute process_id.
-
#process_image_file_name ⇒ Object
Returns the value of attribute process_image_file_name.
-
#real_user_id ⇒ Object
Returns the value of attribute real_user_id.
-
#severity ⇒ Object
Possible values: UNKNOWN, LOW, MEDIUM, HIGH, CRITICAL.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#user_name ⇒ Object
Returns the value of attribute user_name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChangesChange
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ChangesChange
Initializes the object
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 190 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ChangesChange` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ChangesChange`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action_timestamp') self. = attributes[:'action_timestamp'] end if attributes.key?(:'action_type') self.action_type = attributes[:'action_type'] end if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Array) self.attributes = value end end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'command_line') self.command_line = attributes[:'command_line'] end if attributes.key?(:'diff') self.diff = attributes[:'diff'] end if attributes.key?(:'entity_path') self.entity_path = attributes[:'entity_path'] end if attributes.key?(:'entity_path_new') self.entity_path_new = attributes[:'entity_path_new'] end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] end if attributes.key?(:'file_size') self.file_size = attributes[:'file_size'] end if attributes.key?(:'grandparent_process_image_file_name') self.grandparent_process_image_file_name = attributes[:'grandparent_process_image_file_name'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ingestion_timestamp') self. = attributes[:'ingestion_timestamp'] end if attributes.key?(:'is_from_different_mount_namespace') self.is_from_different_mount_namespace = attributes[:'is_from_different_mount_namespace'] end if attributes.key?(:'is_suppressed') self.is_suppressed = attributes[:'is_suppressed'] end if attributes.key?(:'oci_container_id') self.oci_container_id = attributes[:'oci_container_id'] end if attributes.key?(:'parent_process_image_file_name') self.parent_process_image_file_name = attributes[:'parent_process_image_file_name'] end if attributes.key?(:'permissions') self. = attributes[:'permissions'] end if attributes.key?(:'permissions_lin') self. = attributes[:'permissions_lin'] end if attributes.key?(:'permissions_mac') self. = attributes[:'permissions_mac'] end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'policy') self.policy = attributes[:'policy'] end if attributes.key?(:'prevalence') self.prevalence = attributes[:'prevalence'] end if attributes.key?(:'process_id') self.process_id = attributes[:'process_id'] end if attributes.key?(:'process_image_file_name') self.process_image_file_name = attributes[:'process_image_file_name'] end if attributes.key?(:'real_user_id') self.real_user_id = attributes[:'real_user_id'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] end end |
Instance Attribute Details
#action_timestamp ⇒ Object
Returns the value of attribute action_timestamp.
34 35 36 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 34 def @action_timestamp end |
#action_type ⇒ Object
Possible values: UNKNOWN, CREATE, WRITE, DELETE, SET, RENAME.
37 38 39 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 37 def action_type @action_type end |
#aid ⇒ Object
Returns the value of attribute aid.
39 40 41 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 39 def aid @aid end |
#attributes ⇒ Object
Returns the value of attribute attributes.
41 42 43 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 41 def attributes @attributes end |
#cid ⇒ Object
Returns the value of attribute cid.
43 44 45 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 43 def cid @cid end |
#command_line ⇒ Object
Returns the value of attribute command_line.
45 46 47 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 45 def command_line @command_line end |
#diff ⇒ Object
Returns the value of attribute diff.
47 48 49 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 47 def diff @diff end |
#entity_path ⇒ Object
Returns the value of attribute entity_path.
49 50 51 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 49 def entity_path @entity_path end |
#entity_path_new ⇒ Object
Returns the value of attribute entity_path_new.
51 52 53 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 51 def entity_path_new @entity_path_new end |
#entity_type ⇒ Object
Possible values: UNKNOWN, FILE, DIR, REGKEY, REGVAL.
54 55 56 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 54 def entity_type @entity_type end |
#file_size ⇒ Object
Returns the value of attribute file_size.
56 57 58 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 56 def file_size @file_size end |
#grandparent_process_image_file_name ⇒ Object
Returns the value of attribute grandparent_process_image_file_name.
58 59 60 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 58 def grandparent_process_image_file_name @grandparent_process_image_file_name end |
#host ⇒ Object
Returns the value of attribute host.
60 61 62 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 60 def host @host end |
#id ⇒ Object
Returns the value of attribute id.
62 63 64 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 62 def id @id end |
#ingestion_timestamp ⇒ Object
Returns the value of attribute ingestion_timestamp.
64 65 66 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 64 def @ingestion_timestamp end |
#is_from_different_mount_namespace ⇒ Object
Returns the value of attribute is_from_different_mount_namespace.
66 67 68 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 66 def is_from_different_mount_namespace @is_from_different_mount_namespace end |
#is_suppressed ⇒ Object
Returns the value of attribute is_suppressed.
68 69 70 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 68 def is_suppressed @is_suppressed end |
#oci_container_id ⇒ Object
Returns the value of attribute oci_container_id.
70 71 72 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 70 def oci_container_id @oci_container_id end |
#parent_process_image_file_name ⇒ Object
Returns the value of attribute parent_process_image_file_name.
72 73 74 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 72 def parent_process_image_file_name @parent_process_image_file_name end |
#permissions ⇒ Object
Returns the value of attribute permissions.
74 75 76 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 74 def @permissions end |
#permissions_lin ⇒ Object
Returns the value of attribute permissions_lin.
76 77 78 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 76 def @permissions_lin end |
#permissions_mac ⇒ Object
Returns the value of attribute permissions_mac.
78 79 80 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 78 def @permissions_mac end |
#platform_name ⇒ Object
Returns the value of attribute platform_name.
80 81 82 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 80 def platform_name @platform_name end |
#policy ⇒ Object
Returns the value of attribute policy.
82 83 84 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 82 def policy @policy end |
#prevalence ⇒ Object
Returns the value of attribute prevalence.
84 85 86 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 84 def prevalence @prevalence end |
#process_id ⇒ Object
Returns the value of attribute process_id.
86 87 88 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 86 def process_id @process_id end |
#process_image_file_name ⇒ Object
Returns the value of attribute process_image_file_name.
88 89 90 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 88 def process_image_file_name @process_image_file_name end |
#real_user_id ⇒ Object
Returns the value of attribute real_user_id.
90 91 92 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 90 def real_user_id @real_user_id end |
#severity ⇒ Object
Possible values: UNKNOWN, LOW, MEDIUM, HIGH, CRITICAL
93 94 95 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 93 def severity @severity end |
#tags ⇒ Object
Returns the value of attribute tags.
95 96 97 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 95 def @tags end |
#user_id ⇒ Object
Returns the value of attribute user_id.
97 98 99 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 97 def user_id @user_id end |
#user_name ⇒ Object
Returns the value of attribute user_name.
99 100 101 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 99 def user_name @user_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
140 141 142 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 140 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 102 def self.attribute_map { :'action_timestamp' => :'action_timestamp', :'action_type' => :'action_type', :'aid' => :'aid', :'attributes' => :'attributes', :'cid' => :'cid', :'command_line' => :'command_line', :'diff' => :'diff', :'entity_path' => :'entity_path', :'entity_path_new' => :'entity_path_new', :'entity_type' => :'entity_type', :'file_size' => :'file_size', :'grandparent_process_image_file_name' => :'grandparent_process_image_file_name', :'host' => :'host', :'id' => :'id', :'ingestion_timestamp' => :'ingestion_timestamp', :'is_from_different_mount_namespace' => :'is_from_different_mount_namespace', :'is_suppressed' => :'is_suppressed', :'oci_container_id' => :'oci_container_id', :'parent_process_image_file_name' => :'parent_process_image_file_name', :'permissions' => :'permissions', :'permissions_lin' => :'permissions_lin', :'permissions_mac' => :'permissions_mac', :'platform_name' => :'platform_name', :'policy' => :'policy', :'prevalence' => :'prevalence', :'process_id' => :'process_id', :'process_image_file_name' => :'process_image_file_name', :'real_user_id' => :'real_user_id', :'severity' => :'severity', :'tags' => :'tags', :'user_id' => :'user_id', :'user_name' => :'user_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
493 494 495 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 493 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
183 184 185 186 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 183 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 145 def self.openapi_types { :'action_timestamp' => :'String', :'action_type' => :'String', :'aid' => :'String', :'attributes' => :'Array<ChangesAttribute>', :'cid' => :'String', :'command_line' => :'String', :'diff' => :'ChangesDiff', :'entity_path' => :'String', :'entity_path_new' => :'String', :'entity_type' => :'String', :'file_size' => :'Integer', :'grandparent_process_image_file_name' => :'String', :'host' => :'ChangesHost', :'id' => :'String', :'ingestion_timestamp' => :'String', :'is_from_different_mount_namespace' => :'Boolean', :'is_suppressed' => :'Boolean', :'oci_container_id' => :'String', :'parent_process_image_file_name' => :'String', :'permissions' => :'ChangesPermissions', :'permissions_lin' => :'ChangesPermissionsLin', :'permissions_mac' => :'ChangesPermissionsMac', :'platform_name' => :'String', :'policy' => :'ChangesPolicy', :'prevalence' => :'ChangesPrevalence', :'process_id' => :'String', :'process_image_file_name' => :'String', :'real_user_id' => :'String', :'severity' => :'String', :'tags' => :'Array<ChangesTag>', :'user_id' => :'String', :'user_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 441 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && action_type == o.action_type && aid == o.aid && attributes == o.attributes && cid == o.cid && command_line == o.command_line && diff == o.diff && entity_path == o.entity_path && entity_path_new == o.entity_path_new && entity_type == o.entity_type && file_size == o.file_size && grandparent_process_image_file_name == o.grandparent_process_image_file_name && host == o.host && id == o.id && == o. && is_from_different_mount_namespace == o.is_from_different_mount_namespace && is_suppressed == o.is_suppressed && oci_container_id == o.oci_container_id && parent_process_image_file_name == o.parent_process_image_file_name && == o. && == o. && == o. && platform_name == o.platform_name && policy == o.policy && prevalence == o.prevalence && process_id == o.process_id && process_image_file_name == o.process_image_file_name && real_user_id == o.real_user_id && severity == o.severity && == o. && user_id == o.user_id && user_name == o.user_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 524 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
595 596 597 598 599 600 601 602 603 604 605 606 607 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 595 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 500 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
480 481 482 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 480 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
486 487 488 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 486 def hash [, action_type, aid, attributes, cid, command_line, diff, entity_path, entity_path_new, entity_type, file_size, grandparent_process_image_file_name, host, id, , is_from_different_mount_namespace, is_suppressed, oci_container_id, parent_process_image_file_name, , , , platform_name, policy, prevalence, process_id, process_image_file_name, real_user_id, severity, , user_id, user_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 338 def list_invalid_properties invalid_properties = Array.new if @action_timestamp.nil? invalid_properties.push('invalid value for "action_timestamp", action_timestamp cannot be nil.') end if @action_type.nil? invalid_properties.push('invalid value for "action_type", action_type cannot be nil.') end if @aid.nil? invalid_properties.push('invalid value for "aid", aid cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @command_line.nil? invalid_properties.push('invalid value for "command_line", command_line cannot be nil.') end if @entity_path.nil? invalid_properties.push('invalid value for "entity_path", entity_path cannot be nil.') end if @entity_type.nil? invalid_properties.push('invalid value for "entity_type", entity_type cannot be nil.') end if @file_size.nil? invalid_properties.push('invalid value for "file_size", file_size cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @ingestion_timestamp.nil? invalid_properties.push('invalid value for "ingestion_timestamp", ingestion_timestamp cannot be nil.') end if @is_from_different_mount_namespace.nil? invalid_properties.push('invalid value for "is_from_different_mount_namespace", is_from_different_mount_namespace cannot be nil.') end if @is_suppressed.nil? invalid_properties.push('invalid value for "is_suppressed", is_suppressed cannot be nil.') end if @platform_name.nil? invalid_properties.push('invalid value for "platform_name", platform_name cannot be nil.') end if @process_id.nil? invalid_properties.push('invalid value for "process_id", process_id cannot be nil.') end if @process_image_file_name.nil? invalid_properties.push('invalid value for "process_image_file_name", process_image_file_name cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @user_name.nil? invalid_properties.push('invalid value for "user_name", user_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
571 572 573 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 571 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 577 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
565 566 567 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 565 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/crimson-falcon/models/changes_change.rb', line 417 def valid? return false if @action_timestamp.nil? return false if @action_type.nil? return false if @aid.nil? return false if @cid.nil? return false if @command_line.nil? return false if @entity_path.nil? return false if @entity_type.nil? return false if @file_size.nil? return false if @id.nil? return false if @ingestion_timestamp.nil? return false if @is_from_different_mount_namespace.nil? return false if @is_suppressed.nil? return false if @platform_name.nil? return false if @process_id.nil? return false if @process_image_file_name.nil? return false if @severity.nil? return false if @user_id.nil? return false if @user_name.nil? true end |