Class: Falcon::CloudGoogleCloudRegistration
- Inherits:
-
Object
- Object
- Falcon::CloudGoogleCloudRegistration
- Defined in:
- lib/crimson-falcon/api/cloud_google_cloud_registration.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cloud_registration_gcp_create_registration(body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Create a Google Cloud Registration.
-
#cloud_registration_gcp_create_registration_with_http_info(body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Create a Google Cloud Registration.
-
#cloud_registration_gcp_delete_registration(ids, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Deletes a Google Cloud Registration and returns the deleted registration in the response body.
-
#cloud_registration_gcp_delete_registration_with_http_info(ids, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Deletes a Google Cloud Registration and returns the deleted registration in the response body.
-
#cloud_registration_gcp_get_entities(opts = {}) ⇒ DtoGCPEntitiesResponseV1
Retrieve all GCP entities (organizations, folders, projects) grouped by type with support for FQL filtering, sorting, and pagination.
-
#cloud_registration_gcp_get_entities_with_http_info(opts = {}) ⇒ Array<(DtoGCPEntitiesResponseV1, Integer, Hash)>
Retrieve all GCP entities (organizations, folders, projects) grouped by type with support for FQL filtering, sorting, and pagination.
-
#cloud_registration_gcp_get_registration(ids, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Retrieve a Google Cloud Registration.
-
#cloud_registration_gcp_get_registration_with_http_info(ids, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Retrieve a Google Cloud Registration.
-
#cloud_registration_gcp_put_registration(body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Creates/Updates a Google Cloud Registration.
-
#cloud_registration_gcp_put_registration_with_http_info(body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Creates/Updates a Google Cloud Registration.
-
#cloud_registration_gcp_trigger_health_check(opts = {}) ⇒ DtoHealthCheckTriggerResponseExtV1
Trigger health check scan for GCP registrations.
-
#cloud_registration_gcp_trigger_health_check_with_http_info(opts = {}) ⇒ Array<(DtoHealthCheckTriggerResponseExtV1, Integer, Hash)>
Trigger health check scan for GCP registrations.
-
#cloud_registration_gcp_update_registration(ids, body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Update a Google Cloud Registration.
-
#cloud_registration_gcp_update_registration_with_http_info(ids, body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Update a Google Cloud Registration.
-
#initialize(api_client = ApiClient.default) ⇒ CloudGoogleCloudRegistration
constructor
A new instance of CloudGoogleCloudRegistration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CloudGoogleCloudRegistration
Returns a new instance of CloudGoogleCloudRegistration.
35 36 37 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 33 def api_client @api_client end |
Instance Method Details
#cloud_registration_gcp_create_registration(body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Create a Google Cloud Registration.
42 43 44 45 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 42 def cloud_registration_gcp_create_registration(body, opts = {}) data, _status_code, _headers = cloud_registration_gcp_create_registration_with_http_info(body, opts) data end |
#cloud_registration_gcp_create_registration_with_http_info(body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Create a Google Cloud Registration.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 51 def cloud_registration_gcp_create_registration_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_create_registration ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_create_registration" end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registrations/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DtoGCPRegistrationResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_create_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_create_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_delete_registration(ids, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Deletes a Google Cloud Registration and returns the deleted registration in the response body.
108 109 110 111 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 108 def cloud_registration_gcp_delete_registration(ids, opts = {}) data, _status_code, _headers = cloud_registration_gcp_delete_registration_with_http_info(ids, opts) data end |
#cloud_registration_gcp_delete_registration_with_http_info(ids, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Deletes a Google Cloud Registration and returns the deleted registration in the response body.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 117 def cloud_registration_gcp_delete_registration_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_delete_registration ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_delete_registration" end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registrations/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = ids # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DtoGCPRegistrationResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_delete_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_delete_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_get_entities(opts = {}) ⇒ DtoGCPEntitiesResponseV1
Retrieve all GCP entities (organizations, folders, projects) grouped by type with support for FQL filtering, sorting, and pagination. Returns entities grouped by type. Sorting and pagination are applied across all entity types before grouping. Use filter=entity_type:‘project’ to retrieve only specific entity types.
175 176 177 178 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 175 def cloud_registration_gcp_get_entities(opts = {}) data, _status_code, _headers = cloud_registration_gcp_get_entities_with_http_info(opts) data end |
#cloud_registration_gcp_get_entities_with_http_info(opts = {}) ⇒ Array<(DtoGCPEntitiesResponseV1, Integer, Hash)>
Retrieve all GCP entities (organizations, folders, projects) grouped by type with support for FQL filtering, sorting, and pagination. Returns entities grouped by type. Sorting and pagination are applied across all entity types before grouping. Use filter=entity_type:'project' to retrieve only specific entity types.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 189 def cloud_registration_gcp_get_entities_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_get_entities ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 500 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudGoogleCloudRegistration.cloud_registration_gcp_get_entities, must be smaller than or equal to 500.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudGoogleCloudRegistration.cloud_registration_gcp_get_entities, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudGoogleCloudRegistration.cloud_registration_gcp_get_entities, must be greater than or equal to 0.' end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/accounts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DtoGCPEntitiesResponseV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_get_entities", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_get_entities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_get_registration(ids, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Retrieve a Google Cloud Registration.
254 255 256 257 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 254 def cloud_registration_gcp_get_registration(ids, opts = {}) data, _status_code, _headers = cloud_registration_gcp_get_registration_with_http_info(ids, opts) data end |
#cloud_registration_gcp_get_registration_with_http_info(ids, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Retrieve a Google Cloud Registration.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 263 def cloud_registration_gcp_get_registration_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_get_registration ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_get_registration" end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registrations/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = ids # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DtoGCPRegistrationResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_get_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_get_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_put_registration(body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Creates/Updates a Google Cloud Registration. Creates a new Google Cloud Registration if one doesnt exist or updates the existing Google Cloud Registration. We check for an existing registration based on cid, registration scope and entity ids.
317 318 319 320 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 317 def cloud_registration_gcp_put_registration(body, opts = {}) data, _status_code, _headers = cloud_registration_gcp_put_registration_with_http_info(body, opts) data end |
#cloud_registration_gcp_put_registration_with_http_info(body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Creates/Updates a Google Cloud Registration. Creates a new Google Cloud Registration if one doesnt exist or updates the existing Google Cloud Registration. We check for an existing registration based on cid, registration scope and entity ids.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 327 def cloud_registration_gcp_put_registration_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_put_registration ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_put_registration" end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registrations/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DtoGCPRegistrationResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_put_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_put_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_trigger_health_check(opts = {}) ⇒ DtoHealthCheckTriggerResponseExtV1
Trigger health check scan for GCP registrations
384 385 386 387 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 384 def cloud_registration_gcp_trigger_health_check(opts = {}) data, _status_code, _headers = cloud_registration_gcp_trigger_health_check_with_http_info(opts) data end |
#cloud_registration_gcp_trigger_health_check_with_http_info(opts = {}) ⇒ Array<(DtoHealthCheckTriggerResponseExtV1, Integer, Hash)>
Trigger health check scan for GCP registrations
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 393 def cloud_registration_gcp_trigger_health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_trigger_health_check ...' end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registration-scans/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DtoHealthCheckTriggerResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_trigger_health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_trigger_health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cloud_registration_gcp_update_registration(ids, body, opts = {}) ⇒ DtoGCPRegistrationResponseExtV1
Update a Google Cloud Registration.
443 444 445 446 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 443 def cloud_registration_gcp_update_registration(ids, body, opts = {}) data, _status_code, _headers = cloud_registration_gcp_update_registration_with_http_info(ids, body, opts) data end |
#cloud_registration_gcp_update_registration_with_http_info(ids, body, opts = {}) ⇒ Array<(DtoGCPRegistrationResponseExtV1, Integer, Hash)>
Update a Google Cloud Registration.
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/crimson-falcon/api/cloud_google_cloud_registration.rb', line 453 def cloud_registration_gcp_update_registration_with_http_info(ids, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudGoogleCloudRegistration.cloud_registration_gcp_update_registration ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_update_registration" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CloudGoogleCloudRegistration.cloud_registration_gcp_update_registration" end # resource path local_var_path = '/cloud-security-registration-google-cloud/entities/registrations/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = ids # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DtoGCPRegistrationResponseExtV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudGoogleCloudRegistration.cloud_registration_gcp_update_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudGoogleCloudRegistration#cloud_registration_gcp_update_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |