Class: Falcon::CloudSecurity
- Inherits:
-
Object
- Object
- Falcon::CloudSecurity
- Defined in:
- lib/crimson-falcon/api/cloud_security.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#combined_cloud_risks(opts = {}) ⇒ RisksGetCloudRisksResponse
Gets cloud risks with full details based on filters and sort criteria.
-
#combined_cloud_risks_with_http_info(opts = {}) ⇒ Array<(RisksGetCloudRisksResponse, Integer, Hash)>
Gets cloud risks with full details based on filters and sort criteria.
-
#create_cloud_group_external(body, opts = {}) ⇒ AssetgroupmanagerV1CreateCloudGroupResponse
Create a Cloud Group.
-
#create_cloud_group_external_with_http_info(body, opts = {}) ⇒ Array<(AssetgroupmanagerV1CreateCloudGroupResponse, Integer, Hash)>
Create a Cloud Group.
-
#delete_cloud_groups_external(opts = {}) ⇒ Object
Delete Cloud Groups in batch.
-
#delete_cloud_groups_external_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete Cloud Groups in batch.
-
#initialize(api_client = ApiClient.default) ⇒ CloudSecurity
constructor
A new instance of CloudSecurity.
-
#list_cloud_group_ids_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupIDsResponse
Query Cloud Groups and returns IDs.
-
#list_cloud_group_ids_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupIDsResponse, Integer, Hash)>
Query Cloud Groups and returns IDs.
-
#list_cloud_groups_by_id_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupsResponse
List Cloud Groups By ID.
-
#list_cloud_groups_by_id_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupsResponse, Integer, Hash)>
List Cloud Groups By ID.
-
#list_cloud_groups_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupsResponse
Query Cloud Groups and returns entities.
-
#list_cloud_groups_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupsResponse, Integer, Hash)>
Query Cloud Groups and returns entities.
-
#update_cloud_group_external(group, opts = {}) ⇒ AssetgroupmanagerV1UpdateCloudGroupResponse
Update Cloud Group.
-
#update_cloud_group_external_with_http_info(group, opts = {}) ⇒ Array<(AssetgroupmanagerV1UpdateCloudGroupResponse, Integer, Hash)>
Update Cloud Group.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CloudSecurity
Returns a new instance of CloudSecurity.
35 36 37 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 33 def api_client @api_client end |
Instance Method Details
#combined_cloud_risks(opts = {}) ⇒ RisksGetCloudRisksResponse
Gets cloud risks with full details based on filters and sort criteria
45 46 47 48 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 45 def combined_cloud_risks(opts = {}) data, _status_code, _headers = combined_cloud_risks_with_http_info(opts) data end |
#combined_cloud_risks_with_http_info(opts = {}) ⇒ Array<(RisksGetCloudRisksResponse, Integer, Hash)>
Gets cloud risks with full details based on filters and sort criteria
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 57 def combined_cloud_risks_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.combined_cloud_risks ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurity.combined_cloud_risks, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurity.combined_cloud_risks, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurity.combined_cloud_risks, must be greater than or equal to 0.' end # resource path local_var_path = '/cloud-security-risks/combined/cloud-risks/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RisksGetCloudRisksResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.combined_cloud_risks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#combined_cloud_risks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_cloud_group_external(body, opts = {}) ⇒ AssetgroupmanagerV1CreateCloudGroupResponse
Create a Cloud Group. The created_by field will be set to the API client ID.
121 122 123 124 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 121 def create_cloud_group_external(body, opts = {}) data, _status_code, _headers = create_cloud_group_external_with_http_info(body, opts) data end |
#create_cloud_group_external_with_http_info(body, opts = {}) ⇒ Array<(AssetgroupmanagerV1CreateCloudGroupResponse, Integer, Hash)>
Create a Cloud Group. The created_by field will be set to the API client ID.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 130 def create_cloud_group_external_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.create_cloud_group_external ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CloudSecurity.create_cloud_group_external" end # resource path local_var_path = '/cloud-security/entities/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'AssetgroupmanagerV1CreateCloudGroupResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.create_cloud_group_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#create_cloud_group_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_cloud_groups_external(opts = {}) ⇒ Object
Delete Cloud Groups in batch
187 188 189 190 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 187 def delete_cloud_groups_external(opts = {}) data, _status_code, _headers = delete_cloud_groups_external_with_http_info(opts) data end |
#delete_cloud_groups_external_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete Cloud Groups in batch
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 196 def delete_cloud_groups_external_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.delete_cloud_groups_external ...' end # resource path local_var_path = '/cloud-security/entities/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.delete_cloud_groups_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#delete_cloud_groups_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cloud_group_ids_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupIDsResponse
Query Cloud Groups and returns IDs
248 249 250 251 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 248 def list_cloud_group_ids_external(opts = {}) data, _status_code, _headers = list_cloud_group_ids_external_with_http_info(opts) data end |
#list_cloud_group_ids_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupIDsResponse, Integer, Hash)>
Query Cloud Groups and returns IDs
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 260 def list_cloud_group_ids_external_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.list_cloud_group_ids_external ...' end # resource path local_var_path = '/cloud-security/queries/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AssetgroupmanagerV1ListCloudGroupIDsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.list_cloud_group_ids_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#list_cloud_group_ids_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cloud_groups_by_id_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupsResponse
List Cloud Groups By ID
312 313 314 315 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 312 def list_cloud_groups_by_id_external(opts = {}) data, _status_code, _headers = list_cloud_groups_by_id_external_with_http_info(opts) data end |
#list_cloud_groups_by_id_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupsResponse, Integer, Hash)>
List Cloud Groups By ID
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 321 def list_cloud_groups_by_id_external_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.list_cloud_groups_by_id_external ...' end # resource path local_var_path = '/cloud-security/entities/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AssetgroupmanagerV1ListCloudGroupsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.list_cloud_groups_by_id_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#list_cloud_groups_by_id_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cloud_groups_external(opts = {}) ⇒ AssetgroupmanagerV1ListCloudGroupsResponse
Query Cloud Groups and returns entities
373 374 375 376 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 373 def list_cloud_groups_external(opts = {}) data, _status_code, _headers = list_cloud_groups_external_with_http_info(opts) data end |
#list_cloud_groups_external_with_http_info(opts = {}) ⇒ Array<(AssetgroupmanagerV1ListCloudGroupsResponse, Integer, Hash)>
Query Cloud Groups and returns entities
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 385 def list_cloud_groups_external_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.list_cloud_groups_external ...' end # resource path local_var_path = '/cloud-security/combined/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AssetgroupmanagerV1ListCloudGroupsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.list_cloud_groups_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#list_cloud_groups_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_cloud_group_external(group, opts = {}) ⇒ AssetgroupmanagerV1UpdateCloudGroupResponse
Update Cloud Group
437 438 439 440 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 437 def update_cloud_group_external(group, opts = {}) data, _status_code, _headers = update_cloud_group_external_with_http_info(group, opts) data end |
#update_cloud_group_external_with_http_info(group, opts = {}) ⇒ Array<(AssetgroupmanagerV1UpdateCloudGroupResponse, Integer, Hash)>
Update Cloud Group
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/crimson-falcon/api/cloud_security.rb', line 446 def update_cloud_group_external_with_http_info(group, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurity.update_cloud_group_external ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling CloudSecurity.update_cloud_group_external" end # resource path local_var_path = '/cloud-security/entities/cloud-groups/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(group) # return_type return_type = opts[:debug_return_type] || 'AssetgroupmanagerV1UpdateCloudGroupResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurity.update_cloud_group_external", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurity#update_cloud_group_external\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |