Class: Falcon::CloudSecurityDetections
- Inherits:
-
Object
- Object
- Falcon::CloudSecurityDetections
- Defined in:
- lib/crimson-falcon/api/cloud_security_detections.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cspm_evaluations_combined_iom_by_rule(opts = {}) ⇒ EvaluationsIOMsByRuleResponse
returns ioms grouped by rule.
-
#cspm_evaluations_combined_iom_by_rule_with_http_info(opts = {}) ⇒ Array<(EvaluationsIOMsByRuleResponse, Integer, Hash)>
returns ioms grouped by rule.
-
#cspm_evaluations_iom_entities(opts = {}) ⇒ EvaluationsGetIOMsResponse
Gets IOMs based on the provided IDs.
-
#cspm_evaluations_iom_entities_with_http_info(opts = {}) ⇒ Array<(EvaluationsGetIOMsResponse, Integer, Hash)>
Gets IOMs based on the provided IDs.
-
#cspm_evaluations_iom_queries(opts = {}) ⇒ EvaluationsQueryIOMsResponse
Gets a list of IOM IDs for the given parameters, filters and sort criteria.
-
#cspm_evaluations_iom_queries_with_http_info(opts = {}) ⇒ Array<(EvaluationsQueryIOMsResponse, Integer, Hash)>
Gets a list of IOM IDs for the given parameters, filters and sort criteria.
-
#initialize(api_client = ApiClient.default) ⇒ CloudSecurityDetections
constructor
A new instance of CloudSecurityDetections.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CloudSecurityDetections
Returns a new instance of CloudSecurityDetections.
35 36 37 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 33 def api_client @api_client end |
Instance Method Details
#cspm_evaluations_combined_iom_by_rule(opts = {}) ⇒ EvaluationsIOMsByRuleResponse
returns ioms grouped by rule
45 46 47 48 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 45 def cspm_evaluations_combined_iom_by_rule(opts = {}) data, _status_code, _headers = cspm_evaluations_combined_iom_by_rule_with_http_info(opts) data end |
#cspm_evaluations_combined_iom_by_rule_with_http_info(opts = {}) ⇒ Array<(EvaluationsIOMsByRuleResponse, Integer, Hash)>
returns ioms grouped by rule
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 57 def cspm_evaluations_combined_iom_by_rule_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule, must be greater than or equal to 0.' end # resource path local_var_path = '/cloud-security-evaluations/combined/ioms-by-rule/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EvaluationsIOMsByRuleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurityDetections.cspm_evaluations_combined_iom_by_rule", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_combined_iom_by_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cspm_evaluations_iom_entities(opts = {}) ⇒ EvaluationsGetIOMsResponse
Gets IOMs based on the provided IDs
121 122 123 124 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 121 def cspm_evaluations_iom_entities(opts = {}) data, _status_code, _headers = cspm_evaluations_iom_entities_with_http_info(opts) data end |
#cspm_evaluations_iom_entities_with_http_info(opts = {}) ⇒ Array<(EvaluationsGetIOMsResponse, Integer, Hash)>
Gets IOMs based on the provided IDs
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 130 def cspm_evaluations_iom_entities_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_iom_entities ...' end # resource path local_var_path = '/cloud-security-evaluations/entities/ioms/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(opts[:'ids'], :multi) if !opts[:'ids'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EvaluationsGetIOMsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurityDetections.cspm_evaluations_iom_entities", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_iom_entities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#cspm_evaluations_iom_queries(opts = {}) ⇒ EvaluationsQueryIOMsResponse
Gets a list of IOM IDs for the given parameters, filters and sort criteria.
183 184 185 186 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 183 def cspm_evaluations_iom_queries(opts = {}) data, _status_code, _headers = cspm_evaluations_iom_queries_with_http_info(opts) data end |
#cspm_evaluations_iom_queries_with_http_info(opts = {}) ⇒ Array<(EvaluationsQueryIOMsResponse, Integer, Hash)>
Gets a list of IOM IDs for the given parameters, filters and sort criteria.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/crimson-falcon/api/cloud_security_detections.rb', line 196 def cspm_evaluations_iom_queries_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudSecurityDetections.cspm_evaluations_iom_queries ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 0 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling CloudSecurityDetections.cspm_evaluations_iom_queries, must be greater than or equal to 0.' end # resource path local_var_path = '/cloud-security-evaluations/queries/ioms/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EvaluationsQueryIOMsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CloudSecurityDetections.cspm_evaluations_iom_queries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudSecurityDetections#cspm_evaluations_iom_queries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |