Class: Falcon::CorrelationrulesapiRuleCreateRequestV1
- Inherits:
-
Object
- Object
- Falcon::CorrelationrulesapiRuleCreateRequestV1
- Defined in:
- lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb
Instance Attribute Summary collapse
-
#anomaly ⇒ Object
Returns the value of attribute anomaly.
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#guardrail_notifications ⇒ Object
Returns the value of attribute guardrail_notifications.
-
#mitre_attack ⇒ Object
Returns the value of attribute mitre_attack.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notifications ⇒ Object
Returns the value of attribute notifications.
-
#operation ⇒ Object
Returns the value of attribute operation.
-
#search ⇒ Object
Returns the value of attribute search.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tactic ⇒ Object
Returns the value of attribute tactic.
-
#technique ⇒ Object
Returns the value of attribute technique.
-
#template_id ⇒ Object
Returns the value of attribute template_id.
-
#trigger_on_create ⇒ Object
Returns the value of attribute trigger_on_create.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CorrelationrulesapiRuleCreateRequestV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CorrelationrulesapiRuleCreateRequestV1
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::CorrelationrulesapiRuleCreateRequestV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::CorrelationrulesapiRuleCreateRequestV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'anomaly') self.anomaly = attributes[:'anomaly'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'guardrail_notifications') if (value = attributes[:'guardrail_notifications']).is_a?(Array) self.guardrail_notifications = value end end if attributes.key?(:'mitre_attack') if (value = attributes[:'mitre_attack']).is_a?(Array) self.mitre_attack = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'notifications') if (value = attributes[:'notifications']).is_a?(Array) self.notifications = value end end if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'search') self.search = attributes[:'search'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'tactic') self.tactic = attributes[:'tactic'] end if attributes.key?(:'technique') self.technique = attributes[:'technique'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'trigger_on_create') self.trigger_on_create = attributes[:'trigger_on_create'] end end |
Instance Attribute Details
#anomaly ⇒ Object
Returns the value of attribute anomaly.
34 35 36 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 34 def anomaly @anomaly end |
#comment ⇒ Object
Returns the value of attribute comment.
36 37 38 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 36 def comment @comment end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
38 39 40 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 38 def customer_id @customer_id end |
#description ⇒ Object
Returns the value of attribute description.
40 41 42 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 40 def description @description end |
#guardrail_notifications ⇒ Object
Returns the value of attribute guardrail_notifications.
42 43 44 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 42 def guardrail_notifications @guardrail_notifications end |
#mitre_attack ⇒ Object
Returns the value of attribute mitre_attack.
44 45 46 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 44 def mitre_attack @mitre_attack end |
#name ⇒ Object
Returns the value of attribute name.
46 47 48 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 46 def name @name end |
#notifications ⇒ Object
Returns the value of attribute notifications.
48 49 50 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 48 def notifications @notifications end |
#operation ⇒ Object
Returns the value of attribute operation.
50 51 52 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 50 def operation @operation end |
#search ⇒ Object
Returns the value of attribute search.
52 53 54 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 52 def search @search end |
#severity ⇒ Object
Returns the value of attribute severity.
54 55 56 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 54 def severity @severity end |
#status ⇒ Object
Returns the value of attribute status.
56 57 58 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 56 def status @status end |
#tactic ⇒ Object
Returns the value of attribute tactic.
58 59 60 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 58 def tactic @tactic end |
#technique ⇒ Object
Returns the value of attribute technique.
60 61 62 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 60 def technique @technique end |
#template_id ⇒ Object
Returns the value of attribute template_id.
62 63 64 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 62 def template_id @template_id end |
#trigger_on_create ⇒ Object
Returns the value of attribute trigger_on_create.
64 65 66 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 64 def trigger_on_create @trigger_on_create end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 67 def self.attribute_map { :'anomaly' => :'anomaly', :'comment' => :'comment', :'customer_id' => :'customer_id', :'description' => :'description', :'guardrail_notifications' => :'guardrail_notifications', :'mitre_attack' => :'mitre_attack', :'name' => :'name', :'notifications' => :'notifications', :'operation' => :'operation', :'search' => :'search', :'severity' => :'severity', :'status' => :'status', :'tactic' => :'tactic', :'technique' => :'technique', :'template_id' => :'template_id', :'trigger_on_create' => :'trigger_on_create' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 293 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 94 def self.openapi_types { :'anomaly' => :'CorrelationrulesapiAnomalyV1', :'comment' => :'String', :'customer_id' => :'String', :'description' => :'String', :'guardrail_notifications' => :'Array<CorrelationrulesapiCreateRuleNotifications>', :'mitre_attack' => :'Array<CorrelationrulesapiMitreAttackMappingV1>', :'name' => :'String', :'notifications' => :'Array<CorrelationrulesapiCreateRuleNotifications>', :'operation' => :'CorrelationrulesapiCreateRuleOperationV1', :'search' => :'CorrelationrulesapiRuleSearchV1', :'severity' => :'Integer', :'status' => :'String', :'tactic' => :'String', :'technique' => :'String', :'template_id' => :'String', :'trigger_on_create' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && anomaly == o.anomaly && comment == o.comment && customer_id == o.customer_id && description == o.description && guardrail_notifications == o.guardrail_notifications && mitre_attack == o.mitre_attack && name == o.name && notifications == o.notifications && operation == o.operation && search == o.search && severity == o.severity && status == o.status && tactic == o.tactic && technique == o.technique && template_id == o.template_id && trigger_on_create == o.trigger_on_create end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 324 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 395 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 300 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 286 def hash [anomaly, comment, customer_id, description, guardrail_notifications, mitre_attack, name, notifications, operation, search, severity, status, tactic, technique, template_id, trigger_on_create].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 209 def list_invalid_properties invalid_properties = Array.new if @customer_id.nil? invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @operation.nil? invalid_properties.push('invalid value for "operation", operation cannot be nil.') end if @search.nil? invalid_properties.push('invalid value for "search", search cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @template_id.nil? invalid_properties.push('invalid value for "template_id", template_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
371 372 373 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 371 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
365 366 367 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 365 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/crimson-falcon/models/correlationrulesapi_rule_create_request_v1.rb', line 244 def valid? return false if @customer_id.nil? return false if @name.nil? return false if @operation.nil? return false if @search.nil? return false if @severity.nil? return false if @status.nil? return false if @template_id.nil? true end |