Class: Falcon::CspgIacapi
- Inherits:
-
Object
- Object
- Falcon::CspgIacapi
- Defined in:
- lib/crimson-falcon/api/cspg_iacapi.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#combined_detections(opts = {}) ⇒ ModelsDetectionsCombinedResponse
Search IaC Detections using a query in Falcon Query Language.
-
#combined_detections_with_http_info(opts = {}) ⇒ Array<(ModelsDetectionsCombinedResponse, Integer, Hash)>
Search IaC Detections using a query in Falcon Query Language.
-
#initialize(api_client = ApiClient.default) ⇒ CspgIacapi
constructor
A new instance of CspgIacapi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CspgIacapi
Returns a new instance of CspgIacapi.
35 36 37 |
# File 'lib/crimson-falcon/api/cspg_iacapi.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/cspg_iacapi.rb', line 33 def api_client @api_client end |
Instance Method Details
#combined_detections(opts = {}) ⇒ ModelsDetectionsCombinedResponse
Search IaC Detections using a query in Falcon Query Language
45 46 47 48 |
# File 'lib/crimson-falcon/api/cspg_iacapi.rb', line 45 def combined_detections(opts = {}) data, _status_code, _headers = combined_detections_with_http_info(opts) data end |
#combined_detections_with_http_info(opts = {}) ⇒ Array<(ModelsDetectionsCombinedResponse, Integer, Hash)>
Search IaC Detections using a query in Falcon Query Language
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/crimson-falcon/api/cspg_iacapi.rb', line 57 def combined_detections_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CspgIacapi.combined_detections ...' end # resource path local_var_path = '/iac/combined/detections/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ModelsDetectionsCombinedResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"CspgIacapi.combined_detections", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CspgIacapi#combined_detections\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |