Class: Falcon::DeviceControlExceptionReqV1
- Inherits:
-
Object
- Object
- Falcon::DeviceControlExceptionReqV1
- Defined in:
- lib/crimson-falcon/models/device_control_exception_req_v1.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Action to be taken for devices matching this exception.
-
#combined_id ⇒ Object
Combined identifier in the format ‘vendorID_productID_serialNumber’.
-
#description ⇒ Object
Description for this exception.
-
#expiration_time ⇒ Object
yyyy-mm-ddThh:mm:ssZ (UTC) format of the time to remove the exception if temporary.
-
#id ⇒ Object
Unique identifier for an exception.
-
#product_id ⇒ Object
Hexadecimal ProductID used to apply the exception.
-
#product_id_decimal ⇒ Object
Decimal ProductID used to apply the exception.
-
#product_name ⇒ Object
Product Name, optional.
-
#serial_number ⇒ Object
Serial number of the USB device.
-
#use_wildcard ⇒ Object
true indicates using blob syntax for USB serial numbers.
-
#vendor_id ⇒ Object
Hexadecimal VendorID used to apply the exception.
-
#vendor_id_decimal ⇒ Object
Decimal VendorID used to apply the exception.
-
#vendor_name ⇒ Object
Vendor Name, optional.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceControlExceptionReqV1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DeviceControlExceptionReqV1
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 146 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DeviceControlExceptionReqV1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DeviceControlExceptionReqV1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'combined_id') self.combined_id = attributes[:'combined_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'expiration_time') self.expiration_time = attributes[:'expiration_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.key?(:'product_id_decimal') self.product_id_decimal = attributes[:'product_id_decimal'] end if attributes.key?(:'product_name') self.product_name = attributes[:'product_name'] end if attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] end if attributes.key?(:'use_wildcard') self.use_wildcard = attributes[:'use_wildcard'] end if attributes.key?(:'vendor_id') self.vendor_id = attributes[:'vendor_id'] end if attributes.key?(:'vendor_id_decimal') self.vendor_id_decimal = attributes[:'vendor_id_decimal'] end if attributes.key?(:'vendor_name') self.vendor_name = attributes[:'vendor_name'] end end |
Instance Attribute Details
#action ⇒ Object
Action to be taken for devices matching this exception. Note: BLOCK_EXECUTE and BLOCK_WRITE_EXECUTE only valid for MASS_STORAGE class
35 36 37 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 35 def action @action end |
#combined_id ⇒ Object
Combined identifier in the format ‘vendorID_productID_serialNumber’. Not allowed if use_wildcard is true.
38 39 40 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 38 def combined_id @combined_id end |
#description ⇒ Object
Description for this exception. Maximum length: 512 characters.
41 42 43 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 41 def description @description end |
#expiration_time ⇒ Object
yyyy-mm-ddThh:mm:ssZ (UTC) format of the time to remove the exception if temporary. Must be in the future.
44 45 46 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 44 def expiration_time @expiration_time end |
#id ⇒ Object
Unique identifier for an exception. If omitted, a new exception will be created.
47 48 49 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 47 def id @id end |
#product_id ⇒ Object
Hexadecimal ProductID used to apply the exception. Must be a valid hex value representing a decimal value less than 65535. Only one of product_id or product_id_decimal is required.
50 51 52 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 50 def product_id @product_id end |
#product_id_decimal ⇒ Object
Decimal ProductID used to apply the exception. Must be a valid decimal value less than 65535. Only one of product_id or product_id_decimal is required.
53 54 55 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 53 def product_id_decimal @product_id_decimal end |
#product_name ⇒ Object
Product Name, optional.
56 57 58 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 56 def product_name @product_name end |
#serial_number ⇒ Object
Serial number of the USB device. Maximum length: 126 characters. Required when use_wildcard is true.
59 60 61 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 59 def serial_number @serial_number end |
#use_wildcard ⇒ Object
true indicates using blob syntax for USB serial numbers. When true, requires serial_number and either vendor_id(_decimal) and product_id(_decimal). Cannot be used with combined_id. Double asterisks (**) are not supported.
62 63 64 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 62 def use_wildcard @use_wildcard end |
#vendor_id ⇒ Object
Hexadecimal VendorID used to apply the exception. Must be a valid hex value representing a decimal value less than 65535. Only one of vendor_id or vendor_id_decimal is required.
65 66 67 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 65 def vendor_id @vendor_id end |
#vendor_id_decimal ⇒ Object
Decimal VendorID used to apply the exception. Must be a valid decimal value less than 65535. Only one of vendor_id or vendor_id_decimal is required.
68 69 70 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 68 def vendor_id_decimal @vendor_id_decimal end |
#vendor_name ⇒ Object
Vendor Name, optional
71 72 73 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 71 def vendor_name @vendor_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
115 116 117 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 115 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 96 def self.attribute_map { :'action' => :'action', :'combined_id' => :'combined_id', :'description' => :'description', :'expiration_time' => :'expiration_time', :'id' => :'id', :'product_id' => :'product_id', :'product_id_decimal' => :'product_id_decimal', :'product_name' => :'product_name', :'serial_number' => :'serial_number', :'use_wildcard' => :'use_wildcard', :'vendor_id' => :'vendor_id', :'vendor_id_decimal' => :'vendor_id_decimal', :'vendor_name' => :'vendor_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 272 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
139 140 141 142 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 139 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 120 def self.openapi_types { :'action' => :'String', :'combined_id' => :'String', :'description' => :'String', :'expiration_time' => :'Time', :'id' => :'String', :'product_id' => :'String', :'product_id_decimal' => :'String', :'product_name' => :'String', :'serial_number' => :'String', :'use_wildcard' => :'Boolean', :'vendor_id' => :'String', :'vendor_id_decimal' => :'String', :'vendor_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && combined_id == o.combined_id && description == o.description && expiration_time == o.expiration_time && id == o.id && product_id == o.product_id && product_id_decimal == o.product_id_decimal && product_name == o.product_name && serial_number == o.serial_number && use_wildcard == o.use_wildcard && vendor_id == o.vendor_id && vendor_id_decimal == o.vendor_id_decimal && vendor_name == o.vendor_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 303 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 374 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 279 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 265 def hash [action, combined_id, description, expiration_time, id, product_id, product_id_decimal, product_name, serial_number, use_wildcard, vendor_id, vendor_id_decimal, vendor_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 214 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
350 351 352 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 350 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 344 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 |
# File 'lib/crimson-falcon/models/device_control_exception_req_v1.rb', line 221 def valid? action_validator = EnumAttributeValidator.new('String', ["FULL_ACCESS", "BLOCK_ALL", "BLOCK_EXECUTE", "BLOCK_WRITE_EXECUTE"]) return false unless action_validator.valid?(@action) true end |