Class: Falcon::DeviceapiMappedDevicePoliciesSwagger
- Inherits:
-
Object
- Object
- Falcon::DeviceapiMappedDevicePoliciesSwagger
- Defined in:
- lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb
Instance Attribute Summary collapse
-
#aidr ⇒ Object
Returns the value of attribute aidr.
-
#airlock ⇒ Object
Returns the value of attribute airlock.
-
#application_abuse_prevention ⇒ Object
Returns the value of attribute application_abuse_prevention.
-
#automox ⇒ Object
Returns the value of attribute automox.
-
#aws_verified_access ⇒ Object
Returns the value of attribute aws_verified_access.
-
#browser_extension ⇒ Object
Returns the value of attribute browser_extension.
-
#cloud_ml ⇒ Object
Returns the value of attribute cloud_ml.
-
#content_update ⇒ Object
Returns the value of attribute content_update.
-
#customer_entitlements ⇒ Object
Returns the value of attribute customer_entitlements.
-
#data_protection ⇒ Object
Returns the value of attribute data_protection.
-
#data_protection_cloud ⇒ Object
Returns the value of attribute data_protection_cloud.
-
#device_control ⇒ Object
Returns the value of attribute device_control.
-
#exposure_management ⇒ Object
Returns the value of attribute exposure_management.
-
#fem_browser_extension_control ⇒ Object
Returns the value of attribute fem_browser_extension_control.
-
#fim ⇒ Object
Returns the value of attribute fim.
-
#firewall ⇒ Object
Returns the value of attribute firewall.
-
#global_config ⇒ Object
Returns the value of attribute global_config.
-
#host_retention ⇒ Object
Returns the value of attribute host_retention.
-
#identity_endpoint ⇒ Object
Returns the value of attribute identity_endpoint.
-
#identity_protection ⇒ Object
Returns the value of attribute identity_protection.
-
#it_automation ⇒ Object
Returns the value of attribute it_automation.
-
#jumpcloud ⇒ Object
Returns the value of attribute jumpcloud.
-
#kubernetes_admission_control ⇒ Object
Returns the value of attribute kubernetes_admission_control.
-
#logscale_collector ⇒ Object
Returns the value of attribute logscale_collector.
-
#mobile ⇒ Object
Returns the value of attribute mobile.
-
#netskope ⇒ Object
Returns the value of attribute netskope.
-
#network_scan_content ⇒ Object
Returns the value of attribute network_scan_content.
-
#prevention ⇒ Object
Returns the value of attribute prevention.
-
#remote_response ⇒ Object
Returns the value of attribute remote_response.
-
#sca ⇒ Object
Returns the value of attribute sca.
-
#sensor_update ⇒ Object
Returns the value of attribute sensor_update.
-
#system_tray ⇒ Object
Returns the value of attribute system_tray.
-
#vulnerability_management ⇒ Object
Returns the value of attribute vulnerability_management.
-
#ztl ⇒ Object
Returns the value of attribute ztl.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceapiMappedDevicePoliciesSwagger
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DeviceapiMappedDevicePoliciesSwagger
Initializes the object
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 195 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DeviceapiMappedDevicePoliciesSwagger` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DeviceapiMappedDevicePoliciesSwagger`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aidr') self.aidr = attributes[:'aidr'] end if attributes.key?(:'airlock') self.airlock = attributes[:'airlock'] end if attributes.key?(:'application_abuse_prevention') self.application_abuse_prevention = attributes[:'application_abuse_prevention'] end if attributes.key?(:'automox') self.automox = attributes[:'automox'] end if attributes.key?(:'aws_verified_access') self.aws_verified_access = attributes[:'aws_verified_access'] end if attributes.key?(:'browser_extension') self.browser_extension = attributes[:'browser_extension'] end if attributes.key?(:'cloud_ml') self.cloud_ml = attributes[:'cloud_ml'] end if attributes.key?(:'content_update') self.content_update = attributes[:'content_update'] end if attributes.key?(:'customer_entitlements') self.customer_entitlements = attributes[:'customer_entitlements'] end if attributes.key?(:'data_protection') self.data_protection = attributes[:'data_protection'] end if attributes.key?(:'data_protection_cloud') self.data_protection_cloud = attributes[:'data_protection_cloud'] end if attributes.key?(:'device_control') self.device_control = attributes[:'device_control'] end if attributes.key?(:'exposure_management') self.exposure_management = attributes[:'exposure_management'] end if attributes.key?(:'fem_browser_extension_control') self.fem_browser_extension_control = attributes[:'fem_browser_extension_control'] end if attributes.key?(:'fim') self.fim = attributes[:'fim'] end if attributes.key?(:'firewall') self.firewall = attributes[:'firewall'] end if attributes.key?(:'global_config') self.global_config = attributes[:'global_config'] end if attributes.key?(:'host_retention') self.host_retention = attributes[:'host_retention'] end if attributes.key?(:'identity_endpoint') self.identity_endpoint = attributes[:'identity_endpoint'] end if attributes.key?(:'identity_protection') self.identity_protection = attributes[:'identity_protection'] end if attributes.key?(:'it_automation') self.it_automation = attributes[:'it_automation'] end if attributes.key?(:'jumpcloud') self.jumpcloud = attributes[:'jumpcloud'] end if attributes.key?(:'kubernetes_admission_control') self.kubernetes_admission_control = attributes[:'kubernetes_admission_control'] end if attributes.key?(:'logscale_collector') self.logscale_collector = attributes[:'logscale_collector'] end if attributes.key?(:'mobile') self.mobile = attributes[:'mobile'] end if attributes.key?(:'netskope') self.netskope = attributes[:'netskope'] end if attributes.key?(:'network_scan_content') self.network_scan_content = attributes[:'network_scan_content'] end if attributes.key?(:'prevention') self.prevention = attributes[:'prevention'] end if attributes.key?(:'remote_response') self.remote_response = attributes[:'remote_response'] end if attributes.key?(:'sca') self.sca = attributes[:'sca'] end if attributes.key?(:'sensor_update') self.sensor_update = attributes[:'sensor_update'] end if attributes.key?(:'system_tray') self.system_tray = attributes[:'system_tray'] end if attributes.key?(:'vulnerability_management') self.vulnerability_management = attributes[:'vulnerability_management'] end if attributes.key?(:'ztl') self.ztl = attributes[:'ztl'] end end |
Instance Attribute Details
#aidr ⇒ Object
Returns the value of attribute aidr.
34 35 36 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 34 def aidr @aidr end |
#airlock ⇒ Object
Returns the value of attribute airlock.
36 37 38 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 36 def airlock @airlock end |
#application_abuse_prevention ⇒ Object
Returns the value of attribute application_abuse_prevention.
38 39 40 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 38 def application_abuse_prevention @application_abuse_prevention end |
#automox ⇒ Object
Returns the value of attribute automox.
40 41 42 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 40 def automox @automox end |
#aws_verified_access ⇒ Object
Returns the value of attribute aws_verified_access.
42 43 44 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 42 def aws_verified_access @aws_verified_access end |
#browser_extension ⇒ Object
Returns the value of attribute browser_extension.
44 45 46 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 44 def browser_extension @browser_extension end |
#cloud_ml ⇒ Object
Returns the value of attribute cloud_ml.
46 47 48 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 46 def cloud_ml @cloud_ml end |
#content_update ⇒ Object
Returns the value of attribute content_update.
48 49 50 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 48 def content_update @content_update end |
#customer_entitlements ⇒ Object
Returns the value of attribute customer_entitlements.
50 51 52 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 50 def customer_entitlements @customer_entitlements end |
#data_protection ⇒ Object
Returns the value of attribute data_protection.
52 53 54 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 52 def data_protection @data_protection end |
#data_protection_cloud ⇒ Object
Returns the value of attribute data_protection_cloud.
54 55 56 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 54 def data_protection_cloud @data_protection_cloud end |
#device_control ⇒ Object
Returns the value of attribute device_control.
56 57 58 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 56 def device_control @device_control end |
#exposure_management ⇒ Object
Returns the value of attribute exposure_management.
58 59 60 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 58 def exposure_management @exposure_management end |
#fem_browser_extension_control ⇒ Object
Returns the value of attribute fem_browser_extension_control.
60 61 62 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 60 def fem_browser_extension_control @fem_browser_extension_control end |
#fim ⇒ Object
Returns the value of attribute fim.
62 63 64 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 62 def fim @fim end |
#firewall ⇒ Object
Returns the value of attribute firewall.
64 65 66 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 64 def firewall @firewall end |
#global_config ⇒ Object
Returns the value of attribute global_config.
66 67 68 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 66 def global_config @global_config end |
#host_retention ⇒ Object
Returns the value of attribute host_retention.
68 69 70 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 68 def host_retention @host_retention end |
#identity_endpoint ⇒ Object
Returns the value of attribute identity_endpoint.
70 71 72 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 70 def identity_endpoint @identity_endpoint end |
#identity_protection ⇒ Object
Returns the value of attribute identity_protection.
72 73 74 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 72 def identity_protection @identity_protection end |
#it_automation ⇒ Object
Returns the value of attribute it_automation.
74 75 76 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 74 def it_automation @it_automation end |
#jumpcloud ⇒ Object
Returns the value of attribute jumpcloud.
76 77 78 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 76 def jumpcloud @jumpcloud end |
#kubernetes_admission_control ⇒ Object
Returns the value of attribute kubernetes_admission_control.
78 79 80 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 78 def kubernetes_admission_control @kubernetes_admission_control end |
#logscale_collector ⇒ Object
Returns the value of attribute logscale_collector.
80 81 82 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 80 def logscale_collector @logscale_collector end |
#mobile ⇒ Object
Returns the value of attribute mobile.
82 83 84 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 82 def mobile @mobile end |
#netskope ⇒ Object
Returns the value of attribute netskope.
84 85 86 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 84 def netskope @netskope end |
#network_scan_content ⇒ Object
Returns the value of attribute network_scan_content.
86 87 88 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 86 def network_scan_content @network_scan_content end |
#prevention ⇒ Object
Returns the value of attribute prevention.
88 89 90 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 88 def prevention @prevention end |
#remote_response ⇒ Object
Returns the value of attribute remote_response.
90 91 92 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 90 def remote_response @remote_response end |
#sca ⇒ Object
Returns the value of attribute sca.
92 93 94 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 92 def sca @sca end |
#sensor_update ⇒ Object
Returns the value of attribute sensor_update.
94 95 96 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 94 def sensor_update @sensor_update end |
#system_tray ⇒ Object
Returns the value of attribute system_tray.
96 97 98 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 96 def system_tray @system_tray end |
#vulnerability_management ⇒ Object
Returns the value of attribute vulnerability_management.
98 99 100 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 98 def vulnerability_management @vulnerability_management end |
#ztl ⇒ Object
Returns the value of attribute ztl.
100 101 102 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 100 def ztl @ztl end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
143 144 145 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 143 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 103 def self.attribute_map { :'aidr' => :'aidr', :'airlock' => :'airlock', :'application_abuse_prevention' => :'application-abuse-prevention', :'automox' => :'automox', :'aws_verified_access' => :'aws-verified-access', :'browser_extension' => :'browser-extension', :'cloud_ml' => :'cloud-ml', :'content_update' => :'content-update', :'customer_entitlements' => :'customer-entitlements', :'data_protection' => :'data-protection', :'data_protection_cloud' => :'data-protection-cloud', :'device_control' => :'device_control', :'exposure_management' => :'exposure-management', :'fem_browser_extension_control' => :'fem-browser-extension-control', :'fim' => :'fim', :'firewall' => :'firewall', :'global_config' => :'global_config', :'host_retention' => :'host-retention', :'identity_endpoint' => :'identity-endpoint', :'identity_protection' => :'identity-protection', :'it_automation' => :'it-automation', :'jumpcloud' => :'jumpcloud', :'kubernetes_admission_control' => :'kubernetes-admission-control', :'logscale_collector' => :'logscale-collector', :'mobile' => :'mobile', :'netskope' => :'netskope', :'network_scan_content' => :'network-scan-content', :'prevention' => :'prevention', :'remote_response' => :'remote_response', :'sca' => :'sca', :'sensor_update' => :'sensor_update', :'system_tray' => :'system-tray', :'vulnerability_management' => :'vulnerability-management', :'ztl' => :'ztl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
414 415 416 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 414 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
188 189 190 191 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 188 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 148 def self.openapi_types { :'aidr' => :'DeviceDevicePolicy', :'airlock' => :'DeviceDevicePolicy', :'application_abuse_prevention' => :'DeviceDevicePolicy', :'automox' => :'DeviceDevicePolicy', :'aws_verified_access' => :'DeviceDevicePolicy', :'browser_extension' => :'DeviceDevicePolicy', :'cloud_ml' => :'DeviceDevicePolicy', :'content_update' => :'DeviceDevicePolicy', :'customer_entitlements' => :'DeviceDevicePolicy', :'data_protection' => :'DeviceDevicePolicy', :'data_protection_cloud' => :'DeviceDevicePolicy', :'device_control' => :'DeviceDevicePolicy', :'exposure_management' => :'DeviceDevicePolicy', :'fem_browser_extension_control' => :'DeviceDevicePolicy', :'fim' => :'DeviceDevicePolicy', :'firewall' => :'DeviceDevicePolicy', :'global_config' => :'DeviceDevicePolicy', :'host_retention' => :'DeviceDevicePolicy', :'identity_endpoint' => :'DeviceDevicePolicy', :'identity_protection' => :'DeviceDevicePolicy', :'it_automation' => :'DeviceDevicePolicy', :'jumpcloud' => :'DeviceDevicePolicy', :'kubernetes_admission_control' => :'DeviceDevicePolicy', :'logscale_collector' => :'DeviceDevicePolicy', :'mobile' => :'DeviceDevicePolicy', :'netskope' => :'DeviceDevicePolicy', :'network_scan_content' => :'DeviceDevicePolicy', :'prevention' => :'DeviceDevicePolicy', :'remote_response' => :'DeviceDevicePolicy', :'sca' => :'DeviceDevicePolicy', :'sensor_update' => :'DeviceDevicePolicy', :'system_tray' => :'DeviceDevicePolicy', :'vulnerability_management' => :'DeviceDevicePolicy', :'ztl' => :'DeviceDevicePolicy' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 360 def ==(o) return true if self.equal?(o) self.class == o.class && aidr == o.aidr && airlock == o.airlock && application_abuse_prevention == o.application_abuse_prevention && automox == o.automox && aws_verified_access == o.aws_verified_access && browser_extension == o.browser_extension && cloud_ml == o.cloud_ml && content_update == o.content_update && customer_entitlements == o.customer_entitlements && data_protection == o.data_protection && data_protection_cloud == o.data_protection_cloud && device_control == o.device_control && exposure_management == o.exposure_management && fem_browser_extension_control == o.fem_browser_extension_control && fim == o.fim && firewall == o.firewall && global_config == o.global_config && host_retention == o.host_retention && identity_endpoint == o.identity_endpoint && identity_protection == o.identity_protection && it_automation == o.it_automation && jumpcloud == o.jumpcloud && kubernetes_admission_control == o.kubernetes_admission_control && logscale_collector == o.logscale_collector && mobile == o.mobile && netskope == o.netskope && network_scan_content == o.network_scan_content && prevention == o.prevention && remote_response == o.remote_response && sca == o.sca && sensor_update == o.sensor_update && system_tray == o.system_tray && vulnerability_management == o.vulnerability_management && ztl == o.ztl end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 445 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 516 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 421 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
401 402 403 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 401 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
407 408 409 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 407 def hash [aidr, airlock, application_abuse_prevention, automox, aws_verified_access, browser_extension, cloud_ml, content_update, customer_entitlements, data_protection, data_protection_cloud, device_control, exposure_management, fem_browser_extension_control, fim, firewall, global_config, host_retention, identity_endpoint, identity_protection, it_automation, jumpcloud, kubernetes_admission_control, logscale_collector, mobile, netskope, network_scan_content, prevention, remote_response, sca, sensor_update, system_tray, vulnerability_management, ztl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
347 348 349 350 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 347 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
492 493 494 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 492 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 498 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
486 487 488 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 486 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
354 355 356 |
# File 'lib/crimson-falcon/models/deviceapi_mapped_device_policies_swagger.rb', line 354 def valid? true end |