Class: Falcon::DiscoverIot
- Inherits:
-
Object
- Object
- Falcon::DiscoverIot
- Defined in:
- lib/crimson-falcon/api/discover_iot.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_iot_hosts(ids, opts = {}) ⇒ DomainDiscoverAPIIoTHostEntitiesResponse
Get details on IoT assets by providing one or more IDs.
-
#get_iot_hosts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIIoTHostEntitiesResponse, Integer, Hash)>
Get details on IoT assets by providing one or more IDs.
-
#initialize(api_client = ApiClient.default) ⇒ DiscoverIot
constructor
A new instance of DiscoverIot.
-
#query_iot_hosts(opts = {}) ⇒ MsaspecQueryResponse
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_iot_hosts_v2(opts = {}) ⇒ DomainDiscoverAPIResponse
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_iot_hosts_v2_with_http_info(opts = {}) ⇒ Array<(DomainDiscoverAPIResponse, Integer, Hash)>
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
-
#query_iot_hosts_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DiscoverIot
Returns a new instance of DiscoverIot.
35 36 37 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_iot_hosts(ids, opts = {}) ⇒ DomainDiscoverAPIIoTHostEntitiesResponse
Get details on IoT assets by providing one or more IDs.
42 43 44 45 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 42 def get_iot_hosts(ids, opts = {}) data, _status_code, _headers = get_iot_hosts_with_http_info(ids, opts) data end |
#get_iot_hosts_with_http_info(ids, opts = {}) ⇒ Array<(DomainDiscoverAPIIoTHostEntitiesResponse, Integer, Hash)>
Get details on IoT assets by providing one or more IDs.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 51 def get_iot_hosts_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DiscoverIot.get_iot_hosts ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling DiscoverIot.get_iot_hosts" end # resource path local_var_path = '/discover/entities/iot-hosts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPIIoTHostEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"DiscoverIot.get_iot_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DiscoverIot#get_iot_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_iot_hosts(opts = {}) ⇒ MsaspecQueryResponse
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
107 108 109 110 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 107 def query_iot_hosts(opts = {}) data, _status_code, _headers = query_iot_hosts_with_http_info(opts) data end |
#query_iot_hosts_v2(opts = {}) ⇒ DomainDiscoverAPIResponse
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
186 187 188 189 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 186 def query_iot_hosts_v2(opts = {}) data, _status_code, _headers = query_iot_hosts_v2_with_http_info(opts) data end |
#query_iot_hosts_v2_with_http_info(opts = {}) ⇒ Array<(DomainDiscoverAPIResponse, Integer, Hash)>
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 198 def query_iot_hosts_v2_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DiscoverIot.query_iot_hosts_v2 ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DiscoverIot.query_iot_hosts_v2, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DiscoverIot.query_iot_hosts_v2, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/iot-hosts/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainDiscoverAPIResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"DiscoverIot.query_iot_hosts_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DiscoverIot#query_iot_hosts_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_iot_hosts_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for IoT assets in your environment by providing an FQL (Falcon Query Language) filter and paging details. Returns a set of asset IDs which match the filter criteria.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/crimson-falcon/api/discover_iot.rb', line 119 def query_iot_hosts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DiscoverIot.query_iot_hosts ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling DiscoverIot.query_iot_hosts, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DiscoverIot.query_iot_hosts, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DiscoverIot.query_iot_hosts, must be greater than or equal to 1.' end # resource path local_var_path = '/discover/queries/iot-hosts/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"DiscoverIot.query_iot_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DiscoverIot#query_iot_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |