Class: Falcon::DomainAWSAccountV2
- Inherits:
-
Object
- Object
- Falcon::DomainAWSAccountV2
- Defined in:
- lib/crimson-falcon/models/domain_aws_account_v2.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
12 digit AWS provided unique identifier for the account.
-
#account_name ⇒ Object
AWS account name.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#active_regions ⇒ Object
Returns the value of attribute active_regions.
-
#aws_cloudtrail_bucket_name ⇒ Object
AWS CloudTrail bucket name to store logs.
-
#aws_cloudtrail_region ⇒ Object
AWS CloudTrail region.
-
#aws_eventbus_arn ⇒ Object
AWS Eventbus ARN.
-
#aws_permissions_status ⇒ Object
Permissions status returned via API.
-
#behavior_assessment_enabled ⇒ Object
Returns the value of attribute behavior_assessment_enabled.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_registration_enabled ⇒ Object
Returns the value of attribute cloud_registration_enabled.
-
#cloud_scopes ⇒ Object
Returns the value of attribute cloud_scopes.
-
#cloudformation_root_stack_arn ⇒ Object
Returns the value of attribute cloudformation_root_stack_arn.
-
#cloudformation_update_url ⇒ Object
Returns the value of attribute cloudformation_update_url.
-
#cloudformation_url ⇒ Object
Returns the value of attribute cloudformation_url.
-
#conditions ⇒ Object
Returns the value of attribute conditions.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#cspm_enabled ⇒ Object
Returns the value of attribute cspm_enabled.
-
#d4c ⇒ Object
Returns the value of attribute d4c.
-
#d4c_migrated ⇒ Object
Returns the value of attribute d4c_migrated.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#dspm_enabled ⇒ Object
Returns the value of attribute dspm_enabled.
-
#dspm_host_account_id ⇒ Object
Returns the value of attribute dspm_host_account_id.
-
#dspm_role_arn ⇒ Object
Returns the value of attribute dspm_role_arn.
-
#environment ⇒ Object
Returns the value of attribute environment.
-
#eventbus_name ⇒ Object
Returns the value of attribute eventbus_name.
-
#external_id ⇒ Object
ID assigned for use with cross account IAM role access.
-
#falcon_client_id ⇒ Object
Returns the value of attribute falcon_client_id.
-
#features ⇒ Object
Returns the value of attribute features.
-
#iam_role_arn ⇒ Object
The full arn of the IAM role created in this account to control access.
-
#id ⇒ Object
Returns the value of attribute id.
-
#intermediate_role_arn ⇒ Object
Returns the value of attribute intermediate_role_arn.
-
#inventory_filter ⇒ Object
Returns the value of attribute inventory_filter.
-
#is_cloud_registration ⇒ Object
Returns the value of attribute is_cloud_registration.
-
#is_cspm_lite ⇒ Object
Is CSPM Lite enabled.
-
#is_custom_rolename ⇒ Object
Returns the value of attribute is_custom_rolename.
-
#is_delegated_admin ⇒ Object
Returns the value of attribute is_delegated_admin.
-
#is_master ⇒ Object
Returns the value of attribute is_master.
-
#ngsiem_enabled ⇒ Object
Returns the value of attribute ngsiem_enabled.
-
#organization_id ⇒ Object
Up to 34 character AWS provided unique identifier for the organization.
-
#remediation_cloudformation_url ⇒ Object
Returns the value of attribute remediation_cloudformation_url.
-
#remediation_region ⇒ Object
Returns the value of attribute remediation_region.
-
#remediation_tou_accepted ⇒ Object
Returns the value of attribute remediation_tou_accepted.
-
#resource_name_prefix ⇒ Object
Returns the value of attribute resource_name_prefix.
-
#resource_name_suffix ⇒ Object
Returns the value of attribute resource_name_suffix.
-
#root_account_id ⇒ Object
12 digit AWS provided unique identifier for the root account (of the organization this account belongs to).
-
#root_iam_role ⇒ Object
Returns the value of attribute root_iam_role.
-
#s3_url ⇒ Object
Returns the value of attribute s3_url.
-
#secondary_role_arn ⇒ Object
Returns the value of attribute secondary_role_arn.
-
#sensor_management_enabled ⇒ Object
Returns the value of attribute sensor_management_enabled.
-
#settings ⇒ Object
Returns the value of attribute settings.
-
#status ⇒ Object
Account registration status.
-
#target_ous ⇒ Object
Returns the value of attribute target_ous.
-
#template_source_region ⇒ Object
Returns the value of attribute template_source_region.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#use_existing_cloudtrail ⇒ Object
Returns the value of attribute use_existing_cloudtrail.
-
#valid ⇒ Object
Returns the value of attribute valid.
-
#vulnerability_scanning_enabled ⇒ Object
Returns the value of attribute vulnerability_scanning_enabled.
-
#vulnerability_scanning_host_account_id ⇒ Object
Returns the value of attribute vulnerability_scanning_host_account_id.
-
#vulnerability_scanning_role_arn ⇒ Object
Returns the value of attribute vulnerability_scanning_role_arn.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainAWSAccountV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainAWSAccountV2
Initializes the object
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 311 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainAWSAccountV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainAWSAccountV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'active_regions') if (value = attributes[:'active_regions']).is_a?(Array) self.active_regions = value end end if attributes.key?(:'aws_cloudtrail_bucket_name') self.aws_cloudtrail_bucket_name = attributes[:'aws_cloudtrail_bucket_name'] end if attributes.key?(:'aws_cloudtrail_region') self.aws_cloudtrail_region = attributes[:'aws_cloudtrail_region'] end if attributes.key?(:'aws_eventbus_arn') self.aws_eventbus_arn = attributes[:'aws_eventbus_arn'] end if attributes.key?(:'aws_permissions_status') if (value = attributes[:'aws_permissions_status']).is_a?(Array) self. = value end end if attributes.key?(:'behavior_assessment_enabled') self.behavior_assessment_enabled = attributes[:'behavior_assessment_enabled'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_registration_enabled') self.cloud_registration_enabled = attributes[:'cloud_registration_enabled'] end if attributes.key?(:'cloud_scopes') if (value = attributes[:'cloud_scopes']).is_a?(Array) self.cloud_scopes = value end end if attributes.key?(:'cloudformation_root_stack_arn') self.cloudformation_root_stack_arn = attributes[:'cloudformation_root_stack_arn'] end if attributes.key?(:'cloudformation_update_url') self.cloudformation_update_url = attributes[:'cloudformation_update_url'] end if attributes.key?(:'cloudformation_url') self.cloudformation_url = attributes[:'cloudformation_url'] end if attributes.key?(:'conditions') if (value = attributes[:'conditions']).is_a?(Array) self.conditions = value end end if attributes.key?(:'cspm_enabled') self.cspm_enabled = attributes[:'cspm_enabled'] end if attributes.key?(:'d4c') self.d4c = attributes[:'d4c'] end if attributes.key?(:'d4c_migrated') self.d4c_migrated = attributes[:'d4c_migrated'] end if attributes.key?(:'dspm_enabled') self.dspm_enabled = attributes[:'dspm_enabled'] end if attributes.key?(:'dspm_host_account_id') self.dspm_host_account_id = attributes[:'dspm_host_account_id'] end if attributes.key?(:'dspm_role_arn') self.dspm_role_arn = attributes[:'dspm_role_arn'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end if attributes.key?(:'eventbus_name') self.eventbus_name = attributes[:'eventbus_name'] end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'falcon_client_id') self.falcon_client_id = attributes[:'falcon_client_id'] end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end end if attributes.key?(:'iam_role_arn') self.iam_role_arn = attributes[:'iam_role_arn'] end if attributes.key?(:'intermediate_role_arn') self.intermediate_role_arn = attributes[:'intermediate_role_arn'] end if attributes.key?(:'inventory_filter') if (value = attributes[:'inventory_filter']).is_a?(Array) self.inventory_filter = value end end if attributes.key?(:'is_cloud_registration') self.is_cloud_registration = attributes[:'is_cloud_registration'] end if attributes.key?(:'is_cspm_lite') self.is_cspm_lite = attributes[:'is_cspm_lite'] end if attributes.key?(:'is_custom_rolename') self.is_custom_rolename = attributes[:'is_custom_rolename'] end if attributes.key?(:'is_delegated_admin') self.is_delegated_admin = attributes[:'is_delegated_admin'] end if attributes.key?(:'is_master') self.is_master = attributes[:'is_master'] end if attributes.key?(:'ngsiem_enabled') self.ngsiem_enabled = attributes[:'ngsiem_enabled'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'remediation_cloudformation_url') self.remediation_cloudformation_url = attributes[:'remediation_cloudformation_url'] end if attributes.key?(:'remediation_region') self.remediation_region = attributes[:'remediation_region'] end if attributes.key?(:'remediation_tou_accepted') self.remediation_tou_accepted = attributes[:'remediation_tou_accepted'] end if attributes.key?(:'resource_name_prefix') self.resource_name_prefix = attributes[:'resource_name_prefix'] end if attributes.key?(:'resource_name_suffix') self.resource_name_suffix = attributes[:'resource_name_suffix'] end if attributes.key?(:'root_account_id') self.root_account_id = attributes[:'root_account_id'] end if attributes.key?(:'root_iam_role') self.root_iam_role = attributes[:'root_iam_role'] end if attributes.key?(:'s3_url') self.s3_url = attributes[:'s3_url'] end if attributes.key?(:'secondary_role_arn') self.secondary_role_arn = attributes[:'secondary_role_arn'] end if attributes.key?(:'sensor_management_enabled') self.sensor_management_enabled = attributes[:'sensor_management_enabled'] end if attributes.key?(:'settings') self.settings = attributes[:'settings'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'target_ous') if (value = attributes[:'target_ous']).is_a?(Array) self.target_ous = value end end if attributes.key?(:'template_source_region') self.template_source_region = attributes[:'template_source_region'] end if attributes.key?(:'use_existing_cloudtrail') self.use_existing_cloudtrail = attributes[:'use_existing_cloudtrail'] end if attributes.key?(:'valid') self.valid = attributes[:'valid'] end if attributes.key?(:'vulnerability_scanning_enabled') self.vulnerability_scanning_enabled = attributes[:'vulnerability_scanning_enabled'] end if attributes.key?(:'vulnerability_scanning_host_account_id') self.vulnerability_scanning_host_account_id = attributes[:'vulnerability_scanning_host_account_id'] end if attributes.key?(:'vulnerability_scanning_role_arn') self.vulnerability_scanning_role_arn = attributes[:'vulnerability_scanning_role_arn'] end end |
Instance Attribute Details
#account_id ⇒ Object
12 digit AWS provided unique identifier for the account.
43 44 45 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 43 def account_id @account_id end |
#account_name ⇒ Object
AWS account name
46 47 48 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 46 def account_name @account_name end |
#account_type ⇒ Object
Returns the value of attribute account_type.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 48 def account_type @account_type end |
#active_regions ⇒ Object
Returns the value of attribute active_regions.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 50 def active_regions @active_regions end |
#aws_cloudtrail_bucket_name ⇒ Object
AWS CloudTrail bucket name to store logs.
53 54 55 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 53 def aws_cloudtrail_bucket_name @aws_cloudtrail_bucket_name end |
#aws_cloudtrail_region ⇒ Object
AWS CloudTrail region.
56 57 58 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 56 def aws_cloudtrail_region @aws_cloudtrail_region end |
#aws_eventbus_arn ⇒ Object
AWS Eventbus ARN.
59 60 61 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 59 def aws_eventbus_arn @aws_eventbus_arn end |
#aws_permissions_status ⇒ Object
Permissions status returned via API.
62 63 64 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 62 def @aws_permissions_status end |
#behavior_assessment_enabled ⇒ Object
Returns the value of attribute behavior_assessment_enabled.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 64 def behavior_assessment_enabled @behavior_assessment_enabled end |
#cid ⇒ Object
Returns the value of attribute cid.
66 67 68 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 66 def cid @cid end |
#cloud_registration_enabled ⇒ Object
Returns the value of attribute cloud_registration_enabled.
68 69 70 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 68 def cloud_registration_enabled @cloud_registration_enabled end |
#cloud_scopes ⇒ Object
Returns the value of attribute cloud_scopes.
70 71 72 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 70 def cloud_scopes @cloud_scopes end |
#cloudformation_root_stack_arn ⇒ Object
Returns the value of attribute cloudformation_root_stack_arn.
72 73 74 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 72 def cloudformation_root_stack_arn @cloudformation_root_stack_arn end |
#cloudformation_update_url ⇒ Object
Returns the value of attribute cloudformation_update_url.
74 75 76 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 74 def cloudformation_update_url @cloudformation_update_url end |
#cloudformation_url ⇒ Object
Returns the value of attribute cloudformation_url.
76 77 78 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 76 def cloudformation_url @cloudformation_url end |
#conditions ⇒ Object
Returns the value of attribute conditions.
78 79 80 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 78 def conditions @conditions end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 34 def created_at @created_at end |
#cspm_enabled ⇒ Object
Returns the value of attribute cspm_enabled.
80 81 82 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 80 def cspm_enabled @cspm_enabled end |
#d4c ⇒ Object
Returns the value of attribute d4c.
82 83 84 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 82 def d4c @d4c end |
#d4c_migrated ⇒ Object
Returns the value of attribute d4c_migrated.
84 85 86 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 84 def d4c_migrated @d4c_migrated end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 36 def deleted_at @deleted_at end |
#dspm_enabled ⇒ Object
Returns the value of attribute dspm_enabled.
86 87 88 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 86 def dspm_enabled @dspm_enabled end |
#dspm_host_account_id ⇒ Object
Returns the value of attribute dspm_host_account_id.
88 89 90 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 88 def dspm_host_account_id @dspm_host_account_id end |
#dspm_role_arn ⇒ Object
Returns the value of attribute dspm_role_arn.
90 91 92 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 90 def dspm_role_arn @dspm_role_arn end |
#environment ⇒ Object
Returns the value of attribute environment.
92 93 94 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 92 def environment @environment end |
#eventbus_name ⇒ Object
Returns the value of attribute eventbus_name.
94 95 96 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 94 def eventbus_name @eventbus_name end |
#external_id ⇒ Object
ID assigned for use with cross account IAM role access.
97 98 99 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 97 def external_id @external_id end |
#falcon_client_id ⇒ Object
Returns the value of attribute falcon_client_id.
99 100 101 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 99 def falcon_client_id @falcon_client_id end |
#features ⇒ Object
Returns the value of attribute features.
101 102 103 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 101 def features @features end |
#iam_role_arn ⇒ Object
The full arn of the IAM role created in this account to control access.
104 105 106 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 104 def iam_role_arn @iam_role_arn end |
#id ⇒ Object
Returns the value of attribute id.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 38 def id @id end |
#intermediate_role_arn ⇒ Object
Returns the value of attribute intermediate_role_arn.
106 107 108 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 106 def intermediate_role_arn @intermediate_role_arn end |
#inventory_filter ⇒ Object
Returns the value of attribute inventory_filter.
108 109 110 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 108 def inventory_filter @inventory_filter end |
#is_cloud_registration ⇒ Object
Returns the value of attribute is_cloud_registration.
110 111 112 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 110 def is_cloud_registration @is_cloud_registration end |
#is_cspm_lite ⇒ Object
Is CSPM Lite enabled.
113 114 115 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 113 def is_cspm_lite @is_cspm_lite end |
#is_custom_rolename ⇒ Object
Returns the value of attribute is_custom_rolename.
115 116 117 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 115 def is_custom_rolename @is_custom_rolename end |
#is_delegated_admin ⇒ Object
Returns the value of attribute is_delegated_admin.
117 118 119 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 117 def is_delegated_admin @is_delegated_admin end |
#is_master ⇒ Object
Returns the value of attribute is_master.
119 120 121 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 119 def is_master @is_master end |
#ngsiem_enabled ⇒ Object
Returns the value of attribute ngsiem_enabled.
121 122 123 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 121 def ngsiem_enabled @ngsiem_enabled end |
#organization_id ⇒ Object
Up to 34 character AWS provided unique identifier for the organization.
124 125 126 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 124 def organization_id @organization_id end |
#remediation_cloudformation_url ⇒ Object
Returns the value of attribute remediation_cloudformation_url.
126 127 128 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 126 def remediation_cloudformation_url @remediation_cloudformation_url end |
#remediation_region ⇒ Object
Returns the value of attribute remediation_region.
128 129 130 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 128 def remediation_region @remediation_region end |
#remediation_tou_accepted ⇒ Object
Returns the value of attribute remediation_tou_accepted.
130 131 132 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 130 def remediation_tou_accepted @remediation_tou_accepted end |
#resource_name_prefix ⇒ Object
Returns the value of attribute resource_name_prefix.
132 133 134 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 132 def resource_name_prefix @resource_name_prefix end |
#resource_name_suffix ⇒ Object
Returns the value of attribute resource_name_suffix.
134 135 136 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 134 def resource_name_suffix @resource_name_suffix end |
#root_account_id ⇒ Object
12 digit AWS provided unique identifier for the root account (of the organization this account belongs to).
137 138 139 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 137 def root_account_id @root_account_id end |
#root_iam_role ⇒ Object
Returns the value of attribute root_iam_role.
139 140 141 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 139 def root_iam_role @root_iam_role end |
#s3_url ⇒ Object
Returns the value of attribute s3_url.
141 142 143 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 141 def s3_url @s3_url end |
#secondary_role_arn ⇒ Object
Returns the value of attribute secondary_role_arn.
143 144 145 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 143 def secondary_role_arn @secondary_role_arn end |
#sensor_management_enabled ⇒ Object
Returns the value of attribute sensor_management_enabled.
145 146 147 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 145 def sensor_management_enabled @sensor_management_enabled end |
#settings ⇒ Object
Returns the value of attribute settings.
147 148 149 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 147 def settings @settings end |
#status ⇒ Object
Account registration status.
150 151 152 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 150 def status @status end |
#target_ous ⇒ Object
Returns the value of attribute target_ous.
152 153 154 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 152 def target_ous @target_ous end |
#template_source_region ⇒ Object
Returns the value of attribute template_source_region.
154 155 156 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 154 def template_source_region @template_source_region end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 40 def updated_at @updated_at end |
#use_existing_cloudtrail ⇒ Object
Returns the value of attribute use_existing_cloudtrail.
156 157 158 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 156 def use_existing_cloudtrail @use_existing_cloudtrail end |
#valid ⇒ Object
Returns the value of attribute valid.
158 159 160 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 158 def valid @valid end |
#vulnerability_scanning_enabled ⇒ Object
Returns the value of attribute vulnerability_scanning_enabled.
160 161 162 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 160 def vulnerability_scanning_enabled @vulnerability_scanning_enabled end |
#vulnerability_scanning_host_account_id ⇒ Object
Returns the value of attribute vulnerability_scanning_host_account_id.
162 163 164 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 162 def vulnerability_scanning_host_account_id @vulnerability_scanning_host_account_id end |
#vulnerability_scanning_role_arn ⇒ Object
Returns the value of attribute vulnerability_scanning_role_arn.
164 165 166 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 164 def vulnerability_scanning_role_arn @vulnerability_scanning_role_arn end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
233 234 235 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 233 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 167 def self.attribute_map { :'created_at' => :'CreatedAt', :'deleted_at' => :'DeletedAt', :'id' => :'ID', :'updated_at' => :'UpdatedAt', :'account_id' => :'account_id', :'account_name' => :'account_name', :'account_type' => :'account_type', :'active_regions' => :'active_regions', :'aws_cloudtrail_bucket_name' => :'aws_cloudtrail_bucket_name', :'aws_cloudtrail_region' => :'aws_cloudtrail_region', :'aws_eventbus_arn' => :'aws_eventbus_arn', :'aws_permissions_status' => :'aws_permissions_status', :'behavior_assessment_enabled' => :'behavior_assessment_enabled', :'cid' => :'cid', :'cloud_registration_enabled' => :'cloud_registration_enabled', :'cloud_scopes' => :'cloud_scopes', :'cloudformation_root_stack_arn' => :'cloudformation_root_stack_arn', :'cloudformation_update_url' => :'cloudformation_update_url', :'cloudformation_url' => :'cloudformation_url', :'conditions' => :'conditions', :'cspm_enabled' => :'cspm_enabled', :'d4c' => :'d4c', :'d4c_migrated' => :'d4c_migrated', :'dspm_enabled' => :'dspm_enabled', :'dspm_host_account_id' => :'dspm_host_account_id', :'dspm_role_arn' => :'dspm_role_arn', :'environment' => :'environment', :'eventbus_name' => :'eventbus_name', :'external_id' => :'external_id', :'falcon_client_id' => :'falcon_client_id', :'features' => :'features', :'iam_role_arn' => :'iam_role_arn', :'intermediate_role_arn' => :'intermediate_role_arn', :'inventory_filter' => :'inventory_filter', :'is_cloud_registration' => :'is_cloud_registration', :'is_cspm_lite' => :'is_cspm_lite', :'is_custom_rolename' => :'is_custom_rolename', :'is_delegated_admin' => :'is_delegated_admin', :'is_master' => :'is_master', :'ngsiem_enabled' => :'ngsiem_enabled', :'organization_id' => :'organization_id', :'remediation_cloudformation_url' => :'remediation_cloudformation_url', :'remediation_region' => :'remediation_region', :'remediation_tou_accepted' => :'remediation_tou_accepted', :'resource_name_prefix' => :'resource_name_prefix', :'resource_name_suffix' => :'resource_name_suffix', :'root_account_id' => :'root_account_id', :'root_iam_role' => :'root_iam_role', :'s3_url' => :'s3_url', :'secondary_role_arn' => :'secondary_role_arn', :'sensor_management_enabled' => :'sensor_management_enabled', :'settings' => :'settings', :'status' => :'status', :'target_ous' => :'target_ous', :'template_source_region' => :'template_source_region', :'use_existing_cloudtrail' => :'use_existing_cloudtrail', :'valid' => :'valid', :'vulnerability_scanning_enabled' => :'vulnerability_scanning_enabled', :'vulnerability_scanning_host_account_id' => :'vulnerability_scanning_host_account_id', :'vulnerability_scanning_role_arn' => :'vulnerability_scanning_role_arn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
714 715 716 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 714 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
304 305 306 307 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 304 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 238 def self.openapi_types { :'created_at' => :'Time', :'deleted_at' => :'Time', :'id' => :'Integer', :'updated_at' => :'Time', :'account_id' => :'String', :'account_name' => :'String', :'account_type' => :'String', :'active_regions' => :'Array<String>', :'aws_cloudtrail_bucket_name' => :'String', :'aws_cloudtrail_region' => :'String', :'aws_eventbus_arn' => :'String', :'aws_permissions_status' => :'Array<DomainPermission>', :'behavior_assessment_enabled' => :'Boolean', :'cid' => :'String', :'cloud_registration_enabled' => :'Boolean', :'cloud_scopes' => :'Array<DomainCloudScope>', :'cloudformation_root_stack_arn' => :'String', :'cloudformation_update_url' => :'String', :'cloudformation_url' => :'String', :'conditions' => :'Array<StatemgmtCondition>', :'cspm_enabled' => :'Boolean', :'d4c' => :'DomainAWSD4CAccountV1', :'d4c_migrated' => :'Boolean', :'dspm_enabled' => :'Boolean', :'dspm_host_account_id' => :'String', :'dspm_role_arn' => :'String', :'environment' => :'String', :'eventbus_name' => :'String', :'external_id' => :'String', :'falcon_client_id' => :'String', :'features' => :'Array<DomainProductFeatures>', :'iam_role_arn' => :'String', :'intermediate_role_arn' => :'String', :'inventory_filter' => :'Array<DomainAWSInventoryFilterSetting>', :'is_cloud_registration' => :'Boolean', :'is_cspm_lite' => :'Boolean', :'is_custom_rolename' => :'Boolean', :'is_delegated_admin' => :'Boolean', :'is_master' => :'Boolean', :'ngsiem_enabled' => :'Boolean', :'organization_id' => :'String', :'remediation_cloudformation_url' => :'String', :'remediation_region' => :'String', :'remediation_tou_accepted' => :'Time', :'resource_name_prefix' => :'String', :'resource_name_suffix' => :'String', :'root_account_id' => :'String', :'root_iam_role' => :'Boolean', :'s3_url' => :'String', :'secondary_role_arn' => :'String', :'sensor_management_enabled' => :'Boolean', :'settings' => :'Object', :'status' => :'String', :'target_ous' => :'Array<String>', :'template_source_region' => :'String', :'use_existing_cloudtrail' => :'Boolean', :'valid' => :'Boolean', :'vulnerability_scanning_enabled' => :'Boolean', :'vulnerability_scanning_host_account_id' => :'String', :'vulnerability_scanning_role_arn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 634 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && deleted_at == o.deleted_at && id == o.id && updated_at == o.updated_at && account_id == o.account_id && account_name == o.account_name && account_type == o.account_type && active_regions == o.active_regions && aws_cloudtrail_bucket_name == o.aws_cloudtrail_bucket_name && aws_cloudtrail_region == o.aws_cloudtrail_region && aws_eventbus_arn == o.aws_eventbus_arn && == o. && behavior_assessment_enabled == o.behavior_assessment_enabled && cid == o.cid && cloud_registration_enabled == o.cloud_registration_enabled && cloud_scopes == o.cloud_scopes && cloudformation_root_stack_arn == o.cloudformation_root_stack_arn && cloudformation_update_url == o.cloudformation_update_url && cloudformation_url == o.cloudformation_url && conditions == o.conditions && cspm_enabled == o.cspm_enabled && d4c == o.d4c && d4c_migrated == o.d4c_migrated && dspm_enabled == o.dspm_enabled && dspm_host_account_id == o.dspm_host_account_id && dspm_role_arn == o.dspm_role_arn && environment == o.environment && eventbus_name == o.eventbus_name && external_id == o.external_id && falcon_client_id == o.falcon_client_id && features == o.features && iam_role_arn == o.iam_role_arn && intermediate_role_arn == o.intermediate_role_arn && inventory_filter == o.inventory_filter && is_cloud_registration == o.is_cloud_registration && is_cspm_lite == o.is_cspm_lite && is_custom_rolename == o.is_custom_rolename && is_delegated_admin == o.is_delegated_admin && is_master == o.is_master && ngsiem_enabled == o.ngsiem_enabled && organization_id == o.organization_id && remediation_cloudformation_url == o.remediation_cloudformation_url && remediation_region == o.remediation_region && remediation_tou_accepted == o.remediation_tou_accepted && resource_name_prefix == o.resource_name_prefix && resource_name_suffix == o.resource_name_suffix && root_account_id == o.root_account_id && root_iam_role == o.root_iam_role && s3_url == o.s3_url && secondary_role_arn == o.secondary_role_arn && sensor_management_enabled == o.sensor_management_enabled && settings == o.settings && status == o.status && target_ous == o.target_ous && template_source_region == o.template_source_region && use_existing_cloudtrail == o.use_existing_cloudtrail && valid == o.valid && vulnerability_scanning_enabled == o.vulnerability_scanning_enabled && vulnerability_scanning_host_account_id == o.vulnerability_scanning_host_account_id && vulnerability_scanning_role_arn == o.vulnerability_scanning_role_arn end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 745 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
816 817 818 819 820 821 822 823 824 825 826 827 828 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 816 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 721 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
701 702 703 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 701 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
707 708 709 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 707 def hash [created_at, deleted_at, id, updated_at, account_id, account_name, account_type, active_regions, aws_cloudtrail_bucket_name, aws_cloudtrail_region, aws_eventbus_arn, , behavior_assessment_enabled, cid, cloud_registration_enabled, cloud_scopes, cloudformation_root_stack_arn, cloudformation_update_url, cloudformation_url, conditions, cspm_enabled, d4c, d4c_migrated, dspm_enabled, dspm_host_account_id, dspm_role_arn, environment, eventbus_name, external_id, falcon_client_id, features, iam_role_arn, intermediate_role_arn, inventory_filter, is_cloud_registration, is_cspm_lite, is_custom_rolename, is_delegated_admin, is_master, ngsiem_enabled, organization_id, remediation_cloudformation_url, remediation_region, remediation_tou_accepted, resource_name_prefix, resource_name_suffix, root_account_id, root_iam_role, s3_url, secondary_role_arn, sensor_management_enabled, settings, status, target_ous, template_source_region, use_existing_cloudtrail, valid, vulnerability_scanning_enabled, vulnerability_scanning_host_account_id, vulnerability_scanning_role_arn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 581 def list_invalid_properties invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @deleted_at.nil? invalid_properties.push('invalid value for "deleted_at", deleted_at cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @aws_permissions_status.nil? invalid_properties.push('invalid value for "aws_permissions_status", aws_permissions_status cannot be nil.') end if @inventory_filter.nil? invalid_properties.push('invalid value for "inventory_filter", inventory_filter cannot be nil.') end if @is_custom_rolename.nil? invalid_properties.push('invalid value for "is_custom_rolename", is_custom_rolename cannot be nil.') end if @sensor_management_enabled.nil? invalid_properties.push('invalid value for "sensor_management_enabled", sensor_management_enabled cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
792 793 794 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 792 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
798 799 800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 798 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
786 787 788 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 786 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/crimson-falcon/models/domain_aws_account_v2.rb', line 620 def valid? return false if @created_at.nil? return false if @deleted_at.nil? return false if @id.nil? return false if @updated_at.nil? return false if @aws_permissions_status.nil? return false if @inventory_filter.nil? return false if @is_custom_rolename.nil? return false if @sensor_management_enabled.nil? true end |