Class: Falcon::DomainDiscoverAPIApplication
- Inherits:
-
Object
- Object
- Falcon::DomainDiscoverAPIApplication
- Defined in:
- lib/crimson-falcon/models/domain_discover_api_application.rb
Overview
Represents information about an application.
Instance Attribute Summary collapse
-
#architectures ⇒ Object
Represents the application architectures (x86 / x64).
-
#browser_extension ⇒ Object
Returns the value of attribute browser_extension.
-
#category ⇒ Object
The category of the application.
-
#cid ⇒ Object
The customer ID of this application.
-
#dev_package ⇒ Object
Returns the value of attribute dev_package.
-
#extension_id ⇒ Object
The unique identifier for the extension.
-
#first_seen_timestamp ⇒ Object
Timestamp when this application was first seen by the cloud.
-
#groups ⇒ Object
The user defined groups this application is part of.
-
#homepage ⇒ Object
The homepage URL of the application.
-
#host ⇒ Object
Returns the value of attribute host.
-
#id ⇒ Object
The unique ID for the application.
-
#ide_extension ⇒ Object
Returns the value of attribute ide_extension.
-
#installation_paths ⇒ Object
The file paths where the application is installed on the host.
-
#installation_timestamp ⇒ Object
Timestamp when the application was installed on the host.
-
#is_normalized ⇒ Object
Whether or not the application is normalized.
-
#is_suspicious ⇒ Object
Whether or not the application is suspicious (detection-based for malware).
-
#last_published ⇒ Object
Timestamp when this application was last published.
-
#last_updated_timestamp ⇒ Object
Timestamp when this application was last updated (something changed in the application or in the host data).
-
#last_used_file_hash ⇒ Object
The file hash that was last used for this application.
-
#last_used_file_name ⇒ Object
The file name that was last used for this application.
-
#last_used_timestamp ⇒ Object
Timestamp when this application was last used.
-
#last_used_user_name ⇒ Object
The username of the user that last used this application.
-
#last_used_user_sid ⇒ Object
The user SID of the last user that used this application.
-
#name ⇒ Object
The name of the application.
-
#name_vendor ⇒ Object
The combined field on which we will be able to group by app.
-
#name_vendor_version ⇒ Object
The combined field on which we will be able to group by app + version.
-
#software_type ⇒ Object
The type of software of the application.
-
#store_listing ⇒ Object
The store listing information for the application.
-
#store_listing_status ⇒ Object
The status of the application in the store listing.
-
#suspicious_indicators ⇒ Object
List of security risk indicators for this application.
-
#vendor ⇒ Object
The name the application’s vendor.
-
#version ⇒ Object
The version of the application.
-
#versioning_scheme ⇒ Object
The version scheme of the application.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplication
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainDiscoverAPIApplication
Initializes the object
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 221 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainDiscoverAPIApplication` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainDiscoverAPIApplication`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'architectures') if (value = attributes[:'architectures']).is_a?(Array) self.architectures = value end end if attributes.key?(:'browser_extension') self.browser_extension = attributes[:'browser_extension'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'dev_package') self.dev_package = attributes[:'dev_package'] end if attributes.key?(:'extension_id') self.extension_id = attributes[:'extension_id'] end if attributes.key?(:'first_seen_timestamp') self. = attributes[:'first_seen_timestamp'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'homepage') self.homepage = attributes[:'homepage'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ide_extension') self.ide_extension = attributes[:'ide_extension'] end if attributes.key?(:'installation_paths') if (value = attributes[:'installation_paths']).is_a?(Array) self.installation_paths = value end end if attributes.key?(:'installation_timestamp') self. = attributes[:'installation_timestamp'] end if attributes.key?(:'is_normalized') self.is_normalized = attributes[:'is_normalized'] end if attributes.key?(:'is_suspicious') self.is_suspicious = attributes[:'is_suspicious'] end if attributes.key?(:'last_published') self.last_published = attributes[:'last_published'] end if attributes.key?(:'last_updated_timestamp') self. = attributes[:'last_updated_timestamp'] end if attributes.key?(:'last_used_file_hash') self.last_used_file_hash = attributes[:'last_used_file_hash'] end if attributes.key?(:'last_used_file_name') self.last_used_file_name = attributes[:'last_used_file_name'] end if attributes.key?(:'last_used_timestamp') self. = attributes[:'last_used_timestamp'] end if attributes.key?(:'last_used_user_name') self.last_used_user_name = attributes[:'last_used_user_name'] end if attributes.key?(:'last_used_user_sid') self.last_used_user_sid = attributes[:'last_used_user_sid'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'name_vendor') self.name_vendor = attributes[:'name_vendor'] end if attributes.key?(:'name_vendor_version') self.name_vendor_version = attributes[:'name_vendor_version'] end if attributes.key?(:'software_type') self.software_type = attributes[:'software_type'] end if attributes.key?(:'store_listing') self.store_listing = attributes[:'store_listing'] end if attributes.key?(:'store_listing_status') self.store_listing_status = attributes[:'store_listing_status'] end if attributes.key?(:'suspicious_indicators') if (value = attributes[:'suspicious_indicators']).is_a?(Array) self.suspicious_indicators = value end end if attributes.key?(:'vendor') self.vendor = attributes[:'vendor'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'versioning_scheme') self.versioning_scheme = attributes[:'versioning_scheme'] end end |
Instance Attribute Details
#architectures ⇒ Object
Represents the application architectures (x86 / x64).
36 37 38 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 36 def architectures @architectures end |
#browser_extension ⇒ Object
Returns the value of attribute browser_extension.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 38 def browser_extension @browser_extension end |
#category ⇒ Object
The category of the application.
41 42 43 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 41 def category @category end |
#cid ⇒ Object
The customer ID of this application.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 44 def cid @cid end |
#dev_package ⇒ Object
Returns the value of attribute dev_package.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 46 def dev_package @dev_package end |
#extension_id ⇒ Object
The unique identifier for the extension.
49 50 51 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 49 def extension_id @extension_id end |
#first_seen_timestamp ⇒ Object
Timestamp when this application was first seen by the cloud.
52 53 54 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 52 def @first_seen_timestamp end |
#groups ⇒ Object
The user defined groups this application is part of.
55 56 57 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 55 def groups @groups end |
#homepage ⇒ Object
The homepage URL of the application.
58 59 60 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 58 def homepage @homepage end |
#host ⇒ Object
Returns the value of attribute host.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 60 def host @host end |
#id ⇒ Object
The unique ID for the application.
63 64 65 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 63 def id @id end |
#ide_extension ⇒ Object
Returns the value of attribute ide_extension.
65 66 67 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 65 def ide_extension @ide_extension end |
#installation_paths ⇒ Object
The file paths where the application is installed on the host. Or the locations of the executables.
68 69 70 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 68 def installation_paths @installation_paths end |
#installation_timestamp ⇒ Object
Timestamp when the application was installed on the host. We might not have this data.
71 72 73 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 71 def @installation_timestamp end |
#is_normalized ⇒ Object
Whether or not the application is normalized
74 75 76 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 74 def is_normalized @is_normalized end |
#is_suspicious ⇒ Object
Whether or not the application is suspicious (detection-based for malware)
77 78 79 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 77 def is_suspicious @is_suspicious end |
#last_published ⇒ Object
Timestamp when this application was last published.
80 81 82 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 80 def last_published @last_published end |
#last_updated_timestamp ⇒ Object
Timestamp when this application was last updated (something changed in the application or in the host data).
83 84 85 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 83 def @last_updated_timestamp end |
#last_used_file_hash ⇒ Object
The file hash that was last used for this application.
86 87 88 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 86 def last_used_file_hash @last_used_file_hash end |
#last_used_file_name ⇒ Object
The file name that was last used for this application.
89 90 91 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 89 def last_used_file_name @last_used_file_name end |
#last_used_timestamp ⇒ Object
Timestamp when this application was last used.
92 93 94 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 92 def @last_used_timestamp end |
#last_used_user_name ⇒ Object
The username of the user that last used this application.
95 96 97 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 95 def last_used_user_name @last_used_user_name end |
#last_used_user_sid ⇒ Object
The user SID of the last user that used this application.
98 99 100 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 98 def last_used_user_sid @last_used_user_sid end |
#name ⇒ Object
The name of the application.
101 102 103 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 101 def name @name end |
#name_vendor ⇒ Object
The combined field on which we will be able to group by app.
104 105 106 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 104 def name_vendor @name_vendor end |
#name_vendor_version ⇒ Object
The combined field on which we will be able to group by app + version.
107 108 109 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 107 def name_vendor_version @name_vendor_version end |
#software_type ⇒ Object
The type of software of the application. Types are application, browser_extension, dev_package, ide_extension
110 111 112 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 110 def software_type @software_type end |
#store_listing ⇒ Object
The store listing information for the application.
113 114 115 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 113 def store_listing @store_listing end |
#store_listing_status ⇒ Object
The status of the application in the store listing.
116 117 118 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 116 def store_listing_status @store_listing_status end |
#suspicious_indicators ⇒ Object
List of security risk indicators for this application
119 120 121 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 119 def suspicious_indicators @suspicious_indicators end |
#vendor ⇒ Object
The name the application’s vendor.
122 123 124 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 122 def vendor @vendor end |
#version ⇒ Object
The version of the application.
125 126 127 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 125 def version @version end |
#versioning_scheme ⇒ Object
The version scheme of the application.
128 129 130 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 128 def versioning_scheme @versioning_scheme end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
170 171 172 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 170 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 131 def self.attribute_map { :'architectures' => :'architectures', :'browser_extension' => :'browser_extension', :'category' => :'category', :'cid' => :'cid', :'dev_package' => :'dev_package', :'extension_id' => :'extension_id', :'first_seen_timestamp' => :'first_seen_timestamp', :'groups' => :'groups', :'homepage' => :'homepage', :'host' => :'host', :'id' => :'id', :'ide_extension' => :'ide_extension', :'installation_paths' => :'installation_paths', :'installation_timestamp' => :'installation_timestamp', :'is_normalized' => :'is_normalized', :'is_suspicious' => :'is_suspicious', :'last_published' => :'last_published', :'last_updated_timestamp' => :'last_updated_timestamp', :'last_used_file_hash' => :'last_used_file_hash', :'last_used_file_name' => :'last_used_file_name', :'last_used_timestamp' => :'last_used_timestamp', :'last_used_user_name' => :'last_used_user_name', :'last_used_user_sid' => :'last_used_user_sid', :'name' => :'name', :'name_vendor' => :'name_vendor', :'name_vendor_version' => :'name_vendor_version', :'software_type' => :'software_type', :'store_listing' => :'store_listing', :'store_listing_status' => :'store_listing_status', :'suspicious_indicators' => :'suspicious_indicators', :'vendor' => :'vendor', :'version' => :'version', :'versioning_scheme' => :'versioning_scheme' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
453 454 455 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 453 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
214 215 216 217 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 214 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 175 def self.openapi_types { :'architectures' => :'Array<String>', :'browser_extension' => :'DomainDiscoverAPIApplicationBrowserExtension', :'category' => :'String', :'cid' => :'String', :'dev_package' => :'DomainDiscoverAPIApplicationPackage', :'extension_id' => :'String', :'first_seen_timestamp' => :'String', :'groups' => :'Array<String>', :'homepage' => :'String', :'host' => :'DomainDiscoverAPIApplicationHost', :'id' => :'String', :'ide_extension' => :'DomainDiscoverAPIApplicationIDEExtension', :'installation_paths' => :'Array<String>', :'installation_timestamp' => :'String', :'is_normalized' => :'Boolean', :'is_suspicious' => :'Boolean', :'last_published' => :'String', :'last_updated_timestamp' => :'String', :'last_used_file_hash' => :'String', :'last_used_file_name' => :'String', :'last_used_timestamp' => :'String', :'last_used_user_name' => :'String', :'last_used_user_sid' => :'String', :'name' => :'String', :'name_vendor' => :'String', :'name_vendor_version' => :'String', :'software_type' => :'String', :'store_listing' => :'String', :'store_listing_status' => :'String', :'suspicious_indicators' => :'Array<DomainDiscoverAPISuspiciousIndicator>', :'vendor' => :'String', :'version' => :'String', :'versioning_scheme' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 400 def ==(o) return true if self.equal?(o) self.class == o.class && architectures == o.architectures && browser_extension == o.browser_extension && category == o.category && cid == o.cid && dev_package == o.dev_package && extension_id == o.extension_id && == o. && groups == o.groups && homepage == o.homepage && host == o.host && id == o.id && ide_extension == o.ide_extension && installation_paths == o.installation_paths && == o. && is_normalized == o.is_normalized && is_suspicious == o.is_suspicious && last_published == o.last_published && == o. && last_used_file_hash == o.last_used_file_hash && last_used_file_name == o.last_used_file_name && == o. && last_used_user_name == o.last_used_user_name && last_used_user_sid == o.last_used_user_sid && name == o.name && name_vendor == o.name_vendor && name_vendor_version == o.name_vendor_version && software_type == o.software_type && store_listing == o.store_listing && store_listing_status == o.store_listing_status && suspicious_indicators == o.suspicious_indicators && vendor == o.vendor && version == o.version && versioning_scheme == o.versioning_scheme end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 484 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 555 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 460 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
440 441 442 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 440 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
446 447 448 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 446 def hash [architectures, browser_extension, category, cid, dev_package, extension_id, , groups, homepage, host, id, ide_extension, installation_paths, , is_normalized, is_suspicious, last_published, , last_used_file_hash, last_used_file_name, , last_used_user_name, last_used_user_sid, name, name_vendor, name_vendor_version, software_type, store_listing, store_listing_status, suspicious_indicators, vendor, version, versioning_scheme].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 377 def list_invalid_properties invalid_properties = Array.new if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
531 532 533 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 531 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
537 538 539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 537 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
525 526 527 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 525 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
392 393 394 395 396 |
# File 'lib/crimson-falcon/models/domain_discover_api_application.rb', line 392 def valid? return false if @cid.nil? return false if @id.nil? true end |