Class: Falcon::DomainScanProfile
- Inherits:
-
Object
- Object
- Falcon::DomainScanProfile
- Defined in:
- lib/crimson-falcon/models/domain_scan_profile.rb
Instance Attribute Summary collapse
-
#channel_file_status ⇒ Object
Returns the value of attribute channel_file_status.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_ml_level_detection ⇒ Object
Returns the value of attribute cloud_ml_level_detection.
-
#cloud_ml_level_prevention ⇒ Object
Returns the value of attribute cloud_ml_level_prevention.
-
#cloud_pup_adware_level_detection ⇒ Object
Returns the value of attribute cloud_pup_adware_level_detection.
-
#cloud_pup_adware_level_prevention ⇒ Object
Returns the value of attribute cloud_pup_adware_level_prevention.
-
#cpu_priority ⇒ Object
Returns the value of attribute cpu_priority.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#description ⇒ Object
Returns the value of attribute description.
-
#endpoint_notification ⇒ Object
Returns the value of attribute endpoint_notification.
-
#file_paths ⇒ Object
Returns the value of attribute file_paths.
-
#host_groups ⇒ Object
Returns the value of attribute host_groups.
-
#hosts ⇒ Object
Returns the value of attribute hosts.
-
#id ⇒ Object
Returns the value of attribute id.
-
#initiated_from ⇒ Object
Returns the value of attribute initiated_from.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#mac_cloud_ml_level_detection ⇒ Object
Returns the value of attribute mac_cloud_ml_level_detection.
-
#mac_cloud_ml_level_prevention ⇒ Object
Returns the value of attribute mac_cloud_ml_level_prevention.
-
#mac_cloud_pup_adware_level_detection ⇒ Object
Returns the value of attribute mac_cloud_pup_adware_level_detection.
-
#mac_cloud_pup_adware_level_prevention ⇒ Object
Returns the value of attribute mac_cloud_pup_adware_level_prevention.
-
#mac_policy_setting ⇒ Object
Returns the value of attribute mac_policy_setting.
-
#mac_scan_exclusions ⇒ Object
Returns the value of attribute mac_scan_exclusions.
-
#mac_scan_inclusions ⇒ Object
Returns the value of attribute mac_scan_inclusions.
-
#mac_sensor_ml_level_detection ⇒ Object
Returns the value of attribute mac_sensor_ml_level_detection.
-
#mac_sensor_ml_level_prevention ⇒ Object
Returns the value of attribute mac_sensor_ml_level_prevention.
-
#mac_sensor_pup_adware_level_detection ⇒ Object
Returns the value of attribute mac_sensor_pup_adware_level_detection.
-
#mac_sensor_pup_adware_level_prevention ⇒ Object
Returns the value of attribute mac_sensor_pup_adware_level_prevention.
-
#max_duration ⇒ Object
Returns the value of attribute max_duration.
-
#max_file_size ⇒ Object
Returns the value of attribute max_file_size.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#pause_duration ⇒ Object
Returns the value of attribute pause_duration.
-
#policy_setting ⇒ Object
Returns the value of attribute policy_setting.
-
#preemption_priority ⇒ Object
Returns the value of attribute preemption_priority.
-
#quarantine ⇒ Object
Returns the value of attribute quarantine.
-
#scan_exclusions ⇒ Object
Returns the value of attribute scan_exclusions.
-
#scan_inclusions ⇒ Object
Returns the value of attribute scan_inclusions.
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#sensor_ml_level_detection ⇒ Object
Returns the value of attribute sensor_ml_level_detection.
-
#sensor_ml_level_prevention ⇒ Object
Returns the value of attribute sensor_ml_level_prevention.
-
#status ⇒ Object
Returns the value of attribute status.
-
#targeted_host_count ⇒ Object
Returns the value of attribute targeted_host_count.
-
#targeted_platforms ⇒ Object
Returns the value of attribute targeted_platforms.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainScanProfile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainScanProfile
Initializes the object
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 235 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::DomainScanProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::DomainScanProfile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'channel_file_status') self.channel_file_status = attributes[:'channel_file_status'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_ml_level_detection') self.cloud_ml_level_detection = attributes[:'cloud_ml_level_detection'] end if attributes.key?(:'cloud_ml_level_prevention') self.cloud_ml_level_prevention = attributes[:'cloud_ml_level_prevention'] end if attributes.key?(:'cloud_pup_adware_level_detection') self.cloud_pup_adware_level_detection = attributes[:'cloud_pup_adware_level_detection'] end if attributes.key?(:'cloud_pup_adware_level_prevention') self.cloud_pup_adware_level_prevention = attributes[:'cloud_pup_adware_level_prevention'] end if attributes.key?(:'cpu_priority') self.cpu_priority = attributes[:'cpu_priority'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'endpoint_notification') self.endpoint_notification = attributes[:'endpoint_notification'] end if attributes.key?(:'file_paths') if (value = attributes[:'file_paths']).is_a?(Array) self.file_paths = value end end if attributes.key?(:'host_groups') if (value = attributes[:'host_groups']).is_a?(Array) self.host_groups = value end end if attributes.key?(:'hosts') if (value = attributes[:'hosts']).is_a?(Array) self.hosts = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'initiated_from') self.initiated_from = attributes[:'initiated_from'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'mac_cloud_ml_level_detection') self.mac_cloud_ml_level_detection = attributes[:'mac_cloud_ml_level_detection'] end if attributes.key?(:'mac_cloud_ml_level_prevention') self.mac_cloud_ml_level_prevention = attributes[:'mac_cloud_ml_level_prevention'] end if attributes.key?(:'mac_cloud_pup_adware_level_detection') self.mac_cloud_pup_adware_level_detection = attributes[:'mac_cloud_pup_adware_level_detection'] end if attributes.key?(:'mac_cloud_pup_adware_level_prevention') self.mac_cloud_pup_adware_level_prevention = attributes[:'mac_cloud_pup_adware_level_prevention'] end if attributes.key?(:'mac_policy_setting') if (value = attributes[:'mac_policy_setting']).is_a?(Array) self.mac_policy_setting = value end end if attributes.key?(:'mac_scan_exclusions') if (value = attributes[:'mac_scan_exclusions']).is_a?(Array) self.mac_scan_exclusions = value end end if attributes.key?(:'mac_scan_inclusions') if (value = attributes[:'mac_scan_inclusions']).is_a?(Array) self.mac_scan_inclusions = value end end if attributes.key?(:'mac_sensor_ml_level_detection') self.mac_sensor_ml_level_detection = attributes[:'mac_sensor_ml_level_detection'] end if attributes.key?(:'mac_sensor_ml_level_prevention') self.mac_sensor_ml_level_prevention = attributes[:'mac_sensor_ml_level_prevention'] end if attributes.key?(:'mac_sensor_pup_adware_level_detection') self.mac_sensor_pup_adware_level_detection = attributes[:'mac_sensor_pup_adware_level_detection'] end if attributes.key?(:'mac_sensor_pup_adware_level_prevention') self.mac_sensor_pup_adware_level_prevention = attributes[:'mac_sensor_pup_adware_level_prevention'] end if attributes.key?(:'max_duration') self.max_duration = attributes[:'max_duration'] end if attributes.key?(:'max_file_size') self.max_file_size = attributes[:'max_file_size'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Array) self. = value end end if attributes.key?(:'pause_duration') self.pause_duration = attributes[:'pause_duration'] end if attributes.key?(:'policy_setting') if (value = attributes[:'policy_setting']).is_a?(Array) self.policy_setting = value end end if attributes.key?(:'preemption_priority') self.preemption_priority = attributes[:'preemption_priority'] end if attributes.key?(:'quarantine') self.quarantine = attributes[:'quarantine'] end if attributes.key?(:'scan_exclusions') if (value = attributes[:'scan_exclusions']).is_a?(Array) self.scan_exclusions = value end end if attributes.key?(:'scan_inclusions') if (value = attributes[:'scan_inclusions']).is_a?(Array) self.scan_inclusions = value end end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'sensor_ml_level_detection') self.sensor_ml_level_detection = attributes[:'sensor_ml_level_detection'] end if attributes.key?(:'sensor_ml_level_prevention') self.sensor_ml_level_prevention = attributes[:'sensor_ml_level_prevention'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'targeted_host_count') self.targeted_host_count = attributes[:'targeted_host_count'] end if attributes.key?(:'targeted_platforms') if (value = attributes[:'targeted_platforms']).is_a?(Array) self.targeted_platforms = value end end end |
Instance Attribute Details
#channel_file_status ⇒ Object
Returns the value of attribute channel_file_status.
34 35 36 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 34 def channel_file_status @channel_file_status end |
#cid ⇒ Object
Returns the value of attribute cid.
36 37 38 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 36 def cid @cid end |
#cloud_ml_level_detection ⇒ Object
Returns the value of attribute cloud_ml_level_detection.
38 39 40 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 38 def cloud_ml_level_detection @cloud_ml_level_detection end |
#cloud_ml_level_prevention ⇒ Object
Returns the value of attribute cloud_ml_level_prevention.
40 41 42 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 40 def cloud_ml_level_prevention @cloud_ml_level_prevention end |
#cloud_pup_adware_level_detection ⇒ Object
Returns the value of attribute cloud_pup_adware_level_detection.
42 43 44 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 42 def cloud_pup_adware_level_detection @cloud_pup_adware_level_detection end |
#cloud_pup_adware_level_prevention ⇒ Object
Returns the value of attribute cloud_pup_adware_level_prevention.
44 45 46 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 44 def cloud_pup_adware_level_prevention @cloud_pup_adware_level_prevention end |
#cpu_priority ⇒ Object
Returns the value of attribute cpu_priority.
46 47 48 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 46 def cpu_priority @cpu_priority end |
#created_by ⇒ Object
Returns the value of attribute created_by.
48 49 50 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 48 def created_by @created_by end |
#created_on ⇒ Object
Returns the value of attribute created_on.
50 51 52 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 50 def created_on @created_on end |
#deleted ⇒ Object
Returns the value of attribute deleted.
52 53 54 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 52 def deleted @deleted end |
#description ⇒ Object
Returns the value of attribute description.
54 55 56 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 54 def description @description end |
#endpoint_notification ⇒ Object
Returns the value of attribute endpoint_notification.
56 57 58 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 56 def endpoint_notification @endpoint_notification end |
#file_paths ⇒ Object
Returns the value of attribute file_paths.
58 59 60 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 58 def file_paths @file_paths end |
#host_groups ⇒ Object
Returns the value of attribute host_groups.
60 61 62 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 60 def host_groups @host_groups end |
#hosts ⇒ Object
Returns the value of attribute hosts.
62 63 64 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 62 def hosts @hosts end |
#id ⇒ Object
Returns the value of attribute id.
64 65 66 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 64 def id @id end |
#initiated_from ⇒ Object
Returns the value of attribute initiated_from.
66 67 68 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 66 def initiated_from @initiated_from end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
68 69 70 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 68 def last_updated @last_updated end |
#mac_cloud_ml_level_detection ⇒ Object
Returns the value of attribute mac_cloud_ml_level_detection.
70 71 72 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 70 def mac_cloud_ml_level_detection @mac_cloud_ml_level_detection end |
#mac_cloud_ml_level_prevention ⇒ Object
Returns the value of attribute mac_cloud_ml_level_prevention.
72 73 74 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 72 def mac_cloud_ml_level_prevention @mac_cloud_ml_level_prevention end |
#mac_cloud_pup_adware_level_detection ⇒ Object
Returns the value of attribute mac_cloud_pup_adware_level_detection.
74 75 76 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 74 def mac_cloud_pup_adware_level_detection @mac_cloud_pup_adware_level_detection end |
#mac_cloud_pup_adware_level_prevention ⇒ Object
Returns the value of attribute mac_cloud_pup_adware_level_prevention.
76 77 78 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 76 def mac_cloud_pup_adware_level_prevention @mac_cloud_pup_adware_level_prevention end |
#mac_policy_setting ⇒ Object
Returns the value of attribute mac_policy_setting.
78 79 80 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 78 def mac_policy_setting @mac_policy_setting end |
#mac_scan_exclusions ⇒ Object
Returns the value of attribute mac_scan_exclusions.
80 81 82 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 80 def mac_scan_exclusions @mac_scan_exclusions end |
#mac_scan_inclusions ⇒ Object
Returns the value of attribute mac_scan_inclusions.
82 83 84 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 82 def mac_scan_inclusions @mac_scan_inclusions end |
#mac_sensor_ml_level_detection ⇒ Object
Returns the value of attribute mac_sensor_ml_level_detection.
84 85 86 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 84 def mac_sensor_ml_level_detection @mac_sensor_ml_level_detection end |
#mac_sensor_ml_level_prevention ⇒ Object
Returns the value of attribute mac_sensor_ml_level_prevention.
86 87 88 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 86 def mac_sensor_ml_level_prevention @mac_sensor_ml_level_prevention end |
#mac_sensor_pup_adware_level_detection ⇒ Object
Returns the value of attribute mac_sensor_pup_adware_level_detection.
88 89 90 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 88 def mac_sensor_pup_adware_level_detection @mac_sensor_pup_adware_level_detection end |
#mac_sensor_pup_adware_level_prevention ⇒ Object
Returns the value of attribute mac_sensor_pup_adware_level_prevention.
90 91 92 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 90 def mac_sensor_pup_adware_level_prevention @mac_sensor_pup_adware_level_prevention end |
#max_duration ⇒ Object
Returns the value of attribute max_duration.
92 93 94 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 92 def max_duration @max_duration end |
#max_file_size ⇒ Object
Returns the value of attribute max_file_size.
94 95 96 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 94 def max_file_size @max_file_size end |
#metadata ⇒ Object
Returns the value of attribute metadata.
96 97 98 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 96 def @metadata end |
#pause_duration ⇒ Object
Returns the value of attribute pause_duration.
98 99 100 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 98 def pause_duration @pause_duration end |
#policy_setting ⇒ Object
Returns the value of attribute policy_setting.
100 101 102 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 100 def policy_setting @policy_setting end |
#preemption_priority ⇒ Object
Returns the value of attribute preemption_priority.
102 103 104 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 102 def preemption_priority @preemption_priority end |
#quarantine ⇒ Object
Returns the value of attribute quarantine.
104 105 106 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 104 def quarantine @quarantine end |
#scan_exclusions ⇒ Object
Returns the value of attribute scan_exclusions.
106 107 108 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 106 def scan_exclusions @scan_exclusions end |
#scan_inclusions ⇒ Object
Returns the value of attribute scan_inclusions.
108 109 110 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 108 def scan_inclusions @scan_inclusions end |
#schedule ⇒ Object
Returns the value of attribute schedule.
110 111 112 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 110 def schedule @schedule end |
#sensor_ml_level_detection ⇒ Object
Returns the value of attribute sensor_ml_level_detection.
112 113 114 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 112 def sensor_ml_level_detection @sensor_ml_level_detection end |
#sensor_ml_level_prevention ⇒ Object
Returns the value of attribute sensor_ml_level_prevention.
114 115 116 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 114 def sensor_ml_level_prevention @sensor_ml_level_prevention end |
#status ⇒ Object
Returns the value of attribute status.
116 117 118 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 116 def status @status end |
#targeted_host_count ⇒ Object
Returns the value of attribute targeted_host_count.
118 119 120 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 118 def targeted_host_count @targeted_host_count end |
#targeted_platforms ⇒ Object
Returns the value of attribute targeted_platforms.
120 121 122 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 120 def targeted_platforms @targeted_platforms end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
173 174 175 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 173 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 123 def self.attribute_map { :'channel_file_status' => :'channel_file_status', :'cid' => :'cid', :'cloud_ml_level_detection' => :'cloud_ml_level_detection', :'cloud_ml_level_prevention' => :'cloud_ml_level_prevention', :'cloud_pup_adware_level_detection' => :'cloud_pup_adware_level_detection', :'cloud_pup_adware_level_prevention' => :'cloud_pup_adware_level_prevention', :'cpu_priority' => :'cpu_priority', :'created_by' => :'created_by', :'created_on' => :'created_on', :'deleted' => :'deleted', :'description' => :'description', :'endpoint_notification' => :'endpoint_notification', :'file_paths' => :'file_paths', :'host_groups' => :'host_groups', :'hosts' => :'hosts', :'id' => :'id', :'initiated_from' => :'initiated_from', :'last_updated' => :'last_updated', :'mac_cloud_ml_level_detection' => :'mac_cloud_ml_level_detection', :'mac_cloud_ml_level_prevention' => :'mac_cloud_ml_level_prevention', :'mac_cloud_pup_adware_level_detection' => :'mac_cloud_pup_adware_level_detection', :'mac_cloud_pup_adware_level_prevention' => :'mac_cloud_pup_adware_level_prevention', :'mac_policy_setting' => :'mac_policy_setting', :'mac_scan_exclusions' => :'mac_scan_exclusions', :'mac_scan_inclusions' => :'mac_scan_inclusions', :'mac_sensor_ml_level_detection' => :'mac_sensor_ml_level_detection', :'mac_sensor_ml_level_prevention' => :'mac_sensor_ml_level_prevention', :'mac_sensor_pup_adware_level_detection' => :'mac_sensor_pup_adware_level_detection', :'mac_sensor_pup_adware_level_prevention' => :'mac_sensor_pup_adware_level_prevention', :'max_duration' => :'max_duration', :'max_file_size' => :'max_file_size', :'metadata' => :'metadata', :'pause_duration' => :'pause_duration', :'policy_setting' => :'policy_setting', :'preemption_priority' => :'preemption_priority', :'quarantine' => :'quarantine', :'scan_exclusions' => :'scan_exclusions', :'scan_inclusions' => :'scan_inclusions', :'schedule' => :'schedule', :'sensor_ml_level_detection' => :'sensor_ml_level_detection', :'sensor_ml_level_prevention' => :'sensor_ml_level_prevention', :'status' => :'status', :'targeted_host_count' => :'targeted_host_count', :'targeted_platforms' => :'targeted_platforms' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
536 537 538 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 536 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
228 229 230 231 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 228 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 178 def self.openapi_types { :'channel_file_status' => :'Integer', :'cid' => :'String', :'cloud_ml_level_detection' => :'Integer', :'cloud_ml_level_prevention' => :'Integer', :'cloud_pup_adware_level_detection' => :'Integer', :'cloud_pup_adware_level_prevention' => :'Integer', :'cpu_priority' => :'Integer', :'created_by' => :'String', :'created_on' => :'Time', :'deleted' => :'Boolean', :'description' => :'String', :'endpoint_notification' => :'Boolean', :'file_paths' => :'Array<String>', :'host_groups' => :'Array<String>', :'hosts' => :'Array<String>', :'id' => :'String', :'initiated_from' => :'String', :'last_updated' => :'Time', :'mac_cloud_ml_level_detection' => :'Integer', :'mac_cloud_ml_level_prevention' => :'Integer', :'mac_cloud_pup_adware_level_detection' => :'Integer', :'mac_cloud_pup_adware_level_prevention' => :'Integer', :'mac_policy_setting' => :'Array<Integer>', :'mac_scan_exclusions' => :'Array<String>', :'mac_scan_inclusions' => :'Array<String>', :'mac_sensor_ml_level_detection' => :'Integer', :'mac_sensor_ml_level_prevention' => :'Integer', :'mac_sensor_pup_adware_level_detection' => :'Integer', :'mac_sensor_pup_adware_level_prevention' => :'Integer', :'max_duration' => :'Integer', :'max_file_size' => :'Integer', :'metadata' => :'Array<DomainScanProfileMetadata>', :'pause_duration' => :'Integer', :'policy_setting' => :'Array<Integer>', :'preemption_priority' => :'Integer', :'quarantine' => :'Boolean', :'scan_exclusions' => :'Array<String>', :'scan_inclusions' => :'Array<String>', :'schedule' => :'DomainSchedule', :'sensor_ml_level_detection' => :'Integer', :'sensor_ml_level_prevention' => :'Integer', :'status' => :'String', :'targeted_host_count' => :'Integer', :'targeted_platforms' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 472 def ==(o) return true if self.equal?(o) self.class == o.class && channel_file_status == o.channel_file_status && cid == o.cid && cloud_ml_level_detection == o.cloud_ml_level_detection && cloud_ml_level_prevention == o.cloud_ml_level_prevention && cloud_pup_adware_level_detection == o.cloud_pup_adware_level_detection && cloud_pup_adware_level_prevention == o.cloud_pup_adware_level_prevention && cpu_priority == o.cpu_priority && created_by == o.created_by && created_on == o.created_on && deleted == o.deleted && description == o.description && endpoint_notification == o.endpoint_notification && file_paths == o.file_paths && host_groups == o.host_groups && hosts == o.hosts && id == o.id && initiated_from == o.initiated_from && last_updated == o.last_updated && mac_cloud_ml_level_detection == o.mac_cloud_ml_level_detection && mac_cloud_ml_level_prevention == o.mac_cloud_ml_level_prevention && mac_cloud_pup_adware_level_detection == o.mac_cloud_pup_adware_level_detection && mac_cloud_pup_adware_level_prevention == o.mac_cloud_pup_adware_level_prevention && mac_policy_setting == o.mac_policy_setting && mac_scan_exclusions == o.mac_scan_exclusions && mac_scan_inclusions == o.mac_scan_inclusions && mac_sensor_ml_level_detection == o.mac_sensor_ml_level_detection && mac_sensor_ml_level_prevention == o.mac_sensor_ml_level_prevention && mac_sensor_pup_adware_level_detection == o.mac_sensor_pup_adware_level_detection && mac_sensor_pup_adware_level_prevention == o.mac_sensor_pup_adware_level_prevention && max_duration == o.max_duration && max_file_size == o.max_file_size && == o. && pause_duration == o.pause_duration && policy_setting == o.policy_setting && preemption_priority == o.preemption_priority && quarantine == o.quarantine && scan_exclusions == o.scan_exclusions && scan_inclusions == o.scan_inclusions && schedule == o.schedule && sensor_ml_level_detection == o.sensor_ml_level_detection && sensor_ml_level_prevention == o.sensor_ml_level_prevention && status == o.status && targeted_host_count == o.targeted_host_count && targeted_platforms == o.targeted_platforms end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 567 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
638 639 640 641 642 643 644 645 646 647 648 649 650 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 638 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 543 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
523 524 525 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 523 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
529 530 531 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 529 def hash [channel_file_status, cid, cloud_ml_level_detection, cloud_ml_level_prevention, cloud_pup_adware_level_detection, cloud_pup_adware_level_prevention, cpu_priority, created_by, created_on, deleted, description, endpoint_notification, file_paths, host_groups, hosts, id, initiated_from, last_updated, mac_cloud_ml_level_detection, mac_cloud_ml_level_prevention, mac_cloud_pup_adware_level_detection, mac_cloud_pup_adware_level_prevention, mac_policy_setting, mac_scan_exclusions, mac_scan_inclusions, mac_sensor_ml_level_detection, mac_sensor_ml_level_prevention, mac_sensor_pup_adware_level_detection, mac_sensor_pup_adware_level_prevention, max_duration, max_file_size, , pause_duration, policy_setting, preemption_priority, quarantine, scan_exclusions, scan_inclusions, schedule, sensor_ml_level_detection, sensor_ml_level_prevention, status, targeted_host_count, targeted_platforms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 449 def list_invalid_properties invalid_properties = Array.new if @deleted.nil? invalid_properties.push('invalid value for "deleted", deleted cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
614 615 616 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 614 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 620 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
608 609 610 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 608 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
464 465 466 467 468 |
# File 'lib/crimson-falcon/models/domain_scan_profile.rb', line 464 def valid? return false if @deleted.nil? return false if @id.nil? true end |