Class: Falcon::IoaExclusions
- Inherits:
-
Object
- Object
- Falcon::IoaExclusions
- Defined in:
- lib/crimson-falcon/api/ioa_exclusions.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_ioa_exclusions_v1(body, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Create the IOA exclusions.
-
#create_ioa_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Create the IOA exclusions.
-
#delete_ioa_exclusions_v1(ids, opts = {}) ⇒ MsaQueryResponse
Delete the IOA exclusions by id.
-
#delete_ioa_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Delete the IOA exclusions by id.
-
#get_ioa_exclusions_v1(ids, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Get a set of IOA Exclusions by specifying their IDs.
-
#get_ioa_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Get a set of IOA Exclusions by specifying their IDs.
-
#initialize(api_client = ApiClient.default) ⇒ IoaExclusions
constructor
A new instance of IoaExclusions.
-
#query_ioa_exclusions_v1(opts = {}) ⇒ MsaQueryResponse
Search for IOA exclusions.
-
#query_ioa_exclusions_v1_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for IOA exclusions.
-
#ss_ioa_exclusions_aggregates_v2(body, opts = {}) ⇒ MsaAggregatesResponse
Get Self Service IOA Exclusion aggregates as specified via json in the request body.
-
#ss_ioa_exclusions_aggregates_v2_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Get Self Service IOA Exclusion aggregates as specified via json in the request body.
-
#ss_ioa_exclusions_create_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Create new Self Service IOA Exclusions.
-
#ss_ioa_exclusions_create_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Create new Self Service IOA Exclusions.
-
#ss_ioa_exclusions_delete_v2(ids, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Delete the Self Service IOA Exclusions rule by id.
-
#ss_ioa_exclusions_delete_v2_with_http_info(ids, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Delete the Self Service IOA Exclusions rule by id.
-
#ss_ioa_exclusions_get_reports_v2(body, opts = {}) ⇒ nil
Create a report of Self Service IOA Exclusions scoped by the given filters.
-
#ss_ioa_exclusions_get_reports_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create a report of Self Service IOA Exclusions scoped by the given filters.
-
#ss_ioa_exclusions_get_v2(ids, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Get the Self Service IOA Exclusions rules by id.
-
#ss_ioa_exclusions_get_v2_with_http_info(ids, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Get the Self Service IOA Exclusions rules by id.
-
#ss_ioa_exclusions_matched_rule_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Get Self Service IOA Exclusions rules for matched IFN/CLI for child, parent and grandparent.
-
#ss_ioa_exclusions_matched_rule_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Get Self Service IOA Exclusions rules for matched IFN/CLI for child, parent and grandparent.
-
#ss_ioa_exclusions_new_rules_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsNewRuleRespV2
Get defaults for Self Service IOA Exclusions based on provided IFN/CLI for child, parent and grandparent.
-
#ss_ioa_exclusions_new_rules_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsNewRuleRespV2, Integer, Hash)>
Get defaults for Self Service IOA Exclusions based on provided IFN/CLI for child, parent and grandparent.
-
#ss_ioa_exclusions_search_v2(opts = {}) ⇒ MsaspecQueryResponse
Search for Self Service IOA Exclusions.
-
#ss_ioa_exclusions_search_v2_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for Self Service IOA Exclusions.
-
#ss_ioa_exclusions_update_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Update the Self Service IOA Exclusions rule by id.
-
#ss_ioa_exclusions_update_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Update the Self Service IOA Exclusions rule by id.
-
#update_ioa_exclusions_v1(body, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Update the IOA exclusions.
-
#update_ioa_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Update the IOA exclusions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IoaExclusions
Returns a new instance of IoaExclusions.
35 36 37 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 33 def api_client @api_client end |
Instance Method Details
#create_ioa_exclusions_v1(body, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Create the IOA exclusions
42 43 44 45 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 42 def create_ioa_exclusions_v1(body, opts = {}) data, _status_code, _headers = create_ioa_exclusions_v1_with_http_info(body, opts) data end |
#create_ioa_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Create the IOA exclusions
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 51 def create_ioa_exclusions_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.create_ioa_exclusions_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.create_ioa_exclusions_v1" end # resource path local_var_path = '/policy/entities/ioa-exclusions/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'IoaExclusionsIoaExclusionsRespV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.create_ioa_exclusions_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#create_ioa_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_ioa_exclusions_v1(ids, opts = {}) ⇒ MsaQueryResponse
Delete the IOA exclusions by id
109 110 111 112 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 109 def delete_ioa_exclusions_v1(ids, opts = {}) data, _status_code, _headers = delete_ioa_exclusions_v1_with_http_info(ids, opts) data end |
#delete_ioa_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Delete the IOA exclusions by id
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 119 def delete_ioa_exclusions_v1_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.delete_ioa_exclusions_v1 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling IoaExclusions.delete_ioa_exclusions_v1" end # resource path local_var_path = '/policy/entities/ioa-exclusions/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.delete_ioa_exclusions_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#delete_ioa_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_ioa_exclusions_v1(ids, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Get a set of IOA Exclusions by specifying their IDs
173 174 175 176 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 173 def get_ioa_exclusions_v1(ids, opts = {}) data, _status_code, _headers = get_ioa_exclusions_v1_with_http_info(ids, opts) data end |
#get_ioa_exclusions_v1_with_http_info(ids, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Get a set of IOA Exclusions by specifying their IDs
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 182 def get_ioa_exclusions_v1_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.get_ioa_exclusions_v1 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling IoaExclusions.get_ioa_exclusions_v1" end # resource path local_var_path = '/policy/entities/ioa-exclusions/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IoaExclusionsIoaExclusionsRespV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.get_ioa_exclusions_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#get_ioa_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_ioa_exclusions_v1(opts = {}) ⇒ MsaQueryResponse
Search for IOA exclusions.
240 241 242 243 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 240 def query_ioa_exclusions_v1(opts = {}) data, _status_code, _headers = query_ioa_exclusions_v1_with_http_info(opts) data end |
#query_ioa_exclusions_v1_with_http_info(opts = {}) ⇒ Array<(MsaQueryResponse, Integer, Hash)>
Search for IOA exclusions.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 254 def query_ioa_exclusions_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.query_ioa_exclusions_v1 ...' end allowable_values = ["applied_globally.asc", "applied_globally.desc", "created_by.asc", "created_by.desc", "created_on.asc", "created_on.desc", "last_modified.asc", "last_modified.desc", "modified_by.asc", "modified_by.desc", "name.asc", "name.desc", "pattern_id.asc", "pattern_id.desc", "pattern_name.asc", "pattern_name.desc"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/policy/queries/ioa-exclusions/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'ifn_regex'] = opts[:'ifn_regex'] if !opts[:'ifn_regex'].nil? query_params[:'cl_regex'] = opts[:'cl_regex'] if !opts[:'cl_regex'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.query_ioa_exclusions_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#query_ioa_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_aggregates_v2(body, opts = {}) ⇒ MsaAggregatesResponse
Get Self Service IOA Exclusion aggregates as specified via json in the request body.
318 319 320 321 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 318 def ss_ioa_exclusions_aggregates_v2(body, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_aggregates_v2_with_http_info(body, opts) data end |
#ss_ioa_exclusions_aggregates_v2_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Get Self Service IOA Exclusion aggregates as specified via json in the request body.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 333 def ss_ioa_exclusions_aggregates_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_aggregates_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_aggregates_v2" end # resource path local_var_path = '/exclusions/aggregates/ss-ioa-exclusions/GET/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'ifn_regex'] = opts[:'ifn_regex'] if !opts[:'ifn_regex'].nil? query_params[:'cl_regex'] = opts[:'cl_regex'] if !opts[:'cl_regex'].nil? query_params[:'parent_ifn_regex'] = opts[:'parent_ifn_regex'] if !opts[:'parent_ifn_regex'].nil? query_params[:'parent_cl_regex'] = opts[:'parent_cl_regex'] if !opts[:'parent_cl_regex'].nil? query_params[:'grandparent_ifn_regex'] = opts[:'grandparent_ifn_regex'] if !opts[:'grandparent_ifn_regex'].nil? query_params[:'grandparent_cl_regex'] = opts[:'grandparent_cl_regex'] if !opts[:'grandparent_cl_regex'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'MsaAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_aggregates_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_aggregates_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_create_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Create new Self Service IOA Exclusions.
396 397 398 399 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 396 def ss_ioa_exclusions_create_v2(body, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_create_v2_with_http_info(body, opts) data end |
#ss_ioa_exclusions_create_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Create new Self Service IOA Exclusions.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 405 def ss_ioa_exclusions_create_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_create_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_create_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-exclusions/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_create_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_create_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_delete_v2(ids, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Delete the Self Service IOA Exclusions rule by id.
463 464 465 466 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 463 def ss_ioa_exclusions_delete_v2(ids, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_delete_v2_with_http_info(ids, opts) data end |
#ss_ioa_exclusions_delete_v2_with_http_info(ids, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Delete the Self Service IOA Exclusions rule by id.
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 473 def ss_ioa_exclusions_delete_v2_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_delete_v2 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling IoaExclusions.ss_ioa_exclusions_delete_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-exclusions/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_delete_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_delete_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_get_reports_v2(body, opts = {}) ⇒ nil
Create a report of Self Service IOA Exclusions scoped by the given filters
527 528 529 530 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 527 def ss_ioa_exclusions_get_reports_v2(body, opts = {}) ss_ioa_exclusions_get_reports_v2_with_http_info(body, opts) nil end |
#ss_ioa_exclusions_get_reports_v2_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create a report of Self Service IOA Exclusions scoped by the given filters
536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 536 def ss_ioa_exclusions_get_reports_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_get_reports_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_get_reports_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-exclusions/reports/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_get_reports_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_get_reports_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_get_v2(ids, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Get the Self Service IOA Exclusions rules by id.
593 594 595 596 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 593 def ss_ioa_exclusions_get_v2(ids, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_get_v2_with_http_info(ids, opts) data end |
#ss_ioa_exclusions_get_v2_with_http_info(ids, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Get the Self Service IOA Exclusions rules by id.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 602 def ss_ioa_exclusions_get_v2_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_get_v2 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling IoaExclusions.ss_ioa_exclusions_get_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-exclusions/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_get_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_get_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_matched_rule_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Get Self Service IOA Exclusions rules for matched IFN/CLI for child, parent and grandparent
655 656 657 658 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 655 def ss_ioa_exclusions_matched_rule_v2(body, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_matched_rule_v2_with_http_info(body, opts) data end |
#ss_ioa_exclusions_matched_rule_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Get Self Service IOA Exclusions rules for matched IFN/CLI for child, parent and grandparent
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 664 def ss_ioa_exclusions_matched_rule_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_matched_rule_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_matched_rule_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-matched-rules/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_matched_rule_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_matched_rule_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_new_rules_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsNewRuleRespV2
Get defaults for Self Service IOA Exclusions based on provided IFN/CLI for child, parent and grandparent.
721 722 723 724 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 721 def ss_ioa_exclusions_new_rules_v2(body, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_new_rules_v2_with_http_info(body, opts) data end |
#ss_ioa_exclusions_new_rules_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsNewRuleRespV2, Integer, Hash)>
Get defaults for Self Service IOA Exclusions based on provided IFN/CLI for child, parent and grandparent.
730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 730 def ss_ioa_exclusions_new_rules_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_new_rules_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_new_rules_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-new-rules/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsNewRuleRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_new_rules_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_new_rules_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_search_v2(opts = {}) ⇒ MsaspecQueryResponse
Search for Self Service IOA Exclusions.
796 797 798 799 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 796 def ss_ioa_exclusions_search_v2(opts = {}) data, _status_code, _headers = ss_ioa_exclusions_search_v2_with_http_info(opts) data end |
#ss_ioa_exclusions_search_v2_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Search for Self Service IOA Exclusions.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 814 def ss_ioa_exclusions_search_v2_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_search_v2 ...' end allowable_values = ["name.asc", "name.desc", "pattern_id.asc", "pattern_id.desc", "pattern_name.asc", "pattern_name.desc", "created_by.asc", "created_by.desc", "last_modified.asc", "last_modified.desc", "modified_by.asc", "modified_by.desc"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/exclusions/queries/ss-ioa-exclusions/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'ifn_regex'] = opts[:'ifn_regex'] if !opts[:'ifn_regex'].nil? query_params[:'cl_regex'] = opts[:'cl_regex'] if !opts[:'cl_regex'].nil? query_params[:'parent_ifn_regex'] = opts[:'parent_ifn_regex'] if !opts[:'parent_ifn_regex'].nil? query_params[:'parent_cl_regex'] = opts[:'parent_cl_regex'] if !opts[:'parent_cl_regex'].nil? query_params[:'grandparent_ifn_regex'] = opts[:'grandparent_ifn_regex'] if !opts[:'grandparent_ifn_regex'].nil? query_params[:'grandparent_cl_regex'] = opts[:'grandparent_cl_regex'] if !opts[:'grandparent_cl_regex'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_search_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_search_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#ss_ioa_exclusions_update_v2(body, opts = {}) ⇒ DomainSsIoaExclusionsRespV2
Update the Self Service IOA Exclusions rule by id.
876 877 878 879 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 876 def ss_ioa_exclusions_update_v2(body, opts = {}) data, _status_code, _headers = ss_ioa_exclusions_update_v2_with_http_info(body, opts) data end |
#ss_ioa_exclusions_update_v2_with_http_info(body, opts = {}) ⇒ Array<(DomainSsIoaExclusionsRespV2, Integer, Hash)>
Update the Self Service IOA Exclusions rule by id.
885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 885 def ss_ioa_exclusions_update_v2_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.ss_ioa_exclusions_update_v2 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.ss_ioa_exclusions_update_v2" end # resource path local_var_path = '/exclusions/entities/ss-ioa-exclusions/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainSsIoaExclusionsRespV2' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.ss_ioa_exclusions_update_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#ss_ioa_exclusions_update_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_ioa_exclusions_v1(body, opts = {}) ⇒ IoaExclusionsIoaExclusionsRespV1
Update the IOA exclusions
942 943 944 945 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 942 def update_ioa_exclusions_v1(body, opts = {}) data, _status_code, _headers = update_ioa_exclusions_v1_with_http_info(body, opts) data end |
#update_ioa_exclusions_v1_with_http_info(body, opts = {}) ⇒ Array<(IoaExclusionsIoaExclusionsRespV1, Integer, Hash)>
Update the IOA exclusions
951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/crimson-falcon/api/ioa_exclusions.rb', line 951 def update_ioa_exclusions_v1_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IoaExclusions.update_ioa_exclusions_v1 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IoaExclusions.update_ioa_exclusions_v1" end # resource path local_var_path = '/policy/entities/ioa-exclusions/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'IoaExclusionsIoaExclusionsRespV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"IoaExclusions.update_ioa_exclusions_v1", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IoaExclusions#update_ioa_exclusions_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |