Class: Falcon::ModelsAPIRuntimeDetection
- Inherits:
-
Object
- Object
- Falcon::ModelsAPIRuntimeDetection
- Defined in:
- lib/crimson-falcon/models/models_api_runtime_detection.rb
Instance Attribute Summary collapse
-
#action_taken ⇒ Object
Returns the value of attribute action_taken.
-
#agent_type ⇒ Object
Returns the value of attribute agent_type.
-
#aid ⇒ Object
Returns the value of attribute aid.
-
#assigned_to ⇒ Object
Returns the value of attribute assigned_to.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud ⇒ Object
Returns the value of attribute cloud.
-
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
-
#cloud_id ⇒ Object
Returns the value of attribute cloud_id.
-
#cloud_instance_id ⇒ Object
Returns the value of attribute cloud_instance_id.
-
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#command_line ⇒ Object
Returns the value of attribute command_line.
-
#computer_name ⇒ Object
Returns the value of attribute computer_name.
-
#container_devices ⇒ Object
Returns the value of attribute container_devices.
-
#container_id ⇒ Object
Returns the value of attribute container_id.
-
#container_interactive_mode ⇒ Object
Returns the value of attribute container_interactive_mode.
-
#container_name ⇒ Object
Returns the value of attribute container_name.
-
#container_network_ip_address ⇒ Object
Returns the value of attribute container_network_ip_address.
-
#container_privileged ⇒ Object
Returns the value of attribute container_privileged.
-
#container_read_only_root_fs ⇒ Object
Returns the value of attribute container_read_only_root_fs.
-
#container_user_info ⇒ Object
Returns the value of attribute container_user_info.
-
#containers_impacted_count ⇒ Object
Returns the value of attribute containers_impacted_count.
-
#detect_timestamp ⇒ Object
Returns the value of attribute detect_timestamp.
-
#detection_description ⇒ Object
Returns the value of attribute detection_description.
-
#detection_id ⇒ Object
Returns the value of attribute detection_id.
-
#detection_name ⇒ Object
Returns the value of attribute detection_name.
-
#executable_sha_256 ⇒ Object
Returns the value of attribute executable_sha_256.
-
#file_name ⇒ Object
Returns the value of attribute file_name.
-
#file_path ⇒ Object
Returns the value of attribute file_path.
-
#host_containers_count ⇒ Object
Returns the value of attribute host_containers_count.
-
#host_detections_count ⇒ Object
Returns the value of attribute host_detections_count.
-
#host_detections_ids ⇒ Object
Returns the value of attribute host_detections_ids.
-
#host_id ⇒ Object
Returns the value of attribute host_id.
-
#host_last_seen_timestamp ⇒ Object
Returns the value of attribute host_last_seen_timestamp.
-
#host_type ⇒ Object
Returns the value of attribute host_type.
-
#image_digest ⇒ Object
Returns the value of attribute image_digest.
-
#image_first_seen_timestamp ⇒ Object
Returns the value of attribute image_first_seen_timestamp.
-
#image_id ⇒ Object
Returns the value of attribute image_id.
-
#image_label ⇒ Object
Returns the value of attribute image_label.
-
#image_last_seen_timestamp ⇒ Object
Returns the value of attribute image_last_seen_timestamp.
-
#image_maintainer ⇒ Object
Returns the value of attribute image_maintainer.
-
#image_name ⇒ Object
Returns the value of attribute image_name.
-
#images_container_count ⇒ Object
Returns the value of attribute images_container_count.
-
#namespace ⇒ Object
Returns the value of attribute namespace.
-
#network_ip_address ⇒ Object
Returns the value of attribute network_ip_address.
-
#os_version ⇒ Object
Returns the value of attribute os_version.
-
#pod_id ⇒ Object
Returns the value of attribute pod_id.
-
#pod_name ⇒ Object
Returns the value of attribute pod_name.
-
#pod_namespace ⇒ Object
Returns the value of attribute pod_namespace.
-
#sensor_version ⇒ Object
Returns the value of attribute sensor_version.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#tactic_and_technique ⇒ Object
Returns the value of attribute tactic_and_technique.
-
#type ⇒ Object
Returns the value of attribute type.
-
#vulnerabilities_count ⇒ Object
Returns the value of attribute vulnerabilities_count.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsAPIRuntimeDetection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsAPIRuntimeDetection
Initializes the object
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 275 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsAPIRuntimeDetection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsAPIRuntimeDetection`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action_taken') self.action_taken = attributes[:'action_taken'] end if attributes.key?(:'agent_type') self.agent_type = attributes[:'agent_type'] end if attributes.key?(:'aid') self.aid = attributes[:'aid'] end if attributes.key?(:'assigned_to') self.assigned_to = attributes[:'assigned_to'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud') self.cloud = attributes[:'cloud'] end if attributes.key?(:'cloud_account_id') self.cloud_account_id = attributes[:'cloud_account_id'] end if attributes.key?(:'cloud_id') self.cloud_id = attributes[:'cloud_id'] end if attributes.key?(:'cloud_instance_id') self.cloud_instance_id = attributes[:'cloud_instance_id'] end if attributes.key?(:'cloud_name') self.cloud_name = attributes[:'cloud_name'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end if attributes.key?(:'command_line') self.command_line = attributes[:'command_line'] end if attributes.key?(:'computer_name') self.computer_name = attributes[:'computer_name'] end if attributes.key?(:'container_devices') if (value = attributes[:'container_devices']).is_a?(Array) self.container_devices = value end end if attributes.key?(:'container_id') self.container_id = attributes[:'container_id'] end if attributes.key?(:'container_interactive_mode') self.container_interactive_mode = attributes[:'container_interactive_mode'] end if attributes.key?(:'container_name') self.container_name = attributes[:'container_name'] end if attributes.key?(:'container_network_ip_address') self.container_network_ip_address = attributes[:'container_network_ip_address'] end if attributes.key?(:'container_privileged') self.container_privileged = attributes[:'container_privileged'] end if attributes.key?(:'container_read_only_root_fs') self.container_read_only_root_fs = attributes[:'container_read_only_root_fs'] end if attributes.key?(:'container_user_info') self.container_user_info = attributes[:'container_user_info'] end if attributes.key?(:'containers_impacted_count') self.containers_impacted_count = attributes[:'containers_impacted_count'] end if attributes.key?(:'detect_timestamp') self. = attributes[:'detect_timestamp'] end if attributes.key?(:'detection_description') self.detection_description = attributes[:'detection_description'] end if attributes.key?(:'detection_id') self.detection_id = attributes[:'detection_id'] end if attributes.key?(:'detection_name') if (value = attributes[:'detection_name']).is_a?(Array) self.detection_name = value end end if attributes.key?(:'executable_sha_256') self.executable_sha_256 = attributes[:'executable_sha_256'] end if attributes.key?(:'file_name') self.file_name = attributes[:'file_name'] end if attributes.key?(:'file_path') self.file_path = attributes[:'file_path'] end if attributes.key?(:'host_containers_count') self.host_containers_count = attributes[:'host_containers_count'] end if attributes.key?(:'host_detections_count') self.host_detections_count = attributes[:'host_detections_count'] end if attributes.key?(:'host_detections_ids') if (value = attributes[:'host_detections_ids']).is_a?(Array) self.host_detections_ids = value end end if attributes.key?(:'host_id') self.host_id = attributes[:'host_id'] end if attributes.key?(:'host_last_seen_timestamp') self. = attributes[:'host_last_seen_timestamp'] end if attributes.key?(:'host_type') self.host_type = attributes[:'host_type'] end if attributes.key?(:'image_digest') self.image_digest = attributes[:'image_digest'] end if attributes.key?(:'image_first_seen_timestamp') self. = attributes[:'image_first_seen_timestamp'] end if attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] end if attributes.key?(:'image_label') self.image_label = attributes[:'image_label'] end if attributes.key?(:'image_last_seen_timestamp') self. = attributes[:'image_last_seen_timestamp'] end if attributes.key?(:'image_maintainer') self.image_maintainer = attributes[:'image_maintainer'] end if attributes.key?(:'image_name') self.image_name = attributes[:'image_name'] end if attributes.key?(:'images_container_count') self.images_container_count = attributes[:'images_container_count'] end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'network_ip_address') self.network_ip_address = attributes[:'network_ip_address'] end if attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] end if attributes.key?(:'pod_id') self.pod_id = attributes[:'pod_id'] end if attributes.key?(:'pod_name') self.pod_name = attributes[:'pod_name'] end if attributes.key?(:'pod_namespace') self.pod_namespace = attributes[:'pod_namespace'] end if attributes.key?(:'sensor_version') self.sensor_version = attributes[:'sensor_version'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'tactic_and_technique') self.tactic_and_technique = attributes[:'tactic_and_technique'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'vulnerabilities_count') self.vulnerabilities_count = attributes[:'vulnerabilities_count'] end end |
Instance Attribute Details
#action_taken ⇒ Object
Returns the value of attribute action_taken.
34 35 36 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 34 def action_taken @action_taken end |
#agent_type ⇒ Object
Returns the value of attribute agent_type.
36 37 38 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 36 def agent_type @agent_type end |
#aid ⇒ Object
Returns the value of attribute aid.
38 39 40 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 38 def aid @aid end |
#assigned_to ⇒ Object
Returns the value of attribute assigned_to.
40 41 42 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 40 def assigned_to @assigned_to end |
#cid ⇒ Object
Returns the value of attribute cid.
42 43 44 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 42 def cid @cid end |
#cloud ⇒ Object
Returns the value of attribute cloud.
44 45 46 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 44 def cloud @cloud end |
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
46 47 48 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 46 def cloud_account_id @cloud_account_id end |
#cloud_id ⇒ Object
Returns the value of attribute cloud_id.
48 49 50 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 48 def cloud_id @cloud_id end |
#cloud_instance_id ⇒ Object
Returns the value of attribute cloud_instance_id.
50 51 52 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 50 def cloud_instance_id @cloud_instance_id end |
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
52 53 54 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 52 def cloud_name @cloud_name end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
54 55 56 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 54 def cluster_name @cluster_name end |
#command_line ⇒ Object
Returns the value of attribute command_line.
56 57 58 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 56 def command_line @command_line end |
#computer_name ⇒ Object
Returns the value of attribute computer_name.
58 59 60 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 58 def computer_name @computer_name end |
#container_devices ⇒ Object
Returns the value of attribute container_devices.
60 61 62 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 60 def container_devices @container_devices end |
#container_id ⇒ Object
Returns the value of attribute container_id.
62 63 64 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 62 def container_id @container_id end |
#container_interactive_mode ⇒ Object
Returns the value of attribute container_interactive_mode.
64 65 66 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 64 def container_interactive_mode @container_interactive_mode end |
#container_name ⇒ Object
Returns the value of attribute container_name.
66 67 68 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 66 def container_name @container_name end |
#container_network_ip_address ⇒ Object
Returns the value of attribute container_network_ip_address.
68 69 70 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 68 def container_network_ip_address @container_network_ip_address end |
#container_privileged ⇒ Object
Returns the value of attribute container_privileged.
70 71 72 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 70 def container_privileged @container_privileged end |
#container_read_only_root_fs ⇒ Object
Returns the value of attribute container_read_only_root_fs.
72 73 74 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 72 def container_read_only_root_fs @container_read_only_root_fs end |
#container_user_info ⇒ Object
Returns the value of attribute container_user_info.
74 75 76 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 74 def container_user_info @container_user_info end |
#containers_impacted_count ⇒ Object
Returns the value of attribute containers_impacted_count.
76 77 78 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 76 def containers_impacted_count @containers_impacted_count end |
#detect_timestamp ⇒ Object
Returns the value of attribute detect_timestamp.
78 79 80 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 78 def @detect_timestamp end |
#detection_description ⇒ Object
Returns the value of attribute detection_description.
80 81 82 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 80 def detection_description @detection_description end |
#detection_id ⇒ Object
Returns the value of attribute detection_id.
82 83 84 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 82 def detection_id @detection_id end |
#detection_name ⇒ Object
Returns the value of attribute detection_name.
84 85 86 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 84 def detection_name @detection_name end |
#executable_sha_256 ⇒ Object
Returns the value of attribute executable_sha_256.
86 87 88 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 86 def executable_sha_256 @executable_sha_256 end |
#file_name ⇒ Object
Returns the value of attribute file_name.
88 89 90 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 88 def file_name @file_name end |
#file_path ⇒ Object
Returns the value of attribute file_path.
90 91 92 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 90 def file_path @file_path end |
#host_containers_count ⇒ Object
Returns the value of attribute host_containers_count.
92 93 94 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 92 def host_containers_count @host_containers_count end |
#host_detections_count ⇒ Object
Returns the value of attribute host_detections_count.
94 95 96 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 94 def host_detections_count @host_detections_count end |
#host_detections_ids ⇒ Object
Returns the value of attribute host_detections_ids.
96 97 98 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 96 def host_detections_ids @host_detections_ids end |
#host_id ⇒ Object
Returns the value of attribute host_id.
98 99 100 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 98 def host_id @host_id end |
#host_last_seen_timestamp ⇒ Object
Returns the value of attribute host_last_seen_timestamp.
100 101 102 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 100 def @host_last_seen_timestamp end |
#host_type ⇒ Object
Returns the value of attribute host_type.
102 103 104 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 102 def host_type @host_type end |
#image_digest ⇒ Object
Returns the value of attribute image_digest.
104 105 106 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 104 def image_digest @image_digest end |
#image_first_seen_timestamp ⇒ Object
Returns the value of attribute image_first_seen_timestamp.
106 107 108 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 106 def @image_first_seen_timestamp end |
#image_id ⇒ Object
Returns the value of attribute image_id.
108 109 110 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 108 def image_id @image_id end |
#image_label ⇒ Object
Returns the value of attribute image_label.
110 111 112 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 110 def image_label @image_label end |
#image_last_seen_timestamp ⇒ Object
Returns the value of attribute image_last_seen_timestamp.
112 113 114 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 112 def @image_last_seen_timestamp end |
#image_maintainer ⇒ Object
Returns the value of attribute image_maintainer.
114 115 116 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 114 def image_maintainer @image_maintainer end |
#image_name ⇒ Object
Returns the value of attribute image_name.
116 117 118 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 116 def image_name @image_name end |
#images_container_count ⇒ Object
Returns the value of attribute images_container_count.
118 119 120 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 118 def images_container_count @images_container_count end |
#namespace ⇒ Object
Returns the value of attribute namespace.
120 121 122 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 120 def namespace @namespace end |
#network_ip_address ⇒ Object
Returns the value of attribute network_ip_address.
122 123 124 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 122 def network_ip_address @network_ip_address end |
#os_version ⇒ Object
Returns the value of attribute os_version.
124 125 126 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 124 def os_version @os_version end |
#pod_id ⇒ Object
Returns the value of attribute pod_id.
126 127 128 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 126 def pod_id @pod_id end |
#pod_name ⇒ Object
Returns the value of attribute pod_name.
128 129 130 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 128 def pod_name @pod_name end |
#pod_namespace ⇒ Object
Returns the value of attribute pod_namespace.
130 131 132 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 130 def pod_namespace @pod_namespace end |
#sensor_version ⇒ Object
Returns the value of attribute sensor_version.
132 133 134 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 132 def sensor_version @sensor_version end |
#severity ⇒ Object
Returns the value of attribute severity.
134 135 136 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 134 def severity @severity end |
#tactic_and_technique ⇒ Object
Returns the value of attribute tactic_and_technique.
136 137 138 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 136 def tactic_and_technique @tactic_and_technique end |
#type ⇒ Object
Returns the value of attribute type.
138 139 140 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 138 def type @type end |
#vulnerabilities_count ⇒ Object
Returns the value of attribute vulnerabilities_count.
140 141 142 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 140 def vulnerabilities_count @vulnerabilities_count end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
203 204 205 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 203 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 143 def self.attribute_map { :'action_taken' => :'action_taken', :'agent_type' => :'agent_type', :'aid' => :'aid', :'assigned_to' => :'assigned_to', :'cid' => :'cid', :'cloud' => :'cloud', :'cloud_account_id' => :'cloud_account_id', :'cloud_id' => :'cloud_id', :'cloud_instance_id' => :'cloud_instance_id', :'cloud_name' => :'cloud_name', :'cluster_name' => :'cluster_name', :'command_line' => :'command_line', :'computer_name' => :'computer_name', :'container_devices' => :'container_devices', :'container_id' => :'container_id', :'container_interactive_mode' => :'container_interactive_mode', :'container_name' => :'container_name', :'container_network_ip_address' => :'container_network_ip_address', :'container_privileged' => :'container_privileged', :'container_read_only_root_fs' => :'container_read_only_root_fs', :'container_user_info' => :'container_user_info', :'containers_impacted_count' => :'containers_impacted_count', :'detect_timestamp' => :'detect_timestamp', :'detection_description' => :'detection_description', :'detection_id' => :'detection_id', :'detection_name' => :'detection_name', :'executable_sha_256' => :'executable_sha_256', :'file_name' => :'file_name', :'file_path' => :'file_path', :'host_containers_count' => :'host_containers_count', :'host_detections_count' => :'host_detections_count', :'host_detections_ids' => :'host_detections_ids', :'host_id' => :'host_id', :'host_last_seen_timestamp' => :'host_last_seen_timestamp', :'host_type' => :'host_type', :'image_digest' => :'image_digest', :'image_first_seen_timestamp' => :'image_first_seen_timestamp', :'image_id' => :'image_id', :'image_label' => :'image_label', :'image_last_seen_timestamp' => :'image_last_seen_timestamp', :'image_maintainer' => :'image_maintainer', :'image_name' => :'image_name', :'images_container_count' => :'images_container_count', :'namespace' => :'namespace', :'network_ip_address' => :'network_ip_address', :'os_version' => :'os_version', :'pod_id' => :'pod_id', :'pod_name' => :'pod_name', :'pod_namespace' => :'pod_namespace', :'sensor_version' => :'sensor_version', :'severity' => :'severity', :'tactic_and_technique' => :'tactic_and_technique', :'type' => :'type', :'vulnerabilities_count' => :'vulnerabilities_count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
870 871 872 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 870 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
268 269 270 271 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 268 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 208 def self.openapi_types { :'action_taken' => :'String', :'agent_type' => :'String', :'aid' => :'String', :'assigned_to' => :'String', :'cid' => :'String', :'cloud' => :'String', :'cloud_account_id' => :'String', :'cloud_id' => :'String', :'cloud_instance_id' => :'String', :'cloud_name' => :'String', :'cluster_name' => :'String', :'command_line' => :'String', :'computer_name' => :'String', :'container_devices' => :'Array<String>', :'container_id' => :'String', :'container_interactive_mode' => :'String', :'container_name' => :'String', :'container_network_ip_address' => :'String', :'container_privileged' => :'String', :'container_read_only_root_fs' => :'String', :'container_user_info' => :'String', :'containers_impacted_count' => :'String', :'detect_timestamp' => :'String', :'detection_description' => :'String', :'detection_id' => :'String', :'detection_name' => :'Array<String>', :'executable_sha_256' => :'String', :'file_name' => :'String', :'file_path' => :'String', :'host_containers_count' => :'String', :'host_detections_count' => :'String', :'host_detections_ids' => :'Array<String>', :'host_id' => :'String', :'host_last_seen_timestamp' => :'String', :'host_type' => :'String', :'image_digest' => :'String', :'image_first_seen_timestamp' => :'String', :'image_id' => :'String', :'image_label' => :'String', :'image_last_seen_timestamp' => :'String', :'image_maintainer' => :'String', :'image_name' => :'String', :'images_container_count' => :'String', :'namespace' => :'String', :'network_ip_address' => :'String', :'os_version' => :'String', :'pod_id' => :'String', :'pod_name' => :'String', :'pod_namespace' => :'String', :'sensor_version' => :'String', :'severity' => :'String', :'tactic_and_technique' => :'String', :'type' => :'String', :'vulnerabilities_count' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 796 def ==(o) return true if self.equal?(o) self.class == o.class && action_taken == o.action_taken && agent_type == o.agent_type && aid == o.aid && assigned_to == o.assigned_to && cid == o.cid && cloud == o.cloud && cloud_account_id == o.cloud_account_id && cloud_id == o.cloud_id && cloud_instance_id == o.cloud_instance_id && cloud_name == o.cloud_name && cluster_name == o.cluster_name && command_line == o.command_line && computer_name == o.computer_name && container_devices == o.container_devices && container_id == o.container_id && container_interactive_mode == o.container_interactive_mode && container_name == o.container_name && container_network_ip_address == o.container_network_ip_address && container_privileged == o.container_privileged && container_read_only_root_fs == o.container_read_only_root_fs && container_user_info == o.container_user_info && containers_impacted_count == o.containers_impacted_count && == o. && detection_description == o.detection_description && detection_id == o.detection_id && detection_name == o.detection_name && executable_sha_256 == o.executable_sha_256 && file_name == o.file_name && file_path == o.file_path && host_containers_count == o.host_containers_count && host_detections_count == o.host_detections_count && host_detections_ids == o.host_detections_ids && host_id == o.host_id && == o. && host_type == o.host_type && image_digest == o.image_digest && == o. && image_id == o.image_id && image_label == o.image_label && == o. && image_maintainer == o.image_maintainer && image_name == o.image_name && images_container_count == o.images_container_count && namespace == o.namespace && network_ip_address == o.network_ip_address && os_version == o.os_version && pod_id == o.pod_id && pod_name == o.pod_name && pod_namespace == o.pod_namespace && sensor_version == o.sensor_version && severity == o.severity && tactic_and_technique == o.tactic_and_technique && type == o.type && vulnerabilities_count == o.vulnerabilities_count end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 901 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
972 973 974 975 976 977 978 979 980 981 982 983 984 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 972 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 877 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
857 858 859 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 857 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
863 864 865 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 863 def hash [action_taken, agent_type, aid, assigned_to, cid, cloud, cloud_account_id, cloud_id, cloud_instance_id, cloud_name, cluster_name, command_line, computer_name, container_devices, container_id, container_interactive_mode, container_name, container_network_ip_address, container_privileged, container_read_only_root_fs, container_user_info, containers_impacted_count, , detection_description, detection_id, detection_name, executable_sha_256, file_name, file_path, host_containers_count, host_detections_count, host_detections_ids, host_id, , host_type, image_digest, , image_id, image_label, , image_maintainer, image_name, images_container_count, namespace, network_ip_address, os_version, pod_id, pod_name, pod_namespace, sensor_version, severity, tactic_and_technique, type, vulnerabilities_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 513 def list_invalid_properties invalid_properties = Array.new if @action_taken.nil? invalid_properties.push('invalid value for "action_taken", action_taken cannot be nil.') end if @agent_type.nil? invalid_properties.push('invalid value for "agent_type", agent_type cannot be nil.') end if @aid.nil? invalid_properties.push('invalid value for "aid", aid cannot be nil.') end if @assigned_to.nil? invalid_properties.push('invalid value for "assigned_to", assigned_to cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cloud.nil? invalid_properties.push('invalid value for "cloud", cloud cannot be nil.') end if @cloud_account_id.nil? invalid_properties.push('invalid value for "cloud_account_id", cloud_account_id cannot be nil.') end if @cloud_id.nil? invalid_properties.push('invalid value for "cloud_id", cloud_id cannot be nil.') end if @cloud_instance_id.nil? invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.') end if @cloud_name.nil? invalid_properties.push('invalid value for "cloud_name", cloud_name cannot be nil.') end if @cluster_name.nil? invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.') end if @command_line.nil? invalid_properties.push('invalid value for "command_line", command_line cannot be nil.') end if @computer_name.nil? invalid_properties.push('invalid value for "computer_name", computer_name cannot be nil.') end if @container_devices.nil? invalid_properties.push('invalid value for "container_devices", container_devices cannot be nil.') end if @container_id.nil? invalid_properties.push('invalid value for "container_id", container_id cannot be nil.') end if @container_interactive_mode.nil? invalid_properties.push('invalid value for "container_interactive_mode", container_interactive_mode cannot be nil.') end if @container_name.nil? invalid_properties.push('invalid value for "container_name", container_name cannot be nil.') end if @container_network_ip_address.nil? invalid_properties.push('invalid value for "container_network_ip_address", container_network_ip_address cannot be nil.') end if @container_privileged.nil? invalid_properties.push('invalid value for "container_privileged", container_privileged cannot be nil.') end if @container_read_only_root_fs.nil? invalid_properties.push('invalid value for "container_read_only_root_fs", container_read_only_root_fs cannot be nil.') end if @container_user_info.nil? invalid_properties.push('invalid value for "container_user_info", container_user_info cannot be nil.') end if @containers_impacted_count.nil? invalid_properties.push('invalid value for "containers_impacted_count", containers_impacted_count cannot be nil.') end if @detect_timestamp.nil? invalid_properties.push('invalid value for "detect_timestamp", detect_timestamp cannot be nil.') end if @detection_description.nil? invalid_properties.push('invalid value for "detection_description", detection_description cannot be nil.') end if @detection_id.nil? invalid_properties.push('invalid value for "detection_id", detection_id cannot be nil.') end if @detection_name.nil? invalid_properties.push('invalid value for "detection_name", detection_name cannot be nil.') end if @executable_sha_256.nil? invalid_properties.push('invalid value for "executable_sha_256", executable_sha_256 cannot be nil.') end if @file_name.nil? invalid_properties.push('invalid value for "file_name", file_name cannot be nil.') end if @file_path.nil? invalid_properties.push('invalid value for "file_path", file_path cannot be nil.') end if @host_containers_count.nil? invalid_properties.push('invalid value for "host_containers_count", host_containers_count cannot be nil.') end if @host_detections_count.nil? invalid_properties.push('invalid value for "host_detections_count", host_detections_count cannot be nil.') end if @host_detections_ids.nil? invalid_properties.push('invalid value for "host_detections_ids", host_detections_ids cannot be nil.') end if @host_id.nil? invalid_properties.push('invalid value for "host_id", host_id cannot be nil.') end if @host_last_seen_timestamp.nil? invalid_properties.push('invalid value for "host_last_seen_timestamp", host_last_seen_timestamp cannot be nil.') end if @host_type.nil? invalid_properties.push('invalid value for "host_type", host_type cannot be nil.') end if @image_digest.nil? invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.') end if @image_first_seen_timestamp.nil? invalid_properties.push('invalid value for "image_first_seen_timestamp", image_first_seen_timestamp cannot be nil.') end if @image_id.nil? invalid_properties.push('invalid value for "image_id", image_id cannot be nil.') end if @image_label.nil? invalid_properties.push('invalid value for "image_label", image_label cannot be nil.') end if @image_last_seen_timestamp.nil? invalid_properties.push('invalid value for "image_last_seen_timestamp", image_last_seen_timestamp cannot be nil.') end if @image_maintainer.nil? invalid_properties.push('invalid value for "image_maintainer", image_maintainer cannot be nil.') end if @image_name.nil? invalid_properties.push('invalid value for "image_name", image_name cannot be nil.') end if @images_container_count.nil? invalid_properties.push('invalid value for "images_container_count", images_container_count cannot be nil.') end if @namespace.nil? invalid_properties.push('invalid value for "namespace", namespace cannot be nil.') end if @network_ip_address.nil? invalid_properties.push('invalid value for "network_ip_address", network_ip_address cannot be nil.') end if @os_version.nil? invalid_properties.push('invalid value for "os_version", os_version cannot be nil.') end if @pod_id.nil? invalid_properties.push('invalid value for "pod_id", pod_id cannot be nil.') end if @pod_name.nil? invalid_properties.push('invalid value for "pod_name", pod_name cannot be nil.') end if @pod_namespace.nil? invalid_properties.push('invalid value for "pod_namespace", pod_namespace cannot be nil.') end if @sensor_version.nil? invalid_properties.push('invalid value for "sensor_version", sensor_version cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @tactic_and_technique.nil? invalid_properties.push('invalid value for "tactic_and_technique", tactic_and_technique cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @vulnerabilities_count.nil? invalid_properties.push('invalid value for "vulnerabilities_count", vulnerabilities_count cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
948 949 950 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 948 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
954 955 956 957 958 959 960 961 962 963 964 965 966 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 954 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
942 943 944 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 942 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 |
# File 'lib/crimson-falcon/models/models_api_runtime_detection.rb', line 736 def valid? return false if @action_taken.nil? return false if @agent_type.nil? return false if @aid.nil? return false if @assigned_to.nil? return false if @cid.nil? return false if @cloud.nil? return false if @cloud_account_id.nil? return false if @cloud_id.nil? return false if @cloud_instance_id.nil? return false if @cloud_name.nil? return false if @cluster_name.nil? return false if @command_line.nil? return false if @computer_name.nil? return false if @container_devices.nil? return false if @container_id.nil? return false if @container_interactive_mode.nil? return false if @container_name.nil? return false if @container_network_ip_address.nil? return false if @container_privileged.nil? return false if @container_read_only_root_fs.nil? return false if @container_user_info.nil? return false if @containers_impacted_count.nil? return false if @detect_timestamp.nil? return false if @detection_description.nil? return false if @detection_id.nil? return false if @detection_name.nil? return false if @executable_sha_256.nil? return false if @file_name.nil? return false if @file_path.nil? return false if @host_containers_count.nil? return false if @host_detections_count.nil? return false if @host_detections_ids.nil? return false if @host_id.nil? return false if @host_last_seen_timestamp.nil? return false if @host_type.nil? return false if @image_digest.nil? return false if @image_first_seen_timestamp.nil? return false if @image_id.nil? return false if @image_label.nil? return false if @image_last_seen_timestamp.nil? return false if @image_maintainer.nil? return false if @image_name.nil? return false if @images_container_count.nil? return false if @namespace.nil? return false if @network_ip_address.nil? return false if @os_version.nil? return false if @pod_id.nil? return false if @pod_name.nil? return false if @pod_namespace.nil? return false if @sensor_version.nil? return false if @severity.nil? return false if @tactic_and_technique.nil? return false if @type.nil? return false if @vulnerabilities_count.nil? true end |