Class: Falcon::ModelsDeployment
- Inherits:
-
Object
- Object
- Falcon::ModelsDeployment
- Defined in:
- lib/crimson-falcon/models/models_deployment.rb
Instance Attribute Summary collapse
-
#agents ⇒ Object
Returns the value of attribute agents.
-
#annotations ⇒ Object
Returns the value of attribute annotations.
-
#annotations_list ⇒ Object
Returns the value of attribute annotations_list.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
-
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
-
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
-
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
-
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#container_count ⇒ Object
Returns the value of attribute container_count.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#deployment_id ⇒ Object
Returns the value of attribute deployment_id.
-
#deployment_name ⇒ Object
Returns the value of attribute deployment_name.
-
#first_seen ⇒ Object
Returns the value of attribute first_seen.
-
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
-
#labels ⇒ Object
Returns the value of attribute labels.
-
#labels_list ⇒ Object
Returns the value of attribute labels_list.
-
#last_seen ⇒ Object
Returns the value of attribute last_seen.
-
#management_status ⇒ Object
Returns the value of attribute management_status.
-
#namespace ⇒ Object
Returns the value of attribute namespace.
-
#pod_count ⇒ Object
Returns the value of attribute pod_count.
-
#resource_status ⇒ Object
Returns the value of attribute resource_status.
-
#resource_version ⇒ Object
Returns the value of attribute resource_version.
-
#revision ⇒ Object
Returns the value of attribute revision.
-
#selector ⇒ Object
Returns the value of attribute selector.
-
#service_account_name ⇒ Object
Returns the value of attribute service_account_name.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsDeployment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsDeployment
Initializes the object
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 175 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsDeployment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsDeployment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agents') if (value = attributes[:'agents']).is_a?(Array) self.agents = value end end if attributes.key?(:'annotations') if (value = attributes[:'annotations']).is_a?(Hash) self.annotations = value end end if attributes.key?(:'annotations_list') if (value = attributes[:'annotations_list']).is_a?(Array) self.annotations_list = value end end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'cloud_account_id') self.cloud_account_id = attributes[:'cloud_account_id'] end if attributes.key?(:'cloud_name') self.cloud_name = attributes[:'cloud_name'] end if attributes.key?(:'cloud_region') self.cloud_region = attributes[:'cloud_region'] end if attributes.key?(:'cloud_service') self.cloud_service = attributes[:'cloud_service'] end if attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end if attributes.key?(:'container_count') self.container_count = attributes[:'container_count'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] end if attributes.key?(:'deployment_name') self.deployment_name = attributes[:'deployment_name'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'kac_agent_id') self.kac_agent_id = attributes[:'kac_agent_id'] end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Hash) self.labels = value end end if attributes.key?(:'labels_list') if (value = attributes[:'labels_list']).is_a?(Array) self.labels_list = value end end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'management_status') self.management_status = attributes[:'management_status'] end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'pod_count') self.pod_count = attributes[:'pod_count'] end if attributes.key?(:'resource_status') self.resource_status = attributes[:'resource_status'] end if attributes.key?(:'resource_version') self.resource_version = attributes[:'resource_version'] end if attributes.key?(:'revision') self.revision = attributes[:'revision'] end if attributes.key?(:'selector') self.selector = attributes[:'selector'] end if attributes.key?(:'service_account_name') self.service_account_name = attributes[:'service_account_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#agents ⇒ Object
Returns the value of attribute agents.
34 35 36 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 34 def agents @agents end |
#annotations ⇒ Object
Returns the value of attribute annotations.
36 37 38 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 36 def annotations @annotations end |
#annotations_list ⇒ Object
Returns the value of attribute annotations_list.
38 39 40 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 38 def annotations_list @annotations_list end |
#cid ⇒ Object
Returns the value of attribute cid.
40 41 42 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 40 def cid @cid end |
#cloud_account_id ⇒ Object
Returns the value of attribute cloud_account_id.
42 43 44 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 42 def cloud_account_id @cloud_account_id end |
#cloud_name ⇒ Object
Returns the value of attribute cloud_name.
44 45 46 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 44 def cloud_name @cloud_name end |
#cloud_region ⇒ Object
Returns the value of attribute cloud_region.
46 47 48 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 46 def cloud_region @cloud_region end |
#cloud_service ⇒ Object
Returns the value of attribute cloud_service.
48 49 50 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 48 def cloud_service @cloud_service end |
#cluster_id ⇒ Object
Returns the value of attribute cluster_id.
50 51 52 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 50 def cluster_id @cluster_id end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
52 53 54 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 52 def cluster_name @cluster_name end |
#container_count ⇒ Object
Returns the value of attribute container_count.
54 55 56 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 54 def container_count @container_count end |
#created_at ⇒ Object
Returns the value of attribute created_at.
56 57 58 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 56 def created_at @created_at end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
58 59 60 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 58 def deleted_at @deleted_at end |
#deployment_id ⇒ Object
Returns the value of attribute deployment_id.
60 61 62 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 60 def deployment_id @deployment_id end |
#deployment_name ⇒ Object
Returns the value of attribute deployment_name.
62 63 64 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 62 def deployment_name @deployment_name end |
#first_seen ⇒ Object
Returns the value of attribute first_seen.
64 65 66 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 64 def first_seen @first_seen end |
#kac_agent_id ⇒ Object
Returns the value of attribute kac_agent_id.
66 67 68 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 66 def kac_agent_id @kac_agent_id end |
#labels ⇒ Object
Returns the value of attribute labels.
68 69 70 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 68 def labels @labels end |
#labels_list ⇒ Object
Returns the value of attribute labels_list.
70 71 72 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 70 def labels_list @labels_list end |
#last_seen ⇒ Object
Returns the value of attribute last_seen.
72 73 74 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 72 def last_seen @last_seen end |
#management_status ⇒ Object
Returns the value of attribute management_status.
74 75 76 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 74 def management_status @management_status end |
#namespace ⇒ Object
Returns the value of attribute namespace.
76 77 78 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 76 def namespace @namespace end |
#pod_count ⇒ Object
Returns the value of attribute pod_count.
78 79 80 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 78 def pod_count @pod_count end |
#resource_status ⇒ Object
Returns the value of attribute resource_status.
80 81 82 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 80 def resource_status @resource_status end |
#resource_version ⇒ Object
Returns the value of attribute resource_version.
82 83 84 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 82 def resource_version @resource_version end |
#revision ⇒ Object
Returns the value of attribute revision.
84 85 86 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 84 def revision @revision end |
#selector ⇒ Object
Returns the value of attribute selector.
86 87 88 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 86 def selector @selector end |
#service_account_name ⇒ Object
Returns the value of attribute service_account_name.
88 89 90 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 88 def service_account_name @service_account_name end |
#status ⇒ Object
Returns the value of attribute status.
90 91 92 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 90 def status @status end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
128 129 130 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 128 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 93 def self.attribute_map { :'agents' => :'agents', :'annotations' => :'annotations', :'annotations_list' => :'annotations_list', :'cid' => :'cid', :'cloud_account_id' => :'cloud_account_id', :'cloud_name' => :'cloud_name', :'cloud_region' => :'cloud_region', :'cloud_service' => :'cloud_service', :'cluster_id' => :'cluster_id', :'cluster_name' => :'cluster_name', :'container_count' => :'container_count', :'created_at' => :'created_at', :'deleted_at' => :'deleted_at', :'deployment_id' => :'deployment_id', :'deployment_name' => :'deployment_name', :'first_seen' => :'first_seen', :'kac_agent_id' => :'kac_agent_id', :'labels' => :'labels', :'labels_list' => :'labels_list', :'last_seen' => :'last_seen', :'management_status' => :'management_status', :'namespace' => :'namespace', :'pod_count' => :'pod_count', :'resource_status' => :'resource_status', :'resource_version' => :'resource_version', :'revision' => :'revision', :'selector' => :'selector', :'service_account_name' => :'service_account_name', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
514 515 516 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 514 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
168 169 170 171 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 168 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 133 def self.openapi_types { :'agents' => :'Array<Hash>', :'annotations' => :'Hash<String, String>', :'annotations_list' => :'Array<String>', :'cid' => :'String', :'cloud_account_id' => :'String', :'cloud_name' => :'String', :'cloud_region' => :'String', :'cloud_service' => :'String', :'cluster_id' => :'String', :'cluster_name' => :'String', :'container_count' => :'Integer', :'created_at' => :'String', :'deleted_at' => :'String', :'deployment_id' => :'String', :'deployment_name' => :'String', :'first_seen' => :'String', :'kac_agent_id' => :'String', :'labels' => :'Hash<String, String>', :'labels_list' => :'Array<String>', :'last_seen' => :'String', :'management_status' => :'String', :'namespace' => :'String', :'pod_count' => :'Integer', :'resource_status' => :'String', :'resource_version' => :'Integer', :'revision' => :'Integer', :'selector' => :'String', :'service_account_name' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 465 def ==(o) return true if self.equal?(o) self.class == o.class && agents == o.agents && annotations == o.annotations && annotations_list == o.annotations_list && cid == o.cid && cloud_account_id == o.cloud_account_id && cloud_name == o.cloud_name && cloud_region == o.cloud_region && cloud_service == o.cloud_service && cluster_id == o.cluster_id && cluster_name == o.cluster_name && container_count == o.container_count && created_at == o.created_at && deleted_at == o.deleted_at && deployment_id == o.deployment_id && deployment_name == o.deployment_name && first_seen == o.first_seen && kac_agent_id == o.kac_agent_id && labels == o.labels && labels_list == o.labels_list && last_seen == o.last_seen && management_status == o.management_status && namespace == o.namespace && pod_count == o.pod_count && resource_status == o.resource_status && resource_version == o.resource_version && revision == o.revision && selector == o.selector && service_account_name == o.service_account_name && status == o.status end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 545 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 616 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 521 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
501 502 503 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 501 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
507 508 509 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 507 def hash [agents, annotations, annotations_list, cid, cloud_account_id, cloud_name, cloud_region, cloud_service, cluster_id, cluster_name, container_count, created_at, deleted_at, deployment_id, deployment_name, first_seen, kac_agent_id, labels, labels_list, last_seen, management_status, namespace, pod_count, resource_status, resource_version, revision, selector, service_account_name, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 317 def list_invalid_properties invalid_properties = Array.new if @agents.nil? invalid_properties.push('invalid value for "agents", agents cannot be nil.') end if @annotations.nil? invalid_properties.push('invalid value for "annotations", annotations cannot be nil.') end if @annotations_list.nil? invalid_properties.push('invalid value for "annotations_list", annotations_list cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @cloud_account_id.nil? invalid_properties.push('invalid value for "cloud_account_id", cloud_account_id cannot be nil.') end if @cloud_name.nil? invalid_properties.push('invalid value for "cloud_name", cloud_name cannot be nil.') end if @cloud_region.nil? invalid_properties.push('invalid value for "cloud_region", cloud_region cannot be nil.') end if @cloud_service.nil? invalid_properties.push('invalid value for "cloud_service", cloud_service cannot be nil.') end if @cluster_id.nil? invalid_properties.push('invalid value for "cluster_id", cluster_id cannot be nil.') end if @cluster_name.nil? invalid_properties.push('invalid value for "cluster_name", cluster_name cannot be nil.') end if @container_count.nil? invalid_properties.push('invalid value for "container_count", container_count cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @deployment_id.nil? invalid_properties.push('invalid value for "deployment_id", deployment_id cannot be nil.') end if @deployment_name.nil? invalid_properties.push('invalid value for "deployment_name", deployment_name cannot be nil.') end if @first_seen.nil? invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.') end if @kac_agent_id.nil? invalid_properties.push('invalid value for "kac_agent_id", kac_agent_id cannot be nil.') end if @labels.nil? invalid_properties.push('invalid value for "labels", labels cannot be nil.') end if @labels_list.nil? invalid_properties.push('invalid value for "labels_list", labels_list cannot be nil.') end if @last_seen.nil? invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.') end if @management_status.nil? invalid_properties.push('invalid value for "management_status", management_status cannot be nil.') end if @namespace.nil? invalid_properties.push('invalid value for "namespace", namespace cannot be nil.') end if @pod_count.nil? invalid_properties.push('invalid value for "pod_count", pod_count cannot be nil.') end if @resource_status.nil? invalid_properties.push('invalid value for "resource_status", resource_status cannot be nil.') end if @resource_version.nil? invalid_properties.push('invalid value for "resource_version", resource_version cannot be nil.') end if @selector.nil? invalid_properties.push('invalid value for "selector", selector cannot be nil.') end if @service_account_name.nil? invalid_properties.push('invalid value for "service_account_name", service_account_name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
592 593 594 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 592 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 598 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
586 587 588 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 586 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/crimson-falcon/models/models_deployment.rb', line 432 def valid? return false if @agents.nil? return false if @annotations.nil? return false if @annotations_list.nil? return false if @cid.nil? return false if @cloud_account_id.nil? return false if @cloud_name.nil? return false if @cloud_region.nil? return false if @cloud_service.nil? return false if @cluster_id.nil? return false if @cluster_name.nil? return false if @container_count.nil? return false if @created_at.nil? return false if @deployment_id.nil? return false if @deployment_name.nil? return false if @first_seen.nil? return false if @kac_agent_id.nil? return false if @labels.nil? return false if @labels_list.nil? return false if @last_seen.nil? return false if @management_status.nil? return false if @namespace.nil? return false if @pod_count.nil? return false if @resource_status.nil? return false if @resource_version.nil? return false if @selector.nil? return false if @service_account_name.nil? return false if @status.nil? true end |