Class: Falcon::ModelsExtAPIImageCombined
- Inherits:
-
Object
- Object
- Falcon::ModelsExtAPIImageCombined
- Defined in:
- lib/crimson-falcon/models/models_ext_api_image_combined.rb
Instance Attribute Summary collapse
-
#ai_related ⇒ Object
Returns the value of attribute ai_related.
-
#architecture ⇒ Object
Returns the value of attribute architecture.
-
#base_os ⇒ Object
Returns the value of attribute base_os.
-
#cid ⇒ Object
Returns the value of attribute cid.
-
#containers ⇒ Object
Returns the value of attribute containers.
-
#detections ⇒ Object
Returns the value of attribute detections.
-
#first_seen ⇒ Object
Returns the value of attribute first_seen.
-
#highest_detection_severity ⇒ Object
Returns the value of attribute highest_detection_severity.
-
#highest_vulnerability_severity ⇒ Object
Returns the value of attribute highest_vulnerability_severity.
-
#image_digest ⇒ Object
Returns the value of attribute image_digest.
-
#image_id ⇒ Object
Returns the value of attribute image_id.
-
#index_digest ⇒ Object
Returns the value of attribute index_digest.
-
#last_seen ⇒ Object
Returns the value of attribute last_seen.
-
#layers_with_vulnerabilities ⇒ Object
Returns the value of attribute layers_with_vulnerabilities.
-
#multi_arch ⇒ Object
Returns the value of attribute multi_arch.
-
#packages ⇒ Object
Returns the value of attribute packages.
-
#registry ⇒ Object
Returns the value of attribute registry.
-
#report_url_by_id_and_digest ⇒ Object
Returns the value of attribute report_url_by_id_and_digest.
-
#report_url_by_repo_and_tag ⇒ Object
Returns the value of attribute report_url_by_repo_and_tag.
-
#repository ⇒ Object
Returns the value of attribute repository.
-
#tag ⇒ Object
Returns the value of attribute tag.
-
#vulnerabilities ⇒ Object
Returns the value of attribute vulnerabilities.
-
#warning ⇒ Object
Returns the value of attribute warning.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelsExtAPIImageCombined
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ModelsExtAPIImageCombined
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 151 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::ModelsExtAPIImageCombined` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::ModelsExtAPIImageCombined`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ai_related') self. = attributes[:'ai_related'] end if attributes.key?(:'architecture') self.architecture = attributes[:'architecture'] end if attributes.key?(:'base_os') self.base_os = attributes[:'base_os'] end if attributes.key?(:'cid') self.cid = attributes[:'cid'] end if attributes.key?(:'containers') self.containers = attributes[:'containers'] end if attributes.key?(:'detections') self.detections = attributes[:'detections'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'highest_detection_severity') self.highest_detection_severity = attributes[:'highest_detection_severity'] end if attributes.key?(:'highest_vulnerability_severity') self.highest_vulnerability_severity = attributes[:'highest_vulnerability_severity'] end if attributes.key?(:'image_digest') self.image_digest = attributes[:'image_digest'] end if attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] end if attributes.key?(:'index_digest') self.index_digest = attributes[:'index_digest'] end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'layers_with_vulnerabilities') self.layers_with_vulnerabilities = attributes[:'layers_with_vulnerabilities'] end if attributes.key?(:'multi_arch') self.multi_arch = attributes[:'multi_arch'] end if attributes.key?(:'packages') self.packages = attributes[:'packages'] end if attributes.key?(:'registry') self.registry = attributes[:'registry'] end if attributes.key?(:'report_url_by_id_and_digest') self.report_url_by_id_and_digest = attributes[:'report_url_by_id_and_digest'] end if attributes.key?(:'report_url_by_repo_and_tag') self.report_url_by_repo_and_tag = attributes[:'report_url_by_repo_and_tag'] end if attributes.key?(:'repository') self.repository = attributes[:'repository'] end if attributes.key?(:'tag') self.tag = attributes[:'tag'] end if attributes.key?(:'vulnerabilities') self.vulnerabilities = attributes[:'vulnerabilities'] end if attributes.key?(:'warning') self.warning = attributes[:'warning'] end end |
Instance Attribute Details
#ai_related ⇒ Object
Returns the value of attribute ai_related.
34 35 36 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 34 def @ai_related end |
#architecture ⇒ Object
Returns the value of attribute architecture.
36 37 38 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 36 def architecture @architecture end |
#base_os ⇒ Object
Returns the value of attribute base_os.
38 39 40 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 38 def base_os @base_os end |
#cid ⇒ Object
Returns the value of attribute cid.
40 41 42 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 40 def cid @cid end |
#containers ⇒ Object
Returns the value of attribute containers.
42 43 44 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 42 def containers @containers end |
#detections ⇒ Object
Returns the value of attribute detections.
44 45 46 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 44 def detections @detections end |
#first_seen ⇒ Object
Returns the value of attribute first_seen.
46 47 48 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 46 def first_seen @first_seen end |
#highest_detection_severity ⇒ Object
Returns the value of attribute highest_detection_severity.
48 49 50 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 48 def highest_detection_severity @highest_detection_severity end |
#highest_vulnerability_severity ⇒ Object
Returns the value of attribute highest_vulnerability_severity.
50 51 52 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 50 def highest_vulnerability_severity @highest_vulnerability_severity end |
#image_digest ⇒ Object
Returns the value of attribute image_digest.
52 53 54 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 52 def image_digest @image_digest end |
#image_id ⇒ Object
Returns the value of attribute image_id.
54 55 56 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 54 def image_id @image_id end |
#index_digest ⇒ Object
Returns the value of attribute index_digest.
56 57 58 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 56 def index_digest @index_digest end |
#last_seen ⇒ Object
Returns the value of attribute last_seen.
58 59 60 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 58 def last_seen @last_seen end |
#layers_with_vulnerabilities ⇒ Object
Returns the value of attribute layers_with_vulnerabilities.
60 61 62 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 60 def layers_with_vulnerabilities @layers_with_vulnerabilities end |
#multi_arch ⇒ Object
Returns the value of attribute multi_arch.
62 63 64 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 62 def multi_arch @multi_arch end |
#packages ⇒ Object
Returns the value of attribute packages.
64 65 66 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 64 def packages @packages end |
#registry ⇒ Object
Returns the value of attribute registry.
66 67 68 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 66 def registry @registry end |
#report_url_by_id_and_digest ⇒ Object
Returns the value of attribute report_url_by_id_and_digest.
68 69 70 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 68 def report_url_by_id_and_digest @report_url_by_id_and_digest end |
#report_url_by_repo_and_tag ⇒ Object
Returns the value of attribute report_url_by_repo_and_tag.
70 71 72 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 70 def report_url_by_repo_and_tag @report_url_by_repo_and_tag end |
#repository ⇒ Object
Returns the value of attribute repository.
72 73 74 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 72 def repository @repository end |
#tag ⇒ Object
Returns the value of attribute tag.
74 75 76 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 74 def tag @tag end |
#vulnerabilities ⇒ Object
Returns the value of attribute vulnerabilities.
76 77 78 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 76 def vulnerabilities @vulnerabilities end |
#warning ⇒ Object
Returns the value of attribute warning.
78 79 80 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 78 def warning @warning end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 110 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 81 def self.attribute_map { :'ai_related' => :'ai_related', :'architecture' => :'architecture', :'base_os' => :'base_os', :'cid' => :'cid', :'containers' => :'containers', :'detections' => :'detections', :'first_seen' => :'first_seen', :'highest_detection_severity' => :'highest_detection_severity', :'highest_vulnerability_severity' => :'highest_vulnerability_severity', :'image_digest' => :'image_digest', :'image_id' => :'image_id', :'index_digest' => :'index_digest', :'last_seen' => :'last_seen', :'layers_with_vulnerabilities' => :'layers_with_vulnerabilities', :'multi_arch' => :'multi_arch', :'packages' => :'packages', :'registry' => :'registry', :'report_url_by_id_and_digest' => :'report_url_by_id_and_digest', :'report_url_by_repo_and_tag' => :'report_url_by_repo_and_tag', :'repository' => :'repository', :'tag' => :'tag', :'vulnerabilities' => :'vulnerabilities', :'warning' => :'warning' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
430 431 432 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 430 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
144 145 146 147 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 144 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 115 def self.openapi_types { :'ai_related' => :'Boolean', :'architecture' => :'String', :'base_os' => :'String', :'cid' => :'String', :'containers' => :'Integer', :'detections' => :'Integer', :'first_seen' => :'String', :'highest_detection_severity' => :'String', :'highest_vulnerability_severity' => :'String', :'image_digest' => :'String', :'image_id' => :'String', :'index_digest' => :'String', :'last_seen' => :'String', :'layers_with_vulnerabilities' => :'Integer', :'multi_arch' => :'Boolean', :'packages' => :'Integer', :'registry' => :'String', :'report_url_by_id_and_digest' => :'String', :'report_url_by_repo_and_tag' => :'String', :'repository' => :'String', :'tag' => :'String', :'vulnerabilities' => :'Integer', :'warning' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 387 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && architecture == o.architecture && base_os == o.base_os && cid == o.cid && containers == o.containers && detections == o.detections && first_seen == o.first_seen && highest_detection_severity == o.highest_detection_severity && highest_vulnerability_severity == o.highest_vulnerability_severity && image_digest == o.image_digest && image_id == o.image_id && index_digest == o.index_digest && last_seen == o.last_seen && layers_with_vulnerabilities == o.layers_with_vulnerabilities && multi_arch == o.multi_arch && packages == o.packages && registry == o.registry && report_url_by_id_and_digest == o.report_url_by_id_and_digest && report_url_by_repo_and_tag == o.report_url_by_repo_and_tag && repository == o.repository && tag == o.tag && vulnerabilities == o.vulnerabilities && warning == o.warning end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 461 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 532 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 437 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
417 418 419 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 417 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
423 424 425 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 423 def hash [, architecture, base_os, cid, containers, detections, first_seen, highest_detection_severity, highest_vulnerability_severity, image_digest, image_id, index_digest, last_seen, layers_with_vulnerabilities, multi_arch, packages, registry, report_url_by_id_and_digest, report_url_by_repo_and_tag, repository, tag, vulnerabilities, warning].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 259 def list_invalid_properties invalid_properties = Array.new if @ai_related.nil? invalid_properties.push('invalid value for "ai_related", ai_related cannot be nil.') end if @architecture.nil? invalid_properties.push('invalid value for "architecture", architecture cannot be nil.') end if @base_os.nil? invalid_properties.push('invalid value for "base_os", base_os cannot be nil.') end if @cid.nil? invalid_properties.push('invalid value for "cid", cid cannot be nil.') end if @containers.nil? invalid_properties.push('invalid value for "containers", containers cannot be nil.') end if @detections.nil? invalid_properties.push('invalid value for "detections", detections cannot be nil.') end if @first_seen.nil? invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.') end if @highest_detection_severity.nil? invalid_properties.push('invalid value for "highest_detection_severity", highest_detection_severity cannot be nil.') end if @highest_vulnerability_severity.nil? invalid_properties.push('invalid value for "highest_vulnerability_severity", highest_vulnerability_severity cannot be nil.') end if @image_digest.nil? invalid_properties.push('invalid value for "image_digest", image_digest cannot be nil.') end if @image_id.nil? invalid_properties.push('invalid value for "image_id", image_id cannot be nil.') end if @index_digest.nil? invalid_properties.push('invalid value for "index_digest", index_digest cannot be nil.') end if @last_seen.nil? invalid_properties.push('invalid value for "last_seen", last_seen cannot be nil.') end if @layers_with_vulnerabilities.nil? invalid_properties.push('invalid value for "layers_with_vulnerabilities", layers_with_vulnerabilities cannot be nil.') end if @multi_arch.nil? invalid_properties.push('invalid value for "multi_arch", multi_arch cannot be nil.') end if @packages.nil? invalid_properties.push('invalid value for "packages", packages cannot be nil.') end if @registry.nil? invalid_properties.push('invalid value for "registry", registry cannot be nil.') end if @report_url_by_id_and_digest.nil? invalid_properties.push('invalid value for "report_url_by_id_and_digest", report_url_by_id_and_digest cannot be nil.') end if @report_url_by_repo_and_tag.nil? invalid_properties.push('invalid value for "report_url_by_repo_and_tag", report_url_by_repo_and_tag cannot be nil.') end if @repository.nil? invalid_properties.push('invalid value for "repository", repository cannot be nil.') end if @tag.nil? invalid_properties.push('invalid value for "tag", tag cannot be nil.') end if @vulnerabilities.nil? invalid_properties.push('invalid value for "vulnerabilities", vulnerabilities cannot be nil.') end if @warning.nil? invalid_properties.push('invalid value for "warning", warning cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
508 509 510 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 508 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 514 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
502 503 504 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 502 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/crimson-falcon/models/models_ext_api_image_combined.rb', line 358 def valid? return false if @ai_related.nil? return false if @architecture.nil? return false if @base_os.nil? return false if @cid.nil? return false if @containers.nil? return false if @detections.nil? return false if @first_seen.nil? return false if @highest_detection_severity.nil? return false if @highest_vulnerability_severity.nil? return false if @image_digest.nil? return false if @image_id.nil? return false if @index_digest.nil? return false if @last_seen.nil? return false if @layers_with_vulnerabilities.nil? return false if @multi_arch.nil? return false if @packages.nil? return false if @registry.nil? return false if @report_url_by_id_and_digest.nil? return false if @report_url_by_repo_and_tag.nil? return false if @repository.nil? return false if @tag.nil? return false if @vulnerabilities.nil? return false if @warning.nil? true end |