Class: Falcon::NetworkScanZones
- Inherits:
-
Object
- Object
- Falcon::NetworkScanZones
- Defined in:
- lib/crimson-falcon/api/network_scan_zones.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#aggregate_zones(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "zones" aggregations.
-
#aggregate_zones_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "zones" aggregations.
-
#combined_zones(opts = {}) ⇒ DomainZoneEntitiesResponse
Get "zones" by filter.
-
#combined_zones_with_http_info(opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Get "zones" by filter.
-
#create_zones(body, opts = {}) ⇒ DomainZoneEntitiesResponse
Create "zones" using provided specifications.
-
#create_zones_with_http_info(body, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Create "zones" using provided specifications.
-
#delete_zones(ids, opts = {}) ⇒ MsaspecQueryResponse
Delete "zones" by their IDs.
-
#delete_zones_with_http_info(ids, opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Delete "zones" by their IDs.
-
#get_zones(ids, opts = {}) ⇒ DomainZoneEntitiesResponse
Get "zones" by their IDs.
-
#get_zones_with_http_info(ids, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Get "zones" by their IDs.
-
#initialize(api_client = ApiClient.default) ⇒ NetworkScanZones
constructor
A new instance of NetworkScanZones.
-
#query_zones(opts = {}) ⇒ MsaspecQueryResponse
Get "zones IDs" by filter.
-
#query_zones_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "zones IDs" by filter.
-
#update_zones(body, opts = {}) ⇒ DomainZoneEntitiesResponse
Update "zones" using provided specifications.
-
#update_zones_with_http_info(body, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Update "zones" using provided specifications.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ NetworkScanZones
Returns a new instance of NetworkScanZones.
35 36 37 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 33 def api_client @api_client end |
Instance Method Details
#aggregate_zones(body, opts = {}) ⇒ MsaAggregatesResponse
Returns "zones" aggregations
43 44 45 46 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 43 def aggregate_zones(body, opts = {}) data, _status_code, _headers = aggregate_zones_with_http_info(body, opts) data end |
#aggregate_zones_with_http_info(body, opts = {}) ⇒ Array<(MsaAggregatesResponse, Integer, Hash)>
Returns "zones" aggregations
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 53 def aggregate_zones_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.aggregate_zones ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanZones.aggregate_zones" end # resource path local_var_path = '/netscan/aggregates/zones/GET/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'MsaAggregatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.aggregate_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#aggregate_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#combined_zones(opts = {}) ⇒ DomainZoneEntitiesResponse
Get "zones" by filter
115 116 117 118 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 115 def combined_zones(opts = {}) data, _status_code, _headers = combined_zones_with_http_info(opts) data end |
#combined_zones_with_http_info(opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Get "zones" by filter
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 128 def combined_zones_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.combined_zones ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling NetworkScanZones.combined_zones, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanZones.combined_zones, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanZones.combined_zones, must be greater than or equal to 1.' end # resource path local_var_path = '/netscan/combined/zones/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainZoneEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.combined_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#combined_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_zones(body, opts = {}) ⇒ DomainZoneEntitiesResponse
Create "zones" using provided specifications
194 195 196 197 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 194 def create_zones(body, opts = {}) data, _status_code, _headers = create_zones_with_http_info(body, opts) data end |
#create_zones_with_http_info(body, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Create "zones" using provided specifications
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 204 def create_zones_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.create_zones ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanZones.create_zones" end # resource path local_var_path = '/netscan/entities/zones/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainZoneEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.create_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#create_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_zones(ids, opts = {}) ⇒ MsaspecQueryResponse
Delete "zones" by their IDs
263 264 265 266 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 263 def delete_zones(ids, opts = {}) data, _status_code, _headers = delete_zones_with_http_info(ids, opts) data end |
#delete_zones_with_http_info(ids, opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Delete "zones" by their IDs
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 273 def delete_zones_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.delete_zones ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanZones.delete_zones" end # resource path local_var_path = '/netscan/entities/zones/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.delete_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#delete_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_zones(ids, opts = {}) ⇒ DomainZoneEntitiesResponse
Get "zones" by their IDs
328 329 330 331 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 328 def get_zones(ids, opts = {}) data, _status_code, _headers = get_zones_with_http_info(ids, opts) data end |
#get_zones_with_http_info(ids, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Get "zones" by their IDs
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 338 def get_zones_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.get_zones ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling NetworkScanZones.get_zones" end # resource path local_var_path = '/netscan/entities/zones/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :multi) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainZoneEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.get_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#get_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_zones(opts = {}) ⇒ MsaspecQueryResponse
Get "zones IDs" by filter
396 397 398 399 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 396 def query_zones(opts = {}) data, _status_code, _headers = query_zones_with_http_info(opts) data end |
#query_zones_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Get "zones IDs" by filter
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 409 def query_zones_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.query_zones ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling NetworkScanZones.query_zones, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanZones.query_zones, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling NetworkScanZones.query_zones, must be greater than or equal to 1.' end # resource path local_var_path = '/netscan/queries/zones/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.query_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#query_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_zones(body, opts = {}) ⇒ DomainZoneEntitiesResponse
Update "zones" using provided specifications
475 476 477 478 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 475 def update_zones(body, opts = {}) data, _status_code, _headers = update_zones_with_http_info(body, opts) data end |
#update_zones_with_http_info(body, opts = {}) ⇒ Array<(DomainZoneEntitiesResponse, Integer, Hash)>
Update "zones" using provided specifications
485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/crimson-falcon/api/network_scan_zones.rb', line 485 def update_zones_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NetworkScanZones.update_zones ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling NetworkScanZones.update_zones" end # resource path local_var_path = '/netscan/entities/zones/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-CS-USERUUID'] = opts[:'x_cs_useruuid'] if !opts[:'x_cs_useruuid'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'DomainZoneEntitiesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"NetworkScanZones.update_zones", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NetworkScanZones#update_zones\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |