Class: Falcon::PolicymanagerPolicyProperties
- Inherits:
-
Object
- Object
- Falcon::PolicymanagerPolicyProperties
- Defined in:
- lib/crimson-falcon/models/policymanager_policy_properties.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allow_notifications ⇒ Object
Windows only.
-
#be_exclude_domains ⇒ Object
Length must be at most 2048 characters.
-
#be_paste_clipboard_max_size ⇒ Object
Must be a non-negative integer and max 65536.
-
#be_paste_clipboard_max_size_unit ⇒ Object
Accepts values: ‘Bytes’, ‘KiB’.
-
#be_paste_clipboard_min_size ⇒ Object
Must be a non-negative integer and max 65536.
-
#be_paste_clipboard_min_size_unit ⇒ Object
Accepts values: ‘Bytes’, ‘KiB’.
-
#be_paste_clipboard_over_size_behaviour_block ⇒ Object
Returns the value of attribute be_paste_clipboard_over_size_behaviour_block.
-
#be_paste_timeout_duration_milliseconds ⇒ Object
Must be a non-negative integer, between 1 and 10000.
-
#be_paste_timeout_response ⇒ Object
Accepts values: ‘block’, ‘allow’.
-
#be_splash_custom_message ⇒ Object
Length must be at most 256, must follow pattern ‘^([^ ]* )0,3[^ ]*$’.
-
#be_splash_enabled ⇒ Object
Returns the value of attribute be_splash_enabled.
-
#be_splash_message_source ⇒ Object
Accepts values: ‘default’, ‘custom’.
-
#be_upload_timeout_duration_seconds ⇒ Object
Must be a non-negative integer, must be between 1 and 300.
-
#be_upload_timeout_response ⇒ Object
Accepts values: ‘block’, ‘allow’.
-
#block_all_data_access ⇒ Object
Returns the value of attribute block_all_data_access.
-
#block_notifications ⇒ Object
Windows only.
-
#browsers_without_active_extension ⇒ Object
Define behaviour of browsers without active extension, accepts values: ‘allow’, ‘block_policy’.
-
#classifications ⇒ Object
Returns the value of attribute classifications.
-
#custom_allow_notification ⇒ Object
Windows only.
-
#custom_block_notification ⇒ Object
Windows only.
-
#enable_clipboard_inspection ⇒ Object
Returns the value of attribute enable_clipboard_inspection.
-
#enable_content_inspection ⇒ Object
Returns the value of attribute enable_content_inspection.
-
#enable_context_inspection ⇒ Object
Returns the value of attribute enable_context_inspection.
-
#enable_end_user_notifications_unsupported_browser ⇒ Object
Windows only.
-
#enable_network_inspection ⇒ Object
Windows only.
-
#enable_screen_capture ⇒ Object
Windows only.
-
#euj_dialog_box_logo ⇒ Object
Length must be at least 0 and at max 150000, must be a valid png base64 image, which matches this regular expression ‘^data:image/png(?:;charset=utf-8)?;base64,(?:|[
/])=0,2’. -
#euj_dialog_timeout ⇒ Object
Configurable between 60 and 420 sec.
-
#euj_dropdown_options ⇒ Object
Returns the value of attribute euj_dropdown_options.
-
#euj_header_text ⇒ Object
Returns the value of attribute euj_header_text.
-
#euj_require_additional_details ⇒ Object
If enabled, the user must provide additional details to justify the egress.
-
#evidence_download_enabled ⇒ Object
Windows only.
-
#evidence_duplication_enabled_default ⇒ Object
Windows only.
-
#evidence_encrypted_enabled ⇒ Object
Windows only.
-
#evidence_storage_free_disk_perc ⇒ Object
Windows only.
-
#evidence_storage_max_size ⇒ Object
Windows only.
-
#inspection_depth ⇒ Object
Inspection depth accepts values : ‘balanced’, ‘high_performance’, ‘deep_scan’.
-
#max_file_size_to_inspect ⇒ Object
Must be between 512 and 524288000 bytes.
-
#max_file_size_to_inspect_unit ⇒ Object
Must be either ‘Bytes, KB or MB’.
-
#min_confidence_level ⇒ Object
Confidence level accepts values: ‘low’, ‘medium’, ‘high’.
-
#network_inspection_files_exceeding_size_limit ⇒ Object
Windows only.
-
#screen_capture_duration_post_event ⇒ Object
Windows only.
-
#screen_capture_duration_pre_event ⇒ Object
Windows only.
-
#similarity_detection ⇒ Object
Returns the value of attribute similarity_detection.
-
#similarity_threshold ⇒ Object
Similarity threshold percentage values from 10 to 100.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PolicymanagerPolicyProperties
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PolicymanagerPolicyProperties
Initializes the object
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 296 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Falcon::PolicymanagerPolicyProperties` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Falcon::PolicymanagerPolicyProperties`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allow_notifications') self.allow_notifications = attributes[:'allow_notifications'] end if attributes.key?(:'be_exclude_domains') self.be_exclude_domains = attributes[:'be_exclude_domains'] end if attributes.key?(:'be_paste_clipboard_max_size') self.be_paste_clipboard_max_size = attributes[:'be_paste_clipboard_max_size'] end if attributes.key?(:'be_paste_clipboard_max_size_unit') self.be_paste_clipboard_max_size_unit = attributes[:'be_paste_clipboard_max_size_unit'] end if attributes.key?(:'be_paste_clipboard_min_size') self.be_paste_clipboard_min_size = attributes[:'be_paste_clipboard_min_size'] end if attributes.key?(:'be_paste_clipboard_min_size_unit') self.be_paste_clipboard_min_size_unit = attributes[:'be_paste_clipboard_min_size_unit'] end if attributes.key?(:'be_paste_clipboard_over_size_behaviour_block') self.be_paste_clipboard_over_size_behaviour_block = attributes[:'be_paste_clipboard_over_size_behaviour_block'] end if attributes.key?(:'be_paste_timeout_duration_milliseconds') self.be_paste_timeout_duration_milliseconds = attributes[:'be_paste_timeout_duration_milliseconds'] end if attributes.key?(:'be_paste_timeout_response') self.be_paste_timeout_response = attributes[:'be_paste_timeout_response'] end if attributes.key?(:'be_splash_custom_message') self. = attributes[:'be_splash_custom_message'] end if attributes.key?(:'be_splash_enabled') self.be_splash_enabled = attributes[:'be_splash_enabled'] end if attributes.key?(:'be_splash_message_source') self. = attributes[:'be_splash_message_source'] end if attributes.key?(:'be_upload_timeout_duration_seconds') self.be_upload_timeout_duration_seconds = attributes[:'be_upload_timeout_duration_seconds'] end if attributes.key?(:'be_upload_timeout_response') self.be_upload_timeout_response = attributes[:'be_upload_timeout_response'] end if attributes.key?(:'block_all_data_access') self.block_all_data_access = attributes[:'block_all_data_access'] end if attributes.key?(:'block_notifications') self.block_notifications = attributes[:'block_notifications'] end if attributes.key?(:'browsers_without_active_extension') self.browsers_without_active_extension = attributes[:'browsers_without_active_extension'] end if attributes.key?(:'classifications') if (value = attributes[:'classifications']).is_a?(Array) self.classifications = value end end if attributes.key?(:'custom_allow_notification') self.custom_allow_notification = attributes[:'custom_allow_notification'] end if attributes.key?(:'custom_block_notification') self.custom_block_notification = attributes[:'custom_block_notification'] end if attributes.key?(:'enable_clipboard_inspection') self.enable_clipboard_inspection = attributes[:'enable_clipboard_inspection'] end if attributes.key?(:'enable_content_inspection') self.enable_content_inspection = attributes[:'enable_content_inspection'] end if attributes.key?(:'enable_context_inspection') self.enable_context_inspection = attributes[:'enable_context_inspection'] end if attributes.key?(:'enable_end_user_notifications_unsupported_browser') self.enable_end_user_notifications_unsupported_browser = attributes[:'enable_end_user_notifications_unsupported_browser'] end if attributes.key?(:'enable_network_inspection') self.enable_network_inspection = attributes[:'enable_network_inspection'] end if attributes.key?(:'enable_screen_capture') self.enable_screen_capture = attributes[:'enable_screen_capture'] end if attributes.key?(:'euj_dialog_box_logo') self.euj_dialog_box_logo = attributes[:'euj_dialog_box_logo'] end if attributes.key?(:'euj_dialog_timeout') self.euj_dialog_timeout = attributes[:'euj_dialog_timeout'] end if attributes.key?(:'euj_dropdown_options') self. = attributes[:'euj_dropdown_options'] end if attributes.key?(:'euj_header_text') self.euj_header_text = attributes[:'euj_header_text'] end if attributes.key?(:'euj_require_additional_details') self.euj_require_additional_details = attributes[:'euj_require_additional_details'] end if attributes.key?(:'evidence_download_enabled') self.evidence_download_enabled = attributes[:'evidence_download_enabled'] end if attributes.key?(:'evidence_duplication_enabled_default') self.evidence_duplication_enabled_default = attributes[:'evidence_duplication_enabled_default'] end if attributes.key?(:'evidence_encrypted_enabled') self.evidence_encrypted_enabled = attributes[:'evidence_encrypted_enabled'] end if attributes.key?(:'evidence_storage_free_disk_perc') self.evidence_storage_free_disk_perc = attributes[:'evidence_storage_free_disk_perc'] end if attributes.key?(:'evidence_storage_max_size') self.evidence_storage_max_size = attributes[:'evidence_storage_max_size'] end if attributes.key?(:'inspection_depth') self.inspection_depth = attributes[:'inspection_depth'] end if attributes.key?(:'max_file_size_to_inspect') self.max_file_size_to_inspect = attributes[:'max_file_size_to_inspect'] end if attributes.key?(:'max_file_size_to_inspect_unit') self.max_file_size_to_inspect_unit = attributes[:'max_file_size_to_inspect_unit'] end if attributes.key?(:'min_confidence_level') self.min_confidence_level = attributes[:'min_confidence_level'] end if attributes.key?(:'network_inspection_files_exceeding_size_limit') self.network_inspection_files_exceeding_size_limit = attributes[:'network_inspection_files_exceeding_size_limit'] end if attributes.key?(:'screen_capture_duration_post_event') self.screen_capture_duration_post_event = attributes[:'screen_capture_duration_post_event'] end if attributes.key?(:'screen_capture_duration_pre_event') self.screen_capture_duration_pre_event = attributes[:'screen_capture_duration_pre_event'] end if attributes.key?(:'similarity_detection') self.similarity_detection = attributes[:'similarity_detection'] end if attributes.key?(:'similarity_threshold') self.similarity_threshold = attributes[:'similarity_threshold'] end end |
Instance Attribute Details
#allow_notifications ⇒ Object
Windows only. Allow notifications accepts values: ‘default’, ‘custom’
35 36 37 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 35 def allow_notifications @allow_notifications end |
#be_exclude_domains ⇒ Object
Length must be at most 2048 characters
38 39 40 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 38 def be_exclude_domains @be_exclude_domains end |
#be_paste_clipboard_max_size ⇒ Object
Must be a non-negative integer and max 65536
41 42 43 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 41 def be_paste_clipboard_max_size @be_paste_clipboard_max_size end |
#be_paste_clipboard_max_size_unit ⇒ Object
Accepts values: ‘Bytes’, ‘KiB’
44 45 46 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 44 def be_paste_clipboard_max_size_unit @be_paste_clipboard_max_size_unit end |
#be_paste_clipboard_min_size ⇒ Object
Must be a non-negative integer and max 65536
47 48 49 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 47 def be_paste_clipboard_min_size @be_paste_clipboard_min_size end |
#be_paste_clipboard_min_size_unit ⇒ Object
Accepts values: ‘Bytes’, ‘KiB’
50 51 52 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 50 def be_paste_clipboard_min_size_unit @be_paste_clipboard_min_size_unit end |
#be_paste_clipboard_over_size_behaviour_block ⇒ Object
Returns the value of attribute be_paste_clipboard_over_size_behaviour_block.
52 53 54 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 52 def be_paste_clipboard_over_size_behaviour_block @be_paste_clipboard_over_size_behaviour_block end |
#be_paste_timeout_duration_milliseconds ⇒ Object
Must be a non-negative integer, between 1 and 10000
55 56 57 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 55 def be_paste_timeout_duration_milliseconds @be_paste_timeout_duration_milliseconds end |
#be_paste_timeout_response ⇒ Object
Accepts values: ‘block’, ‘allow’
58 59 60 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 58 def be_paste_timeout_response @be_paste_timeout_response end |
#be_splash_custom_message ⇒ Object
Length must be at most 256, must follow pattern ‘^([^ ]* )0,3[^ ]*$’
61 62 63 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 61 def @be_splash_custom_message end |
#be_splash_enabled ⇒ Object
Returns the value of attribute be_splash_enabled.
63 64 65 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 63 def be_splash_enabled @be_splash_enabled end |
#be_splash_message_source ⇒ Object
Accepts values: ‘default’, ‘custom’
66 67 68 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 66 def @be_splash_message_source end |
#be_upload_timeout_duration_seconds ⇒ Object
Must be a non-negative integer, must be between 1 and 300
69 70 71 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 69 def be_upload_timeout_duration_seconds @be_upload_timeout_duration_seconds end |
#be_upload_timeout_response ⇒ Object
Accepts values: ‘block’, ‘allow’
72 73 74 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 72 def be_upload_timeout_response @be_upload_timeout_response end |
#block_all_data_access ⇒ Object
Returns the value of attribute block_all_data_access.
74 75 76 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 74 def block_all_data_access @block_all_data_access end |
#block_notifications ⇒ Object
Windows only. Block notifications accepts values: ‘default’, ‘custom’
77 78 79 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 77 def block_notifications @block_notifications end |
#browsers_without_active_extension ⇒ Object
Define behaviour of browsers without active extension, accepts values: ‘allow’, ‘block_policy’.
80 81 82 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 80 def browsers_without_active_extension @browsers_without_active_extension end |
#classifications ⇒ Object
Returns the value of attribute classifications.
82 83 84 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 82 def classifications @classifications end |
#custom_allow_notification ⇒ Object
Windows only. Length must be at least 2 and at max 256, must follow pattern ‘^([^ ]* )0,3[^ ]*$’
85 86 87 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 85 def custom_allow_notification @custom_allow_notification end |
#custom_block_notification ⇒ Object
Windows only. Length must be at least 2 and at max 256, must follow pattern ‘^([^ ]* )0,3[^ ]*$’
88 89 90 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 88 def custom_block_notification @custom_block_notification end |
#enable_clipboard_inspection ⇒ Object
Returns the value of attribute enable_clipboard_inspection.
90 91 92 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 90 def enable_clipboard_inspection @enable_clipboard_inspection end |
#enable_content_inspection ⇒ Object
Returns the value of attribute enable_content_inspection.
92 93 94 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 92 def enable_content_inspection @enable_content_inspection end |
#enable_context_inspection ⇒ Object
Returns the value of attribute enable_context_inspection.
94 95 96 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 94 def enable_context_inspection @enable_context_inspection end |
#enable_end_user_notifications_unsupported_browser ⇒ Object
Windows only. When enabled, users will receive a notification when data from unsupported browsers is blocked
97 98 99 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 97 def enable_end_user_notifications_unsupported_browser @enable_end_user_notifications_unsupported_browser end |
#enable_network_inspection ⇒ Object
Windows only. Enable or disable network inspection
100 101 102 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 100 def enable_network_inspection @enable_network_inspection end |
#enable_screen_capture ⇒ Object
Windows only. Enable screen capture before and after egress event
103 104 105 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 103 def enable_screen_capture @enable_screen_capture end |
#euj_dialog_box_logo ⇒ Object
Length must be at least 0 and at max 150000, must be a valid png base64 image, which matches this regular expression ‘^data:image/png(?:;charset=utf-8)?;base64,(?:|[/])=0,2’
106 107 108 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 106 def euj_dialog_box_logo @euj_dialog_box_logo end |
#euj_dialog_timeout ⇒ Object
Configurable between 60 and 420 sec. This property sets the timeout for the end user justification dialog box. If the user fails to provide a justification, the egress will be blocked.
109 110 111 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 109 def euj_dialog_timeout @euj_dialog_timeout end |
#euj_dropdown_options ⇒ Object
Returns the value of attribute euj_dropdown_options.
111 112 113 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 111 def @euj_dropdown_options end |
#euj_header_text ⇒ Object
Returns the value of attribute euj_header_text.
113 114 115 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 113 def euj_header_text @euj_header_text end |
#euj_require_additional_details ⇒ Object
If enabled, the user must provide additional details to justify the egress
116 117 118 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 116 def euj_require_additional_details @euj_require_additional_details end |
#evidence_download_enabled ⇒ Object
Windows only. If enabled, Falcon Console users with Data Protection Forensics Manager role can request and download files for egress events. Data will be copied to the host’s local storage when requested, or when matching a classification with storage enabled.
119 120 121 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 119 def evidence_download_enabled @evidence_download_enabled end |
#evidence_duplication_enabled_default ⇒ Object
Windows only. If enabled, data is copied to a protected evidence folder on the host at the time a download is requested to prevent tampering. Copies of data will be stored on the originating host for up to 30 days.
122 123 124 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 122 def evidence_duplication_enabled_default @evidence_duplication_enabled_default end |
#evidence_encrypted_enabled ⇒ Object
Windows only. If enabled, when data encryption occurs, a copy of the original data is stored in a protected folder on the host. This ensures encrypted data is retrievable if it is part of an egress event within the following 30 days.
125 126 127 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 125 def evidence_encrypted_enabled @evidence_encrypted_enabled end |
#evidence_storage_free_disk_perc ⇒ Object
Windows only. Must be between 1 and 90
128 129 130 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 128 def evidence_storage_free_disk_perc @evidence_storage_free_disk_perc end |
#evidence_storage_max_size ⇒ Object
Windows only. Must be between 1 and 100
131 132 133 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 131 def evidence_storage_max_size @evidence_storage_max_size end |
#inspection_depth ⇒ Object
Inspection depth accepts values : ‘balanced’, ‘high_performance’, ‘deep_scan’
134 135 136 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 134 def inspection_depth @inspection_depth end |
#max_file_size_to_inspect ⇒ Object
Must be between 512 and 524288000 bytes
137 138 139 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 137 def max_file_size_to_inspect @max_file_size_to_inspect end |
#max_file_size_to_inspect_unit ⇒ Object
Must be either ‘Bytes, KB or MB’
140 141 142 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 140 def max_file_size_to_inspect_unit @max_file_size_to_inspect_unit end |
#min_confidence_level ⇒ Object
Confidence level accepts values: ‘low’, ‘medium’, ‘high’
143 144 145 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 143 def min_confidence_level @min_confidence_level end |
#network_inspection_files_exceeding_size_limit ⇒ Object
Windows only. Network inspection files exceeding size limit accepts values: ‘block’, ‘allow’
146 147 148 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 146 def network_inspection_files_exceeding_size_limit @network_inspection_files_exceeding_size_limit end |
#screen_capture_duration_post_event ⇒ Object
Windows only. Screen capture duration in seconds after egress event. Only accepts ‘3’, ‘5’, or ‘10’
149 150 151 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 149 def screen_capture_duration_post_event @screen_capture_duration_post_event end |
#screen_capture_duration_pre_event ⇒ Object
Windows only. Screen capture duration in seconds before egress event. Only accepts ‘3’, ‘5’, or ‘10’
152 153 154 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 152 def screen_capture_duration_pre_event @screen_capture_duration_pre_event end |
#similarity_detection ⇒ Object
Returns the value of attribute similarity_detection.
154 155 156 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 154 def similarity_detection @similarity_detection end |
#similarity_threshold ⇒ Object
Similarity threshold percentage values from 10 to 100
157 158 159 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 157 def similarity_threshold @similarity_threshold end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
233 234 235 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 233 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 182 def self.attribute_map { :'allow_notifications' => :'allow_notifications', :'be_exclude_domains' => :'be_exclude_domains', :'be_paste_clipboard_max_size' => :'be_paste_clipboard_max_size', :'be_paste_clipboard_max_size_unit' => :'be_paste_clipboard_max_size_unit', :'be_paste_clipboard_min_size' => :'be_paste_clipboard_min_size', :'be_paste_clipboard_min_size_unit' => :'be_paste_clipboard_min_size_unit', :'be_paste_clipboard_over_size_behaviour_block' => :'be_paste_clipboard_over_size_behaviour_block', :'be_paste_timeout_duration_milliseconds' => :'be_paste_timeout_duration_milliseconds', :'be_paste_timeout_response' => :'be_paste_timeout_response', :'be_splash_custom_message' => :'be_splash_custom_message', :'be_splash_enabled' => :'be_splash_enabled', :'be_splash_message_source' => :'be_splash_message_source', :'be_upload_timeout_duration_seconds' => :'be_upload_timeout_duration_seconds', :'be_upload_timeout_response' => :'be_upload_timeout_response', :'block_all_data_access' => :'block_all_data_access', :'block_notifications' => :'block_notifications', :'browsers_without_active_extension' => :'browsers_without_active_extension', :'classifications' => :'classifications', :'custom_allow_notification' => :'custom_allow_notification', :'custom_block_notification' => :'custom_block_notification', :'enable_clipboard_inspection' => :'enable_clipboard_inspection', :'enable_content_inspection' => :'enable_content_inspection', :'enable_context_inspection' => :'enable_context_inspection', :'enable_end_user_notifications_unsupported_browser' => :'enable_end_user_notifications_unsupported_browser', :'enable_network_inspection' => :'enable_network_inspection', :'enable_screen_capture' => :'enable_screen_capture', :'euj_dialog_box_logo' => :'euj_dialog_box_logo', :'euj_dialog_timeout' => :'euj_dialog_timeout', :'euj_dropdown_options' => :'euj_dropdown_options', :'euj_header_text' => :'euj_header_text', :'euj_require_additional_details' => :'euj_require_additional_details', :'evidence_download_enabled' => :'evidence_download_enabled', :'evidence_duplication_enabled_default' => :'evidence_duplication_enabled_default', :'evidence_encrypted_enabled' => :'evidence_encrypted_enabled', :'evidence_storage_free_disk_perc' => :'evidence_storage_free_disk_perc', :'evidence_storage_max_size' => :'evidence_storage_max_size', :'inspection_depth' => :'inspection_depth', :'max_file_size_to_inspect' => :'max_file_size_to_inspect', :'max_file_size_to_inspect_unit' => :'max_file_size_to_inspect_unit', :'min_confidence_level' => :'min_confidence_level', :'network_inspection_files_exceeding_size_limit' => :'network_inspection_files_exceeding_size_limit', :'screen_capture_duration_post_event' => :'screen_capture_duration_post_event', :'screen_capture_duration_pre_event' => :'screen_capture_duration_pre_event', :'similarity_detection' => :'similarity_detection', :'similarity_threshold' => :'similarity_threshold' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
752 753 754 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 752 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
289 290 291 292 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 289 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 238 def self.openapi_types { :'allow_notifications' => :'String', :'be_exclude_domains' => :'String', :'be_paste_clipboard_max_size' => :'Float', :'be_paste_clipboard_max_size_unit' => :'String', :'be_paste_clipboard_min_size' => :'Float', :'be_paste_clipboard_min_size_unit' => :'String', :'be_paste_clipboard_over_size_behaviour_block' => :'Boolean', :'be_paste_timeout_duration_milliseconds' => :'Integer', :'be_paste_timeout_response' => :'String', :'be_splash_custom_message' => :'String', :'be_splash_enabled' => :'Boolean', :'be_splash_message_source' => :'String', :'be_upload_timeout_duration_seconds' => :'Integer', :'be_upload_timeout_response' => :'String', :'block_all_data_access' => :'Boolean', :'block_notifications' => :'String', :'browsers_without_active_extension' => :'String', :'classifications' => :'Array<String>', :'custom_allow_notification' => :'String', :'custom_block_notification' => :'String', :'enable_clipboard_inspection' => :'Boolean', :'enable_content_inspection' => :'Boolean', :'enable_context_inspection' => :'Boolean', :'enable_end_user_notifications_unsupported_browser' => :'Boolean', :'enable_network_inspection' => :'Boolean', :'enable_screen_capture' => :'Boolean', :'euj_dialog_box_logo' => :'String', :'euj_dialog_timeout' => :'Integer', :'euj_dropdown_options' => :'PolicymanagerEUJDropdownOptions', :'euj_header_text' => :'PolicymanagerEUJHeaderText', :'euj_require_additional_details' => :'Boolean', :'evidence_download_enabled' => :'Boolean', :'evidence_duplication_enabled_default' => :'Boolean', :'evidence_encrypted_enabled' => :'Boolean', :'evidence_storage_free_disk_perc' => :'Float', :'evidence_storage_max_size' => :'Float', :'inspection_depth' => :'String', :'max_file_size_to_inspect' => :'Float', :'max_file_size_to_inspect_unit' => :'String', :'min_confidence_level' => :'String', :'network_inspection_files_exceeding_size_limit' => :'String', :'screen_capture_duration_post_event' => :'String', :'screen_capture_duration_pre_event' => :'String', :'similarity_detection' => :'Boolean', :'similarity_threshold' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 687 def ==(o) return true if self.equal?(o) self.class == o.class && allow_notifications == o.allow_notifications && be_exclude_domains == o.be_exclude_domains && be_paste_clipboard_max_size == o.be_paste_clipboard_max_size && be_paste_clipboard_max_size_unit == o.be_paste_clipboard_max_size_unit && be_paste_clipboard_min_size == o.be_paste_clipboard_min_size && be_paste_clipboard_min_size_unit == o.be_paste_clipboard_min_size_unit && be_paste_clipboard_over_size_behaviour_block == o.be_paste_clipboard_over_size_behaviour_block && be_paste_timeout_duration_milliseconds == o.be_paste_timeout_duration_milliseconds && be_paste_timeout_response == o.be_paste_timeout_response && == o. && be_splash_enabled == o.be_splash_enabled && == o. && be_upload_timeout_duration_seconds == o.be_upload_timeout_duration_seconds && be_upload_timeout_response == o.be_upload_timeout_response && block_all_data_access == o.block_all_data_access && block_notifications == o.block_notifications && browsers_without_active_extension == o.browsers_without_active_extension && classifications == o.classifications && custom_allow_notification == o.custom_allow_notification && custom_block_notification == o.custom_block_notification && enable_clipboard_inspection == o.enable_clipboard_inspection && enable_content_inspection == o.enable_content_inspection && enable_context_inspection == o.enable_context_inspection && enable_end_user_notifications_unsupported_browser == o.enable_end_user_notifications_unsupported_browser && enable_network_inspection == o.enable_network_inspection && enable_screen_capture == o.enable_screen_capture && euj_dialog_box_logo == o.euj_dialog_box_logo && euj_dialog_timeout == o.euj_dialog_timeout && == o. && euj_header_text == o.euj_header_text && euj_require_additional_details == o.euj_require_additional_details && evidence_download_enabled == o.evidence_download_enabled && evidence_duplication_enabled_default == o.evidence_duplication_enabled_default && evidence_encrypted_enabled == o.evidence_encrypted_enabled && evidence_storage_free_disk_perc == o.evidence_storage_free_disk_perc && evidence_storage_max_size == o.evidence_storage_max_size && inspection_depth == o.inspection_depth && max_file_size_to_inspect == o.max_file_size_to_inspect && max_file_size_to_inspect_unit == o.max_file_size_to_inspect_unit && min_confidence_level == o.min_confidence_level && network_inspection_files_exceeding_size_limit == o.network_inspection_files_exceeding_size_limit && screen_capture_duration_post_event == o.screen_capture_duration_post_event && screen_capture_duration_pre_event == o.screen_capture_duration_pre_event && similarity_detection == o.similarity_detection && similarity_threshold == o.similarity_threshold end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 783 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Falcon.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 854 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 759 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
739 740 741 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 739 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
745 746 747 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 745 def hash [allow_notifications, be_exclude_domains, be_paste_clipboard_max_size, be_paste_clipboard_max_size_unit, be_paste_clipboard_min_size, be_paste_clipboard_min_size_unit, be_paste_clipboard_over_size_behaviour_block, be_paste_timeout_duration_milliseconds, be_paste_timeout_response, , be_splash_enabled, , be_upload_timeout_duration_seconds, be_upload_timeout_response, block_all_data_access, block_notifications, browsers_without_active_extension, classifications, custom_allow_notification, custom_block_notification, enable_clipboard_inspection, enable_content_inspection, enable_context_inspection, enable_end_user_notifications_unsupported_browser, enable_network_inspection, enable_screen_capture, euj_dialog_box_logo, euj_dialog_timeout, , euj_header_text, euj_require_additional_details, evidence_download_enabled, evidence_duplication_enabled_default, evidence_encrypted_enabled, evidence_storage_free_disk_perc, evidence_storage_max_size, inspection_depth, max_file_size_to_inspect, max_file_size_to_inspect_unit, min_confidence_level, network_inspection_files_exceeding_size_limit, screen_capture_duration_post_event, screen_capture_duration_pre_event, similarity_detection, similarity_threshold].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
494 495 496 497 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 494 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
830 831 832 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 830 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 836 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
824 825 826 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 824 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/crimson-falcon/models/policymanager_policy_properties.rb', line 501 def valid? allow_notifications_validator = EnumAttributeValidator.new('String', ["default", "custom"]) return false unless allow_notifications_validator.valid?(@allow_notifications) be_paste_clipboard_max_size_unit_validator = EnumAttributeValidator.new('String', ["Bytes", "KiB"]) return false unless be_paste_clipboard_max_size_unit_validator.valid?(@be_paste_clipboard_max_size_unit) be_paste_clipboard_min_size_unit_validator = EnumAttributeValidator.new('String', ["Bytes", "KiB"]) return false unless be_paste_clipboard_min_size_unit_validator.valid?(@be_paste_clipboard_min_size_unit) be_paste_timeout_response_validator = EnumAttributeValidator.new('String', ["block", "allow"]) return false unless be_paste_timeout_response_validator.valid?(@be_paste_timeout_response) = EnumAttributeValidator.new('String', ["default", "custom"]) return false unless .valid?(@be_splash_message_source) be_upload_timeout_response_validator = EnumAttributeValidator.new('String', ["block", "allow"]) return false unless be_upload_timeout_response_validator.valid?(@be_upload_timeout_response) block_notifications_validator = EnumAttributeValidator.new('String', ["default", "custom"]) return false unless block_notifications_validator.valid?(@block_notifications) browsers_without_active_extension_validator = EnumAttributeValidator.new('String', ["allow", "block_policy"]) return false unless browsers_without_active_extension_validator.valid?(@browsers_without_active_extension) inspection_depth_validator = EnumAttributeValidator.new('String', ["balanced", "high_performance", "deep_scan"]) return false unless inspection_depth_validator.valid?(@inspection_depth) max_file_size_to_inspect_unit_validator = EnumAttributeValidator.new('String', ["Bytes", "KB", "MB"]) return false unless max_file_size_to_inspect_unit_validator.valid?(@max_file_size_to_inspect_unit) min_confidence_level_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"]) return false unless min_confidence_level_validator.valid?(@min_confidence_level) network_inspection_files_exceeding_size_limit_validator = EnumAttributeValidator.new('String', ["block", "allow"]) return false unless network_inspection_files_exceeding_size_limit_validator.valid?(@network_inspection_files_exceeding_size_limit) screen_capture_duration_post_event_validator = EnumAttributeValidator.new('String', ["3", "5", "10"]) return false unless screen_capture_duration_post_event_validator.valid?(@screen_capture_duration_post_event) screen_capture_duration_pre_event_validator = EnumAttributeValidator.new('String', ["3", "5", "10"]) return false unless screen_capture_duration_pre_event_validator.valid?(@screen_capture_duration_pre_event) similarity_threshold_validator = EnumAttributeValidator.new('String', ["10", "20", "30", "40", "50", "60", "70", "80", "90", "100"]) return false unless similarity_threshold_validator.valid?(@similarity_threshold) true end |