Class: Falcon::RuntimeDetections
- Inherits:
-
Object
- Object
- Falcon::RuntimeDetections
- Defined in:
- lib/crimson-falcon/api/runtime_detections.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_runtime_detections_combined_v2(opts = {}) ⇒ RuntimedetectionsDetectionsEntityResponse
Retrieve container runtime detections by the provided search criteria.
-
#get_runtime_detections_combined_v2_with_http_info(opts = {}) ⇒ Array<(RuntimedetectionsDetectionsEntityResponse, Integer, Hash)>
Retrieve container runtime detections by the provided search criteria.
-
#initialize(api_client = ApiClient.default) ⇒ RuntimeDetections
constructor
A new instance of RuntimeDetections.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RuntimeDetections
Returns a new instance of RuntimeDetections.
35 36 37 |
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 33 def api_client @api_client end |
Instance Method Details
#get_runtime_detections_combined_v2(opts = {}) ⇒ RuntimedetectionsDetectionsEntityResponse
Retrieve container runtime detections by the provided search criteria
45 46 47 48 |
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 45 def get_runtime_detections_combined_v2(opts = {}) data, _status_code, _headers = get_runtime_detections_combined_v2_with_http_info(opts) data end |
#get_runtime_detections_combined_v2_with_http_info(opts = {}) ⇒ Array<(RuntimedetectionsDetectionsEntityResponse, Integer, Hash)>
Retrieve container runtime detections by the provided search criteria
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/crimson-falcon/api/runtime_detections.rb', line 57 def get_runtime_detections_combined_v2_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RuntimeDetections.get_runtime_detections_combined_v2 ...' end # resource path local_var_path = '/container-security/combined/runtime-detections/v2' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RuntimedetectionsDetectionsEntityResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"RuntimeDetections.get_runtime_detections_combined_v2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RuntimeDetections#get_runtime_detections_combined_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |