Class: Falcon::ServerlessExports
- Inherits:
-
Object
- Object
- Falcon::ServerlessExports
- Defined in:
- lib/crimson-falcon/api/serverless_exports.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#download_export_file_mixin0(id, opts = {}) ⇒ Array<Integer>
Download an export file.
-
#download_export_file_mixin0_with_http_info(id, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
Download an export file.
-
#initialize(api_client = ApiClient.default) ⇒ ServerlessExports
constructor
A new instance of ServerlessExports.
-
#launch_export_job_mixin0(body, opts = {}) ⇒ ExportsLaunchExportResponse
Launch an export job of a Lambda Security resource.
-
#launch_export_job_mixin0_with_http_info(body, opts = {}) ⇒ Array<(ExportsLaunchExportResponse, Integer, Hash)>
Launch an export job of a Lambda Security resource.
-
#query_export_jobs_mixin0(opts = {}) ⇒ MsaspecQueryResponse
Query export jobs entities.
-
#query_export_jobs_mixin0_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Query export jobs entities.
-
#read_export_jobs_mixin0(ids, opts = {}) ⇒ ExportsExportsResponse
Read export jobs entities.
-
#read_export_jobs_mixin0_with_http_info(ids, opts = {}) ⇒ Array<(ExportsExportsResponse, Integer, Hash)>
Read export jobs entities.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ServerlessExports
Returns a new instance of ServerlessExports.
35 36 37 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 33 def api_client @api_client end |
Instance Method Details
#download_export_file_mixin0(id, opts = {}) ⇒ Array<Integer>
Download an export file
42 43 44 45 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 42 def download_export_file_mixin0(id, opts = {}) data, _status_code, _headers = download_export_file_mixin0_with_http_info(id, opts) data end |
#download_export_file_mixin0_with_http_info(id, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
Download an export file
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 51 def download_export_file_mixin0_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServerlessExports.download_export_file_mixin0 ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ServerlessExports.download_export_file_mixin0" end # resource path local_var_path = '/lambdas/entities/exports/files/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'id'] = id # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/octet-stream']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Integer>' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ServerlessExports.download_export_file_mixin0", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServerlessExports#download_export_file_mixin0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#launch_export_job_mixin0(body, opts = {}) ⇒ ExportsLaunchExportResponse
Launch an export job of a Lambda Security resource. Maximum of 1 job in progress per resource. Use expand_vulnerabilities=true to get detailed vulnerability information.
104 105 106 107 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 104 def launch_export_job_mixin0(body, opts = {}) data, _status_code, _headers = launch_export_job_mixin0_with_http_info(body, opts) data end |
#launch_export_job_mixin0_with_http_info(body, opts = {}) ⇒ Array<(ExportsLaunchExportResponse, Integer, Hash)>
Launch an export job of a Lambda Security resource. Maximum of 1 job in progress per resource. Use expand_vulnerabilities=true to get detailed vulnerability information.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 113 def launch_export_job_mixin0_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServerlessExports.launch_export_job_mixin0 ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServerlessExports.launch_export_job_mixin0" end # resource path local_var_path = '/lambdas/entities/exports/v1' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ExportsLaunchExportResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ServerlessExports.launch_export_job_mixin0", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServerlessExports#launch_export_job_mixin0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_export_jobs_mixin0(opts = {}) ⇒ MsaspecQueryResponse
Query export jobs entities
170 171 172 173 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 170 def query_export_jobs_mixin0(opts = {}) data, _status_code, _headers = query_export_jobs_mixin0_with_http_info(opts) data end |
#query_export_jobs_mixin0_with_http_info(opts = {}) ⇒ Array<(MsaspecQueryResponse, Integer, Hash)>
Query export jobs entities
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 179 def query_export_jobs_mixin0_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServerlessExports.query_export_jobs_mixin0 ...' end # resource path local_var_path = '/lambdas/queries/exports/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MsaspecQueryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ServerlessExports.query_export_jobs_mixin0", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServerlessExports#query_export_jobs_mixin0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read_export_jobs_mixin0(ids, opts = {}) ⇒ ExportsExportsResponse
Read export jobs entities
228 229 230 231 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 228 def read_export_jobs_mixin0(ids, opts = {}) data, _status_code, _headers = read_export_jobs_mixin0_with_http_info(ids, opts) data end |
#read_export_jobs_mixin0_with_http_info(ids, opts = {}) ⇒ Array<(ExportsExportsResponse, Integer, Hash)>
Read export jobs entities
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/crimson-falcon/api/serverless_exports.rb', line 237 def read_export_jobs_mixin0_with_http_info(ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServerlessExports.read_export_jobs_mixin0 ...' end # verify the required parameter 'ids' is set if @api_client.config.client_side_validation && ids.nil? fail ArgumentError, "Missing the required parameter 'ids' when calling ServerlessExports.read_export_jobs_mixin0" end # resource path local_var_path = '/lambdas/entities/exports/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'ids'] = @api_client.build_collection_param(ids, :csv) # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExportsExportsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ServerlessExports.read_export_jobs_mixin0", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServerlessExports#read_export_jobs_mixin0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |