Class: Falcon::SpotlightSupportedEvaluation
- Inherits:
-
Object
- Object
- Falcon::SpotlightSupportedEvaluation
- Defined in:
- lib/crimson-falcon/api/spotlight_supported_evaluation.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#combined_supported_evaluation_ext(filter, opts = {}) ⇒ DomainSupportedEvaluationAPICombineResponseV1
Performs a combined query and get operation for retrieving RiskSupportedEvaluation entities.
-
#combined_supported_evaluation_ext_with_http_info(filter, opts = {}) ⇒ Array<(DomainSupportedEvaluationAPICombineResponseV1, Integer, Hash)>
Performs a combined query and get operation for retrieving RiskSupportedEvaluation entities.
-
#initialize(api_client = ApiClient.default) ⇒ SpotlightSupportedEvaluation
constructor
A new instance of SpotlightSupportedEvaluation.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SpotlightSupportedEvaluation
Returns a new instance of SpotlightSupportedEvaluation.
35 36 37 |
# File 'lib/crimson-falcon/api/spotlight_supported_evaluation.rb', line 35 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
33 34 35 |
# File 'lib/crimson-falcon/api/spotlight_supported_evaluation.rb', line 33 def api_client @api_client end |
Instance Method Details
#combined_supported_evaluation_ext(filter, opts = {}) ⇒ DomainSupportedEvaluationAPICombineResponseV1
Performs a combined query and get operation for retrieving RiskSupportedEvaluation entities.
47 48 49 50 |
# File 'lib/crimson-falcon/api/spotlight_supported_evaluation.rb', line 47 def combined_supported_evaluation_ext(filter, opts = {}) data, _status_code, _headers = combined_supported_evaluation_ext_with_http_info(filter, opts) data end |
#combined_supported_evaluation_ext_with_http_info(filter, opts = {}) ⇒ Array<(DomainSupportedEvaluationAPICombineResponseV1, Integer, Hash)>
Performs a combined query and get operation for retrieving RiskSupportedEvaluation entities.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/crimson-falcon/api/spotlight_supported_evaluation.rb', line 61 def combined_supported_evaluation_ext_with_http_info(filter, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SpotlightSupportedEvaluation.combined_supported_evaluation_ext ...' end # verify the required parameter 'filter' is set if @api_client.config.client_side_validation && filter.nil? fail ArgumentError, "Missing the required parameter 'filter' when calling SpotlightSupportedEvaluation.combined_supported_evaluation_ext" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 400 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SpotlightSupportedEvaluation.combined_supported_evaluation_ext, must be smaller than or equal to 400.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SpotlightSupportedEvaluation.combined_supported_evaluation_ext, must be greater than or equal to 1.' end # resource path local_var_path = '/spotlight/combined/supported-evaluation-external/v1' # query parameters query_params = opts[:query_params] || {} query_params[:'filter'] = filter query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'risk_provider'] = @api_client.build_collection_param(opts[:'risk_provider'], :multi) if !opts[:'risk_provider'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DomainSupportedEvaluationAPICombineResponseV1' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"SpotlightSupportedEvaluation.combined_supported_evaluation_ext", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SpotlightSupportedEvaluation#combined_supported_evaluation_ext\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |